% File src/library/base/man/Arithmetic.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{Arithmetic}
\title{Arithmetic Operators}
\usage{
+ x
- x
x + y
x - y
x * y
x / y
x ^ y
x \%\% y
x \%/\% y
}
\alias{+}
\alias{-}
\alias{*}
\alias{**}
\alias{/}
\alias{^}
\alias{\%\%}
\alias{\%/\%}
\alias{Arithmetic}
\concept{remainder}
\concept{modulo}
\concept{modulus}
\concept{quotient}
\concept{division}
\description{
これらの単項，二項演算子は数値や複素数ベクトル
(もしくはそれらに強制変換できるもの)への算術演算を実行する．
}
\arguments{
  \item{x, y}{
  数値や複素数ベクトルもしくはそれらに強制変換できオブジェクト，
  もしくはメソッドが定義されている他のオブジェクト．}
}
\value{

  単項演算 \code{+} と \code{-} は数値もしくは複素数ベクトルを
  返す．(クラスを含む)すべての属性は，もし強制変換が行われなければ
  保存される：論理値 \code{x} は整数に強制変換され，名前，次元，次元名は
  保存される．

  二項演算は要素ごとの演算結果を含むベクトルを返す．もし長さがゼロの
  オブジェクトがあれば結果は長さゼロとされる．さもなければ，
  短い方のベクトルの要素は必要に応じてリサイクルされる
  (部分的にリサイクルされる際は警告 \code{\link{warning}} がされる)．
  演算子 \code{+} は加算，\code{-} は減算，\code{*} は乗算，
  \code{/} は除算，そして \code{^} は指数演算である．

  \code{\%\%} は \code{x mod y} を，そして \code{\%/\%} は
  整数商を表す．\code{y == 0} で無い限り(丸め誤差を除いて)\cr
  \code{x == (x \%\% y) + y * (x \%/\% y )} が
  保証される．もし \code{y == 0} か，引数が \link{finite} で
  無いならば \code{\%\%} の結果は(引数の \code{\link{typeof}} に応じて)
  \code{\link{NA_integer_}} か \code{\link{NaN}} になる．
  
  もしどちらか引数が複素数ならば結果は複素数になる．
  もしどちらの引数も複素数で無く，一方もしくは双方が数値ならば
  結果は数値になる．もし双方の引数がタイプ 
  \link{integer} ならば \code{/} と \code{^} の結果は
  \link{numeric} で，他の演算の結果は整数になる
  (\eqn{\pm(2^{31} - 1)}{+/- (2^31 - 1)} の時はオーバーフロー
  になり警告と共に \code{NA_integer_} とされる)．

  結果の属性を決定する規則はかなり複雑である．
  殆どの属性はより長い方の引数から取られる．
  名前は，もしその長さが結果と同じなら最初の引数からコピーされ，
  さもなければもし二番目の引数の長さが結果のそれと同じなら二番目の引数から
  コピーされる．もし引数が同じ長さなら，属性は双方からコピーされ，
  もし同じ属性が双方の引数に存在すれば，最初の引数のそれらが優先される．
  時系列に対しては，演算は系列が両立するときだけ許され，
  その際は，どちらにせよ時系列であるもの(どちらも時系列ならば同じもの)
  のクラスと \code{\link{tsp}} 属性が使用される．
  配列(及び結果の配列)に対しては，最初の引数が配列ならば次元と次元名は
  それから，さもなければ二番目から取られる．
  
}
\details{
  単項と二項演算子は総称的である：それらからメソッドを個別に，
  もしくは \code{\link[=S3groupGeneric]{Ops}} グループ総称的関数経由で
  定義できる．(これがどのように選択適用されるかについては 
  \code{\link[=S3groupGeneric]{Ops}} を見よ．)

  配列に適用されると，もしそれが意味を持てば，結果は数列になる
  (例えばリサイクル規則が呼び出されるとそうではなくなる)．

  論理ベクトルは整数ベクトル化か数値ベクトルに強制変換される．
  \code{FALSE} は値0を，\code{TRUE} は値1を持つ．

  \code{1 ^ y} と \code{y ^ 0} は\emph{常に} \code{1} であり， 
  \code{x ^ y} はどちらかの数値引数が \link{infinite} (\code{Inf} か 
  \code{-Inf}) の時もまた適正な極限を与えるべきである．

  配列や時系列オブジェクトは，それらが両立可能ならば，このように
  演算可能である．

  倍精度引数に対しては \code{\%\%} は，\code{x} が \code{y} より
  相当大きい場合は，破滅的な精度のロスをもたらす
  可能性があり，これが検知された場合は警告が出される．


  \code{\%\%} と \code{x \%/\% y} は非整数の \code{y} に対しても，例えば 
  \sspace{}\code{1 \%/\% 0.2} のように使える．しかしその結果は
  表示エラーになる可能性があり，従ってプラットフォーム依存である．
  \code{0.2} の IEC 60059 表現は2進少数であり \code{0.2} よりわずかに
  大きいので，\code{1 \%/\% 0.2} への結果は \code{4} になるべきであるが，
  殆どのプラットフォームでは \code{5} になる．
  
  例えば \code{(-8)^(1/3)} がなぜ \code{NaN} になるのかなど，
  ユーザは時折返り値に驚かされるかもしれない．
  \link{double} 入力に対しては，\R はすべてのプラットフォームで
  IEC 60559 算術規則を使い，\code{^} 演算子に対してはCシステムの
  \samp{pow} を使う．関係する標準は多くの境界領域での結果を定義している．
  特に，上の例の結果は C99 標準に従っている．多くのUnix風システムでは
  命令 \command{man pow} が多くの境界領域での値に対する詳細を与える．

  \R でのタイプ \link{double} の演算は
  \sQuote{最近接値への丸め，タイならば平均する} 流儀で行われることになっている．
  しかしながら，これはコンパイラーと FPU が適正に設定されていることに依存
  している．
}
\section{S4 methods}{
  これらの演算子は S4 グループ総称的関数 \code{\link{Arith}} の
  メンバーであり，従ってメソッドを個々に，もしくは
  総称的グループ (もしくは \code{Ops} 総称的グループ)に対して
  定義できる．引数は \code{c(e1, e2)} (単項演算子では
  \code{e2} が欠けている)．
}
\section{Implementation limits}{
  \R は浮動小数点演算に関しては OS サービス(とFPU)に依存している．
  現在のすべての \R プラットフォームでは IEC 60559 (IEEE
  754 としても知られている)算術規則が使われているが，
  これらの標準の幾つかの事項はオプションである．特に，
  \emph{非正規数} (\code{\link{.Machine}}で与えられる
  範囲外の数値)はプラットフォーム間
  や，単一のプラットフォームでも計算ごとに異なる可能性がある．

  今一つの問題は符号付きのゼロである：IEC 60659 準拠のプラットフォームでは
  内部表現が符号だけ異なる二種類のゼロがある．可能な場所では \R は
  それらを同一のものとして扱うが， C コードからの直接の出力は
  しばしばそうではなく，\samp{-0.0} を出力することがある(ウィンドウズでは
  そうなるかどうかはバージョンに依存する)．
  \R でこの違いが顕になるのはゼロによる除算である：
  \code{1/x} はゼロ_code{x} の符号次第で \code{Inf} か \code{-Inf}
  になる．
}
\note{
  長さゼロのベクトルを含むすべての論理値演算は長さゼロの結果を
  返す．

  二項演算子は時折 \sspace{}\code{`&`(x, y)} のような関数として
  呼び出される：引数の照合がどのように行われるかについては 
  \code{\link[base]{Ops}} の記述を見よ．

  \code{**} は構文解析器により \code{^} に変換されるが，このことは
  長い間ドキュメント化されていなかった．これは
  Becker \emph{et al} (1988) の索引項目に登場し，\code{Deprecated} の
  ヘルプを参照しているが実際にはその頁に述べられていなかった．
  S では20年間廃止されているが，2008年の \R では依然として有効である．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  D. Goldberg (1991) \emph{What Every Computer Scientist Should Know
    about Floating-Point Arithmetic}  ACM Computing Surveys, \bold{23(1)}.\cr
  Postscript version available at
  \url{http://www.validlab.com/goldberg/paper.ps}
  Extended PDF version at \url{http://www.validlab.com/goldberg/paper.pdf}

}
\seealso{
  関連する話題は \code{\link{sqrt}} を，特殊な数値関数については
  \code{\link{Special}}．

  演算の優先順位については \code{\link{Syntax}}．

  行列積については \code{\link{\%*\%}}．
}
\examples{
x <- -1:12
x + 1
2 * x + 3
x \%\% 2 #-- 周期的
x \%/\% 5
}
\keyword{arith}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Arithmetic.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Arithmetic}
%\title{Arithmetic Operators}
%\usage{
%+ x
%- x
%x + y
%x - y
%x * y
%x / y
%x ^ y
%x \%\% y
%x \%/\% y
%}
%\alias{+}
%\alias{-}
%\alias{*}
%\alias{**}
%\alias{/}
%\alias{^}
%\alias{\%\%}
%\alias{\%/\%}
%\alias{Arithmetic}
%\concept{remainder}
%\concept{modulo}
%\concept{modulus}
%\concept{quotient}
%\concept{division}
%\description{
%  These unary and binary operators perform arithmetic on numeric or
%  complex vectors (or objects which can be coerced to them).
%}
%\arguments{
%  \item{x, y}{numeric or complex vectors or objects which can be
%    coerced to such, or other objects for which methods have been written.}
%}
%\value{
%  Unary \code{+} and unary \code{-} return a numeric or complex vector.
%  All attributes (including class) are preserved if there is no
%  coercion: logical \code{x} is coerced to integer and names, dims and
%  dimnames are preserved.
%
%  The binary operators return vectors containing the result of the element
%  by element operations.  If involving a zero-length vector the result
%  has length zero.  Otherwise, the elements of shorter vectors are recycled
%  as necessary (with a \code{\link{warning}} when they are recycled only
%  \emph{fractionally}).  The operators are \code{+} for addition,
%  \code{-} for subtraction, \code{*} for multiplication, \code{/} for
%  division and \code{^} for exponentiation.
%
%  \code{\%\%} indicates \code{x mod y} and \code{\%/\%} indicates
%  integer division.  It is guaranteed that \code{x == (x \%\% y) + y * (
%  x \%/\% y )} (up to rounding error) unless \code{y == 0} where the
%  result of \code{\%\%} is \code{\link{NA_integer_}} or
%  \code{\link{NaN}} (depending on the \code{\link{typeof}} of the
%  arguments), and for non-\link{finite} arguments.
%
%  If either argument is complex the result will be complex, otherwise if
%  one or both arguments are numeric, the result will be numeric.  If
%  both arguments are of type \link{integer}, the type of the result of
%  \code{/} and \code{^} is \link{numeric} and for the other operators it
%  is integer (with overflow, which occurs at
%  \eqn{\pm(2^{31} - 1)}{+/- (2^31 - 1)},
%  returned as \code{NA_integer_} with a warning).
%
%  The rules for determining the attributes of the result are rather
%  complicated.  Most attributes are taken from the longer argument.
%  Names will be copied from the first if it is the same length as the
%  answer, otherwise from the second if that is.  If the arguments are
%  the same length, attributes will be copied from both, with those of
%  the first argument taking precedence when the same attribute is
%  present in both arguments. For time series, these operations are
%  allowed only if the series are compatible, when the class and
%  \code{\link{tsp}} attribute of whichever is a time series (the same,
%  if both are) are used.  For arrays (and an array result) the
%  dimensions and dimnames are taken from first argument if it is an
%  array, otherwise the second.
%
%}
%\details{
%  The unary and binary arithmetic operators are generic functions:
%  methods can be written for them individually or via the
%  \code{\link[=S3groupGeneric]{Ops}} group generic function.  (See
%  \code{\link[=S3groupGeneric]{Ops}} for how dispatch is computed.)
%
%  If applied to arrays the result will be an array if this is sensible
%  (for example it will not if the recycling rule has been invoked).
%
%  Logical vectors will be coerced to integer or numeric vectors,
%  \code{FALSE} having value zero and \code{TRUE} having value one.
%
%  \code{1 ^ y} and \code{y ^ 0} are \code{1}, \emph{always}.
%  \code{x ^ y} should also give the proper limit result when
%  either (numeric) argument is \link{infinite} (one of \code{Inf} or
%  \code{-Inf}). 
%
%  Objects such as arrays or time-series can be operated on this
%  way provided they are conformable.
%
%  For double arguments, \code{\%\%} can be subject to catastrophic loss of
%  accuracy if \code{x} is much larger than \code{y}, and a warning is
%  given if this is detected.
%
%  \code{\%\%} and \code{x \%/\% y} can be used for non-integer \code{y},
%  e.g.\sspace{}\code{1 \%/\% 0.2}, but the results are subject to representation
%  error and so may be platform-dependent.  Because the IEC 60059
%  representation of \code{0.2} is a binary fraction slightly larger than
%  \code{0.2}, the answer to \code{1 \%/\% 0.2} should be \code{4} but
%  most platforms give \code{5}.
%
%  Users are sometimes surprised by the value returned, for example why
%  \code{(-8)^(1/3)} is \code{NaN}.  For \link{double} inputs, \R makes
%  use of IEC 60559 arithmetic on all platforms, together with the C
%  system function \samp{pow} for the \code{^} operator.  The relevant
%  standards define the result in many corner cases.  In particular, the
%  result in the example above is mandated by the C99 standard.  On many
%  Unix-alike systems the command \command{man pow} gives details of the
%  values in a large number of corner cases.
%
%  Arithmetic on type \link{double} in \R is supposed to be done in
%  \sQuote{round to nearest, ties to even} mode, but this does depend on
%  the compiler and FPU being set up correctly.
%}
%\section{S4 methods}{
%  These operators are members of the S4 \code{\link{Arith}} group generic,
%  and so methods can be written for them individually as well as for the
%  group generic (or the \code{Ops} group generic), with arguments
%  \code{c(e1, e2)} (with \code{e2} missing for a unary operator).
%}
%\section{Implementation limits}{
%  \R is dependent on OS services (and they on FPUs) for floating-point
%  arithmetic.  On all current \R platforms IEC 60559 (also known as IEEE
%  754) arithmetic is used, but some things in those standards are
%  optional.  In particular, the support for \emph{denormal numbers}
%  (those outside the range given by \code{\link{.Machine}}) may differ
%  between platforms and even between calculations on a single platform.
%
%  Another potential issue is signed zeroes: on IEC 60659 platforms there
%  are two zeroes with internal representations differing by sign.  Where
%  possible \R treats them as the same, but for example direct output
%  from C code often does not do so and may output \samp{-0.0} (and on
%  Windows whether it does so or not depends on the version of Windows).
%  One place in \R where the difference might be seen is in division by
%  zero: \code{1/x} is \code{Inf} or \code{-Inf} depending on the sign of
%  zero \code{x}.
%}
%\note{
%  All logical operations involving a zero-length vector have a
%  zero-length result.
%
%  The binary operators are sometimes called as functions as
%  e.g.\sspace{}\code{`&`(x, y)}: see the description of how
%  argument-matching is done in \code{\link[base]{Ops}}.
%
%  \code{**} is translated in the parser to \code{^}, but this was
%  undocumented for many years.  It appears as an index entry in Becker
%  \emph{et al} (1988), pointing to the help for \code{Deprecated} but
%  is not actually mentioned on that page.  Even though it had been
%  deprecated in S for 20 years, it was still accepted in \R in 2008.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  D. Goldberg (1991) \emph{What Every Computer Scientist Should Know
%    about Floating-Point Arithmetic}  ACM Computing Surveys, \bold{23(1)}.\cr
%  Postscript version available at
%  \url{http://www.validlab.com/goldberg/paper.ps}
%  Extended PDF version at \url{http://www.validlab.com/goldberg/paper.pdf}
%
%}
%\seealso{
%  \code{\link{sqrt}} for miscellaneous and \code{\link{Special}} for special
%  mathematical functions.
%
%  \code{\link{Syntax}} for operator precedence.
%
%  \code{\link{\%*\%}} for matrix multiplication.
%}
%\examples{
%x <- -1:12
%x + 1
%2 * x + 3
%x \%\% 2 #-- is periodic
%x \%/\% 5
%}
%\keyword{arith}
%
\encoding{UTF8}
