% File src/library/base/man/Colon.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2008 R Core Team
% Distributed under GPL 2 or later

\name{Colon}
\title{Colon Operator}
\alias{:}
\alias{colon}
\description{
  規則的な数列を生成する．
}
\usage{
from:to
   a:b
}
\arguments{
  \item{from}{数列の開始値．}
  \item{to}{(最大の)数列の終端値．}
  \item{a, b}{同じ長さの \code{\link{factor}}．}
}
\details{
  二項演算子 \code{:} は二つの意味を持つ：因子に対しては \code{a:b} は
  \code{\link{interaction}(a, b)} と同値である(しかしながら水準は
  順序つけられており，異なるラベルが付く)．

  他の引数については \code{from:to} は \code{seq(from, to)} と同値であり，
  \code{from} から \code{to} までの階差 \code{1} または \code{-1} の数列
  と同値である．値 \code{to} は，もしそれが \code{from} と約 \code{1e-7}
  程度の食い違いを除いて整数分だけ異なれば含められる．
  非数値引数は内部的に(従って選択適用メソッド無しで)数値に強制変換される
  ---複素数値はその虚数部が警告なしに捨てられる．
}
\value{
  数値引数に対しては数値ベクトル．これはもし \code{from} が型 
  \code{\link{integer}} ならば 整数値になり，結果は \R の整数型
  として表現される．さもなければ型 
  \code{"double"} (言い換えれば \code{\link{mode}} \code{"\link{numeric}"})
  になる．

  因子に対しては，順序付きでない因子で，ラベル \code{la:lb} を持ち，
  辞書式に順序が付く(つまり \code{lb} が最速で変化する)．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.\cr
  (数値引数に対して：S は因子に対する \code{:} を持たない．)
}
\seealso{
  \code{\link{seq}} (\code{from:to} の \emph{一般化})．

  因子に対する \code{:} の代替物は \code{\link{interaction}}．

  交互作用の形式的表現中で使われる \code{:} については，
  \code{\link{formula}} を見よ．
}
\examples{
1:4
pi:6 # 実数
6:pi # 整数

f1 <- gl(2, 3); f1
f2 <- gl(3, 2); f2
f1:f2 # 因子，"クロス"  f1 x f2
}
\keyword{manip}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Colon.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2008 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Colon}
%\title{Colon Operator}
%\alias{:}
%\alias{colon}
%\description{
%  Generate regular sequences.
%}
%\usage{
%from:to
%   a:b
%}
%\arguments{
%  \item{from}{starting value of sequence.}
%  \item{to}{(maximal) end value of the sequence.}
%  \item{a, b}{\code{\link{factor}}s of the same length.}
%}
%\details{
%  The binary operator \code{:} has two meanings: for factors \code{a:b} is
%  equivalent to \code{\link{interaction}(a, b)} (but the levels are
%  ordered and labelled differently).
%
%  For other arguments \code{from:to} is equivalent to \code{seq(from, to)},
%  and generates a sequence from \code{from} to \code{to} in steps of \code{1}
%  or \code{-1}.  Value \code{to} will be included if it differs from
%  \code{from} by an integer up to a numeric fuzz of about \code{1e-7}.
%  Non-numeric arguments are coerced internally (hence without
%  dispatching methods) to numeric---complex values will have their
%  imaginary parts discarded with a warning.
%}
%\value{
%  For numeric arguments, a numeric vector.  This will be of type
%  \code{\link{integer}} if \code{from} is integer-valued and the result
%  is representable in the \R integer type, otherwise of type
%  \code{"double"} (aka \code{\link{mode}} \code{"\link{numeric}"}).
%
%  For factors, an unordered factor with levels labelled as \code{la:lb}
%  and ordered lexicographically (that is, \code{lb} varies fastest).
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.\cr
%  (for numeric arguments: S does not have \code{:} for factors.)
%}
%\seealso{
%  \code{\link{seq}} (a \emph{generalization} of \code{from:to}).
%
%  As an alternative to using \code{:} for factors, \code{\link{interaction}}.
%
%  For \code{:} used in the formal representation of an interaction, see
%  \code{\link{formula}}.
%}
%\examples{
%1:4
%pi:6 # real
%6:pi # integer
%
%f1 <- gl(2, 3); f1
%f2 <- gl(3, 2); f2
%f1:f2 # a factor, the "cross"  f1 x f2
%}
%\keyword{manip}
%
\encoding{UTF8}
