% File src/library/base/man/Control.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{Control}
\alias{Control}
\alias{if}
\alias{else}
\alias{for}
\alias{in}
\alias{while}
\alias{repeat}
\alias{break}
\alias{next}
\title{Control Flow}
\description{
  これらは \R 言語の基本的な制御フローである．各種の Algol 風の言語における
  制御文とほぼ同様に動作する．これらは予約語(\link{reserved})である．
}
\usage{
if(cond) expr
if(cond) cons.expr  else  alt.expr

for(var in seq) expr
while(cond) expr
repeat expr
break
next
}
\arguments{
  \item{cond}{長さ1の論理値ベクトルで \code{NA} でない．
    長さが1より大きな条件は警告付きで受け入れられるが，最初の要素しか
    使われない．他の型はもし可能ならば論理値に強制変換され，クラスは
    無視される．
  }
  \item{var}{一つの変数に対する構文的な名前．}
  \item{seq}{ベクトルや \link{pairlist} または \code{NULL} へと
    評価される表現式．因子値は文字列ベクトルに強制変換される．}
  \item{expr, cons.expr, alt.expr}{
    形式的な意味での \emph{表現式}．これは単純な表現式であるか，
    いわゆる \emph{複合表現式} であり，通常 
    \code{\{ expr1 ; expr2 \}} の形を持つ．
  }
}
\details{
  \code{break}  は \code{for}, \code{while} または \code{repeat} ループを中断する；
  制御は最奥のループの外の最初の文に移る．
  \code{next} は現在の反復を停止し，ループ変数を進める．
  \code{break} と \code{next} は入れ子になった最奥のループに適応される．

  文を波括弧(\code{\{ .. \}})で囲むことを忘れるのはよくある間違いである．
  例えば \code{if(..)} や \code{for(....)} の後である．
  特に，キーボードや  \code{source} 経由で \code{if ... else} 構文を
  挿入する際，構文エラーを避けるため \code{\}} と \code{else} の
  間に新行を入れるべきではない．この理由のため，ひとつの(少々極端な)防御的な
  プログラミングは常に波括弧を入れることである．例えば  \code{if} 節に
  対してである．

  \code{for} ループ中の The \code{seq} はループの開始時に評価される．
  それを後で変更してもループに影響を与えない．もし  \code{seq} が
  長さゼロであればループ本体はスキップされる．さもなければ，変数
  \code{var} には \code{seq} の各要素が順に付値される．
  ループ本体中で \code{var} を変更することができるが，これは次の繰り返しに
  影響を与えない．ループが終了する時，変数 
  \code{var} はその最後の値を持つ変数として残る．
}
\value{
  \code{if} は評価された表現式を値として返す．もしくは値がなければ
  (これは \code{else} が無いときに起き得る) \code{NULL} を不可視
  返り値として返す．

  \code{for}, \code{while} そして \code{repeat} は \code{NULL} を
  不可視返り値として返す．\code{for} は \code{var} を最後に使われた
  \code{seq} の値に設定する．もしくはそれが長さゼロなら \code{NULL}  とする．

  \code{break} と \code{next} はループ中で制御を移行するため値を
  返さない．
}

\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \R の基本的な構文と演算子については \code{\link{Syntax}}，
  丸括弧と波括弧については \code{\link{Paren}}．

  制御フローの他の仕組みについては \code{\link{ifelse}}, \code{\link{switch}}．
}
\examples{
for(i in 1:5) print(1:i)
for(n in c(2,5,10,20,50)) {
   x <- stats::rnorm(n)
   cat(n, ": ", sum(x^2), "\n", sep = "")
}
f <- factor(sample(letters[1:5], 10, replace = TRUE))
for(i in unique(f)) print(i)
}
\keyword{programming}
\keyword{iteration}
\keyword{logic}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Control.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Control}
%\alias{Control}
%\alias{if}
%\alias{else}
%\alias{for}
%\alias{in}
%\alias{while}
%\alias{repeat}
%\alias{break}
%\alias{next}
%\title{Control Flow}
%\description{
%  These are the basic control-flow constructs of the \R language.  They
%  function in much the same way as control statements in any Algol-like
%  language.  They are all \link{reserved} words.
%}
%\usage{
%if(cond) expr
%if(cond) cons.expr  else  alt.expr
%
%for(var in seq) expr
%while(cond) expr
%repeat expr
%break
%next
%}
%\arguments{
%  \item{cond}{A length-one logical vector that is not \code{NA}.
%    Conditions of length greater than one are accepted with a warning, but
%    only the first element is used.  Other types are coerced to logical
%    if possible, ignoring any class.
%  }
%  \item{var}{A syntactical name for a variable.}
%  \item{seq}{An expression evaluating to a vector (including a list and
%    an \link{expression}) or to a \link{pairlist} or \code{NULL}.  A
%    factor value will be coerced to a character vector.}
%  \item{expr, cons.expr, alt.expr}{
%    An \emph{expression} in a formal sense.  This is either a
%    simple expression or a so called \emph{compound expression}, usually
%    of the form \code{\{ expr1 ; expr2 \}}.
%  }
%}
%\details{
%  \code{break} breaks out of a \code{for}, \code{while} or \code{repeat}
%  loop; control is transferred to the first statement outside the
%  inner-most loop. \code{next} halts the processing of the current
%  iteration and advances the looping index.  Both \code{break} and
%  \code{next} apply only to the innermost of nested loops.
%
%  Note that it is a common mistake to forget to put braces (\code{\{ .. \}})
%  around your statements, e.g., after \code{if(..)} or \code{for(....)}.
%  In particular, you should not have a newline between \code{\}} and
%  \code{else} to avoid a syntax error in entering a \code{if ... else}
%  construct at the keyboard or via \code{source}.
%  For that reason, one (somewhat extreme) attitude of defensive programming
%  is to always use braces, e.g., for \code{if} clauses.
%
%  The \code{seq} in a \code{for} loop is evaluated at the start of
%  the loop; changing it subsequently does not affect the loop.  If
%  \code{seq} has length zero the body of the loop is skipped. Otherwise the
%  variable \code{var} is assigned in turn the value of each element of
%  \code{seq}. You can assign to \code{var} within the body of the loop,
%  but this will not affect the next iteration.  When the loop terminates,
%  \code{var} remains as a variable containing its latest value.
%
%}
%\value{
%  \code{if} returns the value of the expression evaluated, or
%  \code{NULL} invisibly if none was (which may happen if there is no
%  \code{else}).
%
%  \code{for}, \code{while} and \code{repeat} return \code{NULL} invisibly.
%  \code{for} sets \code{var} to the last used element of \code{seq},
%  or to \code{NULL} if it was of length zero.
%
%  \code{break} and \code{next} do not return a value as they transfer
%  control within the loop.
%}
%
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{Syntax}} for the basic \R syntax and operators,
%  \code{\link{Paren}} for parentheses and braces.
%
%  \code{\link{ifelse}}, \code{\link{switch}} for other ways to control flow.
%}
%\examples{
%for(i in 1:5) print(1:i)
%for(n in c(2,5,10,20,50)) {
%   x <- stats::rnorm(n)
%   cat(n, ": ", sum(x^2), "\n", sep = "")
%}
%f <- factor(sample(letters[1:5], 10, replace = TRUE))
%for(i in unique(f)) print(i)
%}
%\keyword{programming}
%\keyword{iteration}
%\keyword{logic}
%
\encoding{UTF8}
