% File src/library/base/man/Memory.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{Memory}
\alias{Memory}
\title{Memory Available for Data Storage}
\description{
  \R がどのように作業空間を管理するか．
}
\details{
\R は可変サイズの作業領域を持つ．(めったに使われないが)その最小サイズを制御する
コマンドラインのオプションがあるが，最大サイズを制御する物は無い．

Windows ではオプション \option{--max-mem-size} (または環境変数 \env{R_MAX_MEM_SIZE})
が最大の(仮想)メモリ容量を設定する：可能な最小量は32Mである．
これは他のプロセスをリソース不足にする可能性がある過大なメモリ量の確保の
試みを防ぐことを意図している．
\code{\link{memory.limit}} も見よ．

\R は固定サイズと可変サイズのオブジェクトに対して別個の領域を管理する．
これらの最初は \emph{cons cells} の配列として確保される
(リスプのプログラマはこれが何か知っているであろう，そうでない者は
これらを言語自体のの構成ブロック，構文解析木，等と考えれば良い)．
そして二つ目は各々8バイトの \sQuote{Vcell} のヒープで実現される．
各 cons cell は \R の32ビット版では28バイトを占め，64ビット版では(普通)
56バイトを占める．

(現在の)既定値は初期設定で 350k の cons cells と 6Mb のベクトルヒープ
である．これらの領域は実際は初めに確保されるわけではないことを注意しよう．
そうではなくこれらの値はガベージコレクションを引き起こすサイズである．
これらの値は \R 起動時にコマンドラインのオプション \option{--min-nsize} と
 \option{--min-vsize} で設定(もしくはもしそれらを使わなければ，
環境変数 \env{R_NSIZE} と \env{R_VSIZE})できる．
それ以降 \R は使用に応じて領域を拡大・縮小していくが，
決して初期値以下には小さくならない．

\R がガベージコレクションにどれだけの時間を費やすかは，これらの
初期設定と，メモリがいっぱいになった時不要なメモリを開放するためのガベージ
コレクションと領域を増加させることの間でメモリマネージャが行うトレードオフに依存する．
増加に対して使われる戦略は環境変数 \env{R_GC_MEM_GROW} を0から3までの
間の整数に設定することで指定できる．この値は起動時に読み取られる．
大きな値は塊をより積極的に増加させ，それによって
ガベージコレクションの時間を減少させるがより多くのメモリを使用する．

現在のメモリ消費量(使用されるヒープと cons cell の数とメガバイト量)は
 \Rのプロンプトに \code{\link{gc}()} とタイプすれば分かる．
\code{\link{gcinfo}(TRUE)} であれば，自動的なガベージコレクションは常に
メモリ使用統計量をプリントする．

コマンドラインのオプション \option{--max-ppsize} はポインタ防御スタックの
最大サイズを制御する．既定では50000であるが，
深い再帰や大規模で複雑な計算をするために増やすことが出来る．
ガベージコレクションの一部は完全な保存されたポインタ防御スタックを
巡るため，サイズが大きくなると遅くなることを注意しよう．
現在受け付けられる最大の値は500000である．
}

\seealso{
より多くのコマンドラインのオプションについては \emph{An Introduction to R}．

デザイン上の限界については \code{\link{Memory-limits}}．

ガベージコレクションとすべてのメモリ使用量に関する情報に
ついては \code{\link{gc}}，
\R オブジェクト \code{a} の(近似的)サイズについては \code{\link{object.size}(a)}．
cons cell のプロファイリングについては \code{\link{memory.profile}}．

Windows での全メモリの監視については \code{\link{memory.size}}，現在の限界については 
 \code{\link{memory.limit}}．
}

\keyword{environment}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Memory.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Memory}
%\alias{Memory}
%\title{Memory Available for Data Storage}
%\description{
%  How \R manages its workspace.
%}
%\details{
%  \R has a variable-sized workspace.  There are (rarely-used)
%  command-line options to control its minimum size, but no longer any to
%  control the maximum size.
%#ifdef windows
%
%  On Windows the \option{--max-mem-size} option (or environment variable
%  \env{R_MAX_MEM_SIZE}) sets the maximum (virtual) memory allocation: it
%  has a minimum allowed value of 32M.  This is intended to catch
%  attempts to allocate excessive amounts of memory which may cause other
%  processes to run out of resources.  See also \code{\link{memory.limit}}.
%#endif
%
%  \R maintains separate areas for fixed and variable sized objects.  The
%  first of these is allocated as an array of \emph{cons cells} (Lisp
%  programmers will know what they are, others may think of them as the
%  building blocks of the language itself, parse trees, etc.), and the
%  second are thrown on a \emph{heap} of \sQuote{Vcells} of 8 bytes each.
%  Each cons cell occupies 28 bytes on a 32-bit build of \R, (usually) 56
%  bytes on a 64-bit build.
%
%  The default values are (currently) an initial setting of 350k cons
%  cells and 6Mb of vector heap.  Note that the areas are not actually
%  allocated initially: rather these values are the sizes for triggering
%  garbage collection.  These values can be set by the command line
%  options \option{--min-nsize} and \option{--min-vsize} (or if they are
%  not used, the environment variables \env{R_NSIZE} and \env{R_VSIZE})
%  when \R is started. Thereafter \R will grow or shrink the areas
%  depending on usage, never decreasing below the initial values.
%
%  How much time \R spends in the garbage collector will depend on these
%  initial settings and on the trade-off the memory manager makes, when
%  memory fills up, between collecting garbage to free up unused memory
%  and growing these areas.  The strategy used for growth can be
%  specified by setting the environment variable \env{R_GC_MEM_GROW} to
%  an integer value between 0 and 3. This variable is read at
%  start-up. Higher values grow the heap more aggressively, thus reducing
%  garbage collection time but using more memory.
%
%  You can find out the current memory consumption (the heap and cons
%  cells used as numbers and megabytes) by typing \code{\link{gc}()} at the
%  \R prompt.  Note that following \code{\link{gcinfo}(TRUE)}, automatic
%  garbage collection always prints memory use statistics.
%
%  The command-line option \option{--max-ppsize} controls the maximum
%  size of the pointer protection stack.  This defaults to 50000, but can
%  be increased to allow deep recursion or large and complicated
%  calculations to be done.  \emph{Note} that parts of the garbage
%  collection process goes through the full reserved pointer protection
%  stack and hence becomes slower when the size is increased.  Currently
%  the maximum value accepted is 500000.
%}
%
%\seealso{
%  \emph{An Introduction to R} for more command-line options.
%
%  \code{\link{Memory-limits}} for the design limitations.
%
%  \code{\link{gc}} for information on the garbage collector and total
%  memory usage,  \code{\link{object.size}(a)} for the (approximate)
%  size of \R object \code{a}.  \code{\link{memory.profile}} for
%  profiling the usage of cons cells.
%#ifdef windows
%
%  \code{\link{memory.size}} to monitor total memory usage,
%  \code{\link{memory.limit}} for the current limit.
%#endif
%}
%
%\keyword{environment}
%
\encoding{UTF8}
