% File src/library/base/man/abbreviate.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Copyright 2008      The R Foundation
% Distributed under GPL 2 or later

\name{abbreviate}
\title{Abbreviate Strings}
\usage{
abbreviate(names.arg, minlength = 4, use.classes = TRUE,
           dot = FALSE, strict = FALSE,
           method = c("left.kept", "both.sides"))
}
\alias{abbreviate}
\arguments{
  \item{names.arg}{省略されるべき名前の文字列ベクトル．もしくは
 \code{\link{as.character}} によって文字列に変換されるオブジェクト．}
  \item{minlength}{省略の最小長さ．}
  \item{use.classes}{論理値(現在 \R は無視する)．}
  \item{dot}{論理値：ドット(\code{"."})を加えるか?}
  \item{strict}{論理値：\code{minlength} は順守すべきか?
    設定 \code{strict = TRUE} は重複する文字列を返す可能性があることを注意．}
  \item{method}{既定の \code{"left.kept"} と共に使われるメソッドを
指定する文字列．以下の詳細を見よ．部分的マッチングが許される．}
}
\description{
  文字列を少なくとも \code{minlength} 文字に短縮する．
 \code{strict = TRUE} で無い限り，元が重複しなければ結果は重複しない．
}
\details{
  使用される既定のアルゴリズム (\code{method = "left.kept"}) は S の
それに類似する．単一の文字列に対してはこれは以下のように動作する．
最初に文字列の先頭にあるすべての空白が取り除かれる．それから
(もし必要なら)他の空白が取り除かれる．
次に，(右から始めて)小文字の子音が続く小文字の母音が除かれる．
最後にもし省略が依然として \code{minlength} より長ければ大文字が
取り除かれる．

文字は常に単語の末尾から最初に取り除かれる．
もし \code{names.arg} の要素が二つ以上の単語(単語は空白で分離されている)を含めば
少なくとも各単語から一つの文字が残される．

欠損値 (\code{NA}) は変更されない．

もし \code{use.classes} が \code{FALSE} なら唯一の違いは文字と空白の
間にある．これは実装されていない．
}
\value{
  最初の引数中の文字列に対する省略形を含んだ文字列ベクトル．
オリジナルの \code{names.arg} 中の重複は同じ省略形を与える．
もし重複していない要素が同じ長さ \code{minlength} の省略形を持ち，
 \code{method = "both.sides"} ならば，基本の内部的な \code{abbreviate()} アルゴリズムが
文字別に \emph{逆転された} 文字列に適用される；もしそれらが依然として
重複した省略形を持ち，既定である \code{strict = FALSE} ならば，
 \code{minlength} は1だけ増やされ，新しい省略形がこれらの要素だけに適用される．
この手順が \code{names.arg} 中の重複しない要素がユニークな省略形を
持つまで繰り返される．

\code{names.arg} の文字版が返り値に名前引数として付加される．
他の属性は保たれない．
}
\section{警告}{
  これは実際は英語だけにふさわしく，多バイトロケールの非アスキー文字では
うまく行かない．非アスキー文字と共に使われると警告が出る
(そして長さを減らすように求められる)．
}
\seealso{
  \code{\link{substr}}.
}
\examples{
x <- c("abcd", "efgh", "abce")
abbreviate(x, 2)
abbreviate(x, 2, strict = TRUE) # >> 最初と3番目は == "ab"

(st.abb <- abbreviate(state.name, 2))
table(nchar(st.abb)) # 50のうち，3つは4文字必要 :
as <- abbreviate(state.name, 3, strict = TRUE)
as[which(as == "Mss")]
\dontshow{stopifnot(which(as == "Mss") == c(21,24,25))
}
## method="both.sides" が役に立つ： 4文字はなく，3文字は4つだけ：
st.ab2 <- abbreviate(state.name, 2, method = "both")
table(nchar(st.ab2))
## 二つの方法を比べる：
cbind(st.abb, st.ab2)
}
\keyword{character}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/abbreviate.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Copyright 2008      The R Foundation
%% Distributed under GPL 2 or later
%
%\name{abbreviate}
%\title{Abbreviate Strings}
%\usage{
%abbreviate(names.arg, minlength = 4, use.classes = TRUE,
%           dot = FALSE, strict = FALSE,
%           method = c("left.kept", "both.sides"))
%}
%\alias{abbreviate}
%\arguments{
%  \item{names.arg}{a character vector of names to be abbreviated, or an
%    object to be coerced to a character vector by \code{\link{as.character}}.}
%  \item{minlength}{the minimum length of the abbreviations.}
%  \item{use.classes}{logical (currently ignored by \R).}
%  \item{dot}{logical: should a dot (\code{"."}) be appended?}
%  \item{strict}{logical: should \code{minlength} be observed strictly?
%    Note that setting \code{strict = TRUE} may return \emph{non}-unique
%    strings.}
%  \item{method}{a character string specifying the method used with default
%    \code{"left.kept"}, see \sQuote{Details} below. Partial matches allowed.}
%}
%\description{
%  Abbreviate strings to at least \code{minlength} characters,
%  such that they remain \emph{unique} (if they were),
%  unless \code{strict = TRUE}.
%}
%\details{
%  The default algorithm (\code{method = "left.kept"}) used is similar
%  to that of S.  For a single string it works as follows.
%  First all spaces at the beginning of the string are stripped.
%  Then (if necessary) any other spaces are stripped.
%  Next, lower case vowels are removed (starting at the right)
%  followed by lower case consonants.
%  Finally if the abbreviation is still longer than \code{minlength}
%  upper case letters are stripped.
%
%  Characters are always stripped from the end of the word first.
%  If an element of \code{names.arg} contains more than one word (words
%  are separated by space) then at least one letter from each word will be
%  retained.
%
%  Missing (\code{NA}) values are unaltered.
%
%  If \code{use.classes} is \code{FALSE} then the only distinction is to
%  be between letters and space.  This has NOT been implemented.
%}
%\value{
%  A character vector containing abbreviations for the strings in its
%  first argument.  Duplicates in the original \code{names.arg} will be
%  given identical abbreviations.  If any non-duplicated elements have
%  the same \code{minlength} abbreviations then, if \code{method =
%  "both.sides"} the basic internal \code{abbreviate()} algorithm is
%  applied to the characterwise \emph{reversed} strings; if there are
%  still duplicated abbreviations and if \code{strict = FALSE} as by
%  default, \code{minlength} is incremented by one and new abbreviations
%  are found for those elements only.  This process is repeated until all
%  unique elements of \code{names.arg} have unique abbreviations.
%
%  The character version of \code{names.arg} is attached to the returned
%  value as a names argument: no other attributes are retained.
%}
%\section{Warning}{
%  This is really only suitable for English, and does not work correctly with
%  non-ASCII characters in multibyte locales.  It will warn if used with
%  non-ASCII characters (and required to reduce the length).
%}
%\seealso{
%  \code{\link{substr}}.
%}
%\examples{
%x <- c("abcd", "efgh", "abce")
%abbreviate(x, 2)
%abbreviate(x, 2, strict = TRUE) # >> 1st and 3rd are == "ab"
%
%(st.abb <- abbreviate(state.name, 2))
%table(nchar(st.abb)) # out of 50, 3 need 4 letters :
%as <- abbreviate(state.name, 3, strict = TRUE)
%as[which(as == "Mss")]
%\dontshow{stopifnot(which(as == "Mss") == c(21,24,25))
%}
%## method="both.sides" helps:  no 4-letters, and only 4 3-letters:
%st.ab2 <- abbreviate(state.name, 2, method = "both")
%table(nchar(st.ab2))
%## Compare the two methods:
%cbind(st.abb, st.ab2)
%}
%\keyword{character}
%
\encoding{UTF8}
