% File src/library/base/man/assignOps.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{assignOps}
\alias{<-}
\alias{=}
\alias{<<-}
\alias{->}
\alias{->>}
\alias{assignOps}
\title{Assignment Operators}
\description{
  名前に値を付値する．
}
\usage{
\special{x <- value}
\special{x <<- value}
\special{value -> x}
\special{value ->> x}

\special{x = value}
}
\arguments{
  \item{x}{変数名(引用化されている可能性)．}
  \item{value}{\code{x} に与えられる値．}
}
\details{
  三種類の異なった付値演算子がある：そのうち二つは左辺形と右辺形を持つ．

  演算子 \code{<-} と \code{=} はそれらが評価された環境中に付値する．
演算子 \code{<-} はどこでも使えるが，\code{=} はトップレベル
(例えば，コマンドプロンプトにタイプされた完全な表現式中)
か波括弧でくくった表現式のリスト中の副表現式の一つとして
だけ使える．

演算子 \code{<<-} と \code{->>} は通常関数中だけで使われ，
付値される既存の変数を親環境で探すようにする．
もしそうした変数が見つかると(そしてその結合がロックされていなければ)その値が
再定義される．さもなければ付値は大局的環境で行われる．
これらの構文は S 言語のそれらと異なるが，
しかし \R のスコープ規則との関連で有用であることを注意しよう．
さらなる詳細と例はマニュアル \sQuote{The R Language Definition} を参照せよ．

すべての付値演算表現式において，\code{x} は名前か
置き換えられるオブジェクトの一部分を定義する表現式で良いことを
注意しよう(例えば \code{z[[1]]})．構文的な名前は引用化される必要はないが，
そうしても良い(バックチックを使うのが好ましい)．

 左辺形 \code{<- = <<-} は右から左へ，他の形は左から右へ作用する．
}
\value{
  \code{value}. 従って \code{a <- b <- c <- 6} のような使い方が出来る．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Chamber, J. M. (1998)
  \emph{Programming with Data.  A Guide to the S Language}.
  Springer (\code{=} に対して).
}

\seealso{
  \dQuote{subassignment} に対する
  \code{x[i] <- v} \code{\link{assign}}, \code{\link{[<-}}; % ./Extract.Rd
  \code{\link{environment}}.
}
\keyword{data}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/assignOps.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{assignOps}
%\alias{<-}
%\alias{=}
%\alias{<<-}
%\alias{->}
%\alias{->>}
%\alias{assignOps}
%\title{Assignment Operators}
%\description{
%  Assign a value to a name.
%}
%\usage{
%\special{x <- value}
%\special{x <<- value}
%\special{value -> x}
%\special{value ->> x}
%
%\special{x = value}
%}
%\arguments{
%  \item{x}{a variable name (possibly quoted).}
%  \item{value}{a value to be assigned to \code{x}.}
%}
%\details{
%  There are three different assignment operators: two of them
%  have leftwards and rightwards forms.
%
%  The operators \code{<-} and \code{=} assign into the environment in
%  which they are evaluated.  The  operator \code{<-} can be used
%  anywhere, whereas the operator \code{=} is only allowed at the top
%  level (e.g., in the complete expression typed at the command prompt)
%  or as one of the subexpressions in a braced list of expressions.
%
%  The operators \code{<<-} and \code{->>} are normally only used in
%  functions, and cause a search to made through parent environments
%  for an existing definition of the variable being assigned.  If such
%  a variable is found (and its binding is not locked) then its value
%  is redefined, otherwise assignment takes place in the global
%  environment.  Note that their semantics differ from that in the S
%  language, but are useful in conjunction with the scoping rules of
%  \R.  See \sQuote{The R Language Definition} manual for further
%  details and examples.
%
%  In all the assignment operator expressions, \code{x} can be a name
%  or an expression defining a part of an object to be replaced (e.g.,
%  \code{z[[1]]}).  A syntactic name does not need to be quoted,
%  though it can be (preferably by \link{backtick}s).
%
%  The leftwards forms of assignment \code{<- = <<-} group right to left,
%  the other from left to right.
%}
%\value{
%  \code{value}.  Thus one can use \code{a <- b <- c <- 6}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Chamber, J. M. (1998)
%  \emph{Programming with Data.  A Guide to the S Language}.
%  Springer (for \code{=}).
%}
%
%\seealso{
%  \code{\link{assign}}, for \dQuote{subassignment} such
%  as \code{x[i] <- v}, \code{\link{[<-}}; % ./Extract.Rd
%  \code{\link{environment}}.
%}
%\keyword{data}
%
\encoding{UTF8}
