% File src/library/base/man/callCC.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{callCC}
\title{Call With Current Continuation}
\usage{
callCC(fun)
}
\alias{callCC}
\arguments{
  \item{fun}{引数が一つの関数で，終了手続き．}
}
\description{
現在の実行継続に対する Scheme の呼び出しの downward-only 版．
}
\details{
  \code{callCC} は計算の早期終了に対して有用な非局在的終了機構を
  提供する．\code{callCC} は引数が一つの終了関数 \code{fun} を
  呼び出す．終了関数は予期される返り値である一つの引数を持つ．
  もし \code{fun} の本体が終了関数を呼びだせば \code{callCC} への
  呼び出しは終了関数に与えられた値を \code{callCC} が返す値として
  直ちに戻る．
}
\author{Luke Tierney}

\examples{
# 以下はすべて値 1 を返す
callCC(function(k) 1)
callCC(function(k) k(1))
callCC(function(k) {k(1); 2})
callCC(function(k) repeat k(1))
}
\keyword{programming}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% File src/library/base/man/callCC.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later
%
%\name{callCC}
%\title{Call With Current Continuation}
%\usage{
%callCC(fun)
%}
%\alias{callCC}
%\arguments{
%  \item{fun}{function of one argument, the exit procedure.}
%}
%\description{
%A downward-only version of Scheme's call with current continuation.
%}
%\details{
%  \code{callCC} provides a non-local exit mechanism that can be useful
%  for early termination of a computation.  \code{callCC} calls
%  \code{fun} with one argument, an \emph{exit function}.  The exit
%  function takes a single argument, the intended return value.  If the
%  body of \code{fun} calls the exit function then the call to
%  \code{callCC} immediately returns, with the value supplied to the exit
%  function as the value returned by \code{callCC}.
%}
%\author{Luke Tierney}
%
%\examples{
%# The following all return the value 1
%callCC(function(k) 1)
%callCC(function(k) k(1))
%callCC(function(k) {k(1); 2})
%callCC(function(k) repeat k(1))
%}
%\keyword{programming}
%
\encoding{UTF8}
