% File src/library/base/man/cbind.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{cbind}
\alias{cbind}%%--do C-internal method dispatching !!
\alias{rbind}
\alias{cbind.data.frame}
\alias{rbind.data.frame}
\alias{.__H__.cbind}
\alias{.__H__.rbind}
\concept{insert}
\title{Combine R Objects by Rows or Columns}
\description{
  ベクトル，行列又はデータフレームの系列を引数として取り，
  それぞれ列又は行として結合する．
  これらは他の \R クラスに対するメソッドを持つ総称的関数である．
}
\usage{
cbind(\dots, deparse.level = 1)
rbind(\dots, deparse.level = 1)
\method{rbind}{data.frame}(\dots, deparse.level = 1,
 make.row.names = TRUE,
 stringsAsFactors = default.stringsAsFactors())
}
\arguments{
  \item{\dots}{(一般化)ベクトル又は行列．これらは名前付き引数として与えることが出来る．
    他の \R オブジェクトは適当に変換されるか S4 メソッドが使われるかもしれない：
    \sQuote{詳細}節と\sQuote{値}節を見よ．
    (\code{cbind} の \code{"data.frame"} メソッドについては \code{stringsAsFactors}
    のような) \code{\link{data.frame}} への追加引数があり得る．}
  \item{deparse.level}{非行列風引数(既定メソッドに対して)の場合にラベルの後世を
    制御する整数：\cr
    \code{deparse.level = 0} はラベルを構成しない；既定，\cr
    \code{deparse.level = 1 or 2} は引数名からラベルを構成する，
    下の\sQuote{値}節を見よ．}
  \item{make.row.names}{(データフレームメソッドに対してだけ：) 引数から
    ユニークで適正な \code{\link{row.names}} を後世すべきかどうかを指示
    する論理値．}
  \item{stringsAsFactors}{logical, passed to ‘as.data.frame’;
    only has an effect when the ‘...’ arguments contain a
    (non-‘data.frame’) ‘character’.}
}
\details{
  関数 \code{cbind} と \code{rbind} は S3 総称的で，データフレームに
  対するメソッドを持つ．少なくともひとつの引数がデータフレームで残りが
  ベクトルデータフレームならばデータフレームメソッドが使われる．
  他のメソッドもあり得る；特に時系列用がある．
  使われるメソッドがどのように選択されるかについては\sQuote{選択適用}節を
  見よ．もし幾つかの引数が S4 クラス，つまり \code{\link{isS4}(.)} が真，
  ならば S4 メソッドがまた探され，パッケージ \pkg{methods} からの
  隠し \code{cbind} / \code{rbind} 関数が呼び出されるかもしれない．
  これらは順に \code{\link{cbind2}} か \code{\link{rbind2}} の上に
  構築されている．その場合，既定メソッドに習い \code{deparse.level} に
  従う．

  既定メソッドでは，すべてのベクトル/行列は原子的(\code{\link{vector}} を見よ)
  かリストでなければならない．表現式は許されない．
  言語オブジェクト(公式や呼び出し)そして対リストはリストに強制変換される：
  他のオブジェクト(名前や外部ポインターのような)
  は結果リストの要素として含められる．入力が持つ任意のクラスは捨て去られているかもしれない
  (特に因子はその外部コードで置き換えられる)．

  もし複数の行列引数があれば，それらはすべて同じ数の列(又は行)を持たねばならず，
  これが結果の列(又は行)数になる．
  もしすべての引数がベクトルならば，結果の列(行)数は最長ベクトルの
  長さになる．短い引数中の値はこの長さが満足されるまでリサイクル使用される
  (もし部分的にリサイクルされれば警告が出る）．

  もし引数に行列とベクトルが混在すれば，結果の列(行)数は行列引数の
  列(行)数で決まる．すべてのベクトルはこの長さになるようにリサイクルされるか，
  部分使用される．

  S との互換性のため，\code{cbind} (\code{rbind}) に対しては，
  長さゼロの(\code{NULL} を含む)
  は結果がゼロ個の行(列)を持たない限り無視される．
  (行・列数ゼロの行列は S3 では存在せず，\R では無視されない．)

  行列は64ビットシステムでも列と行数が \eqn{2^{31}}{2^31} 以下に
  制限される．従って入力ベクトルも同じ長さの制限を持つ：
  \R 3.2.0 からそれ以上の要素を持つ行列が許されるようになった
  (しかし行と列数の制限を満たさなければならない)．
}
\section{データフレームメソッド}{
  \code{cbind} のデータフレームメソッドは単に
  \code{\link{data.frame}(..., check.names = FALSE)} に対するラッパである．
  これはそれが行列の列を分解しデータフレーム引数にすることを意味する．
  そして \code{stringsAsFactors = FALSE} が指定されない限り文字列の列は
  因子に変換される．

  \code{rbind} のデータフレームメソッドは最初に列・行数がセロの引数を捨て去る．
  (その結果何も残らなければ，列を持つ最初の引数が，さもなければ
  行・列数が共にゼロのデータフレームを返す．)
  それから最初のデータフレームから列のクラスを取り，列を名前でマッチする
  (位置ではなく)．因子は必要に応じてそれらの水準を
  (出会った因子の水準集合のレベルの順序で)拡大し，結果はすべての成分が順序因子の
  時，そしてその時だけ順序因子になる．
  (最後の点は S-PLUS と異なる．)  旧式のカテゴリ
  (水準を持つ整数ベクトル)は因子に変換される．
}
\value{
  既定メソッドに対しては， \code{\dots} 引数を列毎か行毎に連結した行列．
  (例外: もし入力が全くないか，すべての入力が \code{NULL} なら，値は \code{NULL}．)

  行列の結果の型は優先度 raw < logical < integer < double < complex <
  character < list で最高の入力の型から決まる．

  \code{cbind} (\code{rbind}) に対しては列(行)名は引数が行列風なら引数の
  \code{colnames} (\code{rownames}) から取られる．さもなければ引数の名前か，
  それが無く \code{deparse.level > 0} ならば与えられた表現式を逆構文解析して
  決められる(\code{deparse.level = 1} に対してはそれが意味のある
  名前を与えるときだけ(\sQuote{シンボル}, \code{\link{is.symbol}} を見よ))．

  \code{cbind} に対しては行名は適当な名前を持つ最初の引数から取られる：
  行列に対しては行名，又は結果の行数が長さであるベクトルに対する名前．

  \code{rbind} に対しては列名は適当な名前を持つ最初の引数から取られる：
  行列に対しては列名，又は結果の列数が長さであるベクトルに対する名前．
}
\section{選択適用}{
  メソッドの選択適用は \code{\link{UseMethod}()} ではなく，
  C-内部的選択適用によりなされる．従って例えば \code{rbind.default} 
  は不要である．

  選択適用アルゴリズムはソースファイル(\file{.../src/main/bind.c})に
  以下のように記述されている

  \enumerate{
    \item 各引数に対してクラス属性から可能なクラスのメンバーのリストを受け取る．

    \item 適用可能なメソッドがあるか各クラスを順に吟味する．

    \item もし適用可能なメソッドが見つかれば，それが事前の引数に対して
    決定されたメソッドと同じかどうかを確認する．
    もし同一ならばそのまま進行し，さもなければ即座に既定コードに
    切り替える．
   }
   もし他のオブジェクトをデータフレームに結合したければ，最初にそれを
   データフレームに変換する必要があるかもしれない．
   (このアルゴリズムはもしすべての引数がデータフレームかベクトルなら，
   データフレームメソッドを呼び出す結果になり得る．そして
   これは文字列ベクトルの因子への強制変換を招く．)
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  ベクトル(そしてリスト)をベクトルとして結合するには \code{\link{c}}，
  ベクトルと行列をデータフレームとして結合するには \code{\link{data.frame}}．
}
\examples{
m <- cbind(1, 1:7) # '1' (= 短い方のベクトル)はリサイクルされる
m
m <- cbind(m, 8:14)[, c(1, 3, 2)] # 列を挿入
m
cbind(1:7, diag(3)) # ベクトルはサブセット -> 警告

cbind(0, rbind(1, 1:3))
cbind(I = 0, X = rbind(a = 1, b = 1:3))  # ある名前を使う
xx <- data.frame(I = rep(0,2))
cbind(xx, X = rbind(a = 1, b = 1:3))   # 異なった命名

cbind(0, matrix(1, nrow = 0, ncol = 4)) #> 警告 (意味はある)
dim(cbind(0, matrix(1, nrow = 2, ncol = 0))) #-> 2 x 1

## deparse.level
dd <- 10
rbind(1:4, c = 2, "a++" = 10, dd, deparse.level = 0) # middle 2 rownames
rbind(1:4, c = 2, "a++" = 10, dd, deparse.level = 1) # 3 rownames (default)
rbind(1:4, c = 2, "a++" = 10, dd, deparse.level = 2) # 4 rownames

## 簡単な列名：
b0 <- gl(3,4, labels=letters[1:3])
bf <- setNames(b0, paste0("o", seq_along(b0)))
df  <- data.frame(a = 1, B = b0, f = gl(4,3))
df. <- data.frame(a = 1, B = bf, f = gl(4,3))
new <- data.frame(a = 8, B ="B", f = "1")
(df1  <- rbind(df , new))
(df.1 <- rbind(df., new))
stopifnot(identical(df1, rbind(df,  new, make.row.names=FALSE)),
          identical(df1, rbind(df., new, make.row.names=FALSE)))
\dontshow{
## 非公式な使用法のテスト：
d2 <- rbind.data.frame(as.list(df), as.list(new))
d3 <- rbind.data.frame(as.list(df), as.list(new), make.row.names=FALSE)
stopifnot(identical(.row_names_info(d3), -13L),
          attr(d2, "row.names")[c(1,13)] == c("13", "131"))
row.names(d2) <- attr(d3, "row.names")# = 1:13
stopifnot(identical(d2, d3))
}
}
\keyword{array}
\keyword{manip}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/cbind.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{cbind}
%\alias{cbind}%%--do C-internal method dispatching !!
%\alias{rbind}
%\alias{cbind.data.frame}
%\alias{rbind.data.frame}
%\alias{.__H__.cbind}
%\alias{.__H__.rbind}
%\concept{insert}
%\title{Combine R Objects by Rows or Columns}
%\description{
%  Take a sequence of vector, matrix or data-frame arguments and combine
%  by \emph{c}olumns or \emph{r}ows, respectively.  These are generic
%  functions with methods for other \R classes.
%}
%\usage{
%cbind(\dots, deparse.level = 1)
%rbind(\dots, deparse.level = 1)
%\method{rbind}{data.frame}(\dots, deparse.level = 1, make.row.names = TRUE)
%}
%\arguments{
%  \item{\dots}{(generalized) vectors or matrices.  These can be given as named
%    arguments.  Other \R objects may be coerced as appropriate, or S4
%    methods may be used: see sections \sQuote{Details} and
%    \sQuote{Value}.  (For the \code{"data.frame"} method of \code{cbind}
%    these can be further arguments to \code{\link{data.frame}} such as
%    \code{stringsAsFactors}.)}
%  \item{deparse.level}{integer controlling the construction of labels in
%    the case of non-matrix-like arguments (for the default method):\cr
%    \code{deparse.level = 0} constructs no labels; the default,\cr
%    \code{deparse.level = 1 or 2} constructs labels from the argument
%    names, see the \sQuote{Value} section below.}
%  \item{make.row.names}{(only for data frame method:) logical
%    indicating if unique and valid \code{\link{row.names}} should be
%    constructed from the arguments.}
%}
%\details{
%  The functions \code{cbind} and \code{rbind} are S3 generic, with
%  methods for data frames.  The data frame method will be used if at
%  least one argument is a data frame and the rest are vectors or
%  matrices.  There can be other methods; in particular, there is one for
%  time series objects.  See the section on \sQuote{Dispatch} for how
%  the method to be used is selected.  If some of the arguments are of an
%  S4 class, i.e., \code{\link{isS4}(.)} is true, S4 methods are sought
%  also, and the hidden \code{cbind} / \code{rbind} functions
%  from package \pkg{methods} maybe called, which in turn build on
%  \code{\link{cbind2}} or \code{\link{rbind2}}, respectively.  In that
%  case, \code{deparse.level} is obeyed, similarly to the default method.
%
%  In the default method, all the vectors/matrices must be atomic (see
%  \code{\link{vector}}) or lists.  Expressions are not allowed.
%  Language objects (such as formulae and calls) and pairlists will be
%  coerced to lists: other objects (such as names and external pointers)
%  will be included as elements in a list result.  Any classes the inputs
%  might have are discarded (in particular, factors are replaced by their
%  internal codes).
%
%  If there are several matrix arguments, they must all have the same
%  number of columns (or rows) and this will be the number of columns (or
%  rows) of the result.  If all the arguments are vectors, the number of
%  columns (rows) in the result is equal to the length of the longest
%  vector.  Values in shorter arguments are recycled to achieve this
%  length (with a \code{\link{warning}} if they are recycled only
%  \emph{fractionally}).
%
%  When the arguments consist of a mix of matrices and vectors the number
%  of columns (rows) of the result is determined by the number of columns
%  (rows) of the matrix arguments.  Any vectors have their values
%  recycled or subsetted to achieve this length.
%
%  For \code{cbind} (\code{rbind}), vectors of zero length (including
%  \code{NULL}) are ignored unless the result would have zero rows
%  (columns), for S compatibility.
%  (Zero-extent matrices do not occur in S3 and are not ignored in \R.)
%
%  Matrices are restricted to less than \eqn{2^{31}}{2^31} rows and
%  columns even on 64-bit systems.  So input vectors have the same length
%  restriction: as from \R 3.2.0 input matrices with more elements (but
%  meeting the row and column restrictions) are allowed.
%}
%\section{Data frame methods}{
%  The \code{cbind} data frame method is just a wrapper for
%  \code{\link{data.frame}(..., check.names = FALSE)}.  This means that
%  it will split matrix columns in data frame arguments, and convert
%  character columns to factors unless \code{stringsAsFactors = FALSE} is
%  specified.
%
%  The \code{rbind} data frame method first drops all zero-column and
%  zero-row arguments.  (If that leaves none, it returns the first
%  argument with columns otherwise a zero-column zero-row data frame.)
%  It then takes the classes of the columns from the
%  first data frame, and matches columns by name (rather than by
%  position).  Factors have their levels expanded as necessary (in the
%  order of the levels of the levelsets of the factors encountered) and
%  the result is an ordered factor if and only if all the components were
%  ordered factors.  (The last point differs from S-PLUS.)  Old-style
%  categories (integer vectors with levels) are promoted to factors.
%}
%\value{
%  For the default method, a matrix combining the \code{\dots} arguments
%  column-wise or row-wise.  (Exception: if there are no inputs or all
%  the inputs are \code{NULL}, the value is \code{NULL}.)
%
%  The type of a matrix result determined from the highest type of any of
%  the inputs in the hierarchy raw < logical < integer < double < complex <
%  character < list .
%
%  For \code{cbind} (\code{rbind}) the column (row) names are taken from
%  the \code{colnames} (\code{rownames}) of the arguments if these are
%  matrix-like.  Otherwise from the names of the arguments or where those
%  are not supplied and \code{deparse.level > 0}, by deparsing the
%  expressions given, for \code{deparse.level = 1} only if that gives a
%  sensible name (a \sQuote{symbol}, see \code{\link{is.symbol}}).
%
%  For \code{cbind} row names are taken from the first argument with
%  appropriate names: rownames for a matrix, or names for a vector of
%  length the number of rows of the result.
%
%  For \code{rbind} column names are taken from the first argument with
%  appropriate names: colnames for a matrix, or names for a vector of
%  length the number of columns of the result.
%}
%\section{Dispatch}{
%  The method dispatching is \emph{not} done via
%  \code{\link{UseMethod}()}, but by C-internal dispatching.
%  Therefore there is no need for, e.g., \code{rbind.default}.
%
%  The dispatch algorithm is described in the source file
%  (\file{.../src/main/bind.c}) as
%
%  \enumerate{
%    \item For each argument we get the list of possible class
%    memberships from the class attribute.
%
%    \item We inspect each class in turn to see if there is an
%    applicable method.
%
%    \item If we find an applicable method we make sure that it is
%     identical to any method determined for prior arguments.
%     If it is identical, we proceed, otherwise we immediately
%     drop through to the default code.
%   }
%   If you want to combine other objects with data frames, it may be
%   necessary to coerce them to data frames first.  (Note that this
%   algorithm can result in calling the data frame method if all the
%   arguments are either data frames or vectors, and this will result in
%   the coercion of character vectors to factors.)
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{c}} to combine vectors (and lists) as vectors,
%  \code{\link{data.frame}} to combine vectors and matrices as a data
%  frame.
%}
%\examples{
%m <- cbind(1, 1:7) # the '1' (= shorter vector) is recycled
%m
%m <- cbind(m, 8:14)[, c(1, 3, 2)] # insert a column
%m
%cbind(1:7, diag(3)) # vector is subset -> warning
%
%cbind(0, rbind(1, 1:3))
%cbind(I = 0, X = rbind(a = 1, b = 1:3))  # use some names
%xx <- data.frame(I = rep(0,2))
%cbind(xx, X = rbind(a = 1, b = 1:3))   # named differently
%
%cbind(0, matrix(1, nrow = 0, ncol = 4)) #> Warning (making sense)
%dim(cbind(0, matrix(1, nrow = 2, ncol = 0))) #-> 2 x 1
%
%## deparse.level
%dd <- 10
%rbind(1:4, c = 2, "a++" = 10, dd, deparse.level = 0) # middle 2 rownames
%rbind(1:4, c = 2, "a++" = 10, dd, deparse.level = 1) # 3 rownames (default)
%rbind(1:4, c = 2, "a++" = 10, dd, deparse.level = 2) # 4 rownames
%
%## cheap row names:
%b0 <- gl(3,4, labels=letters[1:3])
%bf <- setNames(b0, paste0("o", seq_along(b0)))
%df  <- data.frame(a = 1, B = b0, f = gl(4,3))
%df. <- data.frame(a = 1, B = bf, f = gl(4,3))
%new <- data.frame(a = 8, B ="B", f = "1")
%(df1  <- rbind(df , new))
%(df.1 <- rbind(df., new))
%stopifnot(identical(df1, rbind(df,  new, make.row.names=FALSE)),
%          identical(df1, rbind(df., new, make.row.names=FALSE)))
%\dontshow{
%## Testing a semi-official use:
%d2 <- rbind.data.frame(as.list(df), as.list(new))
%d3 <- rbind.data.frame(as.list(df), as.list(new), make.row.names=FALSE)
%stopifnot(identical(.row_names_info(d3), -13L),
%          attr(d2, "row.names")[c(1,13)] == c("13", "131"))
%row.names(d2) <- attr(d3, "row.names")# = 1:13
%stopifnot(identical(d2, d3))
%}
%}
%\keyword{array}
%\keyword{manip}
%
\encoding{UTF8}
