% File src/library/base/man/charmatch.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{charmatch}
\title{Partial String Matching}
\usage{
charmatch(x, table, nomatch = NA_integer_)
}
\alias{charmatch}
\arguments{
  \item{x}{マッチすべき値：\code{\link{as.character}} で文字列に
  変換される．ロングベクトルがサポートされている．}
  \item{table}{マッチされるべき値：文字列に変換される．
    ロングベクトルはサポートされていない．}
  \item{nomatch}{マッチしない位置で返されるべき(整数)値．}
}
\description{
  \code{charmatch} はその第一引数の要素に対して第二引数中からマッチするものを
  探す．
}
\details{
  正確なマッチングは部分的なマッチング(マッチされるべき値が
  目標の最初の部分に正確に一致するが，目標は更に長い)よりも好ましい．

  もし正確なマッチングが一つだけか，正確なマッチが皆無で部分的なマッチングが
  ひとつだけなら，マッチされた値の添字が返される；
  もし正確なマッチングが複数あるか，複数の部分マッチングがあれば \code{0} が
  返され，マッチングが見つからなければ \code{nomatch} が返される．

  \code{NA} 値は文字列定数 \code{"NA"} と見做される．
}
\value{
  \code{x} と同じ長さの整数ベクトルで，
  マッチした \code{table} 中の要素の添え字か，又は \code{nomatch}．
}
\author{
  この関数は Terry Therneau による C 関数に基づく．
}
\seealso{
  \code{\link{pmatch}}, \code{\link{match}}.

  文字列のより一般的なマッチング(regexp)については \code{\link{grep}} か
  \code{\link{regexpr}}．
}
\examples{
charmatch("", "")                             # 1 を返す
charmatch("m",   c("mean", "median", "mode")) # 0 を返す
charmatch("med", c("mean", "median", "mode")) # 2 を返す
}
\keyword{character}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/charmatch.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{charmatch}
%\title{Partial String Matching}
%\usage{
%charmatch(x, table, nomatch = NA_integer_)
%}
%\alias{charmatch}
%\arguments{
%  \item{x}{the values to be matched: converted to a character vector by
%    \code{\link{as.character}}.  \link{Long vectors} are supported.}
%  \item{table}{the values to be matched against: converted to a character
%    vector.  \link{Long vectors} are not supported.}
%  \item{nomatch}{the (integer) value to be returned at non-matching
%    positions.}
%}
%\description{
%  \code{charmatch} seeks matches for the elements of its first argument
%  among those of its second.
%}
%\details{
%  Exact matches are preferred to partial matches (those where the value
%  to be matched has an exact match to the initial part of the target,
%  but the target is longer).
%
%  If there is a single exact match or no exact match and a unique
%  partial match then the index of the matching value is returned; if
%  multiple exact or multiple partial matches are found then \code{0} is
%  returned and if no match is found then \code{nomatch} is returned.
%
%  \code{NA} values are treated as the string constant \code{"NA"}.
%}
%\value{
%  An integer vector of the same length as \code{x}, giving the
%  indices of the elements in \code{table} which matched, or \code{nomatch}.
%}
%\author{
%  This function is based on a C function written by Terry Therneau.
%}
%\seealso{
%  \code{\link{pmatch}}, \code{\link{match}}.
%
%  \code{\link{grep}} or \code{\link{regexpr}} for more general (regexp)
%  matching of strings.
%}
%\examples{
%charmatch("", "")                             # returns 1
%charmatch("m",   c("mean", "median", "mode")) # returns 0
%charmatch("med", c("mean", "median", "mode")) # returns 2
%}
%\keyword{character}
%
%
\encoding{UTF8}
