% File src/library/base/man/data.matrix.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2008 R Core Team
% Distributed under GPL 2 or later

\name{data.matrix}
\alias{data.matrix}
\title{Convert a Data Frame to a Numeric Matrix}
\description{
  データフレーム中のすべての変数を数値モードに変換しそれを
  行列の列にまとめて得られる行列を返す．因子と順序付き因子は
  それらの内部的コードに置き換えられる．
}
\usage{
data.matrix(frame, rownames.force = NA)
}
\arguments{
  \item{frame}{その成分が論理値ベクトル，因子又は数値ベクトルであるデータフレーム．}
  \item{rownames.force}{論理値で，結果の行列が(\code{NULL} ではなく)
    文字列の行名を持つべきかどうかを指示する．
    もしデータフレームが\sQuote{自動的}な行名をもつか行数ゼロのデータフレーム
    ならば既定 \code{NA} では \code{NULL} の行名を持つ．}
}
\details{
  論理値と因子の列は整数に変換される．
  数値でない(\code{\link{is.numeric}} によれば)他の列は
  \code{\link{as.numeric}} か，S4 オブジェクトに対しては
  \code{\link{as}(, "numeric")} でで数値に変換される．
  もしすべての列が整数(強制変換後)ならば結果は整数行列になる．
  さもなければ数値(倍精度実数)行列になる．
}
\value{
  \code{frame} がクラス \code{"data.frame"} を継承していれば，
  \code{frame} と同じ次元を持つ整数又は数値行列で，
  次元名は \code{row.names} (もしくは \code{rownames.force} に
  応じて \code{NULL}) と \code{names} から取られる．

  さもなければ \code{\link{as.matrix}} の結果．
}
\note{
  データフレームに対する既定動作は \R < 2.5.0 では異なっており，
  常に文字列行名を与えていた．
}
\seealso{
  \code{\link{as.matrix}},
  \code{\link{data.frame}},
  \code{\link{matrix}}.
}
\references{
  Chambers, J. M. (1992)
  \emph{Data for models.}
  Chapter 3 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}
\examples{
DF <- data.frame(a = 1:3, b = letters[10:12],
                 c = seq(as.Date("2004-01-01"), by = "week", len = 3),
                 stringsAsFactors = TRUE)
data.matrix(DF[1:2])
data.matrix(DF)
}
\keyword{array}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/data.matrix.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2008 R Core Team
%% Distributed under GPL 2 or later
%
%\name{data.matrix}
%\alias{data.matrix}
%\title{Convert a Data Frame to a Numeric Matrix}
%\description{
%  Return the matrix obtained by converting all the variables in a data
%  frame to numeric mode and then binding them together as the columns of
%  a matrix.  Factors and ordered factors are replaced by their internal
%  codes.
%}
%\usage{
%data.matrix(frame, rownames.force = NA)
%}
%\arguments{
%  \item{frame}{a data frame whose components are logical vectors,
%    factors or numeric vectors.}
%  \item{rownames.force}{logical indicating if the resulting matrix
%    should have character (rather than \code{NULL})
%    \code{\link{rownames}}.  The default, \code{NA}, uses \code{NULL}
%    rownames if the data frame has \sQuote{automatic} row.names or for a
%    zero-row data frame.}
%}
%\details{
%  Logical and factor columns are converted to integers.  Any other
%  column which is not numeric (according to \code{\link{is.numeric}}) is
%  converted by \code{\link{as.numeric}} or, for S4 objects,
%  \code{\link{as}(, "numeric")}.  If all columns are integer (after
%  conversion) the result is an integer matrix, otherwise a numeric
%  (double) matrix.
%}
%\value{
%  If \code{frame} inherits from class \code{"data.frame"}, an integer or
%  numeric matrix of the same dimensions as \code{frame}, with dimnames
%  taken from the \code{row.names} (or \code{NULL}, depending on
%  \code{rownames.force}) and \code{names}.
%
%  Otherwise, the result of \code{\link{as.matrix}}.
%}
%\note{
%  The default behaviour for data frames differs from \R < 2.5.0 which
%  always gave the result character rownames.
%}
%\seealso{
%  \code{\link{as.matrix}},
%  \code{\link{data.frame}},
%  \code{\link{matrix}}.
%}
%\references{
%  Chambers, J. M. (1992)
%  \emph{Data for models.}
%  Chapter 3 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%\examples{
%DF <- data.frame(a = 1:3, b = letters[10:12],
%                 c = seq(as.Date("2004-01-01"), by = "week", len = 3),
%                 stringsAsFactors = TRUE)
%data.matrix(DF[1:2])
%data.matrix(DF)
%}
%\keyword{array}
%
\encoding{UTF8}
