% File src/library/base/man/difftime.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{difftime}
\alias{difftime}
\alias{as.difftime}
\alias{as.double.difftime}
\alias{is.numeric.difftime}
\alias{print.difftime}
\alias{format.difftime}
\alias{units.difftime}
\alias{units<-.difftime}
\alias{Ops.difftime}
\alias{*.difftime}
\alias{/.difftime}
\alias{Math.difftime}
\alias{Summary.difftime}
\alias{[.difftime}
\alias{mean.difftime}
\alias{units}
\alias{units<-}
\alias{time interval} % used by mean.Rd
\title{Time Intervals}
\description{
  時間区間の作成，プリント，そして幾つかの算術．
}
\usage{
\special{time1 - time2}

difftime(time1, time2, tz,
         units = c("auto", "secs", "mins", "hours",
                   "days", "weeks"))

as.difftime(tim, format = "\%X", units = "auto")

\method{format}{difftime}(x, ...)
\method{units}{difftime}(x)
\method{units}{difftime}(x) <- value
\method{as.double}{difftime}(x, units = "auto", ...)

## グループメソッド，特に round(), signif(), floor(),
## ceiling(), trunc(), abs() 用：Math() でなく直接呼び出す：
\method{Math}{difftime}(x, \dots)
}
\arguments{
  \item{time1, time2}{日付・時間オブジェクトまたは日付オブジェクト．}
  \item{tz}{変換に用いられるタイムゾーン指定で主に
    \code{"POSIXlt"} オブジェクト用．}
  \item{units}{文字列．希望する単位．簡略化可能．}
  \item{value}{文字列．簡略化できないのを除けば \code{units} に類似．}
  \item{tim}{時間区間を指定する文字列または数値．}
  \item{format}{\code{tim} の書式を指定する文字：
    \code{\link{strptime}} を見よ．既定値はロケール固有の時間書式．}
  \item{x}{\code{"difftime"} を継承するオブジェクト．}
  \item{\dots}{他のメソッドへ・から引き渡される引数．}
}
\details{
  関数 \code{difftime} は二つの日付/時刻オブジェクトの差を計算し，
  単位を示す属性付きのクラス \code{"difftime"} のオブジェクトを返す．
  \code{\link[=S3groupGeneric]{Math}} グループメソッドは
  \code{\link{round}}, \code{\link{signif}}, \code{\link{floor}},
  \code{\link{ceiling}}, \code{\link{trunc}}, \code{\link{abs}}，
  このクラスのオブジェクトに対するメソッド \code{\link{sign}} を提供し，
  グループ総称的(\code{\link[=S3groupGeneric]{Ops}} を見よ)な論理と算術
  演算がある．

  もし \code{units = "auto"} ならば，適当な単位のセットが選ばれる．
  これはすべての差の絶対値が1より大きくなるような最大のものである
  (\code{"weeks"} を除く)．

  日付/時刻オブジェクトの差は \code{units = "auto"} を用いた \code{difftime} の
  呼び出しによりこのクラスのオブジェクトを返す．別法として
  \code{as.difftime()} は文字列でコードされたか数値の時刻に関して
  動作する；後者の場合単位を指定すべきで \code{format} は効果を持たない．

  \code{"difftime"} オブジェクトに対する限られた算術が利用できる：
  それらは足したり引いたり，数値ベクトルで掛けたり割ったりできる．
  加えて数値ベクトルから \code{"difftime"} オブジェクトを足したり引いたりすると
  数値ベクトルは暗黙のうちに \code{"difftime"} オブジェクトに同じ
  単位で変換される．\code{\link{mean}} と \code{\link{sum}}
  に対するメソッドがある(\code{\link[=S3groupGeneric]{Summary}} グループメソッド経由で)．

  \code{"difftime"} オブジェクトの単位は \code{units} 関数で取り出すことができ，
  これはまた置き換え形式も持つ．もし単位が変更されると数値ベクトルは
  それにしたがってスケール化される．置き換えバージョンは名前や次元といった
  属性を保存する．

  \code{units = "days"} は24時間周期を持ち，従ってサマータイムを
  考慮しないことを注意しよう．クラス \code{"\link{Date}"} のオブジェクトは
  あたかも UTC タイムゾーン中であるかのように計算される．

  \code{as.double} メソッドは指定単位で表現された数値を返す．
  \code{units = "auto"} の使用はオブジェクトの単位を使うことを意味する．

  \code{format} メソッドは数値を単純に整形し，単位を文字列テキストとして
  付け加える．
}
\note{
  \code{"months"} のような単位は決まった長さではないので使えない．
  月，四半期，年単位の区間を作るには
  \code{\link{seq.Date}} や \code{\link{seq.POSIXt}} を使う．
}
\seealso{
  \code{\link{DateTimeClasses}}.
}
\examples{\donttest{
(z <- Sys.time() - 3600)
Sys.time() - z                # 丁度 3600 秒以上．

## R 1.2.2 と 1.2.3 の公開期間の秒差．
ISOdate(2001, 4, 26) - ISOdate(2001, 2, 26)

as.difftime(c("0:3:20", "11:23:15"))
as.difftime(c("3:20", "23:15", "2:"), format = "\%H:\%M") # 3番目は NA になる
(z <- as.difftime(c(0,30,60), units = "mins"))
as.numeric(z, units = "secs")
as.numeric(z, units = "hours")
format(z)
}}
\keyword{utilities}
\keyword{chron}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/difftime.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{difftime}
%\alias{difftime}
%\alias{as.difftime}
%\alias{as.double.difftime}
%\alias{is.numeric.difftime}
%\alias{print.difftime}
%\alias{format.difftime}
%\alias{units.difftime}
%\alias{units<-.difftime}
%\alias{Ops.difftime}
%\alias{*.difftime}
%\alias{/.difftime}
%\alias{Math.difftime}
%\alias{Summary.difftime}
%\alias{[.difftime}
%\alias{mean.difftime}
%\alias{units}
%\alias{units<-}
%\alias{time interval} % used by mean.Rd
%\title{Time Intervals}
%\description{
%  Time intervals creation, printing, and some arithmetic.
%}
%\usage{
%\special{time1 - time2}
%
%difftime(time1, time2, tz,
%         units = c("auto", "secs", "mins", "hours",
%                   "days", "weeks"))
%
%as.difftime(tim, format = "\%X", units = "auto")
%
%\method{format}{difftime}(x, ...)
%\method{units}{difftime}(x)
%\method{units}{difftime}(x) <- value
%\method{as.double}{difftime}(x, units = "auto", ...)
%
%## Group methods, notably for round(), signif(), floor(),
%## ceiling(), trunc(), abs(); called directly, *not* as Math():
%\method{Math}{difftime}(x, \dots)
%}
%\arguments{
%  \item{time1, time2}{\link{date-time} or \link[=Dates]{date} objects.}
%  \item{tz}{an optional \link{time zone} specification to be used for the
%    conversion, mainly for \code{"POSIXlt"} objects.}
%  \item{units}{character string.  Units in which the results are
%    desired.  Can be abbreviated.}
%  \item{value}{character string.  Like \code{units}, except that
%    abbreviations are not allowed.}
%  \item{tim}{character string or numeric value specifying a time interval.}
%  \item{format}{character specifying the format of \code{tim}: see
%    \code{\link{strptime}}.  The default is a locale-specific time format.}
%  \item{x}{an object inheriting from class \code{"difftime"}.}
%  \item{\dots}{arguments to be passed to or from other methods.}
%}
%\details{
%  Function \code{difftime} calculates a difference of two date/time
%  objects and returns an object of class \code{"difftime"} with an
%  attribute indicating the units.  The
%  \code{\link[=S3groupGeneric]{Math}} group method provides
%  \code{\link{round}}, \code{\link{signif}}, \code{\link{floor}},
%  \code{\link{ceiling}}, \code{\link{trunc}}, \code{\link{abs}}, and
%  \code{\link{sign}} methods for objects of this class, and there are
%  methods for the group-generic (see
%  \code{\link[=S3groupGeneric]{Ops}}) logical and arithmetic
%  operations.
%
%  If \code{units = "auto"}, a suitable set of units is chosen, the largest
%  possible (excluding \code{"weeks"}) in which all the absolute
%  differences are greater than one.
%
%  Subtraction of date-time objects gives an object of this class,
%  by calling \code{difftime} with \code{units = "auto"}.  Alternatively,
%  \code{as.difftime()} works on character-coded or numeric time
%  intervals; in the latter case, units must be specified, and
%  \code{format} has no effect.
%
%  Limited arithmetic is available on \code{"difftime"} objects: they can
%  be added or subtracted, and multiplied or divided by a numeric vector.
%  In addition, adding or subtracting a numeric vector by a
%  \code{"difftime"} object implicitly converts the numeric vector to a
%  \code{"difftime"} object with the same units as the \code{"difftime"}
%  object.  There are methods for \code{\link{mean}} and
%  \code{\link{sum}} (via the \code{\link[=S3groupGeneric]{Summary}}
%  group generic).
%
%  The units of a \code{"difftime"} object can be extracted by the
%  \code{units} function, which also has a replacement form.  If the
%  units are changed, the numerical value is scaled accordingly.  The
%  replacement version keeps attributes such as names and dimensions.
%
%  Note that \code{units = "days"} means a period of 24 hours, hence
%  takes no account of Daylight Savings Time.  Differences in objects
%  of class \code{"\link{Date}"} are computed as if in the UTC time zone.
%
%  The \code{as.double} method returns the numeric value expressed in
%  the specified units.  Using  \code{units = "auto"} means the units of the
%  object.
%
%  The \code{format} method simply formats the numeric value and appends
%  the units as a text string.
%}
%\note{
%  Units such as \code{"months"} are not possible as they are not of
%  constant length.  To create intervals of months, quarters or years
%  use \code{\link{seq.Date}} or \code{\link{seq.POSIXt}}.
%}
%\seealso{
%  \code{\link{DateTimeClasses}}.
%}
%\examples{\donttest{
%(z <- Sys.time() - 3600)
%Sys.time() - z                # just over 3600 seconds.
%
%## time interval between release days of R 1.2.2 and 1.2.3.
%ISOdate(2001, 4, 26) - ISOdate(2001, 2, 26)
%
%as.difftime(c("0:3:20", "11:23:15"))
%as.difftime(c("3:20", "23:15", "2:"), format = "\%H:\%M") # 3rd gives NA
%(z <- as.difftime(c(0,30,60), units = "mins"))
%as.numeric(z, units = "secs")
%as.numeric(z, units = "hours")
%format(z)
%}}
%\keyword{utilities}
%\keyword{chron}
%
\encoding{UTF8}
