% File src/library/base/man/groupGeneric.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{groupGeneric}
\alias{S3groupGeneric}
\alias{groupGeneric}
\alias{.Group}
\alias{Math}
\alias{Math.data.frame}
\alias{Ops}
\alias{Ops.data.frame}
\alias{Summary}
\alias{Summary.data.frame}
\alias{Complex}
\alias{group generic} % used in class.Rd and zMethods.Rd
\concept{group generic}
\title{S3 Group Generic Functions}
\description{
  グループ総称的メソッドは四つの予め指定された関数のグループ
  \code{Math}, \code{Ops}, \code{Summary} そして \code{Complex} に
  対して定義できる．.
  (\R の基本パッケージにはこれらの名前のオブジェクトは無いが，
   \pkg{methods} パッケージにはある．)

  グループの個別のメンバーに対して定義されたメソッドはグループ全体に対して
  定義されたメソッドに優先する．
}
\usage{
## グループ総称的 S3 メソッドは次のプロトタイプを持つ：
\special{Math(x, \dots)}
\special{Ops(e1, e2)}
\special{Complex(z)}
\special{Summary(\dots, na.rm = FALSE)}
}
\arguments{
  \item{x, z, e1, e2}{オブジェクト．}
  \item{\dots}{メソッドに渡される追加引数．}
  \item{na.rm}{論理値：欠損値を取り除くべきか?}
}

\details{
  %% --------------- grep -nw DispatchGroup src/*/*[ch]

  S3 メソッドが掛ける四つの\emph{グループ}がある．つまり
  \code{"Math"}, \code{"Ops"}, \code{"Summary"} そして
  \code{"Complex"} グループである．コレアは \R の基本パッケージ中のオブジェクトではないが，
  それらに対するメソッドを提供でき，\R の基本パッケージは最初の三つの
  グループに対する \code{\link{factor}}, \code{\link{data.frame}} そして 
  \code{\link{difftime}} メソッドを含む．(また \code{Ops} に対する
  \code{\link{ordered}} メソッド，\code{Math} と \code{Ops} に対する
  \code{\link{POSIXt}} と \code{\link{Date}} メソッド，\code{Ops} と \code{Summary}に
  対する \code{\link{package_version}} メソッド，そして
  パッケージ \pkg{stats} 中に \code{Ops} に対する \code{\link{ts}} メソッド
  がある．)

  \enumerate{
    \item グループ \code{"Math"}：
    \itemize{
      \item
      \code{abs}, \code{sign}, \code{sqrt},\cr
      \code{floor}, \code{ceiling}, \code{trunc},\cr
      \code{round}, \code{signif}

      \item
      \code{exp}, \code{log},  \code{expm1}, \code{log1p},\cr
      \code{cos}, \code{sin}, \code{tan},\cr
      \code{cospi}, \code{sinpi}, \code{tanpi},\cr
      \code{acos}, \code{asin}, \code{atan}

      \code{cosh}, \code{sinh}, \code{tanh},\cr
      \code{acosh}, \code{asinh}, \code{atanh}

      \item
      \code{lgamma}, \code{gamma}, \code{digamma}, \code{trigamma}
      %   do_math1() [../../../main/arithmetic.c:794]: if (DispatchGroup("Math",...))
      %
      %
      % "atan", "round", "log", "signif":
      % do_atan()  [arithmetic.c:958]: if (DispatchGroup("Math", ..))
      % do_round() [arithmetic.c:981]: if (DispatchGroup("Math", ..))
      % do_log()   [arithmetic.c:1011]:if (DispatchGroup("Math", ..))
      % do_signif()[arithmetic.c:1034]:if (DispatchGroup("Math", ..))

      \item \code{cumsum}, \code{cumprod}, \code{cummax}, \code{cummin}
      % do_cum()   [cum.c:140]:    if (DispatchGroup("Math", ...))
    }
    このグループのメンバーは \code{x} に対してメソッドを選択適用する．
    殆どのメンバーは引数が一つだけのものを受け入れるが，
    メンバー \code{log}, \code{round} そして \code{signif} は一つもしくは
    二つの引数を受け入れ，そして \code{trunc} は一つもしくはそれ以上を
    引き受ける．

    \item グループ \code{"Ops"}：
    \itemize{
      \item
      \code{"+"}, \code{"-"}, \code{"*"}, \code{"/"},
      \code{"^"}, \code{"\%\%"}, \code{"\%/\%"}
      % do_arith() [arithmetic.c:240]: if (DispatchGroup("Ops", ...))

      \item \code{"&"}, \code{"|"}, \code{"!"}
      % do_logic() [logic.c:32]:   if (DispatchGroup("Ops",...))

      \item \code{"=="}, \code{"!="},
      \code{"<"}, \code{"<="}, \code{">="}, \code{">"}
      % do_relop() [relop.c:35]:   if (DispatchGroup("Ops", ...))
    }
    このグループは単項と二項演算子を含む(\code{+}, \code{-} そして \code{!})：
    単項演算子に出会うと \code{Ops} メソッドが引数一つで呼び出され \code{e2} は
    無い．

    どちらの引数のクラスもこのグループの任意のメンバーに選択適用されると
    考えられている．各引数に対してそのクラスのベクトルが特定の(優先)メソッド
    か \code{Ops} メソッドにマッチするかが吟味される．
    もしあるメソッドが唯一つの引数と二つの引数用に見つかれば
    それが使われる．
    もし異なったメソッドが見つかれば
    \sQuote{不整合なメソッド}という警告がである：
    その場合もしくはどちらの引数に対するメソッドが一つもみつからない場合は
    内部的なメソッドが使われる．

    もしこのグループのメンバーが関数として呼び出されると，位置によるマッチングが
    保証されるように任意の引数名は取り除かれる．

    \item グループ \code{"Summary"}：
    \itemize{
      \item \code{all}, \code{any}
      % do_logic3()[logic.c:278]:  if(DispatchGroup("Summary", ...))
      \item \code{sum}, \code{prod}
      % /*NOMORE:\code{mean}, */
      \item \code{min}, \code{max}
      % do_summary() [summary.c:322]: if(DispatchGroup("Summary",...))
      \item \code{range}
    }
    このグループのメンバーは与えられた最初の引数に関して選択適用を行う．

    \item Group \code{"Complex"}：
    \itemize{
      \item \code{Arg}, \code{Conj}, \code{Im}, \code{Mod}, \code{Re}
      % do_cmathfuns() [complex.c:267]: if(DispatchGroup("Complex",...))
    }
    このグループのメンバーは \code{z} に対して選択適用を行う．
  }

  内部コードは \code{\link{oldClass}} に対して選択適用を行い
  \code{\link{class}} に対してではないため，
  一つのメソッドはこれらのグループの一つに対して使われるか，
  もしそれが一つの \code{"class"} 属性だけに対応すればそのメンバーに
  選択適用される．これは効率性のためである：例えば \code{Ops.integer} の
  選択適用は遅すぎるであろう．

  \code{"Math"} グループ総称的メソッドのプリミティブなメンバーに対して
  提供される引数の数は選択適用に先立ってチェックされない．

  グループ-総称的関数に対する引数の遅延評価はなされない．
}
\section{技術的詳細}{
  これらの関数はすべてプリミティブで内部総称的である．

  メソッドの選択適用と \code{.Generic} のような変数は
  \code{\link{UseMethod}} に対するヘルプで議論されている．僅かな小さな違いがある：
  \itemize{
    \item グループ \code{Ops} の演算子に対しては，オブジェクト
    \code{.Method} は長さが2の文字列ベクトルであり，それぞれ
    左と右の引数に対して選択されたメソッドを要素に持つ．
    (もしどのメソッドも選択されないと対応する要素は \code{""} になる．)
    \item オブジェクト \code{.Group} は選択適用に対して使われたグループ
    を記録する(もし個別メソッドが使われるとこれは \code{""} になる)．
  }
}
\note{
  パッケージ \pkg{methods} はこれらの名前を持つオブジェクトを含む．
  それは混乱させられる似通った(しかし異なった)方法でそれを再利用する．
  このパッケージに対するヘルプを見よ．
}
\references{
  Appendix A, \emph{Classes and Methods} of\cr
  Chambers, J. M.  and Hastie, T. J. eds (1992)
  \emph{Statistical Models in S.}
  Wadsworth & Brooks/Cole.
}
\seealso{
 非内部的な総称的関数のメソッドに対しては \code{\link{methods}}．

  S4 メソッドに対するグループ総称的メソッドは \link{S4groupGeneric}．
}
\examples{
require(utils)

d.fr <- data.frame(x = 1:9, y = stats::rnorm(9))
class(1 + d.fr) == "data.frame" ##-- d.f. に加える ...

methods("Math")
methods("Ops")
methods("Summary")
methods("Complex")  # base R には無い
}
\keyword{methods}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/groupGeneric.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{groupGeneric}
%\alias{S3groupGeneric}
%\alias{groupGeneric}
%\alias{.Group}
%\alias{Math}
%\alias{Math.data.frame}
%\alias{Ops}
%\alias{Ops.data.frame}
%\alias{Summary}
%\alias{Summary.data.frame}
%\alias{Complex}
%\alias{group generic} % used in class.Rd and zMethods.Rd
%\concept{group generic}
%\title{S3 Group Generic Functions}
%\description{
%  Group generic methods can be defined for four pre-specified groups of
%  functions, \code{Math}, \code{Ops}, \code{Summary} and \code{Complex}.
%  (There are no オブジェクトs of these names in base \R, but there are in the
%  \pkg{methods} package.)
%
%  A method defined for an individual member of the group takes
%  precedence over a method defined for the group as a whole.
%}
%\usage{
%## S3 methods for group generics have prototypes:
%\special{Math(x, \dots)}
%\special{Ops(e1, e2)}
%\special{Complex(z)}
%\special{Summary(\dots, na.rm = FALSE)}
%}
%\arguments{
%  \item{x, z, e1, e2}{objects.}
%  \item{\dots}{further arguments passed to methods.}
%  \item{na.rm}{logical: should missing values be removed?}
%}
%
%\details{
%  %% --------------- grep -nw DispatchGroup src/*/*[ch]
%
%  There are four \emph{groups} for which S3 methods can be written,
%  namely the \code{"Math"}, \code{"Ops"}, \code{"Summary"} and
%  \code{"Complex"} groups.  These are not \R objects in base \R, but
%  methods can be supplied for them and base \R contains
%  \code{\link{factor}}, \code{\link{data.frame}} and
%  \code{\link{difftime}} methods for the first three groups.  (There is
%  also a \code{\link{ordered}} method for \code{Ops},
%  \code{\link{POSIXt}} and \code{\link{Date}} methods for \code{Math}
%  and \code{Ops}, \code{\link{package_version}} methods for \code{Ops}
%  and \code{Summary}, as well as a \code{\link{ts}} method for
%  \code{Ops} in package \pkg{stats}.)
%
%  \enumerate{
%    \item Group \code{"Math"}:
%    \itemize{
%      \item
%      \code{abs}, \code{sign}, \code{sqrt},\cr
%      \code{floor}, \code{ceiling}, \code{trunc},\cr
%      \code{round}, \code{signif}
%
%      \item
%      \code{exp}, \code{log},  \code{expm1}, \code{log1p},\cr
%      \code{cos}, \code{sin}, \code{tan},\cr
%      \code{cospi}, \code{sinpi}, \code{tanpi},\cr
%      \code{acos}, \code{asin}, \code{atan}
%
%      \code{cosh}, \code{sinh}, \code{tanh},\cr
%      \code{acosh}, \code{asinh}, \code{atanh}
%
%      \item
%      \code{lgamma}, \code{gamma}, \code{digamma}, \code{trigamma}
%      %   do_math1() [../../../main/arithmetic.c:794]: if (DispatchGroup("Math",...))
%      %
%      %
%      % "atan", "round", "log", "signif":
%      % do_atan()  [arithmetic.c:958]: if (DispatchGroup("Math", ..))
%      % do_round() [arithmetic.c:981]: if (DispatchGroup("Math", ..))
%      % do_log()   [arithmetic.c:1011]:if (DispatchGroup("Math", ..))
%      % do_signif()[arithmetic.c:1034]:if (DispatchGroup("Math", ..))
%
%      \item \code{cumsum}, \code{cumprod}, \code{cummax}, \code{cummin}
%      % do_cum()   [cum.c:140]:    if (DispatchGroup("Math", ...))
%    }
%    Members of this group dispatch on \code{x}.  Most members accept
%    only one argument, but members \code{log}, \code{round} and
%    \code{signif} accept one or two arguments, and \code{trunc} accepts
%    one or more.
%
%    \item Group \code{"Ops"}:
%    \itemize{
%      \item
%      \code{"+"}, \code{"-"}, \code{"*"}, \code{"/"},
%      \code{"^"}, \code{"\%\%"}, \code{"\%/\%"}
%      % do_arith() [arithmetic.c:240]: if (DispatchGroup("Ops", ...))
%
%      \item \code{"&"}, \code{"|"}, \code{"!"}
%      % do_logic() [logic.c:32]:   if (DispatchGroup("Ops",...))
%
%      \item \code{"=="}, \code{"!="},
%      \code{"<"}, \code{"<="}, \code{">="}, \code{">"}
%      % do_relop() [relop.c:35]:   if (DispatchGroup("Ops", ...))
%    }
%    This group contains both binary and unary operators (\code{+},
%    \code{-} and \code{!}): when a unary operator is encountered the
%    \code{Ops} method is called with one argument and \code{e2} is
%    missing.
%
%    The classes of both arguments are considered in dispatching any
%    member of this group.  For each argument its vector of classes is
%    examined to see if there is a matching specific (preferred) or
%    \code{Ops} method.  If a method is found for just one argument or
%    the same method is found for both, it is used.
%    If different methods are found, there is a warning about
%    \sQuote{incompatible methods}: in that case or if no method is found
%    for either argument the internal method is used.
%
%    If the members of this group are called as functions, any argument
%    names are removed to ensure that positional matching is always used.
%
%    \item Group \code{"Summary"}:
%    \itemize{
%      \item \code{all}, \code{any}
%      % do_logic3()[logic.c:278]:  if(DispatchGroup("Summary", ...))
%      \item \code{sum}, \code{prod}
%      % /*NOMORE:\code{mean}, */
%      \item \code{min}, \code{max}
%      % do_summary() [summary.c:322]: if(DispatchGroup("Summary",...))
%      \item \code{range}
%    }
%    Members of this group dispatch on the first argument supplied.
%
%    \item Group \code{"Complex"}:
%    \itemize{
%      \item \code{Arg}, \code{Conj}, \code{Im}, \code{Mod}, \code{Re}
%      % do_cmathfuns() [complex.c:267]: if(DispatchGroup("Complex",...))
%    }
%    Members of this group dispatch on \code{z}.
%  }
%
%  Note that a method will be used for one of these groups or one of its
%  members \emph{only} if it corresponds to a \code{"class"} attribute,
%  as the internal code dispatches on \code{\link{oldClass}} and not on
%  \code{\link{class}}.  This is for efficiency: having to dispatch on,
%  say, \code{Ops.integer} would be too slow.
%
%  The number of arguments supplied for primitive members of the
%  \code{"Math"} group generic methods is not checked prior to dispatch.
%
%  There is no lazy evaluation of arguments for group-generic functions.
%}
%\section{Technical Details}{
%  These functions are all primitive and \link{internal generic}.
%
%  The details of method dispatch and variables such as \code{.Generic}
%  are discussed in the help for \code{\link{UseMethod}}.  There are a
%  few small differences:
%  \itemize{
%    \item For the operators of group \code{Ops}, the object
%    \code{.Method} is a length-two character vector with elements the
%    methods selected for the left and right arguments respectively.  (If
%    no method was selected, the corresponding element is \code{""}.)
%    \item Object \code{.Group} records the group used for dispatch (if
%    a specific method is used this is \code{""}).
%  }
%}
%\note{
%  Package \pkg{methods} does contain objects with these names, which it
%  has re-used in confusing similar (but different) ways.  See the help
%  for that package.
%}
%\references{
%  Appendix A, \emph{Classes and Methods} of\cr
%  Chambers, J. M.  and Hastie, T. J. eds (1992)
%  \emph{Statistical Models in S.}
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{methods}} for methods of non-internal generic functions.
%
%  \link{S4groupGeneric} for group generics for S4 methods.
%}
%\examples{
%require(utils)
%
%d.fr <- data.frame(x = 1:9, y = stats::rnorm(9))
%class(1 + d.fr) == "data.frame" ##-- add to d.f. ...
%
%methods("Math")
%methods("Ops")
%methods("Summary")
%methods("Complex")  # none in base R
%}
%\keyword{methods}
%
\encoding{UTF8}
