% File src/library/base/man/interaction.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{interaction}
\title{Compute Factor Interactions}
\usage{
interaction(\dots, drop = FALSE, sep = ".", lex.order = FALSE)
}
\alias{interaction}
\arguments{
  \item{\dots}{その交互作用を計算すべき因子，または
    これらの因子を与える単一のリスト．}
  \item{drop}{もし \code{drop} が \code{TRUE} なら，未使用の水準は
    結果から取り除かれる．既定ではすべての因子水準を保存する．}
  \item{sep}{構成要素を結合して新しい水準を構成する文字列．}
  \item{lex.order}{論理値で，因子の結合の順序が辞書式でなされるべきかどうかを指示する．}
}
\description{
  \code{interaction} は与えられた因子の交互作用を表す因子を計算する．
  \code{interaction} の結果は常に順序付きではない．
}
\value{
  与えられた因子の交互作用を表す因子．
  水準は個別の因子の水準を \code{sep}，既定値は \code{.}，
  で連結したラベルを持つ．

  既定では，\code{lex.order = FALSE} の時は水準は最初の因子の水準が
  最も速く動き，二番目がそれに続き，等と順序付けられている．
  これは辞書式順序(\code{lex.order = TRUE} で得られる)の逆であり，
  \code{\link{:}} と異なる．(これは S との互換性ためそうされている．)
}
\references{
  Chambers, J. M. and Hastie, T. J. (1992)
  \emph{Statistical Models in S}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{factor}};
  \code{\link{:}}，ここで \code{f:g} は \code{f} と \code{g} が因子の時の
  \code{interaction(f, g, sep = ":")} に類似している．
}
\examples{
a <- gl(2, 4, 8)
b <- gl(2, 2, 8, labels = c("ctrl", "treat"))
s <- gl(2, 1, 8, labels = c("M", "F"))
interaction(a, b)
interaction(a, b, s, sep = ":")
stopifnot(identical(a:s,
                    interaction(a, s, sep = ":", lex.order = TRUE)),
          identical(a:s:b,
                    interaction(a, s, b, sep = ":", lex.order = TRUE)))
}
\keyword{category}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/interaction.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{interaction}
%\title{Compute Factor Interactions}
%\usage{
%interaction(\dots, drop = FALSE, sep = ".", lex.order = FALSE)
%}
%\alias{interaction}
%\arguments{
%  \item{\dots}{the factors for which interaction is to be computed, or a
%    single list giving those factors.}
%  \item{drop}{if \code{drop} is \code{TRUE}, unused factor levels
%    are dropped from the result.  The default is to retain all
%    factor levels.}
%  \item{sep}{string to construct the new level labels by joining the
%    constituent ones.}
%  \item{lex.order}{logical indicating if the order of factor concatenation
%    should be lexically ordered.}
%}
%\description{
%  \code{interaction} computes a factor which represents the interaction
%  of the given factors.  The result of \code{interaction} is always unordered.
%}
%\value{
%  A factor which represents the interaction of the given factors.
%  The levels are labelled as the levels of the individual factors joined
%  by \code{sep} which is \code{.} by default.
%
%  By default, when \code{lex.order = FALSE}, the levels are ordered so
%  the level of the first factor varies fastest, then the second and so
%  on.  This is the reverse of lexicographic ordering (which you can get
%  by  \code{lex.order = TRUE}), and differs from
%  \code{\link{:}}.  (It is done this way for compatibility with S.)
%}
%\references{
%  Chambers, J. M. and Hastie, T. J. (1992)
%  \emph{Statistical Models in S}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{factor}};
%  \code{\link{:}} where \code{f:g} is similar to
%  \code{interaction(f, g, sep = ":")} when \code{f} and  \code{g} are factors.
%}
%\examples{
%a <- gl(2, 4, 8)
%b <- gl(2, 2, 8, labels = c("ctrl", "treat"))
%s <- gl(2, 1, 8, labels = c("M", "F"))
%interaction(a, b)
%interaction(a, b, s, sep = ":")
%stopifnot(identical(a:s,
%                    interaction(a, s, sep = ":", lex.order = TRUE)),
%          identical(a:s:b,
%                    interaction(a, s, b, sep = ":", lex.order = TRUE)))
%}
%\keyword{category}
%
\encoding{UTF8}
