% File src/library/base/man/make.unique.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2008 R Core Team
% Distributed under GPL 2 or later

\name{make.unique}
\alias{make.unique}
\title{Make Character Strings Unique}
\description{
  文字列ベクトルの要素を重複するものに系列番号を加えることでユニークにする．
}
\usage{
make.unique(names, sep = ".")
}
\arguments{
  \item{names}{文字列ベクトル．}
  \item{sep}{重複する名前をその系列番号から分離するのに使われる文字列．}
}
\value{
  重複要素を変更した \code{names} と同じ長さの文字列ベクトルで，
  現在のロケールのエンコーディングを持つ．
}
\details{
  \code{make.unique} が使うアルゴリズムは次の性質を持つ\cr 
  \code{make.unique(c(A, B)) == make.unique(c(make.unique(A), B))}．

  換言すれば，いっときにベクトルに一つの文字列を加えることが出来，
  毎回それをユニークにし，そして全ての文字列に一度に
  \code{make.unique} を提供したのと同じ結果を得る．

  文字列ベクトル \code{A} が既にユニークなら，
  \code{make.unique(c(A, B))} は \code{A} を保存する．
}
\author{Thomas P. Minka}
\seealso{
  \code{\link{make.names}}
}
\examples{
make.unique(c("a", "a", "a"))
make.unique(c(make.unique(c("a", "a")), "a"))

make.unique(c("a", "a", "a.2", "a"))
make.unique(c(make.unique(c("a", "a")), "a.2", "a"))

rbind(data.frame(x = 1), data.frame(x = 2), data.frame(x = 3))
rbind(rbind(data.frame(x = 1), data.frame(x = 2)), data.frame(x = 3))
}
\keyword{character}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/make.unique.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2008 R Core Team
%% Distributed under GPL 2 or later
%
%\name{make.unique}
%\alias{make.unique}
%\title{Make Character Strings Unique}
%\description{
%  Makes the elements of a character vector unique by
%  appending sequence numbers to duplicates.
%}
%\usage{
%make.unique(names, sep = ".")
%}
%\arguments{
%  \item{names}{a character vector}
%  \item{sep}{a character string used to separate a duplicate name from
%    its sequence number.}
%}
%\value{
%  A character vector of same length as \code{names} with duplicates
%  changed, in the current locale's encoding.
%}
%\details{
%  The algorithm used by \code{make.unique} has the property that
%  \code{make.unique(c(A, B)) == make.unique(c(make.unique(A), B))}.
%
%  In other words, you can append one string at a time to a vector,
%  making it unique each time, and get the same result as applying
%  \code{make.unique} to all of the strings at once.
%
%  If character vector \code{A} is already unique, then
%  \code{make.unique(c(A, B))} preserves \code{A}.
%}
%\author{Thomas P. Minka}
%\seealso{
%  \code{\link{make.names}}
%}
%\examples{
%make.unique(c("a", "a", "a"))
%make.unique(c(make.unique(c("a", "a")), "a"))
%
%make.unique(c("a", "a", "a.2", "a"))
%make.unique(c(make.unique(c("a", "a")), "a.2", "a"))
%
%rbind(data.frame(x = 1), data.frame(x = 2), data.frame(x = 3))
%rbind(rbind(data.frame(x = 1), data.frame(x = 2)), data.frame(x = 3))
%}
%\keyword{character}
%
\encoding{UTF8}
