% File src/library/base/man/save.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{save}
\alias{save}
\alias{save.image}
\title{Save R Objects}
\description{
  \code{save} は \R オブジェクトの外部表現を指定されたファイルに書き出す．
  オブジェクトは \code{\link{load}} や \code{\link{attach}}
  (又はある場合には \code{\link{data}})で後から読み戻すことが出来る．.

  \code{save.image()} は\sQuote{作業空間を保存する}ショートカットである，
  つまり\cr
\code{save(list = ls(all.names = TRUE), file = ".RData", envir = .GlobalEnv)}．
これはまた \code{\link{q}("yes")} とした時起きることである．
}
\usage{
save(\dots, list = character(),
     file = stop("'file' must be specified"),
     ascii = FALSE, version = NULL, envir = parent.frame(),
     compress = isTRUE(!ascii), compression_level,
     eval.promises = TRUE, precheck = TRUE)

save.image(file = ".RData", version = NULL, ascii = FALSE,
           compress = !ascii, safe = TRUE)
}
\arguments{
  \item{\dots}{保存されるべきオブジェクトの名前(シンボル又は文字列)．}
  \item{list}{保存されるべきオブジェクトの名前を含む文字列ベクトル．}
  \item{file}{(書き込み可能なバイナリモードの)コネクションまたはデータが
    保存されるファイルの名前(チルド展開が行われる)．
    \code{save.image} に対してはファイル名又は
    \code{version = 1} でなければならない．}
  \item{ascii}{もし \code{TRUE} ならば，データのアスキー表現が書き込まれる．
    \code{ascii} に対する既定値は \code{FALSE} でバイナリファイルへの
    書き込みになる．もし \code{NA} で \code{version >= 2} ならば，
    倍精度/複素数をバイナリの分数で書き込む異なったアスキー表現を用いる．}
  \item{version}{使用する作業空間の書式．\code{NULL} は
    現在の既定書式を指定する．\R 0.99.0 から \R 1.3.1 はバージョン 1 である．
    \R 1.4.0 以来の既定書式はバージョン 2 である．}
  \item{envir}{保存すべきオブジェクトを探索する環境．}
  \item{compress}{名前付きのファイルの保存に圧縮を使うかどうか指定する
    論理近文字列．\code{TRUE} は \command{gzip} 圧縮に対応し，
    文字列 \code{"gzip"}, \code{"bzip2"} 又は \code{"xz"} は
    圧縮のタイプを指定する．\code{file} がコネクションと
    バージョン 1 の作業空間書式では無視される．}
  \item{compression_level}{整数：使用する圧縮のレベル．
    既定値は \command{gzip} に対しては \code{6}，
    \command{bzip2} 又は \command{xz} 圧縮には \code{9}．}
  \item{eval.promises}{論理値：予約であるオブジェクトは保存する前に強制すべきか．}
  \item{precheck}{論理値：保存前にオブジェクトの存在をチェックすべきか
    (そして特にファイル/コネクションを開く前に)?
    バージョン 1 保存には適用されない．}
  \item{safe}{論理値．もし \code{TRUE} ならば保存作業空間の作成のために
    一時ファイルが使われる．一時ファイルは保存が成功すると
    \code{file} に保管される．もし保存が失敗すると，これは既存の
    作業空間 \code{file} を保管するが，保存中に余分のディスクスペース
    を使うコストがかかる．}
}
\details{
  \code{\dots} 中のシンボル(又は文字列)または \code{list} 中の
  文字列ベクトルで指定されたオブジェクトの名前は
  環境 \code{envir} からオブジェクトを検索するのに使われる．
  既定では予約は評価されるが，もし \code{eval.promises = FALSE} なら
  予約は(評価環境と共に)保存される．
  (オブジェクトに埋め込まれた予約は常に未評価で保存される．)

  全ての \R のプラットフォームは C int と double の XDR (ビッグエンディアン) 表現
  をバイナリで保存されたファイルで使う．そしてこれらは全ての \R プラットフォーム
  を通して可搬性を持つ．

  アスキー保存はデータをプラットフォーム間で移動するのに有用であったが，しかし
  今では主に歴史的興味しか無い．それらは圧縮が使われない場合にはバイナリ保存よりも
  よりコンパクトになり得るが，しかしほとんど常に読み書き共に遅い：
  バイナリ保存はアスキーのそれよりはるかに良く圧縮できる．
  更に10進アスキー保存は倍精度/複素数値を正確に復元出来ないかもしれず，
  どのような値が復元できるかは \R プラットフォームに依存するかもしれない．

  \code{ascii}, \code{compress}, \code{safe} そして \code{version} 引数の
  既定値は \code{"save.defaults"} オプション(\code{save} と
  \code{save.image} 双方で使われる)で修正できる，\sQuote{例}も見よ．
  もし \code{"save.image.defaults"} オプションが設定されると，それは
  関数 \code{save.image} に対して \code{"save.defaults"} に優先して
  使われる(これはそれが異なった既定値を持つことを許す)．
  \code{compression_level} は \code{"save.defaults"} オプションの
  一部になり得る．

  既に開かれていないコネクションはモード \code{"wb"} で開かれる．
  開かれていてバイナリモードでないコネクションを与えることはエラーになる．
}

\section{比較}{
  大きなファイルは圧縮により相当サイズを減らせる．
  ある 46MB の \R オブジェクトは圧縮無しで 2 秒で 35MB として保存できる．
  \command{gzip} 圧縮では 8 秒で 22MB，
  \command{bzip2} 圧縮では 13 秒で 19MB，
  \command{xz} 圧縮では 40 秒で 9.4MB になった．
  ロード時間はそれぞれ 1.3, 2.8, 5.5 そして 5.7 秒であった．
  これらの結果は示唆的であるが，相対的なパフォーマンスは実際のファイル
  に依存する：ここでは \command{xz} は異常に優れた圧縮を行った．

  \code{compress = FALSE} で圧縮されたファイルを後で圧縮することが出来る
  (\command{gzip}, \command{bzip2} 又は \command{xz} を使って)：
  効果は圧縮付きで保存したものと同じである．同様に，保存されたファイルは
  異なった圧縮スキームの下で解凍したり再圧縮したり出来る
  (そして \R の内部からそれを行う方法については \code{\link{resaveRdaFiles}} を
  見よ)．
}

\section{並列圧縮}{
  \code{file} はコネクションでも良いことは
  \code{\link{pipe}} コネクションを使って \command{pigz}
  (\url{http://zlib.net/pigz/}) または \command{pbzip2}
  (\url{http://compression.ca/pbzip2/}) 等の外部並列圧縮ユーテリティ
  の利用を可能にする．例えば 8 スレッドを使って次のようにする
\preformatted{    con <- pipe("pigz -p8 > fname.gz", "wb")
    save(myObj, file = con); close(con)

    con <- pipe("pbzip2 -p8 -9 > fname.bz2", "wb")
    save(myObj, file = con); close(con)

    con <- pipe("xz -T8 -6 -e > fname.xz", "wb")
    save(myObj, file = con); close(con)
}
  ここで最後は多重スレッドに対するサポートを持つ \command{xz} 5.1.1
  又はそれ以降を必要とする(そして並列圧縮は大きなオブジェクトに対してだけ
  有効である：水準 6 ではそれは 12 Mb のシリアル化された塊を
  圧縮する)．
}

\note{
  失敗の最もありふれた理由は現在のディレクトリへの書き込み権限の欠如
  である．\code{save.image} とセッションの最後の保存に対しては
  これは次のようなメッセージで示される
\preformatted{    Error in gzfile(file, "wb") : unable to open connection
    In addition: Warning message:
    In gzfile(file, "wb") :
      cannot open compressed file '.RDataTmp',
      probable reason 'Permission denied'
}
#ifdef windows

  \code{file} は現在のロケールに翻訳できない UTF-8 でエンコードされた
  ファイルパスでも良い．
#endif
}

\section{警告}{
  \code{\dots} 引数は保存されるオブジェクトの\emph{名前}だけを与える：
  それらは \code{envir} 引数で与えられる環境中で探索され，
  引数で与えられた実際のオブジェクトは見つかったものである必要はない．

  保存された \R オブジェクトは \code{ascii = TRUE} で保存された場合すら
  バイナリファイルである．従ってそれらが行末マーカーの変換無しで
  8 ビット文字として転送されることを保証しなければならない．
  行は全てのプラットフォーム上で LF で区切られる．

  既定バージョンは \R 1.4.0 以来変更されていないが，これは
  保存されたファイルが後方互換的であることを必ずしも意味しない．
  保存されたイメージは，後に付け加えられたもの
  (例えばバイトベクトル，外部ポインターそして S4 オブジェクト)が
  利用されていなければ，
  \R の初期のバージョンにロードすることが出来る．

  そうした\sQuote{後で付け加えられたもの}には \R 3.0.0 で導入されたロングベクトル
  があり，64 ビットプラットフォームでだけロードできる．

  \code{ASCII = NA} で保存されたファイルのロードは
  C99 準拠の C 関数 \code{sscanf} が必要になる：
  これは Windows では問題であり，最初 \R 3.1.2 で応急処置がなされた：
  これらは全てのプラットフォーム上で初期の \R バージョンで読み込み
  可能であるべきである．
}
\seealso{
  \code{\link{dput}}, \code{\link{dump}}, \code{\link{load}},
  \code{\link{data}}.

  基礎にあるシリアル化書式への他のインタフェイスに付いては
  \code{\link{serialize}} と \code{\link{saveRDS}} を見よ．
}
\examples{
x <- stats::runif(20)
y <- list(a = 1, b = TRUE, c = "oops")
save(x, y, file = "xy.RData")
save.image()
unlink("xy.RData")
unlink(".RData")

# オプションを使って保存既定値を設定する：
options(save.defaults = list(ascii = TRUE, safe = FALSE))
save.image()
unlink(".RData")
}
\keyword{file}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/save.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{save}
%\alias{save}
%\alias{save.image}
%\title{Save R Objects}
%\description{
%  \code{save} writes an external representation of \R objects to the
%  specified file.  The objects can be read back from the file at a later
%  date by using the function \code{\link{load}} or \code{\link{attach}}
%  (or \code{\link{data}} in some cases).
%
%  \code{save.image()} is just a short-cut for \sQuote{save my current
%    workspace}, i.e., \code{save(list = ls(all.names = TRUE), file =
%    ".RData", envir = .GlobalEnv)}.
%  It is also what happens with \code{\link{q}("yes")}.
%}
%\usage{
%save(\dots, list = character(),
%     file = stop("'file' must be specified"),
%     ascii = FALSE, version = NULL, envir = parent.frame(),
%     compress = isTRUE(!ascii), compression_level,
%     eval.promises = TRUE, precheck = TRUE)
%
%save.image(file = ".RData", version = NULL, ascii = FALSE,
%           compress = !ascii, safe = TRUE)
%}
%\arguments{
%  \item{\dots}{the names of the objects to be saved (as symbols or
%    character strings).}
%  \item{list}{A character vector containing the names of objects to be
%    saved.}
%  \item{file}{a (writable binary-mode) \link{connection} or the name of the
%    file where the data will be saved (when \link{tilde expansion}
%    is done).  Must be a file name for \code{save.image} or
%    \code{version = 1}.}
%  \item{ascii}{if \code{TRUE}, an ASCII representation of the data is
%    written.  The default value of \code{ascii} is \code{FALSE} which
%    leads to a binary file being written.  If \code{NA} and
%    \code{version >= 2}, a different ASCII representation is used which
%    writes double/complex numbers as binary fractions.}
%  \item{version}{the workspace format version to use.  \code{NULL}
%    specifies the current default format.  The version used from \R
%    0.99.0 to \R 1.3.1 was version 1.  The default format as from \R
%    1.4.0 is version 2.}
%  \item{envir}{environment to search for objects to be saved.}
%  \item{compress}{logical or character string specifying whether saving
%    to a named file is to use compression.  \code{TRUE} corresponds to
%    \command{gzip} compression, and character strings \code{"gzip"},
%    \code{"bzip2"} or \code{"xz"} specify the type of
%    compression.  Ignored when \code{file} is a connection and
%    for workspace format version 1.}
%  \item{compression_level}{integer: the level of compression to be
%    used.  Defaults to \code{6} for \command{gzip} compression and to
%    \code{9} for \command{bzip2} or \command{xz} compression.}
%  \item{eval.promises}{logical: should objects which are promises be
%    forced before saving?}
%  \item{precheck}{logical: should the existence of the objects be
%    checked before starting to save (and in particular before opening
%    the file/connection)?  Does not apply to version 1 saves.}
%  \item{safe}{logical.  If \code{TRUE}, a temporary file is used for
%    creating the saved workspace.  The temporary file is renamed to
%    \code{file} if the save succeeds.  This preserves an existing
%    workspace \code{file} if the save fails, but at the cost of using
%    extra disk space during the save.}
%}
%\details{
%  The names of the objects specified either as symbols (or character
%  strings) in \code{\dots} or as a character vector in \code{list} are
%  used to look up the objects from environment \code{envir}.  By default
%  \link{promises} are evaluated, but if \code{eval.promises = FALSE}
%  promises are saved (together with their evaluation environments).
%  (Promises embedded in objects are always saved unevaluated.)
%
%  All \R platforms use the XDR (bigendian) representation of C ints and
%  doubles in binary save-d files, and these are portable across all \R
%  platforms.
%
%  ASCII saves used to be useful for moving data between platforms but
%  are now mainly of historical interest.  They can be more compact than
%  binary saves where compression is not used, but are almost always
%  slower to both read and write: binary saves compress much better than
%  ASCII ones.  Further, decimal ASCII saves may not restore
%  double/complex values exactly, and what value is restored may depend
%  on the \R platform.
%
%  Default values for the \code{ascii}, \code{compress}, \code{safe} and
%  \code{version} arguments can be modified with the
%  \code{"save.defaults"} option (used both by \code{save} and
%  \code{save.image}), see also the \sQuote{Examples} section.  If a
%  \code{"save.image.defaults"} option is set it is used in preference to
%  \code{"save.defaults"} for function \code{save.image} (which allows
%  this to have different defaults).  In addition,
%  \code{compression_level} can be part of the \code{"save.defaults"}
%  option.
%
%  A connection that is not already open will be opened in mode
%  \code{"wb"}.  Supplying a connection which is open and not in binary
%  mode gives an error.
%}
%
%\section{Compression}{
%  Large files can be reduced considerably in size by compression.  A
%  particular 46MB \R object was saved as 35MB without compression in 2
%  seconds, 22MB with \command{gzip} compression in 8 secs, 19MB with
%  \command{bzip2} compression in 13 secs and 9.4MB with \command{xz}
%  compression in 40 secs.  The load times were 1.3, 2.8, 5.5 and 5.7
%  seconds respectively.  These results are indicative, but the relative
%  performances do depend on the actual file: \command{xz} compressed
%  unusually well here.
%
%  It is possible to compress later (with \command{gzip}, \command{bzip2}
%  or \command{xz}) a file saved with \code{compress = FALSE}: the effect
%  is the same as saving with compression.  Also, a saved file can be
%  uncompressed and re-compressed under a different compression scheme
%  (and see \code{\link{resaveRdaFiles}} for a way to do so from within \R).
%}
%
%\section{Parallel compression}{
%  That \code{file} can be a connection can be exploited to make use of
%  an external parallel compression utility such as \command{pigz}
%  (\url{http://zlib.net/pigz/}) or \command{pbzip2}
%  (\url{http://compression.ca/pbzip2/}) \emph{via} a \code{\link{pipe}}
%  connection.  For example, using 8 threads,
%\preformatted{    con <- pipe("pigz -p8 > fname.gz", "wb")
%    save(myObj, file = con); close(con)
%
%    con <- pipe("pbzip2 -p8 -9 > fname.bz2", "wb")
%    save(myObj, file = con); close(con)
%
%    con <- pipe("xz -T8 -6 -e > fname.xz", "wb")
%    save(myObj, file = con); close(con)
%}
%  where the last requires \command{xz} 5.1.1 or later built with support
%  for multiple threads (and parallel compression is only effective for
%  large objects: at level 6 it will compress in serialized chunks of 12MB).
%}
%
%\note{
%  The most common reason for failure is lack of write permission in the
%  current directory.  For \code{save.image} and for saving at the end of
%  a session this will shown by messages like
%\preformatted{    Error in gzfile(file, "wb") : unable to open connection
%    In addition: Warning message:
%    In gzfile(file, "wb") :
%      cannot open compressed file '.RDataTmp',
%      probable reason 'Permission denied'
%}
%#ifdef windows
%
%  \code{file} can be a UTF-8-encoded filepath that cannot be translated to
%  the current locale.
%#endif
%}
%
%\section{Warnings}{
%  The \code{\dots} arguments only give the \emph{names} of the objects
%  to be saved: they are searched for in the environment given by the
%  \code{envir} argument, and the actual objects given as arguments need
%  not be those found.
%
%  Saved \R objects are binary files, even those saved with
%  \code{ascii = TRUE}, so ensure that they are transferred without
%  conversion of end-of-line markers and of 8-bit characters.  The lines
%  are delimited by LF on all platforms.
%
%  Although the default version has not changed since \R 1.4.0, this
%  does not mean that saved files are necessarily backwards compatible.
%  You will be able to load a saved image into an earlier version of \R
%  unless use is made of later additions (for example, raw vectors,
%  external pointers and some S4 objects).
%
%  One such \sQuote{later addition} was long vectors, introduced in \R
%  3.0.0 and loadable only on 64-bit platforms.
%
%  Loading files saved with \code{ASCII = NA} requires a C99-compliant C
%  function \code{sscanf}: this is a problem on Windows, first worked
%  around in \R 3.1.2: they should be readable in earlier versions of \R
%  on all other platforms.
%}
%\seealso{
%  \code{\link{dput}}, \code{\link{dump}}, \code{\link{load}},
%  \code{\link{data}}.
%
%  For other interfaces to the underlying serialization format, see
%  \code{\link{serialize}} and \code{\link{saveRDS}}.
%}
%\examples{
%x <- stats::runif(20)
%y <- list(a = 1, b = TRUE, c = "oops")
%save(x, y, file = "xy.RData")
%save.image()
%unlink("xy.RData")
%unlink(".RData")
%
%# set save defaults using option:
%options(save.defaults = list(ascii = TRUE, safe = FALSE))
%save.image()
%unlink(".RData")
%}
%\keyword{file}
%
\encoding{UTF8}
