% File src/library/compiler/man/compile.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2011 R Core Team
% Distributed under GPL 2 or later

\name{compile}
\alias{compile}
\alias{cmpfun}
\alias{cmpfile}
\alias{loadcmp}
\alias{disassemble}
\alias{enableJIT}
\alias{compilePKGS}
\alias{getCompilerOption}
\alias{setCompilerOptions}
\title{Byte Code Compiler}
\usage{
cmpfun(f, options = NULL)
compile(e, env = .GlobalEnv, options = NULL)
cmpfile(infile, outfile, ascii = FALSE, env = .GlobalEnv,
        verbose = FALSE, options = NULL)
loadcmp(file, envir = .GlobalEnv, chdir = FALSE)
disassemble(code)
enableJIT(level)
compilePKGS(enable)
getCompilerOption(name, options)
setCompilerOptions(...)
}
\arguments{
  \item{f}{クロージャ．}
  \item{options}{名前付きコンパイラオプションのリスト．}
  \item{env}{コンパイルのためのトップレベル環境．}
  \item{file,infile,outfile}{パス名；出力ファイルの既定値は
    入力ファイルの拡張子を .Rc に変えたものである．}
  \item{ascii}{論理値；コンパイル済みファイルはアスキー書式で
    保存すべきか?}
  \item{verbose}{論理値；コンパイラーは途中経過を表示すべきか．}
  \item{envir}{ロードされた表現式をそのなかで評価する環境．}
  \item{chdir}{論理値；評価前にディレクトリを変更すべきか?}
  \item{code}{バイトコード表現式かコンパイル済みクロージャ．}
  \item{e}{コンパイルする表現式．}
  \item{level}{整数；使用する JIT レベル．}
  \item{enable}{論理値；もし \code{TRUE} ならばパッケージのコンパイルを可能にする．}
  \item{name}{文字列；返すべきオプションの名前．}
  \item{...}{設定する名前付きコンパイルオプション．}
}
\description{
  これらの関数は R に対するバイトコードコンパイルへの
  インタフェイスを提供する．
}
\details{
  関数 \code{cmpfun} はクロージャの本体をコンパイルし
  同じ形式引数部とコンパイル済みの本体表現式に置き換えられた本体を持つ
  新しいクロージャを返す．

  \code{compile} は表現式をバイトコードオブジェクトにコンパイルする；
  オブジェクトはそれから \code{eval} で評価できる．

  \code{cmpfile} は
  \code{infile} 中の表現式を構文解析し，それらをコンパイルし，
  それからコンパイル済みの表現式を
  \code{outfile} に書き込む．もし
  \code{outfile} が与えられていないと，それは
  \code{infile} の拡張子を
  \code{.Rc} に変換又は付加したものになる．

  \code{loadcmp} はコンパイルされたファイルをロードするのに使われる．
  これは \code{sys.source} に似ているが，その既定の
  環境が基礎環境ではなく大局的環境であることが異なる．

  \code{disassemble} はコードのプリント形式の表現を
  作り，何が行われるのかのヒントを与えるのに役に立つかもしれない．

  \code{enableJIT} はジャストインタイム(JIT)・コンパイルを有効にしたり無効にしたりする．
  引数が 0 ならば JIT は無効になる．
  もし \code{enable} が 1 ならばクロージャはその最初の使用の前に
  コンパイルされる．
  もし \code{enable} が 2 ならば，加えてクロージャはそれらが
  複製される前にコンパイルされる
  (\code{lattice} のようなリスト中にクロージャを保管する
  パッケージに対して役に立つ)．
  もし \code{enable} が 3 ならば更に全てのループが実行前にコンパイルされる．
  レベル 3 の JIT は最適化レベル 2 か 3 を必要とする．
  JIT は又環境変数 \code{R_ENABLE_JIT} をこれらの値の一つに設定して \R を
  開始しても有効に出来る．
  \code{enableJIT} を負の値で呼び出すと現在の JIT レベルを返す．

  \code{compilePKGS} はパッケージをインストールする際に
  コンパイルすることを有効にしたり無効にしたりする．
  コンパイルは関数が遅延ロードのデータベースに書き込まれるときに
  行われるため，これはパッケージが遅延ロードを使っている必要がある．
  これは又
  環境変数 \code{R_COMPILE_PKGS} を正の整数値に設定して
  \R を開始しても有効に出来る．

  現在コンパイラーは様々な事柄について警告する．
  これは \code{cat} を使ってメッセージをプリントする．
  いつかはこれは条件付き処理機構を使うべきである．

  \code{options} 引数はコンパイラの操作を制御できる．
  現在三つのオプションがある：
  \code{optimize}, \code{suppressAll} そして \code{suppressUndefined}
  である．\code{optimize} は最適化のレベルを指定し，
  0 から 3 までの整数である．
  \code{suppressAll} はスカラの論理値でなければならない；
  もし \code{TRUE} ならメッセージは一切表示されない．
  \code{suppressUndefined} が \code{TRUE} なら
  未定義の変数に関するメッセージが抑制され，
  もしくはそれはメッセージの表示を抑制する変数名のベクトルでも良い．

  \code{getCompilerOption} は指定されたオプションの値を返す．
  \code{options} 引数中に値が提供されない限り既定値が返される；
  \code{options} 引数は主に内部用である．
  \code{setCompilerOption} は既定のオプションの値を設定する．
  それは以前の値の名前付きリストを返す．

  コンパイラをバイトコードコンパイラと呼ぶのは
  実際には不適切である：
  コードオブジェクトの外部表現は現在
  \code{int} オペランドを使っており，
  \code{gcc} でコンパイルすると内部表現は実際は
  バイトコードではなくスレッド化されたコードである．
}
\author{Luke Tierney}

\examples{
# 簡単な例
f <- function(x) x+1
fc <- cmpfun(f)
fc(2)
disassemble(fc)

# lapply の古い R バージョン
la1 <- function(X, FUN, ...) {
    FUN <- match.fun(FUN)
    if (!is.list(X))
	X <- as.list(X)
    rval <- vector("list", length(X))
    for(i in seq(along = X))
	rval[i] <- list(FUN(X[[i]], ...))
    names(rval) <- names(X)		  # `names' を保存!
    return(rval)
}
# 少し変更
la2 <- function(X, FUN, ...) {
    FUN <- match.fun(FUN)
    if (!is.list(X))
	X <- as.list(X)
    rval <- vector("list", length(X))
    for(i in seq(along = X)) {
        v <- FUN(X[[i]], ...)
        if (is.null(v)) rval[i] <- list(v)
        else rval[[i]] <- v
    }
    names(rval) <- names(X)		  # `names' を保存!
    return(rval)
}
# コンパイルされたバージョン
la1c <- cmpfun(la1)
la2c <- cmpfun(la2)
# あるタイミング
x <- 1:10
y <- 1:100
\donttest{
system.time(for (i in 1:10000) lapply(x, is.null))
system.time(for (i in 1:10000) la1(x, is.null))
system.time(for (i in 1:10000) la1c(x, is.null))
system.time(for (i in 1:10000) la2(x, is.null))
system.time(for (i in 1:10000) la2c(x, is.null))
system.time(for (i in 1:1000) lapply(y, is.null))
system.time(for (i in 1:1000) la1(y, is.null))
system.time(for (i in 1:1000) la1c(y, is.null))
system.time(for (i in 1:1000) la2(y, is.null))
system.time(for (i in 1:1000) la2c(y, is.null))
}
\testonly{
for (i in 1:10000) lapply(x, is.null)
for (i in 1:10000) la1(x, is.null)
for (i in 1:10000) la1c(x, is.null)
for (i in 1:10000) la2(x, is.null)
for (i in 1:10000) la2c(x, is.null)
for (i in 1:1000) lapply(y, is.null)
for (i in 1:1000) la1(y, is.null)
for (i in 1:1000) la1c(y, is.null)
for (i in 1:1000) la2(y, is.null)
for (i in 1:1000) la2c(y, is.null)
}}
\keyword{programming}

\encoding{UTF8}
