% File src/library/datasets/man/LifeCycleSavings.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{LifeCycleSavings}
\docType{data}
\title{ライフサイクル貯蓄データ}
\alias{LifeCycleSavings}
%%\title{Intercountry Life-Cycle Savings Data}
\description{
  1960--1970年の貯蓄率データ．.
}
\usage{LifeCycleSavings}
\format{
  50 観測値と 5 変数を持つデータフレーム．
  \tabular{rlll}{
    [,1]  \tab sr    \tab 数値  \tab 累積個人貯蓄 \cr
    [,2]  \tab pop15 \tab 数値  \tab 15才以下の人口 \%\cr
    [,3]  \tab pop75 \tab 数値  \tab 75才以上の人口 \%\cr
    [,4]  \tab dpi   \tab 数値  \tab 一人あたりの可処分所得 \cr
    [,5]  \tab ddpi  \tab numeric  \tab 可処分所得の増加率 
  }
}
\source{
  このデータは Belsley, Kuh and Welsch (1980) から得られた．
  それらは更に Sterling (1977) のデータから得られた．
}
\details{
  Franco Modigliani のライフサイクル貯蓄仮説によれば．
  貯蓄率(可処分所得で割られた累計個人貯蓄)は，
  一人あたりの収入，一人あたりの収入のパーセント変化率，そして
  二つの民生変数：15才未満の人口パーセントと
  75才以上の人口パーセント，で説明できる．
  このデータはビジネスサイクルや他の短期間変動を除くために
  期間 1960--1970 で平均されている．
}
\references{
  Sterling, Arnie (1977) Unpublished BS Thesis.
  Massachusetts Institute of Technology.

  Belsley, D. A., Kuh. E. and Welsch, R. E. (1980)
  \emph{Regression Diagnostics}.
  New York: Wiley.
}
\examples{
require(stats); require(graphics)
pairs(LifeCycleSavings, panel = panel.smooth,
      main = "LifeCycleSavings data")
fm1 <- lm(sr ~ pop15 + pop75 + dpi + ddpi, data = LifeCycleSavings)
summary(fm1)
}
\keyword{datasets}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/datasets/man/LifeCycleSavings.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{LifeCycleSavings}
%\docType{data}
%\alias{LifeCycleSavings}
%\title{Intercountry Life-Cycle Savings Data}
%\description{
%  Data on the savings ratio 1960--1970.
%}
%\usage{LifeCycleSavings}
%\format{
%  A data frame with 50 observations on 5 variables.
%  \tabular{rlll}{
%    [,1]  \tab sr    \tab numeric  \tab aggregate personal savings \cr
%    [,2]  \tab pop15 \tab numeric  \tab \% of population under 15 \cr
%    [,3]  \tab pop75 \tab numeric  \tab \% of population over 75 \cr
%    [,4]  \tab dpi   \tab numeric  \tab real per-capita disposable
%    income \cr
%    [,5]  \tab ddpi  \tab numeric  \tab \% growth rate of dpi
%  }
%}
%\source{
%  The data were obtained from Belsley, Kuh and Welsch (1980).
%  They in turn obtained the data from Sterling (1977).
%}
%\details{
%  Under the life-cycle savings hypothesis as developed by Franco
%  Modigliani, the savings ratio (aggregate personal saving divided by
%  disposable income) is explained by per-capita disposable income, the
%  percentage rate of change in per-capita disposable income, and two
%  demographic variables: the percentage of population less than 15
%  years old and the percentage of the population over 75 years old.
%  The data are averaged over the decade 1960--1970 to remove the
%  business cycle or other short-term fluctuations.
%}
%\references{
%  Sterling, Arnie (1977) Unpublished BS Thesis.
%  Massachusetts Institute of Technology.
%
%  Belsley, D. A., Kuh. E. and Welsch, R. E. (1980)
%  \emph{Regression Diagnostics}.
%  New York: Wiley.
%}
%\examples{
%require(stats); require(graphics)
%pairs(LifeCycleSavings, panel = panel.smooth,
%      main = "LifeCycleSavings data")
%fm1 <- lm(sr ~ pop15 + pop75 + dpi + ddpi, data = LifeCycleSavings)
%summary(fm1)
%}
%\keyword{datasets}
%
%\encoding{UTF8}
%