% File src/library/datasets/man/morley.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{morley}
\docType{data}
\alias{morley}
\title{Michelson Speed of Light Data}
\description{
  Michelson (しかし Morley と一緒のではない)の1879年に行われた光の速度
  に関する古典的なデータ．
  データは5回の実験からなり，各々は20回の
  引き続く \sQuote{実行}からなる．
  応答は光の速度の測定値であり，適当にコードされている
  (単位 km/sec で \code{299000} が引かれている)．
}
\usage{
morley
}
\format{
  次の3変数に対する 100 観測値からなるデータフレームである．
  \describe{
    \item{\code{Expt}}{実験番号．1 から 5．}
    \item{\code{Run}}{各実験内の実行番号．}
    \item{\code{Speed}}{光の速度の測定値．}
  }
}
\details{
  このデータはここでは
  \sQuote{experiment} と \sQuote{run} を因子とするランダムブロック実験として
  眺められる．
  \sQuote{run} はまた一つの実験のコースに関する測定値の
  線形(又は多項式)的変化を説明する量的変数と考えられる．
}
\note{
  これはパッケージ \CRANpkg{MASS} 中のデータセット \code{michelson}
  と同じものである．
  
}
\source{
  A. J. Weekes (1986)
  \emph{A Genstat Primer}.
  London: Edward Arnold.

  S. M. Stigler (1977)
  Do robust estimators work with real data?
  \emph{Annals of Statistics} \bold{5}, 1055--1098. (See Table 6.)

  A. A. Michelson (1882)
  Experimental determination of the velocity of light made at the United
  States Naval Academy, Annapolis.
  \emph{Astronomic Papers} \bold{1} 135--8.
  U.S. Nautical Almanac Office.  (See Table 24.)
}
\examples{
require(stats); require(graphics)
michelson <- transform(morley,
                       Expt = factor(Expt), Run = factor(Run))
xtabs(~ Expt + Run, data = michelson)  # 5 x 20 釣り合い型(二元)
plot(Speed ~ Expt, data = michelson,
     main = "Speed of Light Data", xlab = "Experiment No.")
fm <- aov(Speed ~ Run + Expt, data = michelson)
summary(fm)
fm0 <- update(fm, . ~ . - Run)
anova(fm0, fm)
}
\keyword{datasets}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/datasets/man/morley.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{morley}
%\docType{data}
%\alias{morley}
%\title{Michelson Speed of Light Data}
%\description{
%  A classical data of Michelson (but not this one with Morley) on
%  measurements done in 1879 on the speed of light.  The data consists of
%  five experiments, each consisting of 20 consecutive \sQuote{runs}.
%  The response is the speed of light measurement, suitably coded
%  (km/sec, with \code{299000} subtracted).
%}
%\usage{
%morley
%}
%\format{
%  A data frame with 100 observations on the following 3 variables.
%  \describe{
%    \item{\code{Expt}}{The experiment number, from 1 to 5.}
%    \item{\code{Run}}{The run number within each experiment.}
%    \item{\code{Speed}}{Speed-of-light measurement.}
%  }
%}
%\details{
%  The data is here viewed as a randomized block experiment with
%  \sQuote{experiment} and \sQuote{run} as the factors.  \sQuote{run} may
%  also be considered a quantitative variate to account for linear (or
%  polynomial) changes in the measurement over the course of a single
%  experiment.
%}
%\note{
%  This is the same dataset as \code{michelson} in package
%  \CRANpkg{MASS}.
%}
%\source{
%  A. J. Weekes (1986)
%  \emph{A Genstat Primer}.
%  London: Edward Arnold.
%
%  S. M. Stigler (1977)
%  Do robust estimators work with real data?
%  \emph{Annals of Statistics} \bold{5}, 1055--1098. (See Table 6.)
%
%  A. A. Michelson (1882)
%  Experimental determination of the velocity of light made at the United
%  States Naval Academy, Annapolis.
%  \emph{Astronomic Papers} \bold{1} 135--8.
%  U.S. Nautical Almanac Office.  (See Table 24.)
%}
%\examples{
%require(stats); require(graphics)
%michelson <- transform(morley,
%                       Expt = factor(Expt), Run = factor(Run))
%xtabs(~ Expt + Run, data = michelson)  # 5 x 20 balanced (two-way)
%plot(Speed ~ Expt, data = michelson,
%     main = "Speed of Light Data", xlab = "Experiment No.")
%fm <- aov(Speed ~ Run + Expt, data = michelson)
%summary(fm)
%fm0 <- update(fm, . ~ . - Run)
%anova(fm0, fm)
%}
%\keyword{datasets}
%
%\encoding{UTF8}
%
