% File src/library/grDevices/man/dev2.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{dev2}
\title{複数のデバイス間でグラフィックスをコピー}
\alias{dev.copy}
\alias{dev.print}
\alias{dev.copy2eps}
\alias{dev.copy2pdf}
\alias{dev.control}
%%\title{Copy Graphics Between Multiple Devices}
\usage{
dev.copy(device, \dots, which = dev.next())
dev.print(device = postscript, \dots)
dev.copy2eps(\dots)
dev.copy2pdf(\dots, out.type = "pdf")
dev.control(displaylist = c("inhibit", "enable"))
}
\arguments{
  \item{device}{デバイス関数(例えば，\code{x11},
    \code{postscript}, \ldots)．}
  \item{\dots}{上の \code{device} 関数への引数：
    \code{\link{postscript}} への \code{dev.copy2eps} 引数と\cr
    \code{dev.copy2pdf} に対しては \code{\link{pdf}} への引数．
    \code{dev.print} に対しては，これは \code{which} を含み，既定で
    任意の \code{\link{postscript}} 引数を含む．}
  \item{which}{コピー先のデバイスを指定するデバイス番号．}
  \item{out.type}{出力デバイス番号：
    \code{"pdf"}, \code{"quartz"} (ある種の OS X ビルド)又は
    \code{"cairo"} (Windows とある種の Unix 風システム，
    \code{\link{cairo_pdf}} を見よ)が可能．}
  \item{displaylist}{文字列：唯一の適正な値は
    \code{"inhibit"} と \code{"enable"}．}
}
\description{
  \code{dev.copy} は現在のデバイスのグラフィックスの内容を
  \code{which} で指定されるデバイス，又は \code{device}
  (\code{which} と \code{device} の両方を指定するのはエラーになる)
  で指定される関数で作られる新しいデバイスにコピーする．
  (もし現在のデバイス上で記録が停止されていれば，コピーする
  内容はない：これはプロット無しか空のプロットになる．)
  コピーされたデバイスは現在のデバイスになる．

  \code{dev.print} は現在のデバイスのグラフィックスの内容を
  \code{device} で指定される関数で作られる新しいデバイスにコピーし，
  それから新しいデバイスを閉じる．

  \code{dev.copy2eps} は \code{dev.print} に似るが
  ポートレイトの向き(\code{horizontal = FALSE})の
  EPSF 出力ファイルを作る．
  \code{dev.copy2pdf} は PDF 出力に対する類似物である．

  \code{dev.control} はユーザが
  デバイス中のグラフィックス内容の記録を制御することを許す．
  もし \code{displaylist} が \code{"inhibit"}
  (\code{"enable"}) ならば記録はオフ(オン)になる．
  これを変更するのはプロットの最初でだけが安全である
  (新しいページの直前又は直後)．
  最初スクリーンデバイスに対しては記録はオンで，
  プリントデバイスに対してはオフである．
}
\value{
  \code{dev.copy} はコピーされたデバイスの名前と番号を返す．

  \code{dev.print}, \code{dev.copy2eps} そして \code{dev.copy2pdf}
  はそこからコピーされたデバイスの名前と番号を返す．
}
\details{
  これらの関数は\emph{デバイス領域}をコピーしプロットをコピーするのではないことを
  注意する：デバイス面の背景色はコピーされるものの一部である．
  殆どのスクリーンデバイスは既定で透明な背景を持ち，
  それは恐らく
  \code{\link{png}} のようなデバイスへコピーする際に必要とされるものではない．

  \code{dev.copy2eps} と \code{dev.copy2pdf} に対しては，\code{width} と
  \code{height} はそれ以外が指定されていない限り現在のデバイスから
  取られる．
  もし \code{width} と \code{height} のどちらかだけが指定されると，他は
  コピーされるデバイスのアスペクト比を保つように補正される．
  既定のファイル名は \code{Rplot.eps} か \code{Rplot.pdf} であり，
  \code{file} 引数を指定することで上書きできる．

  フォントファミリを予め指定する必要がある \code{\link{postscript}} と
  \code{\link{pdf}} のようなデバイスへのコピーは
  特別な注意が必要になる
  -- \R はどのフォントファミリが使われていたかは知らないので，
  それらは
  \code{\dots} の一部として渡される \code{fonts} 引数で手動で
  指定する必要がある．
  同様に，もしコピーされるデバイスが
  \code{family} 引数付きで開かれていると，適当な
  \code{family} 引数が
  \code{\dots} 中に含められる必要がある．

  \code{dev.print} に対する既定はポストスクリプトコピーを
  作りコピーすることである．
  これは \code{\link{options}("printcmd")} が適当に設定され，
  ポストスクリプトをプリントできるシステムで
  ないと動作しない：
  これをそのように設定するかは
  \code{\link{postscript}} を見よ．
  Windows のユーザは
  \code{dev.print(win.print)} を使う方を好むかもしれない．

  \code{dev.print} は以下が当てはまる場合は
  ポストスクリプトのプリントを作る(既定)のに最も有用である．
  \code{file} が指定されていない限りプロットがプリントされる．
  \code{width}, \code{height} そして \code{pointsize} が指定されていない限り，
  プロットの次元は現在のデバイスから取られ，
  用紙に適合するように必要なら縮小される．
  (\code{pointsize} はもしプロットが縮小されるならば再スケール化される．)
  もし \code{horizontal} が指定されずプロットがその値を
  切り替えることでフルサイズでプリントできるのならば，
  プロット領域を縮小する代わりにこれが行われる．

  もし \code{dev.print} が指定された \code{device}
  で使われるのなら(\code{postscript} ですら)，それは幅と高さを
  \code{dev.copy2eps} と同様に設定する．
  これはデバイスが次元をインチで指定しない限り適切ではない．
  特に \code{units = "inches"} が指定されない限り
  \code{png}, \code{jpeg}, \code{tiff} そして \code{bmp}
  に対してそうである．
}
\note{
  殆どのデバイス(全てのスクリーンデバイスを含む)はデバイス中で起きた全ての
  グラフィックス操作を記録するディスプレイリストを持つ．
  \code{dev.copy} はグラフィックスの内容をディスプレイリストを
  一つのデバイスから別のデバイスにコピーすることでグラフィックスの内容を
  コピーする．同様に．デバイスのサイズ変更に続く
  グラフィックスの内容の自動再描画も
  ディスプレイリストの内容に依存する．

  \code{dev.control("inhibit")} の後では，グラフィックス操作は
  ディスプレイリストに記録されないので，
  \code{dev.copy} と \code{dev.print} は何もコピーせず，
  デバイスの内容はデバイスのサイズが変更されても自動的には再描画されない．

  グラフィックス操作の記録は相対的にメモリーの観点から高く付くので，
  もしメモリー使用が問題になる
  ならば命令 \code{dev.control("inhibit")} は有用になり得る．
}
\seealso{
  \code{\link{dev.cur}} そして他の \code{dev.xxx} 関数．
}
\examples{
\dontrun{
x11() # Unix 風システムで
plot(rnorm(10), main = "Plot 1")
dev.copy(device = x11)
mtext("Copy 1", 3)
dev.print(width = 6, height = 6, horizontal = FALSE) # それをプリント
dev.off(dev.prev())
dev.off()
}
}
\keyword{device}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/dev2.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{dev2}
%\alias{dev.copy}
%\alias{dev.print}
%\alias{dev.copy2eps}
%\alias{dev.copy2pdf}
%\alias{dev.control}
%\title{Copy Graphics Between Multiple Devices}
%\usage{
%dev.copy(device, \dots, which = dev.next())
%dev.print(device = postscript, \dots)
%dev.copy2eps(\dots)
%dev.copy2pdf(\dots, out.type = "pdf")
%dev.control(displaylist = c("inhibit", "enable"))
%}
%\arguments{
%  \item{device}{A device function (e.g., \code{x11},
%    \code{postscript}, \ldots)}
%  \item{\dots}{Arguments to the \code{device} function above: for
%    \code{dev.copy2eps} arguments to \code{\link{postscript}} and for
%    \code{dev.copy2pdf}, arguments to \code{\link{pdf}}.
%    For \code{dev.print}, this includes \code{which} and by default any
%    \code{\link{postscript}} arguments.}
%  \item{which}{A device number specifying the device to copy to.}
%  \item{out.type}{The name of the output device: can be \code{"pdf"}, or
%    \code{"quartz"} (some OS X builds) or \code{"cairo"} (Windows
%    and some Unix-alikes, see \code{\link{cairo_pdf}}).}
%  \item{displaylist}{A character string: the only valid values are
%    \code{"inhibit"} and \code{"enable"}.}
%}
%\description{
%  \code{dev.copy} copies the graphics contents of the current device
%  to the device specified by \code{which} or to a new device which has
%  been created by the function specified by \code{device} (it is an
%  error to specify both \code{which} and \code{device}).  (If recording
%  is off on the current device, there are no contents to copy: this will
%  result in no plot or an empty plot.)
%  The device copied to becomes the current device.
%
%  \code{dev.print} copies the graphics contents of the current device
%  to a new device which has been created by the function specified by
%  \code{device} and then shuts the new device.
%
%  \code{dev.copy2eps} is similar to \code{dev.print} but produces an
%  EPSF output file in portrait orientation (\code{horizontal = FALSE}).
%  \code{dev.copy2pdf} is the analogue for PDF output.
%
%  \code{dev.control} allows the user to control the recording of
%  graphics operations in a device.  If \code{displaylist} is \code{"inhibit"}
%  (\code{"enable"}) then recording is turned off (on). It is only safe
%  to change this at the beginning of a plot (just before or just after a
%  new page).  Initially recording is on for screen devices, and off for
%  print devices.
%}
%\value{
%  \code{dev.copy} returns the name and number of the device which has
%  been copied to.
%
%  \code{dev.print}, \code{dev.copy2eps} and \code{dev.copy2pdf} return
%  the name and number of the device which has been copied from.
%}
%\details{
%  Note that these functions copy the \emph{device region} and not a
%  plot: the background colour of the device surface is part of what is
%  copied.  Most screen devices default to a transparent background, which
%  is probably not what is needed when copying to a device such as
%  \code{\link{png}}.
%
%  For \code{dev.copy2eps} and \code{dev.copy2pdf}, \code{width} and
%  \code{height} are taken from the current device unless otherwise
%  specified.  If just one of \code{width} and \code{height} is
%  specified, the other is adjusted to preserve the aspect ratio of the
%  device being copied.  The default file name is \code{Rplot.eps} or
%  \code{Rplot.pdf}, and can be overridden by specifying a \code{file}
%  argument.
%
%  Copying to devices such as \code{\link{postscript}} and
%  \code{\link{pdf}} which need font families pre-specified needs extra
%  care -- \R is unaware of which families were used in a plot and so
%  they will need to manually specified by the \code{fonts} argument
%  passed as part of \code{\dots}.  Similarly, if the device to be copied
%  from was opened with a \code{family} argument, a suitable
%  \code{family} argument will need to be included in \code{\dots}.
%
%  The default for \code{dev.print} is to produce and print a postscript
%  copy.  This will not work unless \code{\link{options}("printcmd")} is
%  set suitably and you have a PostScript printing system: see
%  \code{\link{postscript}} for how to set this up.  Windows users may
%  prefer to use \code{dev.print(win.print)}.
%
%  \code{dev.print} is most useful for producing a postscript print
%  (its default) when the following applies.  Unless
%  \code{file} is specified, the plot will be printed.  Unless
%  \code{width}, \code{height} and \code{pointsize} are specified
%  the plot dimensions will be taken from the current device, shrunk
%  if necessary to fit on the paper. (\code{pointsize} is rescaled if the
%  plot is shrunk.)  If \code{horizontal} is not specified and the plot
%  can be printed at full size by switching its value this is done
%  instead of shrinking the plot region.
%
%  If \code{dev.print} is used with a specified \code{device} (even
%  \code{postscript}) it sets the width and height in the same way as
%  \code{dev.copy2eps}.  This will not be appropriate unless the device
%  specifies dimensions in inches, in particular not for
%  \code{png}, \code{jpeg}, \code{tiff} and \code{bmp} unless
%  \code{units = "inches"} is specified.
%}
%\note{
%  Most devices (including all screen devices) have a display list
%  which records all of the graphics operations that occur in the device.
%  \code{dev.copy} copies graphics contents by copying the display list
%  from one device to another device.  Also, automatic redrawing of
%  graphics contents following the resizing of a device depends on the
%  contents of the display list.
%
%  After the command \code{dev.control("inhibit")}, graphics operations
%  are not recorded in the display list so that \code{dev.copy} and
%  \code{dev.print} will not copy anything and the contents of a device
%  will not be redrawn automatically if the device is resized.
%
%  The recording of graphics operations is relatively expensive in
%  terms of memory so the command \code{dev.control("inhibit")} can be
%  useful if memory usage is an issue.
%}
%\seealso{
%  \code{\link{dev.cur}} and other \code{dev.xxx} functions.
%}
%\examples{
%\dontrun{
%x11() # on a Unix-alike
%plot(rnorm(10), main = "Plot 1")
%dev.copy(device = x11)
%mtext("Copy 1", 3)
%dev.print(width = 6, height = 6, horizontal = FALSE) # prints it
%dev.off(dev.prev())
%dev.off()
%}
%}
%\keyword{device}
%
%\encoding{UTF-8}
%