% File src/library/grDevices/man/gray.colors.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{gray.colors}
\title{グレイの色パレット}
\alias{gray.colors}
\alias{grey.colors}
%%\title{Gray Color Palette}
\description{
  \code{n} 個のガンマ補正されたグレイ色のベクトルを作る．
}
\usage{
gray.colors(n, start = 0.3, end = 0.9, gamma = 2.2, alpha = NULL)
grey.colors(n, start = 0.3, end = 0.9, gamma = 2.2, alpha = NULL)
}
\arguments{
  \item{n}{パレット中のグレイ色の数(\eqn{\ge 1})．}
  \item{start}{
    パレット中のグレイレベルの開始値
    (\code{0} と \code{1} の間になければならず，ゼロは \code{"black"}
    そして 1 は \code{"white"} を指示する)．}
  \item{end}{パレット中のグレイレベルの終わり値．}
  \item{gamma}{ガンマ補正．}
  \item{alpha}{もし指定するならば不透明度．}
}
\details{
  関数 \code{gray.colors} は
  \code{n} このガンマ補正された
  \code{start} と \code{end} の間のグレイレベルの系列を選択する：
  \code{seq(start^gamma, end^gamma, length = n)^(1/gamma)}．
  返されるパレットは対応するグレイ色を含む．
  このパレットは \code{\link{barplot.default}} 中で使われる．

  \code{grey.colors} は \code{gray.colors} の別名である．
}
\value{
  \code{n} 個のグレイ色のベクトル．
}
\seealso{
  \code{\link{gray}},
  \code{\link{rainbow}},
  \code{\link{palette}}.
}
\examples{
require(graphics)

pie(rep(1, 12), col = gray.colors(12))
barplot(1:12, col = gray.colors(12))
}
\keyword{color}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/gray.colors.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{gray.colors}
%\alias{gray.colors}
%\alias{grey.colors}
%\title{Gray Color Palette}
%\description{
%  Create a vector of \code{n} gamma-corrected gray colors.
%}
%\usage{
%gray.colors(n, start = 0.3, end = 0.9, gamma = 2.2, alpha = NULL)
%grey.colors(n, start = 0.3, end = 0.9, gamma = 2.2, alpha = NULL)
%}
%\arguments{
%  \item{n}{the number of gray colors (\eqn{\ge 1}) to be in the
%    palette.}
%  \item{start}{starting gray level in the palette (should be between
%    \code{0} and \code{1} where zero indicates \code{"black"} and one
%    indicates \code{"white"}).}
%  \item{end}{ending gray level in the palette.}
%  \item{gamma}{the gamma correction.}
%  \item{alpha}{the opacity, is specified.}
%}
%\details{
%  The function \code{gray.colors} chooses a series of \code{n}
%  gamma-corrected gray levels between \code{start} and \code{end}:
%  \code{seq(start^gamma, end^gamma, length = n)^(1/gamma)}.
%  The returned palette contains the corresponding gray colors.
%  This palette is used in \code{\link{barplot.default}}.
%
%  \code{grey.colors} is an alias for \code{gray.colors}.
%}
%\value{
%  A vector of \code{n} gray colors.
%}
%\seealso{
%  \code{\link{gray}},
%  \code{\link{rainbow}},
%  \code{\link{palette}}.
%}
%\examples{
%require(graphics)
%
%pie(rep(1, 12), col = gray.colors(12))
%barplot(1:12, col = gray.colors(12))
%}
%\keyword{color}
%
%\encoding{UTF-8}
%