% File src/library/grDevices/man/unix/x11.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{x11}
\title{X11 ウィンドシステムのグラフィックス}
\alias{x11}
\alias{X11}
\alias{X11.options}

%%\title{X Window System Graphics}
\encoding{UTF-8}
\description{
  \code{X11} は
  X ウィンドシステム(version 11)に対するグラフィックスデバイスドライバを開始する．
  これは機械/アカウントが X サーバーにアクセスできる時だけ行われる．

  \code{x11} は \code{X11} の同義語と認識される．

  この \R 関数は二つのデバイスに対するラッパである，
  一つは
  Xlib (\url{https://en.wikipedia.org/wiki/Xlib}) に基づき，
  もう一つは cairographics
  (\url{http://www.cairographics.org}) を使う．
}
\usage{
X11(display = "", width, height, pointsize, gamma, bg, canvas,
    fonts, family, xpos, ypos, title, type, antialias)

X11.options(\dots, reset = FALSE)
}
\arguments{
  \item{display}{その上にグラフィックスウィンドが現れるディスプレイ．
    既定ではユーザの環境変数 \env{DISPLAY} 中の値が使われる．
    これはもし X11 デバイスが既に別のディスプレイ上に開かれている時は無視される．}

  \item{width, height}{インチ単位のプロットウィンドの幅と高さ．
    もし \code{NA} ならリソースから取られ，そしてそこで指定されなければ
    既定で \code{7} インチになる．\sQuote{リソース}節も見よ．}

  \item{pointsize}{使用される既定のポイントサイズ．
    既定値は \code{12}．}

  \item{gamma}{ガンマ修正の曖昧さ因子．
    R 中の色は sRGB である；もし自分のモニターが sRGB と同等でなければ，
    このパラメータをいじくって RGB チャンネルに追加のガンマ補正を適用することで
    色を改良することが出来るかもしれない．
    既定では 1 (追加のガンマ補正は無い)．}

  \item{bg}{初期背景色．既定では \code{"transparent"}．}

  \item{canvas}{キャンバスの色で，
    背景色が透明の時だけ目に見える．
    不透明な色であるべき(そして任意のアルファ値は無視される)．
    既定では \code{"white"}．}

  \item{fonts}{\code{type = "Xlib"} の時だけ：
    重み，傾きそしてサイズがその中に代入される X11 フォントの記述文字列．
    二種類あり，最初はフォント 1 から 4 で，
    二番目はシンボルフォントであるフォント 5 用．
    \sQuote{フォント}節を見よ．}

  \item{family}{既定のファミリ：長さ1の文字列．
    これは第一に
    cairo ベースのデバイス用を意図しているが，
    \code{type = "Xlib"} に対してはファミリ名を
    \code{fonts} にマップするのに
    \code{\link{X11Fonts}()} データベースが使われる
    (そしてこの引数がそれに優先する)．}

  \item{xpos, ypos}{整数：ピクセル単位の
    ウィンドの上左隅の初期位置．
    負の値は反対側，つまり\sspace{}\code{xpos = -100} は
    上右隅がスクリーンの右隅から 100 ピクセルの位置にあることを主張する．
    もし \code{NA} (既定)なら，
    引き続くデバイスは上左隅から 20 ピクセルずつ縦に連なる．
    \sQuote{リソース}節も見よ．}

  \item{title}{文字列で最大 100 バイト．既定の
    \code{""} では適当なタイトルが内部的に作られる．
    整数に対する C スタイルの書式はデバイス番号が代入される
    (よし詳細は \code{\link{postscript}} に対する
    \code{file} 引数を見よ)．非アスキーなタイトルが
    どのように処理されるかは実装依存である．}

  \item{type}{文字列，\code{"Xlib"}, \code{"cairo"},
    \code{"nbcairo"} 又は \code{"dbcairo"} のどれか．
    もしシステムが
    cairographics のサポート無しにコンパイルされていれば最初だけが
    利用できる．既定は OS X を除き利用できれば \code{"cairo"} で，
    さもなければ \code{"Xlib"}．}

  \item{antialias}{cairo タイプに対し，使用されるアンチエイリアシング
    (もしあれば)のタイプ．
    \code{c("default", "none", "gray", "subpixel")} の一つ．}

  \item{reset}{論理値：既定値をそれらの既定値にリセットすべきか?}

  \item{\dots}{
    \code{X11} への任意の引数，プラス \code{colortype}
    と \code{maxcubesize} (\sQuote{色描画}節を見よ)．}
}
\details{
  \code{X11} の引数の全てに対する既定値は
  \code{X11.options} で設定される：
  \sQuote{引数}節は\sQuote{工場出荷時}既定値を与える．

  初期サイズと位置はヒントに過ぎず，
  ウィンドマネージャにより決定されないかもしれない．
  またある種のシステム(特にラップトップ)は
  物理的なスクリーンとは異なったサイズのスクリーンを
  持つように見えるように設定される．

  オプション \code{type} は二つの別個のデバイス間を選択する：
  \R はどちらのサポートも無し，
  \code{type = "Xlib"} 又は双方で構築できる．
  もし双方が利用可能なら，タイプ \code{"cairo"}, \code{"nbcairo"} そして
  \code{"dbcairo"} は以下を提供する
   \itemize{
    \item
    テキストと線のアンチエイリアシング．
    \item
    半透明色．
    \item
    可変サイズテキスト，4.5 pt の様なテキストを含む．
    \item
    UTF-8 に対する完全なサポート．従って適当なフォントを持つシステムでは
    多くの言語で単一の図にプロットできる
    (そしてこれは非 UTF-8 ロケールでも動作する)．
    出力はロケール独立であるべきである．
  }
  
  cairo デバイスの三つの変種がある．
  \code{type = "nbcairo"} はバッファリングをしない．
  \code{type = "cairo"} はある程度のバッファリングを行い，
  \code{\link{dev.hold}} と \code{dev.flush} をサポートする．
  \code{type = "dbcairo"} は出力をバッファしスクリーンを
  約 100ms 毎に更新する(既定で)．リフレッシュ間隔は
  (秒単位で)例えば\sspace{}\code{\link{options}(X11updates = 0.25)} で
  設定できる：この値はデバイスが開かれる時参照される．
  更新は 50ms (最大)毎だけに参照され，思いグラフィックス計算の間は
  500ms 毎にだけ参照される．

  どのバージョンが最速かは
  X11 接続とプロットのタイプに依存する．
  大規模な記録装置が使われていない限り，恐らくバッファ付きタイプ
  を使いたいであろう
  (これは例えば OS X ディスプレイでは常に使われる)．
  さもなければウィンドが呈示される時の再描画が遅くなるであろう．
  遅いコネクションでは \code{type = "dbcairo"} が恐らく
  最良の結果を与える．

  Pango 無しの OS X 
  (例えば CRAN 配布物)でのフォント選択の既知の問題から，
  \code{type = "cairo"} はそこでは既定ではない．
  これらの問題はボールド体とイタリック体の混ぜあわせ
  (応急措置済み)，不正確なグリフの選択，そして
  醜い又は欠損したグリフである．

  X11 サーバーを使う全てのデバイス
  (\code{\link{png}} の様なビットマップデバイスの \code{type = "Xlib"} バージョン
  を含む)は内部構造を共有し，これはそれらが
  同じ \code{display} と外観を持たなければならないことを意味する．
  もしディスプレイを変更したければ，先ず全てのそうしたデバイスを閉じる．

  提示されるカーソルはデバイスの状態を指示する．
  もし停止していればカーソルは矢印である：
  locator を使用中はそれは十字線で，
  そしてプロットが進行中
  (そしてこれは検出可能)はそれは時計印カーソルである．
  (表示される正確なカーソルは使用中のウィンドマネージャに
  依存する．)
}

\section{X11 フォント}{
  この節は \code{type = "Xlib"} にだけ適用される．

  デバイスに対する初期/既定のフォントファミリは
  \code{fonts} 引数で指定できるが，もしデバイス独立な R
  グラフィックスフォントファミリが
  (例えば \code{par(family =) によりグラフィックスパッケージ中で}
  指定されると，
  X11 デバイスは
  X11 フォントのデータベース
  (\code{X11Fonts} を見よ)を R グラフィックスフォントファミリを
  X11 固有のフォントファミリ記述に変換するのに使う．
  もし \code{family} が引数として提供されると，
  X11 のフォントデータベースがそれを変換するのに使われるが，
  さもなければ引数 \code{fonts}
  (既定値は \code{X11.options} で与えられる)が使われる．

  X11 はフォントをパターンマッチングにより選択し，そして
  間違ったエンコーディング中のフォントを選んだり
  自分の言語に対するグリフを含まないすることが十分あり得る
  (特に \code{iso10646-1} フォントでは普通である)．

  \code{fonts} 引数は二つの等その文字列ベクトルであり，
  そして最初の要素は非西洋フォントを成功裡に使う際は
  不可欠である．有用と証明されている設定は次を含む

  CJK フォントに対しては
  \code{"-*-mincho-\%s-\%s-*-*-\%d-*-*-*-*-*-*-*"} で
  ロシア語に対しては
  \code{"-cronyx-helvetica-\%s-\%s-*-*-\%d-*-*-*-*-*-*-*"}．

  UTF-8 ロケールに対しては \code{XLC_LOCALE} データベースが
  文字エンコーディング間のマッピングを提供し，
  そして自分のロケールに対する項目を付け加える必要があるかもしれない
  (例えば Fedora Core 3 は \code{ru_RU.utf8} に対するものを欠いている)．
}

\section{Cairo フォント}{
  cairographics に基づくデバイスは
  \code{"Helvetica"} のようなフォントファミリ名と共に
  直接動作する．これは最初
  \code{family} 引数で，それから \code{\link{par}} や
  \code{\link{gpar}} で選択することが出来る．
  三つのデバイス独立なフォントファミリに対するマッピングがある，
  sans-serif フォントに対する font\code{"sans"}
  (\code{"Helvetica"} に)，serif フォントに対する \code{"serif"}
  (\code{"Times"} へ)，そして monospace フォントに対しては\code{"mono"}
  (\code{"Courier"} へ)．

  フォントの選択は
  \code{Pango} (普通 \code{fontconfig} \emph{経由で})，又は
  \code{fontconfig} (OS X と恐らく他でも)により処理される．
  結果は \R が動いているシステム上にインストールされているフォントに
  依存する -- 環境変数
  \env{FC_DEBUG} を 1 に設定すると普通選択の過程のあるトレース
  を許す．

  これは普通 Type 1 や TrueType 書式の高品質の可変サイズのフォントが
  インストールされている時に最も良く動作する：
  そうしたフォントをどこで入手しインストールするかについては
  現在最良の描画(カーニングを含む)は
  TrueType フォントで得られる：
  自分のシステムでそれらを優先する設定の仕方については
  \url{http://www.freedesktop.org/software/fontconfig/fontconfig-user.html}
  を見よ．既定のファミリ
  (\code{"Helvetica"}) はカーニングを恐らく使わない：
  カーニングを使う別のものはもしインストールしていれば
  \code{"Arial"},
  \code{"DejaVu Sans"} そして \code{"Liberation Sans"} (そして恐らく
  \code{"FreeSans"}) である．セリフ付きフォントが好みなら
  \code{"Times New Roman"}, \code{"DejaVu Serif"} そして
  \code{"Liberation Serif"} を試してみよ．
  LaTeX テキストとマッチさせるには \code{"CM Roman"} の様なものを使う．

  %  https://bugs.launchpad.net/ubuntu/+source/fontconfig/+bug/551977
  シンボルの不正確な描画を伴う問題
  (例えば \code{quote(pi)} と \code{expression(10^degree))})
  が Wine シンボルフォントをインストールした Linux システムで
  観察されてきた
  -- \code{fontconfig} はするとこれを優先しそして
  そのエンコーディングを誤って解釈する．
  次の行を
  \file{~/.fonts.conf} や \file{/etc/fonts/local.conf} に付け加えれば
  URW Type 1 シンボルフォントを優先することでこの問題を克服する．
\preformatted{<fontconfig>
<match target="pattern">
  <test name="family"><string>Symbol</string></test>
  <edit name="family" mode="prepend" binding="same">
    <string>Standard Symbols L</string>
  </edit>
</match>
</fontconfig>
}
これをテストするにはコマンドラインで
\command{fc-match Symbol} を実行する．
もしこれが \code{symbol.ttf} を示せばそれは Wine シンボルフォントかもしれない
 -- それが名前 \samp{wine} を持つディレクトリから見つかるかどうかを見るには
\command{locate symbol.ttf} を使う．
}

\section{リソース}{
  X11 の標準的リソース \code{geometry} は
  ウィンドの位置 and/or サイズを指定するのに使うことが出来るが，
  引数として指定される値や
  \code{X11.options} 中の非 \code{NA} 既定設定で上書きされる．
  求められるクラスは \code{R_x11} である．
  リソースは幅と高さをインチ単位でなくピクセル単位で指定することを
  注意する．
  \samp{man X} に対する例 (又は
  \url{http://www.xfree86.org/current/X.7.html}) を見よ．
  \file{~/.Xresources} 中の一行の例は次のようになるかもしれない
\preformatted{R_x11*geometry: 900x900-0+0
}
  これはスクリーンの上右隅の 900 x 900 ピクセルウィンドを指定する．
}

\section{色描画}{
  X11 は幾つかの\sQuote{視覚}タイプをサポートし，
  現在ではほとんどすべてのシステムは
  \sQuote{truecolor} をサポートし，\code{X11} は既定でこれを使う．
  これはサポートされる深さ
  (普通色毎に 8 ビット)までの任意の RGB 色の直接の指定を使う．
  他の視覚タイプはより少ない色をサポートするパレットを使い，
  
  グレイや黒/白だけを使う．
  パレットは全ての X11 クライエント間で共有されるので，
  \R が使う色数を制限することが必要かもしれない．

  \code{type = "Xlib"} に対する既定は
  X11 サーバーに対する視覚に対して最良の色モデルを使うことである：
  最近ではこれは常に
  \sQuote{truecolor} である．これは
    \code{X11.options} への \code{colortype} 引数で上書きすることが出来る．
 
  \bold{注意：} 全ての
  \code{X11} と \code{type = "Xlib"} では \code{\link{bmp}}, \code{jpeg},
  \code{png} そして \code{tiff} デバイスは最初にデバイスが開かれた際に
  設定される \code{colortype} を共有する．
  \code{colortype} を変更するには
  \emph{全ての}開かれたそうしたデバイスを閉じる必要があり，そしてそれから
  \code{X11.options(colortype =)} を使う．

  色タイプは
  \code{"true"}, \code{"pseudo"}, \code{"gray"} そして \code{"mono"}
  (白黒のみ)の順で試みられる．
  値 \code{"pseudo"} と \code{"pseudo.cube"} は
  擬似色の見かけに対する二つの方策を提供する．
  最初の方策はディスプレイの色のリソースが尽きるまで(プロットが失敗した時)
  要求に応じた色の割り当てを提供する．
  二つ目の方策は(もし可能なら)標準の色キューブを割り当て，
  要求された色がキューブ中の最も近い色で近似される．

  \code{colortype} が \code{"pseudo.cube"} か \code{"gray"} に
  等しければ次々とより小さなパレットが
  完全な割り当てが達成されるまで試みられる．
  もし最少の試みの割り当てが失敗すればデバイスは
  \code{"mono"} に戻る．\code{"gray"} に対しては捜索は
  深さが 8 より大きなディスプレイに対して 256 のグレイから始まり，
  さもなければ利用可能な色の半分から始まる．
  \code{"pseudo.cube"} に対しては最大のキューブサイズは
  \code{X11.options(maxcolorsize =)} で設定され，既定は
  256 である．その設定では試みられる最大のキューブは
  RGB に対しては 4 水準で，パレット中で
  64 色を使う．

  % A test in 2011 showed that cairo >= 1.6 works on 8-bit visuals,
  % but does not interpret colours correctly.  Done via VNC.
  cairographics に基づくデバイスは
  \sQuote{TrueColor} 外観でのみ動作する(又は正確に動作する)ことが
  最もありそうであるが，原則として
  これは cairo のインストールの仕方に依存する：
  もし他の任意の外観に出会うと警告が与えられる．

  \code{type = "Xlib"} は \sQuote{TrueColor},
  \sQuote{PseudoColor}, \sQuote{GrayScale}, \code{StaticGray} そして
  \code{MonoChrome} 外観をサポートする：外観 \sQuote{StaticColor} と
  \sQuote{DirectColor} は白黒でのみ処理される．
}

\section{アンチエイリアシング}{アンチエイリアシングは
  cairographics に基づくデバイスに対してだけサポートされており，
  グラフィックスとフォントの双方に適用される．
  これは一般に線とテキストには好ましいが，例えば\sspace{} \code{\link{image}}
  プロット等の塗りつぶしには好ましくない効果を
  もたらすかもしれず，塗りつぶしには決して使われない．

  \code{antialias = "default"} は原則としてプラットフォーム独立であるが，
  しばしば\cr
  \code{antialias = "gray"} と同値であるように見える．
}

\section{慣例}{
  この節は
  \dQuote{R Internals Manual} で設定されているグラフィックスデバイスに
  対する慣例の実装を説明する．

  \itemize{
    \item 既定のデバイスサイズは 7 インチ四方．
    \item フォントサイズはビッグポイント．
    \item 既定フォントファミリは Helvetica．
    \item 線幅の単位は 1/96 インチで，
      \code{type = "Xlib"} に対する最少ピクセルで，さもなければ 0.01．
    \item \code{type = "Xlib"} に対しては円半径はピクセル単位で，最小値は 1．
    \item 色は X11 サーバーにより解釈され，
    sRGB と同等であることが\emph{仮定される}．
  }
}
\seealso{
  \code{\link{Devices}}, \code{\link{X11Fonts}}, \code{\link{savePlot}}.
}
\examples{\dontrun{
## 既定値をカスタマイズするには次のようなものを自分の .Rprofile に置く
setHook(packageEvent("grDevices", "onLoad"),
        function(...) grDevices::X11.options(width = 8, height = 6, xpos = 0,
                                             pointsize = 10))
}}
\keyword{device}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/unix/x11.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{x11}
%\alias{x11}
%\alias{X11}
%\alias{X11.options}
%
%\title{X Window System Graphics}
%\description{
%  \code{X11} starts a graphics device driver for the X Window System
%  (version 11).  This can only be done on machines/accounts that have
%  access to an X server.
%
%  \code{x11} is recognized as a synonym for \code{X11}.
%
%  The \R function is a wrapper for two devices, one based on Xlib
%  (\url{https://en.wikipedia.org/wiki/Xlib}) and one using cairographics
%  (\url{http://www.cairographics.org}).
%}
%\usage{
%X11(display = "", width, height, pointsize, gamma, bg, canvas,
%    fonts, family, xpos, ypos, title, type, antialias)
%
%X11.options(\dots, reset = FALSE)
%}
%\arguments{
%  \item{display}{the display on which the graphics window will appear.
%    The default is to use the value in the user's environment variable
%    \env{DISPLAY}.  This is ignored (with a warning) if an X11 device is
%    already open on another display.}
%
%  \item{width, height}{the width and height of the plotting window, in
%    inches.  If \code{NA}, taken from the resources and if
%    not specified there defaults to \code{7} inches.  See also
%    \sQuote{Resources}.}
%
%  \item{pointsize}{the default pointsize to be used.  Defaults to \code{12}.}
%
%  \item{gamma}{gamma correction fudge factor.
%    Colours in R are sRGB;  if your monitor does not conform to
%    sRGB, you might be able to improve things by tweaking this
%    parameter to apply additional gamma correction to the RGB channels.
%    By default 1 (no additional gamma correction).}
%
%  \item{bg}{colour, the initial background colour.  Default
%    \code{"transparent"}.}
%
%  \item{canvas}{colour.  The colour of the canvas, which is visible only
%    when the background colour is transparent.  Should be an opaque colour
%    (and any alpha value will be ignored).  Default \code{"white"}.}
%
%  \item{fonts}{for \code{type = "Xlib"} only:
%    X11 font description strings into which weight, slant and
%    size will be substituted.  There are two, the first for fonts 1 to 4
%    and the second for font 5, the symbol font.  See section \sQuote{Fonts}.}
%
%  \item{family}{The default family: a length-one character string.  This
%    is primarily intended for cairo-based devices, but for \code{type =
%    "Xlib"}, the \code{\link{X11Fonts}()} database is used to map family
%    names to \code{fonts} (and this argument takes precedence over that
%    one).}
%
%  \item{xpos, ypos}{integer: initial position of the top left corner of the
%    window, in pixels.  Negative values are from the opposite corner,
%    e.g.\sspace{}\code{xpos = -100} says the top right corner should be 100 pixels
%    from the right edge of the screen.  If \code{NA} (the default),
%    successive devices are cascaded in 20 pixel steps from the top left.
%    See also \sQuote{Resources}.}
%
%  \item{title}{character string, up to 100 bytes.  With the default,
%    \code{""}, a suitable title is created internally.  A C-style format
%    for an integer will be substituted by the device number (see the
%    \code{file} argument to \code{\link{postscript}} for further
%    details).  How non-ASCII titles are handled is
%    implementation-dependent.}
%
%  \item{type}{character string, one of \code{"Xlib"}, \code{"cairo"},
%    \code{"nbcairo"} or \code{"dbcairo"}.  Only the first will be
%    available if the system was compiled without support for
%    cairographics.  The default is \code{"cairo"} where available except
%    on OS X, otherwise \code{"Xlib"}.}
%
%  \item{antialias}{for cairo types, the type of anti-aliasing (if any)
%    to be used.  One of \code{c("default", "none", "gray", "subpixel")}.}
%
%  \item{reset}{logical: should the defaults be reset to their defaults?}
%
%  \item{\dots}{Any of the arguments to \code{X11}, plus \code{colortype}
%    and \code{maxcubesize} (see section \sQuote{Colour Rendering}).}
%}
%\details{
%  The defaults for all of the arguments of \code{X11} are set by
%  \code{X11.options}: the \sQuote{Arguments} section gives the
%  \sQuote{factory-fresh} defaults.
%
%  The initial size and position are only hints, and may not be acted on
%  by the window manager.  Also, some systems (especially laptops) are
%  set up to appear to have a screen of a different size to the physical
%  screen.
%
%  Option \code{type} selects between two separate devices: \R can be
%  built with support for neither, \code{type = "Xlib"} or both.  Where
%  both are available, types \code{"cairo"}, \code{"nbcairo"} and
%  \code{"dbcairo"} offer
%  \itemize{
%    \item
%    antialiasing of text and lines.
%    \item
%    translucent colours.
%    \item
%    scalable text, including to sizes like 4.5 pt.
%    \item
%    full support for UTF-8, so on systems with suitable fonts you can
%    plot in many languages on a single figure (and this will work even
%    in non-UTF-8 locales).  The output should be locale-independent.
%  }
%
%  There are three variants of the cairo-based device.  \code{type =
%  "nbcairo"} has no buffering.  \code{type = "cairo"} has some
%  buffering, and supports \code{\link{dev.hold}} and \code{dev.flush}.
%  \code{type = "dbcairo"} buffers output and updates the screen about
%  every 100ms (by default).  The refresh interval can be set (in units
%  of seconds) by e.g.\sspace{}\code{\link{options}(X11updates = 0.25)}: the
%  value is consulted when a device is opened.  Updates are only looked
%  for every 50ms (at most), and during heavy graphics computations only
%  every 500ms.
%
%  Which version will be fastest depends on the X11 connection and the
%  type of plotting.  You will probably want to use a buffered type
%  unless backing store is in use on the X server (which for example it
%  always is on OS X displays), as otherwise repainting when the
%  window is exposed will be slow.  On slow connections \code{type =
%    "dbcairo"} will probably give the best performance.
%
%  Because of known problems with font selection on OS X without
%  Pango (for example, the CRAN distribution), \code{type = "cairo"} is
%  not the default there.  These problems have included mixing up bold
%  and italic (since worked around), selecting incorrect glyphs and ugly
%  or missing symbol glyphs.
%
%  All devices which use an X11 server (including the \code{type =
%    "Xlib"} versions of bitmap devices such as \code{\link{png}}) share
%  internal structures, which means that they must use the same
%  \code{display} and visual.  If you want to change display, first close
%  all such devices.
%
%  The cursor shown indicates the state of the device.  If quiescent the
%  cursor is an arrow: when the locator is in use it is a crosshair
%  cursor, and when plotting computations are in progress (and this can
%  be detected) it is a watch cursor.  (The exact cursors displayed will
%  depend on the window manager in use.)
%}
%
%\section{X11 Fonts}{
%  This section applies only to \code{type = "Xlib"}.
%
%  An initial/default font family for the device can be specified via
%  the \code{fonts} argument, but if a device-independent R graphics font
%  family is specified (e.g., via \code{par(family =)} in the graphics
%  package), the X11 device makes use of the X11 font database (see
%  \code{X11Fonts}) to convert the R graphics font family to an
%  X11-specific font family description.  If \code{family} is supplied as
%  an argument, the X11 font database is used to convert that, but
%  otherwise the argument \code{fonts} (with default given by
%  \code{X11.options}) is used.
%
%  X11 chooses fonts by matching to a pattern, and it is quite possible
%  that it will choose a font in the wrong encoding or which does not
%  contain glyphs for your language (particularly common in
%  \code{iso10646-1} fonts).
%
%  The \code{fonts} argument is a two-element character vector, and the
%  first element will be crucial in successfully using
%  non-Western-European fonts.  Settings that have proved useful include
%
%  \code{"-*-mincho-\%s-\%s-*-*-\%d-*-*-*-*-*-*-*"} for CJK languages and
%  \code{"-cronyx-helvetica-\%s-\%s-*-*-\%d-*-*-*-*-*-*-*"} for Russian.
%
%  For UTF-8 locales, the \code{XLC_LOCALE} databases provide mappings
%  between character encodings, and you may need to add an entry for your
%  locale (e.g., Fedora Core 3 lacked one for \code{ru_RU.utf8}).
%}
%
%\section{Cairo Fonts}{
%  The cairographics-based devices work directly with font family names
%  such as \code{"Helvetica"} which can be selected initially by the
%  \code{family} argument and subsequently by \code{\link{par}} or
%  \code{\link{gpar}}.  There are mappings for the three
%  device-independent font families, \code{"sans"} for a sans-serif font
%  (to \code{"Helvetica"}), \code{"serif"} for a serif font (to
%  \code{"Times"}) and \code{"mono"} for a monospaced font (to
%  \code{"Courier"}).
%
%  The font selection is handled by \code{Pango} (usually \emph{via}
%  \code{fontconfig}) or \code{fontconfig} (on OS X and perhaps
%  elsewhere).  The results depend on the fonts installed on the system
%  running \R -- setting the environmnent variable \env{FC_DEBUG} to 1
%  normally allows some tracing of the selection process.
%
%  This works best when high-quality scalable fonts are installed,
%  usually in Type 1 or TrueType formats: see the \dQuote{R Installation
%  and Administration Manual} for advice on how to obtain and install
%  such fonts.  At present the best rendering (including using kerning)
%  will be achieved with TrueType fonts: see
%  \url{http://www.freedesktop.org/software/fontconfig/fontconfig-user.html}
%  for ways to set up your system to prefer them.  The default family
%  (\code{"Helvetica"}) is likely not to use kerning: alternatives which
%  should if you have them installed are \code{"Arial"},
%  \code{"DejaVu Sans"} and \code{"Liberation Sans"} (and perhaps
%  \code{"FreeSans"}).  For those who prefer fonts with serifs, try
%  \code{"Times New Roman"}, \code{"DejaVu Serif"} and \code{"Liberation
%  Serif"}.  To match LaTeX text, use something like \code{"CM Roman"}.
%
%  %  https://bugs.launchpad.net/ubuntu/+source/fontconfig/+bug/551977
%  Problems with incorrect rendering of symbols (e.g., of
%  \code{quote(pi)} and \code{expression(10^degree))})
%  have been seen on Linux systems which have the Wine
%  symbol font installed -- \code{fontconfig} then prefers this and
%  misinterprets its encoding.  Adding the following lines
%  to \file{~/.fonts.conf} or \file{/etc/fonts/local.conf} may circumvent
%  this problem by preferring the URW Type 1 symbol font.
%\preformatted{<fontconfig>
%<match target="pattern">
%  <test name="family"><string>Symbol</string></test>
%  <edit name="family" mode="prepend" binding="same">
%    <string>Standard Symbols L</string>
%  </edit>
%</match>
%</fontconfig>
%}
%A test for this is to run at the command line \command{fc-match Symbol}.
%If that shows \code{symbol.ttf} that may be the Wine symbol font -- use
%\command{locate symbol.ttf} to see if it is found from a directory with
%\samp{wine} in the name.
%}
%
%\section{Resources}{
%  The standard X11 resource \code{geometry} can be used to specify the
%  window position and/or size, but will be overridden by values
%  specified as arguments or non-\code{NA} defaults set in
%  \code{X11.options}.  The class looked for is \code{R_x11}.  Note that
%  the resource specifies the width and height in pixels and not in
%  inches.  See for example \samp{man X} (or
%  \url{http://www.xfree86.org/current/X.7.html}).
%  An example line in \file{~/.Xresources} might be
%\preformatted{R_x11*geometry: 900x900-0+0
%}
%  which specifies a 900 x 900 pixel window at the top right of the screen.
%}
%
%\section{Colour Rendering}{
%  X11 supports several \sQuote{visual} types, and nowadays almost all
%  systems support \sQuote{truecolor} which \code{X11} will use by
%  default.  This uses a direct specification of any RGB colour up to the
%  depth supported (usually 8 bits per colour).  Other visuals make use
%  of a palette to support fewer colours, only grays or even only
%  black/white.  The palette is shared between all X11 clients, so it can
%  be necessary to limit the number of colours used by \R.
%
%  The default for \code{type = "Xlib"} is to use the best possible colour
%  model for the visual of the X11 server: these days this will almost
%  always be \sQuote{truecolor}.  This can be overridden by the
%  \code{colortype} argument of \code{X11.options}.  \bold{Note:} All
%  \code{X11} and \code{type = "Xlib"} \code{\link{bmp}}, \code{jpeg},
%  \code{png} and \code{tiff} devices share a \code{colortype} which is
%  set when the first device to be opened.  To change the
%  \code{colortype} you need to close \emph{all} open such devices, and
%  then use \code{X11.options(colortype =)}.
%
%  The colortype types are tried in the order \code{"true"},
%  \code{"pseudo"}, \code{"gray"} and \code{"mono"} (black or white
%  only).  The values \code{"pseudo"} and \code{"pseudo.cube"} provide
%  two colour strategies for a pseudocolor visual.  The first strategy
%  provides on-demand colour allocation which produces exact colours
%  until the colour resources of the display are exhausted (when plotting
%  will fail).  The second allocates (if possible) a standard colour
%  cube, and requested colours are approximated by the closest value in
%  the cube.
%
%  With \code{colortype} equal to \code{"pseudo.cube"} or \code{"gray"}
%  successively smaller palettes are tried until one is completely
%  allocated.  If allocation of the smallest attempt fails the device will
%  revert to \code{"mono"}.  For \code{"gray"} the search starts at 256
%  grays for a display with depth greater than 8, otherwise with half
%  the available colours.  For \code{"pseudo.cube"} the maximum cube size
%  is set by \code{X11.options(maxcolorsize =)} and defaults to
%  256.  With that setting the largest cube tried is 4 levels each for
%  RGB, using 64 colours in the palette.
%
%  % A test in 2011 showed that cairo >= 1.6 works on 8-bit visuals,
%  % but does not interpret colours correctly.  Done via VNC.
%  The cairographics-based devices most likely only work (or work
%  correctly) with \sQuote{TrueColor} visuals, although in principle this
%  depends on the cairo installation: a warning is given if any other
%  visual is encountered.
%
%  \code{type = "Xlib"} supports \sQuote{TrueColor},
%  \sQuote{PseudoColor}, \sQuote{GrayScale}, \code{StaticGray} and
%  \code{MonoChrome} visuals: \sQuote{StaticColor} and
%  \sQuote{DirectColor} visuals are handled only in black/white.
%}
%
%\section{Anti-aliasing}{
%  Anti-aliasing is only supported for cairographics-based devices, and
%  applies to both graphics and fonts.  It is generally preferable for
%  lines and text, but can lead to undesirable effects for fills,
%  e.g.\sspace{}for \code{\link{image}} plots, and so is never used for fills.
%
%  \code{antialias = "default"} is in principle platform-dependent, but
%  seems most often equivalent to \code{antialias = "gray"}.
%}
%
%\section{Conventions}{
%  This section describes the implementation of the conventions for
%  graphics devices set out in the \dQuote{R Internals Manual}.
%
%  \itemize{
%    \item The default device size is 7 inches square.
%    \item Font sizes are in big points.
%    \item The default font family is Helvetica.
%    \item Line widths in 1/96 inch, minimum one pixel for \code{type =
%      "Xlib"}, 0.01 otherwise.
%    \item For \code{type = "Xlib"} circle radii are in pixels with
%    minimum one.
%    \item Colours are interpreted by the X11 server, which is
%    \emph{assumed} to conform to sRGB.
%  }
%}
%
%\seealso{
%  \code{\link{Devices}}, \code{\link{X11Fonts}}, \code{\link{savePlot}}.
%}
%\examples{\dontrun{
%## put something like this is your .Rprofile to customize the defaults
%setHook(packageEvent("grDevices", "onLoad"),
%        function(...) grDevices::X11.options(width = 8, height = 6, xpos = 0,
%                                             pointsize = 10))
%}}
%\keyword{device}
%
