% File src/library/graphics/man/dotchart.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{dotchart}
\alias{dotchart}
\title{Cleveland's Dot Plots}
\description{
  Cleveland のドットプロットを描く．
}
\usage{
dotchart(x, labels = NULL, groups = NULL, gdata = NULL,
         cex = par("cex"), pt.cex = cex,
         pch = 21, gpch = 21, bg = par("bg"),
         color = par("fg"), gcolor = par("fg"), lcolor = "gray",
         xlim = range(x[is.finite(x)]),
         main = NULL, xlab = NULL, ylab = NULL, \dots)
}
\arguments{
  \item{x}{数値のベクトルか行列(\code{NA} が許される)．
    もし \code{x} が行列ならばプロット全体は各行に対するドットプロット
    を併置したものからなる．
    \code{\link{is.numeric}(x)} を満たすが
    \code{is.vector(x) || is.matrix(x)} で無い入力は
    \code{\link{as.numeric}} で強制変換され警告がでる．}
  \item{labels}{各点に対するラベルのベクトル．
    ベクトルに対しては既定は \code{names(x)} を使用し，
    行列に対しては行ラベル \code{dimnames(x)[[1]]} である．}
  \item{groups}{\code{x} の要素をどのようにグループ化するかを
    指示するオプションの因子．
    もし \code{x} が行列ならば \code{groups} は \code{x} の
    列になる．}
  \item{gdata}{グループに対するデータ値．
    これは典型的には各グループの中央値や平均のような要約である．}
  \item{cex}{使用される文字サイズ．\code{cex} を1より小さくすることは
    ラベルが重なりあうことを避ける有用な方法である．
    多くの他のグラフィックス関数と異なり，これは実際のサイズを
    設定し，\code{par("cex")} の倍数ではない．}
  \item{pt.cex}{プロット用のシンボルに適用される \code{cex}．
    これは \code{plot()} 中の \code{cex} の用に振る舞う．}
  \item{pch}{使用されるプロット用の文字かシンボル．}
  \item{gpch}{グループ用に使用されるプロット用の文字かシンボル．}
  \item{bg}{文字かシンボルのプロットの背景色；
    全てのプロットの背景色の設定には \code{\link{par}(bg= *)} を使う．}
  \item{color}{点とラベル用に使われる色．}
  \item{gcolor}{グループラベルと値に対して使われる単一の色．}
  \item{lcolor}{水平線に使われる色．}
  \item{xlim}{プロットの水平レンジ，例えば
    \code{\link{plot.window}} を見よ．}
  \item{main}{プロットの全体的タイトル，\code{\link{title}} を見よ．}
  \item{xlab, ylab}{\code{title} 中におけるような軸注釈．}
  \item{\dots}{グラフィカルパラメータをまた引数として指定できる．}
}
\value{
  この関数はその副作用のために起動され，
  Cleveland (1985) で説明されているドットプロットの二つの変種を
  作りだす．

  ドットプロットはバープロットに対する合理的な代替物である．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Cleveland, W. S. (1985)
  \emph{The Elements of Graphing Data.}
  Monterey, CA: Wadsworth.

  Murrell, P. (2005) \emph{R Graphics}. Chapman & Hall/CRC Press.
}
\examples{
dotchart(VADeaths, main = "Death Rates in Virginia - 1940")
op <- par(xaxs = "i")  # 0 -- 100\%
dotchart(t(VADeaths), xlim = c(0,100),
         main = "Death Rates in Virginia - 1940")
par(op)
}
\keyword{hplot}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/dotchart.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{dotchart}
%\alias{dotchart}
%\title{Cleveland's Dot Plots}
%\description{
%  Draw a Cleveland dot plot.
%}
%\usage{
%dotchart(x, labels = NULL, groups = NULL, gdata = NULL,
%         cex = par("cex"), pt.cex = cex,
%         pch = 21, gpch = 21, bg = par("bg"),
%         color = par("fg"), gcolor = par("fg"), lcolor = "gray",
%         xlim = range(x[is.finite(x)]),
%         main = NULL, xlab = NULL, ylab = NULL, \dots)
%}
%\arguments{
%  \item{x}{either a vector or matrix of numeric values (\code{NA}s are
%    allowed).  If \code{x} is a matrix the overall plot consists of
%    juxtaposed dotplots for each row.  Inputs which satisfy
%    \code{\link{is.numeric}(x)} but not
%    \code{is.vector(x) || is.matrix(x)} are coerced by
%    \code{\link{as.numeric}}, with a warning.}
%  \item{labels}{a vector of labels for each point.
%    For vectors the default is to use \code{names(x)} and for matrices
%    the row labels \code{dimnames(x)[[1]]}.}
%  \item{groups}{an optional factor indicating how the elements of
%    \code{x} are grouped.
%    If \code{x} is a matrix, \code{groups} will default to the columns
%    of \code{x}.}
%  \item{gdata}{data values for the groups.
%    This is typically a summary such as the median or mean
%    of each group.}
%  \item{cex}{the character size to be used.  Setting \code{cex}
%    to a value smaller than one can be a useful way of avoiding label
%    overlap.  Unlike many other graphics functions, this sets the actual
%    size, not a multiple of \code{par("cex")}.}
%  \item{pt.cex}{the \code{cex} to be applied to plotting symbols.
%    This behaves like \code{cex} in \code{plot()}.}
%  \item{pch}{the plotting character or symbol to be used.}
%  \item{gpch}{the plotting character or symbol to be used for group
%    values.}
%  \item{bg}{the background color of plotting characters or symbols to be
%    used; use \code{\link{par}(bg= *)} to set the background color of
%    the whole plot.}
%  \item{color}{the color(s) to be used for points and labels.}
%  \item{gcolor}{the single color to be used for group labels and
%    values.}
%  \item{lcolor}{the color(s) to be used for the horizontal lines.}
%  \item{xlim}{horizontal range for the plot, see
%    \code{\link{plot.window}}, for example.}
%  \item{main}{overall title for the plot, see \code{\link{title}}.}
%  \item{xlab, ylab}{axis annotations as in \code{title}.}
%  \item{\dots}{\link{graphical parameters} can also be specified as arguments.}
%}
%\value{
%  This function is invoked for its side effect, which is to produce two
%  variants of dotplots as described in Cleveland (1985).
%
%  Dot plots are a reasonable substitute for bar plots.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Cleveland, W. S. (1985)
%  \emph{The Elements of Graphing Data.}
%  Monterey, CA: Wadsworth.
%
%  Murrell, P. (2005) \emph{R Graphics}. Chapman & Hall/CRC Press.
%}
%\examples{
%dotchart(VADeaths, main = "Death Rates in Virginia - 1940")
%op <- par(xaxs = "i")  # 0 -- 100\%
%dotchart(t(VADeaths), xlim = c(0,100),
%         main = "Death Rates in Virginia - 1940")
%par(op)
%}
%\keyword{hplot}

\encoding{UTF8}
