% File src/library/graphics/man/filled.contour.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{filled.contour}
\alias{filled.contour}
\alias{.filled.contour}

\title{Level (Contour) Plots}
\usage{
filled.contour(x = seq(0, 1, length.out = nrow(z)),
               y = seq(0, 1, length.out = ncol(z)),
               z,
               xlim = range(x, finite = TRUE),
               ylim = range(y, finite = TRUE),
               zlim = range(z, finite = TRUE),
               levels = pretty(zlim, nlevels), nlevels = 20,
               color.palette = cm.colors,
               col = color.palette(length(levels) - 1),
               plot.title, plot.axes, key.title, key.axes,
               asp = NA, xaxs = "i", yaxs = "i", las = 1,
               axes = TRUE, frame.plot = axes, \dots)

.filled.contour(x, y, z, levels, col)
}
\arguments{
 \item{x, y}{\code{z} 中の値が測られるグリッド線の位置．
   増加順でなければならない．
   (この説明の残りは \code{.filled.contour} には適用されない．)
   既定では，0 から 1 までの等間隔の値が使われる．
   もし \code{x} がリストならば，その成分 
   \code{x$x} と \code{x$y} がそれぞれ \code{x} と \code{y} として
   使われる．もしリストが成分 \code{z} を持てばこれが \code{z} として使われる．}
 \item{z}{プロットされる値を含む数値行列．
   簡便さのために \code{x} を \code{z} の代わりに使えることを注意する．}
 \item{xlim}{プロットのための x 限界．}
 \item{ylim}{プロットのための y 限界．}
 \item{zlim}{プロットのための z 限界．}
 \item{levels}{\code{z} の範囲を分割するのに使われるレベルのセット．
    \bold{狭義に}増加(そして有限)でなければならない．
    隣接する水準の間に \code{z} の値がある領域は同じ色で
    塗られる．}
 \item{nlevels}{もし \code{levels} が指定されていないと，
    \code{z} 値の範囲は近似的にこの数のレベルに分割される．}
 \item{color.palette}{プロットに色を割り振るのに使われる
   カラーパレット関数．}
 \item{col}{プロット中に使われる色の明示的なセット．
    この引数はパレット関数の指定を上書きする．
    レベルよりも一つ少ない色が必要．}
 \item{plot.title}{主プロットにタイトルを加える記述．}
 \item{plot.axes}{主プロット上に軸(そして \code{\link{box}})
   を描く記述．これは既定の軸を上書きする．}
 \item{key.title}{プロットキーに対するタイトルを加える記述．}
 \item{key.axes}{プロットキーの上に軸を書く記述．
    これは既定の軸を上書きする．}
 \item{asp}{\eqn{y/x} アスペクト比，\code{\link{plot.window}} を見よ．}
 \item{xaxs}{x 軸のスタイル．既定では内部的なラベリングを使う．}
 \item{yaxs}{y 軸のスタイル．既定では内部的なラベリングを使う．}
 \item{las}{使用されるラベリングのスタイル．既定では水平なラベリングを使う．}
 \item{axes, frame.plot}{\code{\link{plot.default}} に於けるような，
   軸と箱を描くかどうかを指定する論理値．}
 \item{\dots}{追加のグラフィックスパラメータ，現在
   \code{\link{title}()} にだけ渡される．}
}
\description{
  この関数は等高線の間の領域がが一体色で塗りつぶされた
  等高線図を作る(Cleveland はこれをレベルプロットと読んでいる)．
  色がどのように z 値にマップされるかのキーはプロットの右に示される．
}
\details{
  プロットされる値は \code{NA} を含んで良い．二つ又はそれ以上の隅の
  値が \code{NA} の矩形は完全に除外される：一つの \code{NA} があるときは
  \code{NA} に向き合う三角形は除外される．

  プロットされる値は無限値でも良い．その効果は \code{NA} 値に対するものと
  似ている．

  \code{.filled.contour} は既に設定されたプロット領域に単に
  等高線図を付け加える\sQuote{骨子}のインタフェイスである．
  これはプログラムでの使用を意図しており，プログラマーは引数に関する
  条件をチェックする責任がある．
}
\references{
  Cleveland, W. S. (1993)
  \emph{Visualizing Data}.
  Summit, New Jersey: Hobart.
}
\author{Ross Ihaka and R-core.}
\note{
  \code{filled.contour} は \code{\link{layout}} 関数を使うので
  ページ全体を使う画像に制限される．

  \code{filled.contour} で作られる出力は実際には二つのプロットの
  組み合わせである；一つは塗りつぶし等高線図であり，もうひとつは
  凡例である．これらの二つのプロットのために二つの独立の座標系が
  設定されるが，それらは内部的にのみ使われる
  -- 関数が終了するとこれらの座標系は失われる．
  もし主の等高線図に注釈を加え，例えば点を加える，たければ，
  \code{plot.axes} 引数中にグラフィックス命令を指定することが
  出来る．例を見よ．
}
\seealso{
  \code{\link{contour}}, \code{\link{image}},
  \code{\link{palette}};
  パッケージ \CRANpkg{lattice} からの \code{\link[lattice:levelplot]{contourplot}}
  そして \code{\link[lattice]{levelplot}}．
}
\examples{
require(grDevices) # 色のため
filled.contour(volcano, color = terrain.colors, asp = 1) # 簡単

x <- 10*1:nrow(volcano)
y <- 10*1:ncol(volcano)
filled.contour(x, y, volcano, color = terrain.colors,
    plot.title = title(main = "The Topography of Maunga Whau",
    xlab = "Meters North", ylab = "Meters West"),
    plot.axes = { axis(1, seq(100, 800, by = 100))
                  axis(2, seq(100, 600, by = 100)) },
    key.title = title(main = "Height\n(meters)"),
    key.axes = axis(4, seq(90, 190, by = 10)))  # maybe also asp = 1
mtext(paste("filled.contour(.) from", R.version.string),
      side = 1, line = 4, adj = 1, cex = .66)

# 塗りつぶし等高線プロットの注釈
a <- expand.grid(1:20, 1:20)
b <- matrix(a[,1] + a[,2], 20)
filled.contour(x = 1:20, y = 1:20, z = b,
               plot.axes = { axis(1); axis(2); points(10, 10) })

## ペルシャ絨毯アート：
x <- y <- seq(-4*pi, 4*pi, len = 27)
r <- sqrt(outer(x^2, y^2, "+"))
filled.contour(cos(r^2)*exp(-r/(2*pi)), axes = FALSE)
## rather, the key *should* be labeled:
filled.contour(cos(r^2)*exp(-r/(2*pi)), frame.plot = FALSE,
               plot.axes = {})
}
\keyword{hplot}
\keyword{aplot}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/filled.contour.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{filled.contour}
%\alias{filled.contour}
%\alias{.filled.contour}
%
%\title{Level (Contour) Plots}
%\usage{
%filled.contour(x = seq(0, 1, length.out = nrow(z)),
%               y = seq(0, 1, length.out = ncol(z)),
%               z,
%               xlim = range(x, finite = TRUE),
%               ylim = range(y, finite = TRUE),
%               zlim = range(z, finite = TRUE),
%               levels = pretty(zlim, nlevels), nlevels = 20,
%               color.palette = cm.colors,
%               col = color.palette(length(levels) - 1),
%               plot.title, plot.axes, key.title, key.axes,
%               asp = NA, xaxs = "i", yaxs = "i", las = 1,
%               axes = TRUE, frame.plot = axes, \dots)
%
%.filled.contour(x, y, z, levels, col)
%}
%\arguments{
% \item{x, y}{locations of grid lines at which the values in \code{z} are
%   measured.  These must be in ascending order.  (The rest of this
%   description does not apply to \code{.filled.contour}.)
%   By default, equally spaced values from 0 to 1 are used.  If \code{x}
%   is a \code{list}, its components \code{x$x} and \code{x$y} are used
%   for \code{x} and \code{y}, respectively.  If the list has component
%   \code{z} this is used for \code{z}.}
% \item{z}{a numeric matrix containing the values to be plotted..  Note that
%   \code{x} can be used instead of \code{z} for convenience.}
% \item{xlim}{x limits for the plot.}
% \item{ylim}{y limits for the plot.}
% \item{zlim}{z limits for the plot.}
% \item{levels}{a set of levels which are used to partition the range
%    of \code{z}.  Must be \bold{strictly} increasing (and finite).  Areas
%    with \code{z} values between consecutive levels are painted with the
%    same color.}
% \item{nlevels}{if \code{levels} is not specified, the range of \code{z},
%    values is divided into approximately this many levels.}
% \item{color.palette}{a color palette function to be used to assign
%    colors in the plot.}
% \item{col}{an explicit set of colors to be used in the plot.
%    This argument overrides any palette function specification.  There
%    should be one less color than levels}
% \item{plot.title}{statements which add titles to the main plot.}
% \item{plot.axes}{statements which draw axes (and a \code{\link{box}})
%   on the main plot.  This overrides the default axes.}
% \item{key.title}{statements which add titles for the plot key.}
% \item{key.axes}{statements which draw axes on the plot key.
%    This overrides the default axis.}
% \item{asp}{the \eqn{y/x} aspect ratio, see \code{\link{plot.window}}.}
% \item{xaxs}{the x axis style.  The default is to use internal
%    labeling.}
% \item{yaxs}{the y axis style.  The default is to use internal
%    labeling.}
% \item{las}{the style of labeling to be used.  The default is to
%    use horizontal labeling.}
% \item{axes, frame.plot}{logicals indicating if axes and a box should be
%   drawn, as in \code{\link{plot.default}}.}
% \item{\dots}{additional \link{graphical parameters}, currently only passed to
%   \code{\link{title}()}.}
%}
%\description{
%  This function produces a contour plot with the areas between the
%  contours filled in solid color (Cleveland calls this a level plot).  A
%  key showing how the colors map to z values is shown to the right of
%  the plot.
%}
%\details{
%  The values to be plotted can contain \code{NA}s.  Rectangles with two
%  or more corner values are \code{NA} are omitted entirely: where there
%  is a single \code{NA} value the triangle opposite the \code{NA} is
%  omitted.
%
%  Values to be plotted can be infinite: the effect is similar to that
%  described for \code{NA} values.
%
%  \code{.filled.contour} is a \sQuote{bare bones} interface to add
%  just the contour plot to an already-set-up plot region.  It is is
%  intended for programmatic use, and the programmer is
%  responsible for checking the conditions on the arguments.
%}
%\references{
%  Cleveland, W. S. (1993)
%  \emph{Visualizing Data}.
%  Summit, New Jersey: Hobart.
%}
%\author{Ross Ihaka and R-core.}
%\note{
%  \code{filled.contour} uses the \code{\link{layout}} function and so is
%  restricted to a full page display.
%
%  The output produced by \code{filled.contour} is actually a combination
%  of two plots; one is the filled contour and one is the legend.  Two
%  separate coordinate systems are set up for these two plots, but they
%  are only used internally -- once the function has returned these
%  coordinate systems are lost.  If you want to annotate the main contour
%  plot, for example to add points, you can specify graphics commands in
%  the \code{plot.axes} argument.  See the examples.
%}
%\seealso{
%  \code{\link{contour}}, \code{\link{image}},
%  \code{\link{palette}}; \code{\link[lattice:levelplot]{contourplot}}
%  and \code{\link[lattice]{levelplot}} from package \CRANpkg{lattice}.
%}
%\examples{
%require(grDevices) # for colours
%filled.contour(volcano, color = terrain.colors, asp = 1) # simple
%
%x <- 10*1:nrow(volcano)
%y <- 10*1:ncol(volcano)
%filled.contour(x, y, volcano, color = terrain.colors,
%    plot.title = title(main = "The Topography of Maunga Whau",
%    xlab = "Meters North", ylab = "Meters West"),
%    plot.axes = { axis(1, seq(100, 800, by = 100))
%                  axis(2, seq(100, 600, by = 100)) },
%    key.title = title(main = "Height\n(meters)"),
%    key.axes = axis(4, seq(90, 190, by = 10)))  # maybe also asp = 1
%mtext(paste("filled.contour(.) from", R.version.string),
%      side = 1, line = 4, adj = 1, cex = .66)
%
%# Annotating a filled contour plot
%a <- expand.grid(1:20, 1:20)
%b <- matrix(a[,1] + a[,2], 20)
%filled.contour(x = 1:20, y = 1:20, z = b,
%               plot.axes = { axis(1); axis(2); points(10, 10) })
%
%## Persian Rug Art:
%x <- y <- seq(-4*pi, 4*pi, len = 27)
%r <- sqrt(outer(x^2, y^2, "+"))
%filled.contour(cos(r^2)*exp(-r/(2*pi)), axes = FALSE)
%## rather, the key *should* be labeled:
%filled.contour(cos(r^2)*exp(-r/(2*pi)), frame.plot = FALSE,
%               plot.axes = {})
%}
%\keyword{hplot}
%\keyword{aplot}
%
\encoding{UTF8}
