% File src/library/graphics/man/pie.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{pie}
\title{Pie Charts}
\alias{pie}
\description{
  パイチャートを描く．
}
\usage{
pie(x, labels = names(x), edges = 200, radius = 0.8,
    clockwise = FALSE, init.angle = if(clockwise) 90 else 0,
    density = NULL, angle = 45, col = NULL, border = NULL,
    lty = NULL, main = NULL, \dots)
}
\arguments{
  \item{x}{非負の数値のベクトル．
    \code{x} 中の値がパイのスライスの面積として表示される．}
  \item{labels}{スライスの名前を与える一つ又はそれ以上の表現式か文字列．
    他のオブジェクトは \code{\link{as.graphicsAnnot}} で変換される．
    空か \code{NA} (文字列への変換後)のラベルに対しては
    ラベルも指し示す線も描かれない．}
  \item{edges}{パイの円状輪郭はこの数の辺を持つ多角形で近似される．}
  \item{radius}{パイは側面が
    \eqn{-1} から \eqn{1} の範囲の正方形のボックスの中心に描かれる．
    スライスのラベルになる文字列が長ければ，より小さな半径を使う
    必要があるかもしれない．}
  \item{clockwise}{スライスを時計回りか半時計回り
    (つまり数学的に正の報告)
    に描くかを指示する論理値で，後者が既定値．}
  \item{init.angle}{
    スライスの\emph{開始角}(度単位)を指示する数．
    \code{clockwise} が真でない限り既定値は 0 (つまり\sQuote{3時})で，
    真ならば \code{init.angle} の既定値は90度
    (つまり\sQuote{12時})．}
  \item{density}{陰影線の密度で，インチあたりの線数．
    既定値の \code{NULL} は陰影線を描かないことを意味する．
    正でない \code{density} の値は陰影線を描くことを禁止する．}
  \item{angle}{陰影線の傾きで，度単位の角(半時計回り)で与えられる．}
  \item{col}{スライスを埋めたり陰影を付けたりするのに使われる色の
    ベクトル．
    もし欠損していれば，\code{par("fg")} が使われ
    \code{density} が指定されない限り，
    6 つのパステル色のセットが使われる．}
  \item{border, lty}{各スライスを描く \code{\link{polygon}} に渡される
    (もしかするとベクトルの)引数．}
  \item{main}{プロットの全体的タイトル．}
  \item{\dots}{グラフィカルパラメータを
    \code{pie} への引数として与えることができる．
    これらは主タイトルとラベルにだけ影響する．}
}
\note{
  パイチャートは情報を表示するには非常にまずい方法である．
  視覚は線形な量の判別には鋭敏であるが，相対的な面積の把握は
  苦手である．棒グラフやドットチャートの方がこのタイプのデータの
  表示には好ましい方法である．

  Cleveland (1985), page 264: \dQuote{パイチャートで表示できるデータは
    常にドットチャートで表現できる．
    これは共通スケールに沿った位置の判断がより不正確な角度の比較の
    代わりになされるからである．}
  この主張は Cleveland と McGill の経験的な調査と共に
  認知心理学者の調査に基づいている．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Cleveland, W. S. (1985)
  \emph{The Elements of Graphing Data}.
  Wadsworth: Monterey, CA, USA.
}
\seealso{
  \code{\link{dotchart}}.
}
\examples{
require(grDevices)
pie(rep(1, 24), col = rainbow(24), radius = 0.9)

pie.sales <- c(0.12, 0.3, 0.26, 0.16, 0.04, 0.12)
names(pie.sales) <- c("Blueberry", "Cherry",
    "Apple", "Boston Cream", "Other", "Vanilla Cream")
pie(pie.sales) # 既定色
pie(pie.sales, col = c("purple", "violetred1", "green3",
                       "cornsilk", "cyan", "white"))
pie(pie.sales, col = gray(seq(0.4, 1.0, length = 6)))
pie(pie.sales, density = 10, angle = 15 + 10 * 1:6)
pie(pie.sales, clockwise = TRUE, main = "pie(*, clockwise = TRUE)")
segments(0, 0, 0, 1, col = "red", lwd = 2)
text(0, 1, "init.angle = 90", col = "red")

n <- 200
pie(rep(1, n), labels = "", col = rainbow(n), border = NA,
    main = "pie(*, labels=\"\", col=rainbow(n), border=NA,..")

## pie() が科学よりは娯楽であることを示す別の例：
## Another case showing pie() is rather fun than science:
## (オリジナルは FinalBackwardsGlance on http://imgur.com/gallery/wWrpU4X)
pie(c(Sky = 78, "Sunny side of pyramid" = 17, "Shady side of pyramid" = 5),
    init.angle = 315, col = c("deepskyblue", "yellow", "yellow3"), border = FALSE)
}
\keyword{hplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/pie.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{pie}
%\title{Pie Charts}
%\alias{pie}
%\description{
%  Draw a pie chart.
%}
%\usage{
%pie(x, labels = names(x), edges = 200, radius = 0.8,
%    clockwise = FALSE, init.angle = if(clockwise) 90 else 0,
%    density = NULL, angle = 45, col = NULL, border = NULL,
%    lty = NULL, main = NULL, \dots)
%}
%\arguments{
%  \item{x}{a vector of non-negative numerical quantities.
%    The values in \code{x} are displayed as the areas of pie slices.}
%  \item{labels}{one or more expressions or character strings giving
%    names for the slices.  Other objects are coerced by
%    \code{\link{as.graphicsAnnot}}.  For empty or \code{NA}
%    (after coercion to character) labels, no label nor pointing line
%    is drawn.}
%  \item{edges}{the circular outline of the pie is approximated by a
%    polygon with this many edges.}
%  \item{radius}{the pie is drawn centered in a square box whose sides
%    range from \eqn{-1} to \eqn{1}.  If the character strings labeling
%    the slices are long it may be necessary to use a smaller radius.}
%  \item{clockwise}{logical indicating if slices are drawn clockwise or
%    counter clockwise (i.e., mathematically positive direction), the
%    latter is default.}
%  \item{init.angle}{number specifying the \emph{starting angle} (in
%    degrees) for the slices. Defaults to 0 (i.e., \sQuote{3 o'clock})
%    unless \code{clockwise} is true where \code{init.angle}
%    defaults to 90 (degrees), (i.e., \sQuote{12 o'clock}).}
%  \item{density}{the density of shading lines, in lines per inch.
%    The default value of \code{NULL} means that no shading lines
%    are drawn. Non-positive values of \code{density} also inhibit the
%    drawing of shading lines.}
%  \item{angle}{the slope of shading lines, given as an angle in
%    degrees (counter-clockwise).}
%  \item{col}{a vector of colors to be used in filling or shading
%    the slices. If missing a set of 6 pastel colours is used,
%    unless \code{density} is specified when \code{par("fg")} is used.}
%  \item{border, lty}{(possibly vectors) arguments passed to
%    \code{\link{polygon}} which draws each slice.}
%  \item{main}{an overall title for the plot.}
%  \item{\dots}{\link{graphical parameters} can be given as arguments to
%    \code{pie}.  They will affect the main title and labels only.}
%}
%\note{
%  Pie charts are a very bad way of displaying information.
%  The eye is good at judging linear measures and bad at judging
%  relative areas.  A bar chart or dot chart is a preferable way of
%  displaying this type of data.
%
%  Cleveland (1985), page 264: \dQuote{Data that can be shown by pie charts
%    always can be shown by a dot chart.  This means that judgements of
%    position along a common scale can be made instead of the less
%    accurate angle judgements.}
%  This statement is based on the empirical investigations of Cleveland
%  and McGill as well as investigations by perceptual psychologists.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Cleveland, W. S. (1985)
%  \emph{The Elements of Graphing Data}.
%  Wadsworth: Monterey, CA, USA.
%}
%\seealso{
%  \code{\link{dotchart}}.
%}
%\examples{
%require(grDevices)
%pie(rep(1, 24), col = rainbow(24), radius = 0.9)
%
%pie.sales <- c(0.12, 0.3, 0.26, 0.16, 0.04, 0.12)
%names(pie.sales) <- c("Blueberry", "Cherry",
%    "Apple", "Boston Cream", "Other", "Vanilla Cream")
%pie(pie.sales) # default colours
%pie(pie.sales, col = c("purple", "violetred1", "green3",
%                       "cornsilk", "cyan", "white"))
%pie(pie.sales, col = gray(seq(0.4, 1.0, length = 6)))
%pie(pie.sales, density = 10, angle = 15 + 10 * 1:6)
%pie(pie.sales, clockwise = TRUE, main = "pie(*, clockwise = TRUE)")
%segments(0, 0, 0, 1, col = "red", lwd = 2)
%text(0, 1, "init.angle = 90", col = "red")
%
%n <- 200
%pie(rep(1, n), labels = "", col = rainbow(n), border = NA,
%    main = "pie(*, labels=\"\", col=rainbow(n), border=NA,..")
%
%## Another case showing pie() is rather fun than science:
%## (original by FinalBackwardsGlance on http://imgur.com/gallery/wWrpU4X)
%pie(c(Sky = 78, "Sunny side of pyramid" = 17, "Shady side of pyramid" = 5),
%    init.angle = 315, col = c("deepskyblue", "yellow", "yellow3"), border = FALSE)
%}
%\keyword{hplot}
%
%\encoding{UTF8}
%