% File src/library/grid/man/gpar.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{gpar}
%@%\alias{グリッドのグラフィカルパラメータ}
\alias{gpar}
\alias{get.gpar}
\title{グリッドのグラフィカルパラメータの処理}
%\title{Handling Grid Graphical Parameters}
\description{
  \code{gpar()} はグラフィカルパラメータ設定のセットを
  作るために使われるべきである．これは
  クラス \code{"gpar"} のオブジェクトを返す．これは基本的に
  名前と値の対のリストである．

  \code{get.gpar()} は現在の
  グラフィカルパラメータ設定のセットを問い合わせるのに
  使うことが出来る．
}
\usage{
gpar(...)
get.gpar(names = NULL)
}
\arguments{
  \item{\dots}{幾つかの名前付きの引数．}
  \item{names}{適正なグラフィカルパラメータ名の
    文字列ベクトル．}
}
\details{
  全てのグリッドのビューポートと
  (予め定義された)グラフィカルオブジェクトは
  \code{gp} と呼ばれるスロットを持ち，
  これは \code{"gpar"} オブジェクトを持つ．
  ビューポートがビューポートスタック上にプッシュされ
  そしてグラフィカルオブジェクトが描画されると，
  \code{"gpar"} 中の設定が強要される．
  このようにして，グラフィカル出力は
  \code{gp} によりグラフィカルオブジェクトの描画が終了するまで
  ，またはビューポートがビューポートスタックからポップオフされるまで，
  またはある他のビューポートまたはグラフィカルオブジェクト
  がプッシュされるか描画されるまで，変更される．

  既定のパラメータ設定は
  ROOT ビューポートにより定義され，これは
  その設定をグラフィカルデバイスから取る．
  これらの既定はデバイス間で異なるかもしれない
  (例えば既定の \code{fill} 設定は PDF デバイスと比較した
  PNG デバイスに対しては異なる)．

  適正なパラメータ名は次の通りである：
  \tabular{ll}{
    col \tab 線と境界のための色\cr
    fill \tab 矩形や多角形等を塗り潰すための色\cr
    alpha \tab 透明性のためのアルファチャンネル\cr
    lty \tab 線種 \cr
    lwd \tab 線幅 \cr
    lex \tab 線幅に対する倍数 \cr
    lineend \tab 線の端のスタイル(丸，石突，正方形) \cr
    linejoin \tab 線の結び目のスタイル(丸，留繋ぎ，はす縁) \cr
    linemitre \tab 線の留繋ぎ限界(1より大きな数値) \cr
    fontsize \tab テキストのサイズ(ポイント単位) \cr
    cex \tab fontsize に対する倍数 \cr
    fontfamily \tab フォント族 \cr
    fontface \tab フォントのフェイス(ボールド，イタリック，...) \cr
    lineheight \tab テキストのサイズの倍数としての一行の高さ \cr
    font \tab フォントのフェイス(fontface に対する別名；後ろ向きの互換性のため) \cr
  }
  これらの多くに対するより詳細は基本パッケージ中の
  対応するグラフィカルパラメータ \code{\link{par}} に対するヘルプを見よ．
  (これは少し異なる名前を持つかもしれない，例えば
  \code{lend}, \code{ljoin}, \code{lmitre}, \code{family}．)

  色は \code{\link{rgb}} が返す形式の一つで指定できる，
  名前(\code{\link{colors}} を見よ)または
  現在の \link{palette} 中の非負整数添字
  (ゼロは透明色とされる)．
  (負の値は今はエラーになる．)

  \code{alpha} の設定は個々の色に対するアルファチャンネルに
  掛けることで結び付けられる
  (双方のアルファ設定は範囲 0 から 1 に正規化される)．

  テキストのサイズは \code{fontsize}*\code{cex} である．
  線のサイズは \code{fontsize}*\code{cex}*\code{lineheight}．

  \code{cex} 設定は累積的である；もしビューポートが
  \code{cex} が 0.5 でプッシュされ，別のビューポートが
  \code{cex} が 0.5 でプッシュされると，実効的な \code{cex}
  は 0.25 になる．

  \code{alpha} と \code{lex} の設定もまた累積的である．

  \code{fontfamily} の変更はある種のデバイスでは無視されるが，
  PostScript, PDF, X11, Windows そして Quartz ではサポートされる．
  \code{fontfamily} は
  Hershey フォント族の一つを指定するのに使うことが出来
  (例えば \code{HersheySerif})そしてこの指定は
  全てのデバイス上で尊重される．

  \code{fontface} の指定は整数や文字列が可能である．
  もし整数なら，それは
  R の基本グラフィカル標準に従う：
  1 = プレーン，2 = ボールド，3 = イタリック，4 = ボールドイタリック．
  もし文字列なら適正な値は：
  \code{"plain"}, \code{"bold"}, \code{"italic"}, \code{"oblique"} そして
  \code{"bold.italic"} である．
  HersheySerif フォント族の特殊例では
  \code{"cyrillic"}, \code{"cyrillic.oblique"} そして \code{"EUC"}
  が又利用できる．

  全てのパラメータ値は複数の値のベクトルになり得る．
  (これは常に意味を持つわけではない
  -- 例えば，ビューポートは最初のパラメータ値だけを
  留意する．)

  \code{get.gpar()} は全ての現在のグラフィカルパラメータの
  設定を返す．
}
\value{
  クラス \code{"gpar"} のオブジェクト．
}
\seealso{
  \code{\link{Hershey}}.
}
\author{Paul Murrell}
\examples{
gp <- get.gpar()
utils::str(gp)
## これは "gpar" オブジェクトを作るだけ：
gpar(col = "red")
gpar(col = "blue", lty = "solid", lwd = 3, fontsize = 16)
get.gpar(c("col", "lty"))
grid.newpage()
vp <- viewport(w = .8, h = .8, gp = gpar(col="blue"))
grid.draw(gTree(children=gList(rectGrob(gp = gpar(col="red")),
                     textGrob(paste("The rect is its own colour (red)",
                                    "but this text is the colour",
                                    "set by the gTree (green)",
                                    sep = "\n"))),
      gp = gpar(col="green"), vp = vp))
grid.text("This text is the colour set by the viewport (blue)",
          y = 1, just = c("center", "bottom"),
          gp = gpar(fontsize=20), vp = vp)
grid.newpage()
## パラメータに対する多重値の例
pushViewport(viewport())
grid.points(1:10/11, 1:10/11, gp = gpar(col=1:10))
popViewport()
}
\keyword{ dplot }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/gpar.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{gpar}
%\alias{gpar}
%\alias{get.gpar}
%\title{Handling Grid Graphical Parameters}
%\description{
%  \code{gpar()} should be used to create a set of graphical
%  parameter settings.  It returns an object of class \code{"gpar"}.  This is
%  basically a list of name-value pairs.
%
%  \code{get.gpar()} can be used to query the current
%  graphical parameter settings.
%}
%\usage{
%gpar(...)
%get.gpar(names = NULL)
%}
%\arguments{
%  \item{\dots}{ Any number of named arguments. }
%  \item{names}{A character vector of valid graphical parameter names.}
%}
%\details{
%  All grid viewports and (predefined) graphical objects have a slot
%  called \code{gp}, which contains a \code{"gpar"} object.  When
%  a viewport is pushed onto the viewport stack and when a graphical object
%  is drawn, the settings in the \code{"gpar"} object are enforced.
%  In this way, the graphical output is modified by the \code{gp}
%  settings until the graphical object has finished drawing, or until the
%  viewport is popped off the viewport stack, or until some other
%  viewport or graphical object is pushed or begins drawing.
%
%  The default parameter settings are defined by the ROOT viewport, which
%  takes its settings from the graphics device.  These defaults may
%  differ between devices (e.g., the default \code{fill} setting is
%  different for a PNG device compared to a PDF device).
%
%  Valid parameter names are:
%  \tabular{ll}{
%    col \tab Colour for lines and borders. \cr
%    fill \tab Colour for filling rectangles, polygons, ... \cr
%    alpha \tab Alpha channel for transparency \cr
%    lty \tab Line type \cr
%    lwd \tab Line width \cr
%    lex \tab Multiplier applied to line width \cr
%    lineend \tab Line end style (round, butt, square) \cr
%    linejoin \tab Line join style (round, mitre, bevel) \cr
%    linemitre \tab Line mitre limit (number greater than 1) \cr
%    fontsize \tab The size of text (in points) \cr
%    cex \tab Multiplier applied to fontsize \cr
%    fontfamily \tab The font family \cr
%    fontface \tab The font face (bold, italic, ...) \cr
%    lineheight \tab The height of a line as a multiple of the size of text \cr
%    font \tab Font face (alias for fontface; for backward compatibility) \cr
%  }
%  For more details of many of these, see the help for the corresponding
%  graphical parameter \code{\link{par}} in base graphics.  (This may
%  have a slightly different name, e.g.\sspace{}\code{lend}, \code{ljoin},
%  \code{lmitre}, \code{family}.)
%
%  Colours can be specified in one of the forms returned by
%  \code{\link{rgb}}, as a name (see \code{\link{colors}}) or as a
%  non-negative integer index into the current \link{palette} (with zero
%  being taken as transparent).  (Negative integer values are now an
%  error.)
%
%  The \code{alpha} setting is combined with the alpha channel for
%  individual colours by multiplying (with both alpha settings
%  normalised to the range 0 to 1).
%
%  The size of text is \code{fontsize}*\code{cex}.  The size of a line
%  is \code{fontsize}*\code{cex}*\code{lineheight}.
%
%  The \code{cex} setting is cumulative;  if a viewport is pushed
%  with a \code{cex} of 0.5 then another viewport is pushed with a
%  \code{cex} of 0.5, the effective \code{cex} is 0.25.
%
%  The \code{alpha} and \code{lex} settings are also cumulative.
%
%  Changes to the \code{fontfamily} may be ignored by some devices,
%  but is supported by PostScript, PDF, X11, Windows, and Quartz.  The
%  \code{fontfamily} may be used to specify one
%  of the Hershey Font families (e.g., \code{HersheySerif})
%  and this specification will be honoured
%  on all devices.
%
%  The specification of \code{fontface} can be an integer or a string.
%  If an integer, then it
%  follows the R base graphics
%  standard:  1 = plain, 2 = bold, 3 = italic, 4 = bold italic.
%  If a string, then valid values are: \code{"plain"},
%  \code{"bold"}, \code{"italic"}, \code{"oblique"}, and
%  \code{"bold.italic"}.
%  For the special case of the HersheySerif font family,
%  \code{"cyrillic"}, \code{"cyrillic.oblique"}, and \code{"EUC"}
%  are also available.
%
%  All parameter values can be vectors of multiple values.  (This will
%  not always make sense -- for example, viewports will only take
%  notice of the first parameter value.)
%
%  \code{get.gpar()} returns all current graphical parameter settings.
%}
%\value{
%  An object of class \code{"gpar"}.
%}
%\seealso{
%  \code{\link{Hershey}}.
%}
%\author{Paul Murrell}
%\examples{
%gp <- get.gpar()
%utils::str(gp)
%## These *do* nothing but produce a "gpar" object:
%gpar(col = "red")
%gpar(col = "blue", lty = "solid", lwd = 3, fontsize = 16)
%get.gpar(c("col", "lty"))
%grid.newpage()
%vp <- viewport(w = .8, h = .8, gp = gpar(col="blue"))
%grid.draw(gTree(children=gList(rectGrob(gp = gpar(col="red")),
%                     textGrob(paste("The rect is its own colour (red)",
%                                    "but this text is the colour",
%                                    "set by the gTree (green)",
%                                    sep = "\n"))),
%      gp = gpar(col="green"), vp = vp))
%grid.text("This text is the colour set by the viewport (blue)",
%          y = 1, just = c("center", "bottom"),
%          gp = gpar(fontsize=20), vp = vp)
%grid.newpage()
%## example with multiple values for a parameter
%pushViewport(viewport())
%grid.points(1:10/11, 1:10/11, gp = gpar(col=1:10))
%popViewport()
%}
%\keyword{ dplot }
%
%\encoding{UTF8}
%