% File src/library/grid/man/grid.delay.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{grid.delay}
%@%\alias{計算と grob の生成のカプセル化}
\alias{grid.delay}
\alias{delayGrob}
\title{計算と grob の生成のカプセル化}
%\title{ Encapsulate calculations and generating a grob }
\description{
  計算と計算結果に依存する grob の生成を共に含み，
  場面が再描画されると(例えばデバイスのサイズが変更されたり編集
  されたりして)計算と grob の生成が再実行されるような
  表現式を評価する．

  エキスパート\emph{だけ}が使用することを意図している．
}
\usage{
delayGrob(expr, list, name=NULL, gp=NULL, vp=NULL)
grid.delay(expr, list, name=NULL, gp=NULL, vp=NULL)
}
\arguments{
  \item{expr}{
    モード \code{\link{expression}} のオブジェクト，または \code{call}，
    または未評価の表現式．}
  \item{list}{
    その中で \code{expr} が評価される環境を定義するリスト．}
  \item{name}{文字列識別子．}
  \item{gp}{
    クラス \code{gpar} のオブジェクトで，典型的には
    関数 \code{gpar} の呼び出しからの出力．
    これは基本的にはグラフィカルパラメータの設定である．}
  \item{vp}{グリッドのビューポートオブジェクト(または NULL)．}
}
\details{
  特別なクラス \code{"delayedgrob"} の grob が生成される
  (そして \code{grid.delay} の場合は描かれる)．
  このクラスに対する \code{makeContent} メソッドは
  リストを評価環境として表現式を
  (そしてその環境を親とするグリッドの名前空間として)評価する．

  \code{expr} 引数はその結果として grob を返すべきである．

  これらの関数は
  \code{grid.record()} と \code{recordGrob()} 関数の類似物である；
  違いはこれらの関数は
  \code{makeContent()} フックに基づいている一方，
  それらは \code{drawDetails()} フックに基づいていることである．
}
\author{ Paul Murrell }
\note{ この関数は
  関数 \code{recordGraphics} の代わりに使われなければ
  \emph{ならない}；
  \code{recordGraphics} の使用に関する恐ろしい警告の
  全てがまたここで責任を持って適用される．
}
\seealso{ \code{\link{recordGraphics}} }
\examples{
grid.delay({
              w <- convertWidth(unit(1, "inches"), "npc")
              rectGrob(width=w)
            },
            list())
}
\keyword{ dplot }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/grid.delay.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{grid.delay}
%\alias{grid.delay}
%\alias{delayGrob}
%\title{ Encapsulate calculations and generating a grob }
%\description{
%  Evaluates an expression that includes both calculations
%  and generating a grob that depends on the calculations so that
%  both the calculations and the grob generation will be rerun when
%  the scene is redrawn (e.g., device resize or editing).
%
%  Intended \emph{only} for expert use.
%}
%\usage{
%delayGrob(expr, list, name=NULL, gp=NULL, vp=NULL)
%grid.delay(expr, list, name=NULL, gp=NULL, vp=NULL)
%}
%\arguments{
%  \item{expr}{object of mode \code{\link{expression}} or \code{call} or
%    an unevaluated expression.}
%  \item{list}{a list defining the environment in which \code{expr} is to
%    be evaluated.}
%  \item{name}{ A character identifier. }
%  \item{gp}{An object of class \code{gpar}, typically the output
%    from a call to the function \code{gpar}.  This is basically
%    a list of graphical parameter settings.}
%  \item{vp}{A Grid viewport object (or NULL).}
%}
%\details{
%  A grob is created of special class \code{"delayedgrob"}
%  (and drawn, in the case of \code{grid.delay}).
%  The \code{makeContent} method for this class
%  evaluates the expression with the list as the evaluation
%  environment (and the grid Namespace as the parent of that
%  environment).
%
%  The \code{expr} argument should return a grob as its result.
%
%  These functions are analogues of the \code{grid.record()}
%  and \code{recordGrob()} functions;  the difference is that
%  these functions are based on the \code{makeContent()} hook,
%  while those functions are based on the \code{drawDetails()}
%  hook.
%}
%\author{ Paul Murrell }
%\note{ This function \emph{must} be used instead of the
%  function \code{recordGraphics};  all of the dire warnings
%  about using \code{recordGraphics} responsibly also apply here.
%}
%\seealso{ \code{\link{recordGraphics}} }
%\examples{
%grid.delay({
%              w <- convertWidth(unit(1, "inches"), "npc")
%              rectGrob(width=w)
%            },
%            list())
%}
%\keyword{ dplot }
%
%\encoding{UTF8}
%