% File src/library/grid/man/grid.grab.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{grid.grab}
%@%\alias{グリッド出力の捕捉}
\alias{grid.grab}
\alias{grid.grabExpr}
\title{現在のグリッドの出力を捕捉する}
%\title{ Grab the current grid output }
\description{
  現在のグリッドのディスプレイリスト
  またはユーザ固有のコードから生成されたシーンから
  gTree オブジェクトを作る，
}
\usage{
grid.grab(warn = 2, wrap = FALSE, ...)
grid.grabExpr(expr, warn = 2, wrap = FALSE, ...)
}
\arguments{
  \item{expr}{評価されるべき表現式．典型的には
    グリッドの描画関数へのある呼び出し．}
  \item{warn}{
    発行される警告の量を指定する整数．
    0 は警告なしを意味し，
    1 は grab が忠実にオリジナルのシーンを表現していないことが
    確実な場合に警告することを意味する．
    2 は grab が忠実にオリジナルのシーンを表現していない
    可能性がある場合に警告することを意味する．
  }
  \item{wrap}{
    出力がどのように捕捉されるかを指示する論理値．
    もし \code{TRUE} ならば，ディスプレイリスト上の各非 grob 要素は
    それを grob 中にラップすることで捕捉される．
  }
  \item{\dots}{
    gTree に渡される引数で，例えば生成される gTree の
    名前またはクラス，もしくは双方．}
}
\details{
  グリッドの出力を gTree として捕捉する四種類の方法がある．

  出力を捕捉する二つの関数がある：
  既存の描画を捕捉するには \code{grid.grab} を使い
  表現式からの出力(何も描くこと無く)を捕捉するには
  \code{grid.grabExpr} を使う．

  これらの関数の各々に対して，出力は二つの方法で捕捉できる．
  一つの方法はより賢明であろうとし
  ディスプレイリスト上の全てのビューポート
  (ポップされたものを含む)を含む
  childrenvp スロットを持つ gTree を作り，
  そしてディスプレイリスト上の全ての grob は
  新しい gTree の子供になる；
  各子供はそれらが適当なビューポート中で描画されるように
  vp スロットに vpPath を持つ．
  換言すれば gTree はディスプレイリスト上の全ての要素を含むが，
  少々変更された型式を持つ．

  他の方法 \code{wrap=TRUE} は grob を
  ディスプレイリスト上の全ての要素に対して grob を
  生成する(そしてこれら全てを gTree の子供とする)．

  最初のアプローチはよりコンパクトでエレガントな
  gTree を作り，これは作業に関してより柔軟であるが，
  全ての可能なグリッド出力を忠実に複製する保証はない．
  二番目のアプローチはより直截的であり，そして作業しにくいが，
  オリジナルの出力を常に忠実に複製すべきである．
}
\value{
  gTree オブジェクト．
}
\seealso{ \code{\link{gTree}}
}
\examples{
pushViewport(viewport(w=.5, h=.5))
grid.rect()
grid.points(stats::runif(10), stats::runif(10))
popViewport()
grab <- grid.grab()
grid.newpage()
grid.draw(grab)
}
\keyword{ dplot }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/grid.grab.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{grid.grab}
%\alias{grid.grab}
%\alias{grid.grabExpr}
%\title{ Grab the current grid output }
%\description{
%  Creates a gTree object from the current grid display list
%  or from a scene generated by user-specified code.
%}
%\usage{
%grid.grab(warn = 2, wrap = FALSE, ...)
%grid.grabExpr(expr, warn = 2, wrap = FALSE, ...)
%}
%\arguments{
%  \item{expr}{ An expression to be evaluated.  Typically,
%    some calls to grid drawing functions. }
%  \item{warn}{ An integer specifying the amount of warnings
%    to emit.  0 means no warnings, 1 means warn when it is
%    certain that the grab will not faithfully represent the
%    original scene. 2 means warn if there's any possibility
%    that the grab will not faithfully represent the
%    original scene.
%  }
%  \item{wrap}{ A logical indicating how the output should
%    be captured. If \code{TRUE}, each non-grob element on the
%    display list is captured by wrapping it in a grob.
%  }
%  \item{\dots}{ arguments passed to gTree, for example, a
%    name and/or class for the gTree that is created.}
%}
%\details{
%  There are four ways to capture grid output as a gTree.
%
%  There are two functions for capturing output:
%  use \code{grid.grab} to capture an existing drawing
%  and \code{grid.grabExpr} to capture the output from
%  an expression (without drawing anything).
%
%  For each of these functions, the output can be captured in
%  two ways.  One way tries to be clever and make a
%  gTree with a childrenvp slot containing all viewports on
%  the display list (including those
%  that are popped) and every
%  grob on the display list as a child of the new
%  gTree;  each child has a vpPath in the vp slot so that it is
%  drawn in the appropriate viewport.
%  In other words, the gTree contains all elements on the display
%  list, but in a slightly altered form.
%
%  The other way, \code{wrap=TRUE},
%  is to create a grob for every element on the
%  display list (and make all of those grobs children of the
%  gTree).
%
%  The first approach creates a more compact and elegant gTree,
%  which is more flexible to work with,
%  but is not guaranteed to faithfully replicate all possible
%  grid output.  The second approach is more brute force, and
%  harder to work with, but
%  should always faithfully replicate the original output.
%}
%\value{
%  A gTree object.
%}
%\seealso{ \code{\link{gTree}}
%}
%\examples{
%pushViewport(viewport(w=.5, h=.5))
%grid.rect()
%grid.points(stats::runif(10), stats::runif(10))
%popViewport()
%grab <- grid.grab()
%grid.newpage()
%grid.draw(grab)
%}
%\keyword{ dplot }
%
%\encoding{UTF8}
