% File src/library/grid/man/grid.layout.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{grid.layout}
%@%\alias{グリッドのレイアウト}
\alias{grid.layout}
\title{グリッドのレイアウトを作る}
%\title{Create a Grid Layout}
\description{
  この関数はグリッドのレイアウトを返し，これは矩形領域の
  分割を記述する．
}
\usage{
grid.layout(nrow = 1, ncol = 1,
        widths = unit(rep_len(1, ncol), "null"),
        heights = unit(rep_len(1, nrow), "null"),
        default.units = "null", respect = FALSE,
        just="centre")
}
\arguments{
  \item{nrow}{レイアウト中の行数を指定する整数．}
  \item{ncol}{レイアウト中の列数を指定する整数．}
  \item{widths}{
    レイアウト中の列の幅を記述する数値ベクトル化単位オブジェクト．}
  \item{heights}{
    レイアウト中の行の幅を記述する数値ベクトル化単位オブジェクト．}
  \item{default.units}{
    もし \code{widths} か \code{heights} が数値ベクトルとしてだけ
    与えられるならば使われる既定の単位を指示する文字列．.}
  \item{respect}{
    論理値か数値行列．もし論理値なら，これは
    行の高さと列の幅が互いを尊重するかどうかを指示する．
    もし行列ならば，ゼロでない値は対応する行と列が
    尊重すべきことを指示する(下の例を見よ)．
  }
  \item{just}{
    文字列または数値ベクトルで
    もしそれがその親ビューポートと同じサイズでなければ
    レイアウトをどのように位置揃えするかを指示する文字列か
    数値ベクトル．もし二つの値があれば，最初の値は水平方向の位置揃え，
    二番目の値は垂直方向の位置揃えを指定する．
    可能な文字列値は：
    \code{"left"}, \code{"right"}, \code{"centre"}, \code{"center"}, \code{"bottom"},
    そして \code{"top"}．数値に対しては，
    0 は右揃えを，そして 1 は右揃えを意味する．
    この文脈では，例えば
    \code{"left"} は親のビューポートの左隅の最左翼のレイアウト列の
    左隅で位置揃えすることを意味する．}
}
\details{
  レイアウトの \code{widths} と \code{heights} に対して
  与えられた単位オブジェクトはレイアウトに対してだけ
  意味を持つ特殊な \code{units} を使うかもしれない．
  これは \code{"null"} 単位で，
  どれだけの利用可能な幅/高さの相対的な割合を
  列/行が占めるかを指示する．
  レイアウト中の相対的な幅と高さの
  より優れた記述に対しては参考文献を見よ．
}
\section{警告}{
  この関数は基本の R のグラフィックス関数
  \code{layout} と混同されるべきではない．
  特に \code{layout} をグリッドのグラフィックスと一緒に使わない．
  \code{layout} に対するドキュメントはある種の有用な情報を提供する
  かもしれず，そしてこの関数は比較可能な状況では同一の挙動を
  すべきである．
  \code{grid.layout} 関数は行の高さと列の幅に対する
  より広い範囲の単位を指定する能力を
  \emph{加えて}おり，入れ子のレイアウトを許す(\code{viewport} を見よ)．
}
\value{
  グリッドのレイアウトオブジェクト．
}
\references{Murrell, P. R. (1999), Layouts: A Mechanism for Arranging
  Plots on a Page, \emph{Journal of Computational and Graphical
  Statistics}, \bold{8}, 121--134.}
\author{Paul Murrell}
\seealso{
  \link{Grid},
  \code{\link{grid.show.layout}},
  \code{\link{viewport}},
  \code{\link{layout}}}

\examples{
## 様々なレイアウト(あるものは少々途中で曲がっている ...)
layout.torture()
## レイアウトの位置揃えのデモ
grid.newpage()
testlay <- function(just="centre") {
  pushViewport(viewport(layout=grid.layout(1, 1, widths=unit(1, "inches"),
                          heights=unit(0.25, "npc"),
                          just=just)))
  pushViewport(viewport(layout.pos.col=1, layout.pos.row=1))
  grid.rect()
  grid.text(paste(just, collapse="-"))
  popViewport(2)
}
testlay()
testlay(c("left", "top"))
testlay(c("right", "top"))
testlay(c("right", "bottom"))
testlay(c("left", "bottom"))
testlay(c("left"))
testlay(c("right"))
testlay(c("bottom"))
testlay(c("top"))
}
\keyword{dplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/grid.layout.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{grid.layout}
%\alias{grid.layout}
%\title{Create a Grid Layout}
%\description{
%  This function returns a Grid layout, which describes a subdivision
%  of a rectangular region.
%}
%\usage{
%grid.layout(nrow = 1, ncol = 1,
%        widths = unit(rep_len(1, ncol), "null"),
%        heights = unit(rep_len(1, nrow), "null"),
%        default.units = "null", respect = FALSE,
%        just="centre")
%}
%\arguments{
%  \item{nrow}{An integer describing the number of rows in the layout.}
%  \item{ncol}{An integer describing the number of columns in the layout.}
%  \item{widths}{A numeric vector or unit object
%    describing the widths of the columns
%    in the layout.}
%  \item{heights}{A numeric vector or unit object
%    describing the heights of the rows
%    in the layout.}
%  \item{default.units}{A string indicating the default units to use
%    if \code{widths} or \code{heights} are only given as numeric vectors.}
%  \item{respect}{A logical value or a numeric matrix.
%    If a logical, this indicates whether
%    row heights and column widths should respect each other.
%    If a matrix, non-zero values indicate that the corresponding
%    row and column should be respected (see examples below).
%  }
%  \item{just}{A string or numeric
%    vector specifying how the
%    layout should be
%    justified if it is not the same size as its parent viewport.
%    If there are two values, the first
%    value specifies horizontal justification and the second value specifies
%    vertical justification.  Possible string values are: \code{"left"},
%    \code{"right"}, \code{"centre"}, \code{"center"}, \code{"bottom"},
%    and \code{"top"}.  For numeric values, 0 means left alignment
%    and 1 means right alignment. NOTE that in this context,
%    \code{"left"}, for example, means align the left
%    edge of the left-most layout column with the left edge of the
%    parent viewport.}
%}
%\details{
%  The unit objects given for the \code{widths} and \code{heights}
%  of a layout may use a special \code{units} that only has
%  meaning for layouts.  This is the \code{"null"} unit, which
%  indicates what relative fraction of the available width/height the
%  column/row occupies.  See the reference for a better description
%  of relative widths and heights in layouts.
%}
%\section{WARNING}{
%  This function must NOT be confused with the base R graphics function
%  \code{layout}.  In particular, do not use \code{layout} in
%  combination with Grid graphics.  The documentation for
%  \code{layout} may provide some useful information and this
%  function should behave identically in comparable situations.  The
%  \code{grid.layout}
%  function has \emph{added} the ability to specify a broader range
%  of units for row heights and column widths, and allows for nested
%  layouts (see \code{viewport}).
%}
%\value{
%  A Grid layout object.
%}
%\references{Murrell, P. R. (1999), Layouts: A Mechanism for Arranging
%  Plots on a Page, \emph{Journal of Computational and Graphical
%  Statistics}, \bold{8}, 121--134.}
%\author{Paul Murrell}
%\seealso{
%  \link{Grid},
%  \code{\link{grid.show.layout}},
%  \code{\link{viewport}},
%  \code{\link{layout}}}
%
%\examples{
%## A variety of layouts (some a bit mid-bending ...)
%layout.torture()
%## Demonstration of layout justification
%grid.newpage()
%testlay <- function(just="centre") {
%  pushViewport(viewport(layout=grid.layout(1, 1, widths=unit(1, "inches"),
%                          heights=unit(0.25, "npc"),
%                          just=just)))
%  pushViewport(viewport(layout.pos.col=1, layout.pos.row=1))
%  grid.rect()
%  grid.text(paste(just, collapse="-"))
%  popViewport(2)
%}
%testlay()
%testlay(c("left", "top"))
%testlay(c("right", "top"))
%testlay(c("right", "bottom"))
%testlay(c("left", "bottom"))
%testlay(c("left"))
%testlay(c("right"))
%testlay(c("bottom"))
%testlay(c("top"))
%}
%\keyword{dplot}
%
%\encoding{UTF8}
%