% File src/library/grid/man/grid.pack.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{grid.pack}
%@%\alias{オブジェクトのパック}
\alias{grid.pack}
\alias{packGrob}
\title{フレーム中のオブジェクトをパックする}
%\title{ Pack an Object within a Frame }
\description{
  これらの関数は，
  \code{grid.frame} と \code{frameGrob} と共に，
  グラフィカルイメージを構成する
  GUI 構成子風のインタフェイスの一部である．
  アイデアは
  \code{grid.frame} または \code{frameGrob} を使いフレームを作り，
  それからこれらの関数を使いオブジェクトをフレーム中に
  パックするということである．
}
\usage{
grid.pack(gPath, grob, redraw = TRUE, side = NULL,
          row = NULL, row.before = NULL, row.after = NULL,
          col = NULL, col.before = NULL, col.after = NULL,
          width = NULL, height = NULL,
          force.width = FALSE, force.height = FALSE, border = NULL,
          dynamic = FALSE)

packGrob(frame, grob, side = NULL,
          row = NULL, row.before = NULL, row.after = NULL,
          col = NULL, col.before = NULL, col.after = NULL,
          width = NULL, height = NULL,
          force.width = FALSE, force.height = FALSE, border = NULL,
          dynamic = FALSE)
}
\arguments{
  \item{gPath}{gPath オブジェクトで，ディスプレイリスト上の
    フレームを指定する．}
  \item{frame}{クラス \code{frame} のオブジェクトで，
    典型的には \code{grid.frame} への呼び出しからの出力．}
  \item{grob}{
    クラス \code{grob} のオブジェクト．パックされるオブジェクト．}
  \item{redraw}{
    出力は更新されるべきかどうかを指示するブール値．}
  \item{side}{
    \code{"left"}, \code{"top"}, \code{"right"},
    \code{"bottom"} の一つでどちら側でオブジェクトをパックするかを
    指示する．}
  \item{row}{
    どの行にオブジェクトを加えるか．
    1 とフレーム中の現在の行数プラス1の間でなければならず，
    オブジェクトが全ての行を占めれば \code{NULL}．}
  \item{row.before}{この行の丁度一つ前の新しい行にオブジェクトを加える．}
  \item{row.after}{この行の丁度一つ後の新しい行にオブジェクトを加える．}
  \item{col}{どの列にオブジェクトを加えるか．
    1 とフレーム中の現在の列数プラス1の間でなければならず，
    オブジェクトが全ての列を占めれば \code{NULL}．}
  \item{col.before}{この列の丁度一つ前の新しい列にオブジェクトを加える．}
  \item{col.after}{この列の丁度一つ後の新しい列にオブジェクトを加える．}
  \item{width}{
    オブジェクトが加えられる列の幅を指定する
    (幅をオブジェクトから取るのを許す代わりに)．}
  \item{height}{
    オブジェクトが加えられる行の高さを指定する
    (高さをオブジェクトから取るのを許す代わりに)．}
  \item{force.width}{
    grob がその中にパックされる行の幅は
    \code{grid.pack} への呼び出し中で指定された幅か，
    幅と既に存在する幅の最大値のどちらかであるべきことを
    指示する論理値．}
  \item{force.height}{
    grob がその中にパックされる列の高さは
    \code{grid.pack} への呼び出し中で指定された高さ，
    その高さと既に存在する高さの最大値のどちらかであるべきことを
    指示する論理値．}
  \item{border}{
    オブジェクトの周囲を指示する長さ4の \code{unit} オブジェクト．}
  \item{dynamic}{もし幅/高さがパックされている grob から
    取られていれば，このブール値フラグは
    grobの幅/高さの単位が grob を直接参照するか，それとも
    grob への gPath を使うか，を指定する．
    後者の場合，grob への変更は
    幅/高さの再計算を惹き起こす．}
}
\details{
  \code{packGrob} は与えられたフレーム grob を修正し
  修正された grob を返す．

  \code{grid.pack} はディスプレイリスト上のフレーム grob を
  破壊的に変更する
  (そしてもし \code{redraw} が \code{TRUE} ならばディスプレイリストを
  再描画する)．

  これらは非常に柔軟な関数(であるはず)である．
  既にフレーム中にあるオブジェクトに相対的に
  新しいオブジェクトをどこに付け加えるかを指定する多くの異なった
  方法がある．
  この関数は指定が自己矛盾していないかをチェックする．

  オブジェクトに付け加えられる行/列の幅/高さは
  \code{width}/\code{height} が指定されない限りオブジェクト自体から
  取られることを注意する．
}
\value{
  \code{packGrob} はフレーム grob を返すが，
  \code{grid.pack} は \code{NULL} を返す．.
}
\author{ Paul Murrell }
\seealso{
  \code{\link{grid.frame}},
    \code{\link{grid.place}},
    \code{\link{grid.edit}} そして \code{\link{gPath}}．
}
\keyword{dplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/grid.pack.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{grid.pack}
%\alias{grid.pack}
%\alias{packGrob}
%\title{ Pack an Object within a Frame }
%\description{
%  these functions, together with \code{grid.frame} and \code{frameGrob}
%  are part of a
%  GUI-builder-like interface to constructing graphical images.
%  The idea is that you create a frame with \code{grid.frame} or
%  \code{frameGrob} then
%  use these functions to pack objects into the frame.
%}
%\usage{
%grid.pack(gPath, grob, redraw = TRUE, side = NULL,
%          row = NULL, row.before = NULL, row.after = NULL,
%          col = NULL, col.before = NULL, col.after = NULL,
%          width = NULL, height = NULL,
%          force.width = FALSE, force.height = FALSE, border = NULL,
%          dynamic = FALSE)
%
%packGrob(frame, grob, side = NULL,
%          row = NULL, row.before = NULL, row.after = NULL,
%          col = NULL, col.before = NULL, col.after = NULL,
%          width = NULL, height = NULL,
%          force.width = FALSE, force.height = FALSE, border = NULL,
%          dynamic = FALSE)
%}
%\arguments{
%  \item{gPath}{ A gPath object, which specifies a frame on the
%    display list.}
%  \item{frame}{ An object of class \code{frame}, typically the output
%  from a call to \code{grid.frame}. }
%  \item{grob}{ An object of class \code{grob}.  The object to be
%    packed. }
%  \item{redraw}{ A boolean indicating whether the output should be updated. }
%  \item{side}{ One of \code{"left"}, \code{"top"}, \code{"right"},
%    \code{"bottom"} to indicate which side to pack the object on. }
%  \item{row}{ Which row to add the object to.  Must be between 1 and
%    the-number-of-rows-currently-in-the-frame + 1, or \code{NULL} in
%    which case the object occupies all rows. }
%  \item{row.before}{ Add the object to a new row just before this row. }
%  \item{row.after}{ Add the object to a new row just after this row. }
%  \item{col}{ Which col to add the object to.  Must be between 1 and
%    the-number-of-cols-currently-in-the-frame + 1, or \code{NULL} in
%    which case the object occupies all cols.  }
%  \item{col.before}{Add the object to a new col just before this col.}
%  \item{col.after}{ Add the object to a new col just after this col. }
%  \item{width}{ Specifies the width of the column that the object is
%    added to (rather than allowing the width to be taken from the object). }
%  \item{height}{ Specifies the height of the row that the object is
%    added to (rather than allowing the height to be taken from the
%    object). }
%  \item{force.width}{ A logical value indicating whether the width of
%    the column that the grob is being packed into should be EITHER the
%    width specified in the call to \code{grid.pack} OR the maximum of
%    that width and the pre-existing width. }
%  \item{force.height}{ A logical value indicating whether the height of
%    the column that the grob is being packed into should be EITHER the
%    height specified in the call to \code{grid.pack} OR the maximum of
%    that height and the pre-existing height. }
%  \item{border}{ A \code{unit} object of length 4 indicating the borders
%    around the object. }
%  \item{dynamic}{ If the width/height is taken from the grob being
%    packed, this boolean flag indicates whether the grobwidth/height
%    unit refers directly to the grob, or uses a gPath to the grob.
%    In the latter case, changes to the grob will trigger a
%    recalculation of the width/height.}
%}
%\details{
%  \code{packGrob} modifies the given frame grob and returns the modified
%  frame grob.
%
%  \code{grid.pack} destructively modifies a frame grob on the display
%  list (and redraws the display list if \code{redraw} is \code{TRUE}).
%
%  These are (meant to be) very flexible functions.  There are many
%  different
%  ways to specify where the new object is to be added relative to the
%  objects already in the frame.  The function checks that the
%  specification is not self-contradictory.
%
%  NOTE that the width/height of the row/col that the object is added to
%  is taken from the object itself unless the \code{width}/\code{height}
%  is specified.
%}
%\value{
%  \code{packGrob} returns a frame grob, but \code{grid.pack} returns
%  \code{NULL}.
%}
%\author{ Paul Murrell }
%\seealso{
%  \code{\link{grid.frame}},
%    \code{\link{grid.place}},
%    \code{\link{grid.edit}}, and \code{\link{gPath}}.
%}
%\keyword{dplot}
%
%\encoding{UTF8}
%