% File src/library/grid/man/grid.record.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2009-2013 R Core Team
% Distributed under GPL 2 or later

\name{grid.raster}
\alias{grid.raster}
%@%\alias{ラスタ―オブジェクト}
\alias{rasterGrob}
\title{ラスタ―オブジェクトを作る}
%\title{Render a raster object}
\description{
  与えられた位置，サイズそして方角のラスタ―オブジェクト(ビットマップイメージ)
  を作る．
}
\usage{
grid.raster(image,
            x = unit(0.5, "npc"), y = unit(0.5, "npc"),
            width = NULL, height = NULL,
            just = "centre", hjust = NULL, vjust = NULL,
            interpolate = TRUE, default.units = "npc",
            name = NULL, gp = gpar(), vp = NULL)

rasterGrob(image,
           x = unit(0.5, "npc"), y = unit(0.5, "npc"),
           width = NULL, height = NULL,
           just = "centre", hjust = NULL, vjust = NULL,
           interpolate = TRUE, default.units = "npc",
           name = NULL, gp = gpar(), vp = NULL)
}
\arguments{
  \item{image}{
    ラスタ―オブジェクトに強制変換される任意の R オブジェクト．
  }
  \item{x}{
    x 位置を指定する数値ベクトルか単位オブジェクト．}
  \item{y}{
    y 位置を指定する数値ベクトルか単位オブジェクト．}
  \item{width}{
    幅を指定する数値ベクトルか単位オブジェクト．}
  \item{height}{
    高さを指定する数値ベクトルか単位オブジェクト．}
  \item{just}{
    矩形のその (x, y) 位置に対する位置揃え．
    もし二つの値があると，最初の値は水平方向の位置揃えで
    二番目の値は垂直方向の位置揃えを指定する．
    可能な文字列値は：
    \code{"left"},
    \code{"right"}, \code{"centre"}, \code{"center"}, \code{"bottom"},
    そして \code{"top"}．数値の値に対しては
    0 は左揃え，1 は右揃えを意味する．
  }
  \item{hjust}{
    水平方向の位置揃えを指定する数値ベクトル．
    もし指定されると \code{just} の設定を上書きする．}
  \item{vjust}{
    垂直方向の位置揃えを指定する数値ベクトル．
    もし指定されると \code{just} の設定を上書きする．}
  \item{default.units}{
    もし \code{x}, \code{y}, \code{width} または
    \code{height} が数値ベクトルとしてだけ与えられた時に
    使われる既定の単位を指示する文字列．}
  \item{name}{文字列識別子．}
  \item{gp}{
    クラス \code{gpar} のオブジェクトで，典型的には
    関数 \code{gpar} への呼び出しからの出力．
    これは基本的にグラフィカルパラメータ設定のリストである．}
  \item{vp}{グリッドのビューポートオブジェクト(または NULL)．}
  \item{interpolate}{
    イメージを線形に補間するかどうかを指示する論理値
    (別法は最近接近傍補間を使うことであるが
    よりゴツゴツした結果を与える)．
  }
}
\details{
  \code{width} も \code{height} もどちらも指定される必要がなく，
  その場合画像のアスペクト比は保存される．
  もし \code{width} と \code{height} の双方が指定されると，
  画像は歪められる可能性が高い．

  全てのグラフィックスデバイスがラスタ―イメージを
  作る機能を持つわけではなく，ある種のそれは回転イメージを
  作ることが出来ないかもしれない
  (つまり，もしラスタ―オブジェクトが回転されたビューポート中で
  描かれた場合)．
  \code{\link{rasterImage}} の下のコメントも見よ．

  \code{alpha} を含む \code{gp} 中の全てのグラフィカル
  パラメータ設定は無視される．
}
\value{
  rastergrob grob．
}
\author{
  Paul Murrell
}
\seealso{
  \code{\link{as.raster}}.

  サポートされているかどうかを見るには \code{\link{dev.capabilities}}．
}
\examples{
redGradient <- matrix(hcl(0, 80, seq(50, 80, 10)),
                      nrow=4, ncol=5)
# 補間
grid.newpage()
grid.raster(redGradient)
# むらのある
grid.newpage()
grid.raster(redGradient, interpolate=FALSE)
# むらがあり伸びた
grid.newpage()
grid.raster(redGradient, interpolate=FALSE, height=unit(1, "npc"))
# 同じラスタ―を何度も描く
grid.newpage()
grid.raster(0, x=1:3/4, y=1:3/4, w=.1, interp=FALSE)
}
\keyword{ dplot }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/grid.record.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2009-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{grid.raster}
%\alias{grid.raster}
%\alias{rasterGrob}
%\title{
%  Render a raster object
%}
%\description{
%  Render a raster object (bitmap image) at the given location, size,
%  and orientation.
%}
%\usage{
%grid.raster(image,
%            x = unit(0.5, "npc"), y = unit(0.5, "npc"),
%            width = NULL, height = NULL,
%            just = "centre", hjust = NULL, vjust = NULL,
%            interpolate = TRUE, default.units = "npc",
%            name = NULL, gp = gpar(), vp = NULL)
%
%rasterGrob(image,
%           x = unit(0.5, "npc"), y = unit(0.5, "npc"),
%           width = NULL, height = NULL,
%           just = "centre", hjust = NULL, vjust = NULL,
%           interpolate = TRUE, default.units = "npc",
%           name = NULL, gp = gpar(), vp = NULL)
%}
%\arguments{
%  \item{image}{
%    Any R object that can be coerced to a raster object.
%  }
%  \item{x}{A numeric vector or unit object specifying x-location.}
%  \item{y}{A numeric vector or unit object specifying y-location.}
%  \item{width}{A numeric vector or unit object specifying width.}
%  \item{height}{A numeric vector or unit object specifying height.}
%  \item{just}{The justification of the rectangle
%    relative to its (x, y) location.  If there are two values, the first
%    value specifies horizontal justification and the second value specifies
%    vertical justification.  Possible string values are: \code{"left"},
%    \code{"right"}, \code{"centre"}, \code{"center"}, \code{"bottom"},
%    and \code{"top"}.  For numeric values, 0 means left alignment
%    and 1 means right alignment.
%  }
%  \item{hjust}{A numeric vector specifying horizontal justification.
%    If specified, overrides the \code{just} setting.}
%  \item{vjust}{A numeric vector specifying vertical justification.
%    If specified, overrides the \code{just} setting.}
%  \item{default.units}{A string indicating the default units to use
%    if \code{x}, \code{y}, \code{width}, or \code{height}
%    are only given as numeric vectors.}
%  \item{name}{ A character identifier. }
%  \item{gp}{An object of class \code{gpar}, typically the output
%    from a call to the function \code{gpar}.  This is basically
%    a list of graphical parameter settings.}
%  \item{vp}{A Grid viewport object (or NULL).}
%  \item{interpolate}{
%    A logical value indicating whether to linearly interpolate the
%    image (the alternative is to use nearest-neighbour interpolation,
%    which gives a more blocky result).
%  }
%}
%\details{
%  Neither \code{width} nor \code{height} needs to be specified,
%  in which case, the aspect ratio of the image is preserved.  If
%  both \code{width} and \code{height} are specified, it is likely
%  that the image will be distorted.
%
%  Not all graphics devices are capable of rendering raster images
%  and some may not be able to produce rotated images (i.e., if
%  a raster object is rendered within a rotated viewport).  See also the
%  comments under \code{\link{rasterImage}}.
%
%  All graphical parameter settings in \code{gp} will be ignored,
%  including \code{alpha}.
%}
%\value{
%  A rastergrob grob.
%}
%\author{
%  Paul Murrell
%}
%\seealso{
%  \code{\link{as.raster}}.
%
%  \code{\link{dev.capabilities}} to see if it is supported.
%}
%\examples{
%redGradient <- matrix(hcl(0, 80, seq(50, 80, 10)),
%                      nrow=4, ncol=5)
%# interpolated
%grid.newpage()
%grid.raster(redGradient)
%# blocky
%grid.newpage()
%grid.raster(redGradient, interpolate=FALSE)
%# blocky and stretched
%grid.newpage()
%grid.raster(redGradient, interpolate=FALSE, height=unit(1, "npc"))
%
%# The same raster drawn several times
%grid.newpage()
%grid.raster(0, x=1:3/4, y=1:3/4, w=.1, interp=FALSE)
%}
%\keyword{ dplot }
%
%\encoding{UTF8}
%