% File src/library/grid/man/grid.remove.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{grid.remove}
\alias{grid.remove}
%@%\alias{グラフィカルオブジェクトの除去}
\alias{grid.gremove}
\alias{removeGrob}
\title{グリッドのグラフィカルオブジェクトを取り除く}
%\title{Remove a Grid Graphical Object}
\description{
  gTree または gTree の子孫を grob から取り除く．
}
\usage{
grid.remove(gPath, warn = TRUE, strict  =  FALSE, grep = FALSE,
            global = FALSE, allDevices = FALSE, redraw = TRUE)

grid.gremove(\dots, grep = TRUE, global = TRUE)

removeGrob(gTree, gPath, strict = FALSE, grep = FALSE,
           global = FALSE, warn = TRUE)
}
\arguments{
  \item{gTree}{gTree オブジェクト．}
  \item{gPath}{gPath オブジェクト．\code{grid.remove} に対してはこれは
    ディスプレイリスト上の gTree を指定する．
    \code{removeGrob} に対してはこれは
    指定された gTree の子孫を意味する．}
  \item{strict}{
    gPath が正確にマッチされるべきかどうかを指示するブール値．}
  \item{grep}{
    \code{gPath} が正規表現として扱われるべきかどうかを指示するブール値．
    値は \code{gPath} の要素を跨ってリサイクルされる．
    (例えば \code{c(TRUE, FALSE)} は
    \code{gPath} の奇数番目の要素だけが正規表現として扱われる)．
  }
  \item{global}{
    関数が \code{gPath} の最初のマッチに影響するか，または全てのマッチに
    影響すべきかを指示するブール値．
  }
  \item{allDevices}{
    全ての開かれたデバイスにマッチするものを探すか，または単に現在の
    デバイスを探すかを指示するブール値．
    まだ実装されていない．
  }
  \item{warn}{
    指定された grob が見つからなければエラーを発生するかを
    指示する論理値．}
  \item{redraw}{
    grob を再描画するかどうかを指示する．論理値．}
  \item{\dots}{
    \code{grid.get} に渡される引数．}
}
\details{
  \code{removeGrob} は指定された grob をコピーしそして
  修正された grob を返す．

  \code{grid.remove} はディスプレイリスト上の
  grob を破壊的に修正する．
  もし \code{redraw} が \code{TRUE} ならばそれから
  変更を反映するために全てを再描画する．

  \code{grid.gremove} (global の \code{g})は異なった既定値を
  持つ \code{grid.remove} に対する便利なラッパである．
}
\value{
  \code{removeGrob} は grob オブジェクトを返す；
  \code{grid.remove} は \code{NULL} を返す．
}
\author{Paul Murrell}
\seealso{
  \code{\link{grob}}, \code{\link{getGrob}},
  \code{\link{removeGrob}}, \code{\link{removeGrob}}.
}
\keyword{dplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/grid.remove.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{grid.remove}
%\alias{grid.remove}
%\alias{grid.gremove}
%\alias{removeGrob}
%\title{Remove a Grid Graphical Object}
%\description{
%  Remove a grob from a gTree or a descendant of a gTree.
%}
%\usage{
%grid.remove(gPath, warn = TRUE, strict  =  FALSE, grep = FALSE,
%            global = FALSE, allDevices = FALSE, redraw = TRUE)
%
%grid.gremove(\dots, grep = TRUE, global = TRUE)
%
%removeGrob(gTree, gPath, strict = FALSE, grep = FALSE,
%           global = FALSE, warn = TRUE)
%}
%\arguments{
%  \item{gTree}{A gTree object.}
%  \item{gPath}{ A gPath object. For \code{grid.remove} this
%    specifies a gTree on the display list.  For \code{removeGrob} this
%    specifies a descendant of the specified gTree. }
%  \item{strict}{ A boolean indicating whether the gPath must be
%    matched exactly. }
%  \item{grep}{A boolean indicating whether the \code{gPath} should
%    be treated as a regular expression.  Values are recycled across
%    elements of the \code{gPath} (e.g., \code{c(TRUE, FALSE)} means
%    that every odd element of the \code{gPath} will be treated as
%    a regular expression).
%  }
%  \item{global}{ A boolean indicating whether the function should affect
%    just the first match of the \code{gPath}, or whether all matches
%    should be affected.
%  }
%  \item{allDevices}{ A boolean indicating whether all open devices
%    should
%    be searched for matches, or just the current device.
%    NOT YET IMPLEMENTED.
%  }
%  \item{warn}{A logical to indicate whether failing to find the
%    specified grob should trigger an error.  }
%  \item{redraw}{A logical value to indicate whether to redraw the grob. }
%  \item{\dots}{ Arguments that are passed to \code{grid.get}. }
%}
%\details{
%  \code{removeGrob} copies the specified grob and returns a modified
%  grob.
%
%  \code{grid.remove} destructively modifies a grob on the display list.
%  If \code{redraw}
%  is \code{TRUE} it then redraws everything to reflect the change.
%
%  \code{grid.gremove} (\code{g} for global) is just a convenience wrapper for
%  \code{grid.remove} with different defaults.
%}
%\value{
%  \code{removeGrob} returns a grob object;  \code{grid.remove} returns
%  \code{NULL}.
%}
%\author{Paul Murrell}
%\seealso{
%  \code{\link{grob}}, \code{\link{getGrob}},
%  \code{\link{removeGrob}}, \code{\link{removeGrob}}.
%}
%\keyword{dplot}
%
%\encoding{UTF8}
%