% File src/library/grid/man/showViewport.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{showViewport}
%@%\alias{showViewport}
\alias{showViewport}
\title{グリッドのビューポートを表示する．}
%\title{Display grid viewports.}
\description{
  現在のグリッドのビューポート(既定)のグラフィカルな表示を作る．
  特定のビューポートだけを表示することも出来る．
  各ビューポートは矩形で描かれビューポートの名前のラベルが付く．
}
\usage{
showViewport(vp = NULL, recurse = TRUE, depth = NULL,
             newpage = FALSE, leaves = FALSE,
             col = rgb(0, 0, 1, 0.2), fill = rgb(0, 0, 1, 0.1),
             label = TRUE, nrow = 3, ncol = nrow)
}
\arguments{
  \item{vp}{
    もし \code{NULL} なら現在のビューポートのツリーが
    表示される．
    さもなければビューポート(または vpList または vpStack または vpTree)
    ，またはどのビューポートを表示するかを指定する vpPath．
  }
  \item{recurse}{
    指定されたビューポートの子供達もまた表示するか?
  }
  \item{depth}{
    指定された深さ(深さのベクトルかもしれない)のビューポートだけを表示する．
  }
  \item{newpage}{
    表示のために新しいページを開始するか?
    さもなければビューポートは現在のプロットの上に表示される．
  }
  \item{leaves}{
    小さなディスプレイの行列を作り，
    葉のビューポートはそれ自体のディスプレイ中にある．
  }
  \item{col}{
    各ビューポートに対する矩形の境界と
    各ビューポートに対するラベルを描くのに使われる色．
    もしベクトルならば，最初の色は
    トップレベルのビューポートに使われ，二番目の色は
    その子供達に使われ，三番目の色は彼らの子供達に使われる，
    云々．
  }
  \item{fill}{
    各ビューポートを塗りつぶすのに使われる色．
    \code{col} 毎のベクトルかもしれない．
  }
  \item{label}{
    ビューポートはラベル(ビューポートの名前の)を付けるか?
  }
  \item{nrow, ncol}{
    \code{leaves} が \code{TRUE} の時の行と列の数．
    さもなければ無視される．
  }
}

\seealso{
  \code{\link{viewport}} と
  \code{\link{grid.show.viewport}}
}
\examples{
showViewport(viewport(width=.5, height=.5, name="vp"))

grid.newpage()
pushViewport(viewport(width=.5, height=.5, name="vp"))
upViewport()
showViewport(vpPath("vp"))

showViewport(vpStack(viewport(width=.5, height=.5, name="vp1"),
                     viewport(width=.5, height=.5, name="vp2")),
             newpage=TRUE)

showViewport(vpStack(viewport(width=.5, height=.5, name="vp1"),
                     viewport(width=.5, height=.5, name="vp2")),
             fill=rgb(1:0, 0:1, 0, .1),
             newpage=TRUE)
}
\keyword{ dplot }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/showViewport.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{showViewport}
%\alias{showViewport}
%\title{
%  Display grid viewports.
%}
%\description{
%  Produces a graphical display of (by default) the current
%  grid viewport tree.  It is also possible to display only
%  specific viewports.  Each viewport is drawn as a rectangle
%  and the leaf viewports are labelled with the viewport name.
%}
%\usage{
%showViewport(vp = NULL, recurse = TRUE, depth = NULL,
%             newpage = FALSE, leaves = FALSE,
%             col = rgb(0, 0, 1, 0.2), fill = rgb(0, 0, 1, 0.1),
%             label = TRUE, nrow = 3, ncol = nrow)
%}
%\arguments{
%  \item{vp}{
%    If \code{NULL}, the current viewport tree is displayed.
%    Otherwise, a viewport (or vpList, or vpStack, or vpTree) or
%    a vpPath that specifies which viewport to display.
%  }
%  \item{recurse}{
%    Should the children of the specified viewport also be displayed?
%  }
%  \item{depth}{
%    Only display viewports at the specified depth (may be a vector
%    of depths).
%  }
%  \item{newpage}{
%    Start a new page for the display?  Otherwise, the viewports
%    are displayed on top of the current plot.
%  }
%  \item{leaves}{
%    Produce a matrix of smaller displays, with each leaf viewport
%    in its own display.
%  }
%  \item{col}{
%    The colour used to draw the border of the rectangle for each
%    viewport \emph{and} to draw the label for each viewport.
%    If a vector, then the first colour is used for the
%    top-level viewport, the second colour is used for its children,
%    the third colour for their children, and so on.
%  }
%  \item{fill}{
%    The colour used to fill each viewport.  May be a vector as per
%    \code{col}.
%  }
%  \item{label}{
%    Should the viewports be labelled (with the viewport name)?
%  }
%  \item{nrow, ncol}{
%    The number of rows and columns when \code{leaves} is \code{TRUE}.
%    Otherwise ignored.
%  }
%}
%
%\seealso{
%  \code{\link{viewport}} and
%  \code{\link{grid.show.viewport}}
%}
%\examples{
%showViewport(viewport(width=.5, height=.5, name="vp"))
%
%grid.newpage()
%pushViewport(viewport(width=.5, height=.5, name="vp"))
%upViewport()
%showViewport(vpPath("vp"))
%
%showViewport(vpStack(viewport(width=.5, height=.5, name="vp1"),
%                     viewport(width=.5, height=.5, name="vp2")),
%             newpage=TRUE)
%
%showViewport(vpStack(viewport(width=.5, height=.5, name="vp1"),
%                     viewport(width=.5, height=.5, name="vp2")),
%             fill=rgb(1:0, 0:1, 0, .1),
%             newpage=TRUE)
%}
%\keyword{ dplot }
%
%\encoding{UTF8}
%<