% File src/library/grid/man/unit.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{unit}
%@%\alias{単位オブジェクトを作る}
\alias{unit}
\title{単位オブジェクトを作る関数}
%\title{Function to Create a Unit Object}
\description{
  この関数は単位値のベクトルである単位オブジェクトを作る．
  単位値は典型的には単に関連する単位を備えた単一の数値である．
}
\usage{
unit(x, units, data=NULL)
}
\arguments{
  \item{x}{数値ベクトル．}
  \item{units}{対応する数値に対する単位を指定する文字列ベクトル．}
  \item{data}{この引数は
    特別な \code{unit} タイプに対する追加の情報を提供するのに使われる．}
}
\details{
  単位オブジェクトはユーザが異なった多数の座標系中の位置や次元を指定することを
  可能にする．全ての描画はビューポートに相対的になされ，
  \code{units} はそのビューポート中でどの座標系を使うかを指定する．

  可能な \code{units} (座標系)は：
  \describe{
    \item{\code{"npc"}}{正規化された親座標(既定値)．
      ビューポートの原点は (0, 0) でビューポートは
      幅と高さを持つ．例えば
      (0.5, 0.5) はビューポートの中心である．}
    \item{\code{"cm"}}{センチメートル．}
    \item{\code{"inches"}}{インチ．1 in = 2.54 cm．}
    \item{\code{"mm"}}{ミリメートル．10 mm = 1 cm．}
    \item{\code{"points"}}{ポイント．72.27 pt = 1 in．}
    \item{\code{"picas"}}{パイカ．1 pc = 12 pt．}
    \item{\code{"bigpts"}}{ビッグポイント．72 bp = 1 in．}
    \item{\code{"dida"}}{ジーダ．1157 dd = 1238 pt．}
    \item{\code{"cicero"}}{キケロ.  1 cc = 12 dd.}
    \item{\code{"scaledpts"}}{スケールドポイント．65536 sp = 1 pt．}
    \item{\code{"lines"}}{
      テキストの行数．位置と次元は
      ビューポートの既定のテキストのサイズの倍数で与えられる
      (ビューポートの \code{fontsize} と \code{lineheight} で
      指定されるような).}
    \item{\code{"char"}}{
      ビューポートの名目上のフォントの高さの倍数
      (ビューポートの \code{fontsize} で指定されるような).}
    \item{\code{"native"}}{
      位置と次元はビューポートの \code{xscale} と \code{yscale}
      に関して相対的である．}
    \item{\code{"snpc"}}{
      正方形に正規化された親座標．
      水平と垂直方向の位置/次元に対して同じ回答を与えることを
      除けば正規化親座標と同じ．
      これは npc 幅と npc 高さの\emph{小さい方}を使う．
      これはビューポートの比率であるようなものを作るのに役立つが，
      正方形でなければならない
      (または固定されたアスペクト比を持つ)．}
    \item{\code{"strwidth"}}{
      \code{data} 引数中で指定された文字列の幅の倍数．
      フォントのサイズはビューポートのポイントサイズで決定される．}
    \item{\code{"strheight"}}{
      \code{data} 引数中で指定された文字列の高さの倍数．
      フォントのサイズはビューポートのポイントサイズで決定される．}
    \item{\code{"grobwidth"}}{
      \code{data} 引数中で指定された grob の幅の倍数．}
    \item{\code{"grobheight"}}{
      \code{data} 引数中で指定された grob の高さの倍数．}
  }

  殆どの通常の単位に対する幾つかの変種がまた許される．
  例えば，
  \code{"inches"} と \code{"centimetre"} の代わりに
  \code{"in"} か \code{"inch"}，または
  \code{"cm"} の代わりに \code{"centimeter"} を使うことが出来る．

  特殊な \code{units} 値の \code{"null"} がまた許されるが，
  グリッドのレイアウトの列の幅や行の高さを
  指定する時にだけ意味を持つ．

  \code{unit.length()} が1より大きければ
  \code{data} 引数はリストでなければならない．例えば
\preformatted{  unit(rep(1, 3), c("npc", "strwidth", "inches"),
  data = list(NULL, "my string", NULL)).
}

  単位オブジェクトを通常の仕方による部分操作と
  部分的付値をすることが可能である
  (例を見よ)が，単位オブジェクトを連結するには
  特別な関数 \code{unit.c} が用意されている．

  単位オブジェクトに対するある算術と要約操作が
  定義されている．
  特に単位オブジェクトの和と差
  (例えば \code{unit(1, "npc") - unit(1, "inches")})，
  単位オブジェクトのりストの最小値と最大値を指定することが
  可能である(例えば \code{min(unit(0.5, "npc"), unit(1, "inches"))})．
  }
\section{警告}{
  幾つかの単位オブジェクトを連結するための特別な関数
  \code{unit.c} がある．

  \code{c} 関数は正しい回答を与えない．

  単位 \code{"mylines"}, \code{"mychar"}, \code{"mystrwidth"},
  \code{"mystrheight"} が使われてきた．これらは依然受け入れられるが，
  \code{"lines"}, \code{"char"}, \code{"strwidth"},
  \code{"strheight"} と正確に同じ動作をする．
}
\value{
  クラス \code{"unit"} のオブジェクト．
}
\author{Paul Murrell}
\seealso{
  \code{\link{unit.c}}
}

\examples{
unit(1, "npc")
unit(1:3/4, "npc")
unit(1:3/4, "npc") + unit(1, "inches")
min(unit(0.5, "npc"), unit(1, "inches"))
unit.c(unit(0.5, "npc"), unit(2, "inches") + unit(1:3/4, "npc"),
       unit(1, "strwidth", "hi there"))
x <- unit(1:5, "npc")
x[2:4]
x[2:4] <- unit(1, "mm")
x
}
\keyword{dplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/unit.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{unit}
%\alias{unit}
%\title{Function to Create a Unit Object}
%\description{
%  This function creates a unit object --- a vector of unit values.
%  A unit value is typically just a single numeric value with an
%  associated unit.
%}
%\usage{
%unit(x, units, data=NULL)
%}
%\arguments{
%  \item{x}{A numeric vector.}
%  \item{units}{A character vector specifying the units for the
%    corresponding numeric values.}
%  \item{data}{This argument is used to supply extra information
%    for special \code{unit} types.}
%}
%\details{
%  Unit objects allow the user to specify locations and dimensions
%  in a large number of different coordinate systems.  All drawing
%  occurs relative to a viewport and the \code{units} specifies
%  what coordinate system to use within that viewport.
%
%  Possible \code{units} (coordinate systems) are:
%  \describe{
%    \item{\code{"npc"}}{Normalised Parent Coordinates (the default).
%      The origin of the viewport is (0, 0) and the viewport has a width
%      and height of 1 unit.  For example, (0.5, 0.5) is the centre of
%      the viewport.}
%    \item{\code{"cm"}}{Centimetres.}
%    \item{\code{"inches"}}{Inches.  1 in = 2.54 cm.}
%    \item{\code{"mm"}}{Millimetres.  10 mm = 1 cm.}
%    \item{\code{"points"}}{Points.  72.27 pt = 1 in.}
%    \item{\code{"picas"}}{Picas.  1 pc = 12 pt.}
%    \item{\code{"bigpts"}}{Big Points.  72 bp = 1 in.}
%    \item{\code{"dida"}}{Dida.  1157 dd = 1238 pt.}
%    \item{\code{"cicero"}}{Cicero.  1 cc = 12 dd.}
%    \item{\code{"scaledpts"}}{Scaled Points.  65536 sp = 1 pt.}
%    \item{\code{"lines"}}{Lines of text.  Locations and dimensions
%      are in terms of multiples of the default text size of the viewport
%      (as specified by the viewport's \code{fontsize} and \code{lineheight}).}
%    \item{\code{"char"}}{Multiples of nominal font height of the
%      viewport (as specified by the viewport's \code{fontsize}).}
%    \item{\code{"native"}}{Locations and dimensions are relative to
%      the viewport's \code{xscale} and \code{yscale}.}
%    \item{\code{"snpc"}}{Square Normalised Parent Coordinates.
%      Same as Normalised Parent Coordinates, except gives the same answer for
%      horizontal and vertical locations/dimensions.  It uses the
%      \emph{lesser} of npc-width and npc-height.  This is useful for making
%      things which are a proportion of the viewport, but have to be square
%      (or have a fixed aspect ratio).}
%    \item{\code{"strwidth"}}{Multiples of the width of the string
%      specified in the \code{data} argument.  The font size is
%      determined by the pointsize of the viewport.}
%    \item{\code{"strheight"}}{Multiples of the height of the string
%      specified in the \code{data} argument.  The font size is
%      determined by the pointsize of the viewport.}
%    \item{\code{"grobwidth"}}{Multiples of the width of the grob
%      specified in the \code{data} argument.}
%    \item{\code{"grobheight"}}{Multiples of the height of the grob
%      specified in the \code{data} argument.}
%  }
%
%  A number of variations are also allowed for the most common units.
%  For example, it is possible to use \code{"in"} or \code{"inch"}
%  instead of \code{"inches"} and \code{"centimetre"} or
%  \code{"centimeter"} instead of \code{"cm"}.
%
%  A special \code{units} value of \code{"null"} is also allowed,
%  but only makes sense when used in specifying widths of columns
%  or heights of rows in grid layouts (see \code{\link{grid.layout}}).
%
%  The \code{data} argument must be a list when the \code{unit.length()}
%  is greater than 1.  For example,
%\preformatted{  unit(rep(1, 3), c("npc", "strwidth", "inches"),
%  data = list(NULL, "my string", NULL))
%}.
%
%  It is possible to subset unit objects in the normal way and to perform
%  subassignment (see the examples),
%  but a special function
%  \code{unit.c} is provided for combining unit objects.
%
%  Certain arithmetic and summary operations are defined for
%  unit objects.  In particular, it is possible to add and subtract
%  unit objects (e.g., \code{unit(1, "npc") - unit(1, "inches")}),
%  and to specify the minimum or maximum of a list
%  of unit objects (e.g., \code{min(unit(0.5, "npc"), unit(1,
%    "inches"))}).
%}
%\section{WARNING}{
%  There is a special function \code{unit.c} for concatenating
%  several unit objects.
%
%  The \code{c} function will not give the right answer.
%
%  There used to be \code{"mylines"}, \code{"mychar"}, \code{"mystrwidth"},
%  \code{"mystrheight"} units.  These will still be accepted, but
%  work exactly the same as
%  \code{"lines"}, \code{"char"}, \code{"strwidth"},
%  \code{"strheight"}.
%}
%\value{
%  An object of class \code{"unit"}.
%}
%\author{Paul Murrell}
%\seealso{
%  \code{\link{unit.c}}
%}
%
%\examples{
%unit(1, "npc")
%unit(1:3/4, "npc")
%unit(1:3/4, "npc") + unit(1, "inches")
%min(unit(0.5, "npc"), unit(1, "inches"))
%unit.c(unit(0.5, "npc"), unit(2, "inches") + unit(1:3/4, "npc"),
%       unit(1, "strwidth", "hi there"))
%x <- unit(1:5, "npc")
%x[2:4]
%x[2:4] <- unit(1, "mm")
%x
%}
%\keyword{dplot}
%
%\encoding{UTF8}
%