% File src/library/stats/man/Hypergeometric.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2016 R Core Team
% Distributed under GPL 2 or later

\name{Hypergeometric}
\alias{Hypergeometric}
\alias{dhyper}
\alias{phyper}
\alias{qhyper}
\alias{rhyper}
\title{The Hypergeometric Distribution}
\description{
 超幾何分布に対する密度，分布関数，クォンタイル関数と乱数生成．
}
\usage{
dhyper(x, m, n, k, log = FALSE)
phyper(q, m, n, k, lower.tail = TRUE, log.p = FALSE)
qhyper(p, m, n, k, lower.tail = TRUE, log.p = FALSE)
rhyper(nn, m, n, k)
}
\arguments{
  \item{x, q}{クォンタイルのベクトル，黒と白のボールを含む壺から
    置き換え無しで取り出された白いボールの数を表す．}
  \item{m}{壺の中の白いボールの数．}
  \item{n}{壺の中の黒いボールの数．}
  \item{k}{壺から取り出されたボールの数．}
  \item{p}{確率，0 と 1 の間でなければならない．}
  \item{nn}{観測値の数．もし\code{length(nn) > 1} なら
    その長さは必要な数とされる．}
  \item{log, log.p}{論理値；もし TRUE なら確率 p は log(p) とされる．}
  \item{lower.tail}{論理値；もし TRUE (既定値)なら
    確率は \eqn{P[X \le x]} で，さもなければ \eqn{P[X > x]}．}
}
\value{
  \code{dbeta} は密度，\code{pbeta} は分布関数，
  \code{qbeta} はクォンタイル関数，そして
  \code{rbeta} は乱数を生成する．

  不正な引数は値 \code{NaN} を返し，警告が出る．

  \code{rbeta} に対しては結果の長さは \code{n} で決まり，
  そして他の関数に対しては数値引数の最大長である．

  \code{n} 以外の数値引数は結果の長さまでリサイクルされる．
  論理値引数は最初の要素だけが使われる．
}
\details{
  超幾何分布は
  \emph{置き換え無し}のサンプリングに対して使われる．
  パラメータ \code{m}, \code{n} そして \code{k}
  (以下の参考文献ではそれぞれ名前 \eqn{Np}, \eqn{N-Np}
  そして \eqn{n} を持つ)は \eqn{x = 0, \ldots, k} に対して
  次のように与えられる
  \deqn{
    p(x) = \left. {m \choose x}{n \choose k-x} \right/ {m+n \choose k}%
  }{p(x) =      choose(m, x) choose(n, k-x) / choose(m+n, k)}

  \eqn{p(x)} は
  \eqn{\max(0, k-n) \le x \le \min(k, m)}{max(0, k-n) <= x <= min(k, m)}
  に対してだけゼロでないことを注意する．

  \eqn{p := m/(m+n)} では(従って参考文献の表記では
  \eqn{Np = N \times p})最初の二つのモーメントは
  平均 \deqn{E[X] = \mu = k p} で分散は
  \deqn{\mbox{Var}(X) = k p (1 - p) \frac{m+n-k}{m+n-1},}{%
               Var(X) = k p (1 - p) * (m+n-k)/(m+n-1),}
  であり
  Binomial\eqn{(k,p)} (そこでは
  \eqn{k = 1} で無い限り超幾何分布は小さな分散を持つ)
  に似ている．

  クォンタイルは
  \eqn{F(x) \ge p} となる最少の \eqn{x} である，
  ここで \eqn{F} は分布関数である．

  もし \eqn{m, n, k} の一つが \code{\link{.Machine}$integer.max}
  を超えれば同値な
  \code{qhyper(runif(nn),m,n,k)} が現在使われるが，
  二項分布近似の方が相当効率的かもしれないが．
}
\source{
  \code{dhyper} は二項確率経由で計算され，
  Catherine Loader (\code{\link{dbinom}} を見よ)のコードを使う．

  \code{phyper} は
  is based on calculating
  \code{dhyper} と \code{phyper(...)/dhyper(...)} (和として)の
  計算に基づき，Ian Smith と Morten Welinder のアイデアに基づく．

  \code{qhyper} は逆関数に基づく．

  \code{rhyper} は次の修正バージョンに基づく

  Kachitvichyanukul, V. and Schmeiser, B. (1985).
  Computer generation of hypergeometric random variates.
  \emph{Journal of Statistical Computation and Simulation},
  \bold{22}, 127--145.
}
\references{
  Johnson, N. L., Kotz, S., and Kemp, A. W. (1992)
  \emph{Univariate Discrete Distributions},
  Second Edition. New York: Wiley.
}
\seealso{
  他の標準分布については \link{Distributions}．
}
\examples{
m <- 10; n <- 7; k <- 8
x <- 0:(k+1)
rbind(phyper(x, m, n, k), dhyper(x, m, n, k))
all(phyper(x, m, n, k) == cumsum(dhyper(x, m, n, k)))  # FALSE
\donttest{## しかしエラーは非常に小さい：
signif(phyper(x, m, n, k) - cumsum(dhyper(x, m, n, k)), digits = 3)
}}
\keyword{distribution}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/Hypergeometric.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2016 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Hypergeometric}
%\alias{Hypergeometric}
%\alias{dhyper}
%\alias{phyper}
%\alias{qhyper}
%\alias{rhyper}
%\title{The Hypergeometric Distribution}
%\description{
%  Density, distribution function, quantile function and random
%  generation for the hypergeometric distribution.
%}
%\usage{
%dhyper(x, m, n, k, log = FALSE)
%phyper(q, m, n, k, lower.tail = TRUE, log.p = FALSE)
%qhyper(p, m, n, k, lower.tail = TRUE, log.p = FALSE)
%rhyper(nn, m, n, k)
%}
%\arguments{
%  \item{x, q}{vector of quantiles representing the number of white balls
%    drawn without replacement from an urn which contains both black and
%    white balls.}
%  \item{m}{the number of white balls in the urn.}
%  \item{n}{the number of black balls in the urn.}
%  \item{k}{the number of balls drawn from the urn.}
%  \item{p}{probability, it must be between 0 and 1.}
%  \item{nn}{number of observations.  If \code{length(nn) > 1}, the length
%    is taken to be the number required.}
%  \item{log, log.p}{logical; if TRUE, probabilities p are given as log(p).}
%  \item{lower.tail}{logical; if TRUE (default), probabilities are
%    \eqn{P[X \le x]}, otherwise, \eqn{P[X > x]}.}
%}
%\value{
%  \code{dhyper} gives the density,
%  \code{phyper} gives the distribution function,
%  \code{qhyper} gives the quantile function, and
%  \code{rhyper} generates random deviates.
%
%  Invalid arguments will result in return value \code{NaN}, with a warning.
%
%  The length of the result is determined by \code{n} for
%  \code{rhyper}, and is the maximum of the lengths of the
%  numerical arguments for the other functions.
%
%  The numerical arguments other than \code{n} are recycled to the
%  length of the result.  Only the first elements of the logical
%  arguments are used.
%}
%\details{
%  The hypergeometric distribution is used for sampling \emph{without}
%  replacement.  The density of this distribution with parameters
%  \code{m}, \code{n} and \code{k} (named \eqn{Np}, \eqn{N-Np}, and
%  \eqn{n}, respectively in the reference below) is given by
%  \deqn{
%    p(x) = \left. {m \choose x}{n \choose k-x} \right/ {m+n \choose k}%
%  }{p(x) =      choose(m, x) choose(n, k-x) / choose(m+n, k)}
%  for \eqn{x = 0, \ldots, k}.
%
%  Note that \eqn{p(x)} is non-zero only for
%  \eqn{\max(0, k-n) \le x \le \min(k, m)}{max(0, k-n) <= x <= min(k, m)}.
%
%  With \eqn{p := m/(m+n)} (hence \eqn{Np = N \times p} in the
%  reference's notation), the first two moments are mean
%  \deqn{E[X] = \mu = k p} and variance
%  \deqn{\mbox{Var}(X) = k p (1 - p) \frac{m+n-k}{m+n-1},}{%
%               Var(X) = k p (1 - p) * (m+n-k)/(m+n-1),}
%  which shows the closeness to the Binomial\eqn{(k,p)} (where the
%  hypergeometric has smaller variance unless \eqn{k = 1}).
%
%  The quantile is defined as the smallest value \eqn{x} such that
%  \eqn{F(x) \ge p}, where \eqn{F} is the distribution function.
%
%  If one of \eqn{m, n, k}, exceeds \code{\link{.Machine}$integer.max},
%  currently the equivalent of \code{qhyper(runif(nn), m,n,k)} is used,
%  when a binomial approximation may be considerably more efficient.
%}
%\source{
%  \code{dhyper} computes via binomial probabilities, using code
%  contributed by Catherine Loader (see \code{\link{dbinom}}).
%
%  \code{phyper} is based on calculating \code{dhyper} and
%  \code{phyper(...)/dhyper(...)} (as a summation), based on ideas of Ian
%  Smith and Morten Welinder.
%
%  \code{qhyper} is based on inversion.
%
%  \code{rhyper} is based on a corrected version of
%
%  Kachitvichyanukul, V. and Schmeiser, B. (1985).
%  Computer generation of hypergeometric random variates.
%  \emph{Journal of Statistical Computation and Simulation},
%  \bold{22}, 127--145.
%}
%\references{
%  Johnson, N. L., Kotz, S., and Kemp, A. W. (1992)
%  \emph{Univariate Discrete Distributions},
%  Second Edition. New York: Wiley.
%}
%\seealso{
%  \link{Distributions} for other standard distributions.
%}
%\examples{
%m <- 10; n <- 7; k <- 8
%x <- 0:(k+1)
%rbind(phyper(x, m, n, k), dhyper(x, m, n, k))
%all(phyper(x, m, n, k) == cumsum(dhyper(x, m, n, k)))  # FALSE
%\donttest{## but error is very small:
%signif(phyper(x, m, n, k) - cumsum(dhyper(x, m, n, k)), digits = 3)
%}}
%\keyword{distribution}
%
%\encoding{UTF-8}
%