% File src/library/stats/man/acf.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{acf}
\alias{acf}%@%\alias{自己共分散関数}%@%\alias{自己相関係数関数}
\alias{ccf}
\alias{pacf}
\alias{pacf.default}
\alias{[.acf}
\title{Auto- and Cross- Covariance and -Correlation Function Estimation}
\description{
  関数 \code{acf} は
  自己共分散と自己相関係数関数を計算する(そして既定ではプロットする)．
  関数 \code{pacf} は自己部分共分散を計算するのに使われる関数である．
  関数 \code{ccf} は二つの一変量時系列のクロス相関係数または
  クロス共分散を計算する．
}
\usage{
acf(x, lag.max = NULL,
    type = c("correlation", "covariance", "partial"),
    plot = TRUE, na.action = na.fail, demean = TRUE, \dots)

pacf(x, lag.max, plot, na.action, \dots)

\method{pacf}{default}(x, lag.max = NULL, plot = TRUE, na.action = na.fail,
    ...)

ccf(x, y, lag.max = NULL, type = c("correlation", "covariance"),
    plot = TRUE, na.action = na.fail, \dots)

\method{[}{acf}(x, i, j)
}
\arguments{
  \item{x, y}{一変量又は多変量(\code{ccf} 以外)数値時系列オブジェクト，
    数値ベクトル，行列，もしくは \code{"acf"} オブジェクト．}
  \item{lag.max}{acf をそこで計算する最大ラグ．
    既定値は \eqn{10\log_{10}(N/m)}{10*log10(N/m)} で，
    ここで \eqn{N} は観測値数で \eqn{m} は時系列の数．
    系列中の観測値数よりも自動的に一つ小さくされる．}
  \item{type}{計算される acf のタイプを指示する文字列．
    可能な値は
    \code{"correlation"} (既定), \code{"covariance"} 又は
    \code{"partial"}．部分マッチングがされる．}
  \item{plot}{論理値．もし \code{TRUE} (既定)なら acf がプロットされる．}．
  \item{na.action}{欠損値を処理するために呼び出される関数．
    \code{na.pass} を使うことが出来る．}
  \item{demean}{論理値．共分散は標本平均周りにすべきか?}
  \item{\dots}{\code{plot.acf} に渡される追加の引数．}
  \item{i}{保持されるラグ(時間差)のセット．}
  \item{j}{保持される系列(名前か番号)のセット．}
}
\value{
  An object of class
  クラス \code{"acf"} のオブジェクトで次の成分を持つリスト：

  \item{lag}{そこで acf が推定されたラグを含む2次元配列．}
  \item{acf}{
    \code{lag} と同じ次元の配列で，推定された acf を含む．}
  \item{type}{相関の種類(\code{type} 引数と同じ)．}
  \item{n.used}{時系列中の観測値数．}
  \item{series}{系列 \code{x} の名前．}
  \item{snames}{多変量時系列の系列名．}

  
  \code{ccf(x, y)} が返すラグ \code{k} 値は
  \code{x[t+k]} と \code{y[t]} の間の相関を推定する.

  結果は
  もし \code{plot} が \code{TRUE} ならば不可視で返される．
}
\details{
  \code{type} = \code{"correlation"} と \code{"covariance"} に対しては，
  推定量は標本共分散に基づく．
  (慣習的にラグ 0 の自己相関は 1 に固定されている．)

  既定では欠損値は許されない．
  もし \code{na.action} 関数が欠損値に出会うと
  (\code{na.pass} がするように)，
  共分散は完全なケースから計算される．
  これは計算された推定値が真正な自己相関系列ではないかもしれないことを
  意味し，欠損値を含むかもしれない．
  多変量時系列の PACF を計算する際は欠損値は許されない．
  
  部分相関係数は
  次数 \code{lag.max} まで自己回帰モデルを当てはめることで
  推定される．

  総称的関数 \code{plot} はクラス
  \code{"acf"} のオブジェクトに対するメソッドを持つ．

  ラグが返され観測値数ではなく時刻単位でプロットされる．

  クラス \code{"acf"} のオブジェクトに対しては
  \code{print} と部分抽出メソッドがある．
}
\author{
  オリジナル：Paul Gilbert, Martyn Plummer.
  \code{pacf} の大幅な修正と一変量ケースは B. D. Ripley による．
}
\references{
  Venables, W. N. and Ripley, B. D. (2002)
  \emph{Modern Applied Statistics with S}.  Fourth Edition.
  Springer-Verlag.

  (これは使われている正確な定義を含む．)
}

\seealso{
  与えられた ARMA プロセスの正確な自己相関に対しては
  \code{\link{plot.acf}}, \code{\link{ARMAacf}}．
}
\examples{
require(graphics)

## Venables & Ripley からの例
acf(lh)
acf(lh, type = "covariance")
pacf(lh)

acf(ldeaths)
acf(ldeaths, ci.type = "ma")
acf(ts.union(mdeaths, fdeaths))
ccf(mdeaths, fdeaths, ylab = "cross-correlation")
# (単にクロス相関)

presidents # 欠損値を含む
acf(presidents, na.action = na.pass)
pacf(presidents, na.action = na.pass)
}
\keyword{ts}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/acf.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{acf}
%\alias{acf}
%\alias{ccf}
%\alias{pacf}
%\alias{pacf.default}
%\alias{[.acf}
%\title{Auto- and Cross- Covariance and -Correlation Function Estimation}
%\description{
%  The function \code{acf} computes (and by default plots) estimates of
%  the autocovariance or autocorrelation function.  Function \code{pacf}
%  is the function used for the partial autocorrelations.  Function
%  \code{ccf} computes the cross-correlation or cross-covariance of two
%  univariate series.
%}
%\usage{
%acf(x, lag.max = NULL,
%    type = c("correlation", "covariance", "partial"),
%    plot = TRUE, na.action = na.fail, demean = TRUE, \dots)
%
%pacf(x, lag.max, plot, na.action, \dots)
%
%\method{pacf}{default}(x, lag.max = NULL, plot = TRUE, na.action = na.fail,
%    ...)
%
%ccf(x, y, lag.max = NULL, type = c("correlation", "covariance"),
%    plot = TRUE, na.action = na.fail, \dots)
%
%\method{[}{acf}(x, i, j)
%}
%\arguments{
%  \item{x, y}{a univariate or multivariate (not \code{ccf}) numeric time
%    series object or a numeric vector or matrix, or an \code{"acf"} object.}
%  \item{lag.max}{maximum lag at which to calculate the acf.
%    Default is \eqn{10\log_{10}(N/m)}{10*log10(N/m)} where \eqn{N} is the
%    number of observations and \eqn{m} the number of series.  Will
%    be automatically limited to one less than the number of observations
%    in the series.}
%  \item{type}{character string giving the type of acf to be computed.
%    Allowed values are
%    \code{"correlation"} (the default), \code{"covariance"} or
%    \code{"partial"}.  Will be partially matched.}
%  \item{plot}{logical. If \code{TRUE} (the default) the acf is plotted.}
%  \item{na.action}{function to be called to handle missing
%    values. \code{na.pass} can be used.}
%  \item{demean}{logical.  Should the covariances be about the sample
%    means?}
%  \item{\dots}{further arguments to be passed to \code{plot.acf}.}
%
%  \item{i}{a set of lags (time differences) to retain.}
%  \item{j}{a set of series (names or numbers) to retain.}
%}
%\value{
%  An object of class \code{"acf"}, which is a list with the following
%  elements:
%
%  \item{lag}{A three dimensional array containing the lags at which
%    the acf is estimated.}
%  \item{acf}{An array with the same dimensions as \code{lag} containing
%    the estimated acf.}
%  \item{type}{The type of correlation (same as the \code{type}
%    argument).}
%  \item{n.used}{The number of observations in the time series.}
%  \item{series}{The name of the series \code{x}.}
%  \item{snames}{The series names for a multivariate time series.}
%
%  The lag \code{k} value returned by \code{ccf(x, y)} estimates the
%  correlation between \code{x[t+k]} and \code{y[t]}.
%
%  The result is returned invisibly if \code{plot} is \code{TRUE}.
%}
%\details{
%  For \code{type} = \code{"correlation"} and \code{"covariance"}, the
%  estimates are based on the sample covariance. (The lag 0 autocorrelation
%  is fixed at 1 by convention.)
%
%  By default, no missing values are allowed.  If the \code{na.action}
%  function passes through missing values (as \code{na.pass} does), the
%  covariances are computed from the complete cases.  This means that the
%  estimate computed may well not be a valid autocorrelation sequence,
%  and may contain missing values.  Missing values are not allowed when
%  computing the PACF of a multivariate time series.
%
%  The partial correlation coefficient is estimated by fitting
%  autoregressive models of successively higher orders up to
%  \code{lag.max}.
%
%  The generic function \code{plot} has a method for objects of class
%  \code{"acf"}.
%
%  The lag is returned and plotted in units of time, and not numbers of
%  observations.
%
%  There are \code{print} and subsetting methods for objects of class
%  \code{"acf"}.
%}
%\author{
%  Original: Paul Gilbert, Martyn Plummer.
%  Extensive modifications and univariate case of \code{pacf} by
%  B. D. Ripley.
%}
%\references{
%  Venables, W. N. and Ripley, B. D. (2002)
%  \emph{Modern Applied Statistics with S}.  Fourth Edition.
%  Springer-Verlag.
%
%  (This contains the exact definitions used.)
%}
%
%\seealso{
%  \code{\link{plot.acf}}, \code{\link{ARMAacf}} for the exact
%  autocorrelations of a given ARMA process.
%}
%\examples{
%require(graphics)
%
%## Examples from Venables & Ripley
%acf(lh)
%acf(lh, type = "covariance")
%pacf(lh)
%
%acf(ldeaths)
%acf(ldeaths, ci.type = "ma")
%acf(ts.union(mdeaths, fdeaths))
%ccf(mdeaths, fdeaths, ylab = "cross-correlation")
%# (just the cross-correlations)
%
%presidents # contains missing values
%acf(presidents, na.action = na.pass)
%pacf(presidents, na.action = na.pass)
%}
%\keyword{ts}
%
%\encoding{UTF-8}
