% File src/library/stats/man/binom.test.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{binom.test}
\alias{binom.test}
%%\title{Exact Binomial Test}
\title{二項分布の正確検定}
\description{
  ベルヌイ実験で成功確率に関する単純な帰無仮説の正確検定を実行する．
}
\usage{
binom.test(x, n, p = 0.5,
           alternative = c("two.sided", "less", "greater"),
           conf.level = 0.95)
}
\arguments{
  \item{x}{成功数，又はそれぞれ成功数と失敗数を与える長さ 2 のベクトル．}
  \item{n}{試行数：
    もし \code{x} が長さ 2 なら無視される．}
  \item{p}{仮説の成功確率．}
  \item{alternative}{対立仮説を指定し，
    \code{"two.sided"}, \code{"greater"} 又は \code{"less"}
    のどれかでなければならない．
    頭文字だけ指定すれば良い．}
  \item{conf.level}{返される信頼区間に対する信頼水準．}
}
\details{
  信頼区間は最初
  Clopper and Pearson (1934) で与えられた手順で得られる．
  これは信頼水準が少なくとも
  \code{conf.level} であることを保証するが，一般には
  長さが最少の信頼区間を与えない．
}
\value{
  クラス \code{"htest"} のりストで次の成分を含む：
  \item{statistic}{成功数．}
  \item{parameter}{試行数．}
  \item{p.value}{検定の p 値．}
  \item{conf.int}{成功確率に対する信頼区間．}
  \item{estimate}{推定成功確率．}
  \item{null.value}{帰無仮説の下での確率 \code{p}．}
  \item{alternative}{対立仮説を記述する文字列．}
  \item{method}{文字列 \code{"Exact binomial test"}．}
  \item{data.name}{データの名前を与える文字列．}
}
\references{
  Clopper, C. J. & Pearson, E. S. (1934).
  The use of confidence or fiducial limits illustrated in the case of
  the binomial.
  \emph{Biometrika}, \bold{26}, 404--413.

  William J. Conover (1971),
  \emph{Practical nonparametric statistics}.
  New York: John Wiley & Sons.
  Pages 97--104.

  Myles Hollander & Douglas A. Wolfe (1973),
  \emph{Nonparametric Statistical Methods.}
  New York: John Wiley & Sons.
  Pages 15--22.
}
\seealso{
  等しいか与えられた比例定数に対する
  一般の(近似)検定は \code{\link{prop.test}}．
}
\examples{
## Conover (1971), p. 97f.
##  単純なメンデル型遺伝(の仮定)の下で，二つの遺伝子形の
##  植物の交配では子孫のそれぞれ 1/4 が "矮性" で，3/4が "巨大" になる．
##  この仮定が合理的かどうかを決定する実験で交配の結果が子供の 243 が矮性で
##  682 が巨大植物になった．もし "巨大" を成功と考えると，帰無仮説は p = 3/4 で
##  対立仮説は  p != 3/4 である．
binom.test(c(682, 243), p = 3/4)
binom.test(682, 682 + 243, p = 3/4)   # The same.
## => データは帰無仮説と合致している．
}
\keyword{htest}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/binom.test.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{binom.test}
%\alias{binom.test}
%\title{Exact Binomial Test}
%\description{
%  Performs an exact test of a simple null hypothesis about the
%  probability of success in a Bernoulli experiment.
%}
%\usage{
%binom.test(x, n, p = 0.5,
%           alternative = c("two.sided", "less", "greater"),
%           conf.level = 0.95)
%}
%\arguments{
%  \item{x}{number of successes, or a vector of length 2 giving the
%    numbers of successes and failures, respectively.}
%  \item{n}{number of trials; ignored if \code{x} has length 2.}
%  \item{p}{hypothesized probability of success.}
%  \item{alternative}{indicates the alternative hypothesis and must be
%    one of \code{"two.sided"}, \code{"greater"} or \code{"less"}.
%    You can specify just the initial letter.}
%  \item{conf.level}{confidence level for the returned confidence
%    interval.}
%}
%\details{
%  Confidence intervals are obtained by a procedure first given in
%  Clopper and Pearson (1934).  This guarantees that the confidence level
%  is at least \code{conf.level}, but in general does not give the
%  shortest-length confidence intervals.
%}
%\value{
%  A list with class \code{"htest"} containing the following components:
%  \item{statistic}{the number of successes.}
%  \item{parameter}{the number of trials.}
%  \item{p.value}{the p-value of the test.}
%  \item{conf.int}{a confidence interval for the probability of success.}
%  \item{estimate}{the estimated probability of success.}
%  \item{null.value}{the probability of success under the null,
%    \code{p}.}
%  \item{alternative}{a character string describing the alternative
%    hypothesis.}
%  \item{method}{the character string \code{"Exact binomial test"}.}
%  \item{data.name}{a character string giving the names of the data.}
%}
%\references{
%  Clopper, C. J. & Pearson, E. S. (1934).
%  The use of confidence or fiducial limits illustrated in the case of
%  the binomial.
%  \emph{Biometrika}, \bold{26}, 404--413.
%
%  William J. Conover (1971),
%  \emph{Practical nonparametric statistics}.
%  New York: John Wiley & Sons.
%  Pages 97--104.
%
%  Myles Hollander & Douglas A. Wolfe (1973),
%  \emph{Nonparametric Statistical Methods.}
%  New York: John Wiley & Sons.
%  Pages 15--22.
%}
%\seealso{
%  \code{\link{prop.test}} for a general (approximate) test for equal or
%  given proportions.
%}
%\examples{
%## Conover (1971), p. 97f.
%## Under (the assumption of) simple Mendelian inheritance, a cross
%##  between plants of two particular genotypes produces progeny 1/4 of
%##  which are "dwarf" and 3/4 of which are "giant", respectively.
%##  In an experiment to determine if this assumption is reasonable, a
%##  cross results in progeny having 243 dwarf and 682 giant plants.
%##  If "giant" is taken as success, the null hypothesis is that p =
%##  3/4 and the alternative that p != 3/4.
%binom.test(c(682, 243), p = 3/4)
%binom.test(682, 682 + 243, p = 3/4)   # The same.
%## => Data are in agreement with the null hypothesis.
%}
%\keyword{htest}
%
%\encoding{UTF-8}
%
