% File src/library/stats/man/coef.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{coef}
\title{Extract Model Coefficients}
\usage{
coef(object, \dots)
coefficients(object, \dots)
}
\alias{coef}
\alias{coefficients}
\arguments{
  \item{object}{モデル係数の取り出しが意味を持つオブジェクト．}
  \item{\dots}{他の引数．}
}
\description{
  \code{coef} はモデル当てはめ関数から返されたオブジェクトから
  モデル係数を取り出す総称的関数である．
  \code{coefficients} はその\emph{別名}である．
}
\details{
  モデリング関数から返された全てのオブジェクトは
  \code{coef} メソッド又は既定のそれを提供すべきである．
  (メソッドは \code{coef} 用であり \code{coefficients} 用ではないことを
  注意する．)

  クラス \code{"aov"} は別名の係数を報告しない \code{coef} メソッドを持つ
  (\code{\link{alias}} を見よ)．
}
\value{
  モデルオブジェクト \code{object} から取り出された係数．

  標準のモデル当てはめ関数に対してはこれは名前付き数値ベクトルである．
  \code{"maov"} オブジェクト(\code{\link{aov}} で作られる)に
  対してはこれは行列である．
}
\seealso{
  関連メソッドに対しては \code{\link{fitted.values}} と \code{\link{residuals}}；
  モデル当てはめに対しては \code{\link{glm}}, \code{\link{lm}}．
}
\references{
  Chambers, J. M. and Hastie, T. J. (1992)
  \emph{Statistical Models in S}.
  Wadsworth & Brooks/Cole.
}
\examples{
x <- 1:5; coef(lm(c(1:3, 7, 6) ~ x))
}
\keyword{regression}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/coef.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{coef}
%\title{Extract Model Coefficients}
%\usage{
%coef(object, \dots)
%coefficients(object, \dots)
%}
%\alias{coef}
%\alias{coefficients}
%\arguments{
%  \item{object}{an object for which the extraction of model coefficients is
%    meaningful.}
%  \item{\dots}{other arguments.}
%}
%\description{
%  \code{coef} is a generic function which extracts model coefficients
%  from objects returned by modeling functions.  \code{coefficients} is
%  an \emph{alias} for it.
%}
%\details{
%  All object classes which are returned by model fitting functions
%  should provide a \code{coef} method or use the default one.
%  (Note that the method is for \code{coef} and not \code{coefficients}.)
%
%  Class \code{"aov"} has a \code{coef} method that does not report
%  aliased coefficients (see \code{\link{alias}}).
%}
%\value{
%  Coefficients extracted from the model object \code{object}.
%
%  For standard model fitting classes this will be a named numeric vector.
%  For \code{"maov"} objects (produced by \code{\link{aov}}) it will be a matrix.
%}
%\seealso{
%  \code{\link{fitted.values}} and \code{\link{residuals}} for related methods;
%  \code{\link{glm}}, \code{\link{lm}} for model fitting.
%}
%\references{
%  Chambers, J. M. and Hastie, T. J. (1992)
%  \emph{Statistical Models in S}.
%  Wadsworth & Brooks/Cole.
%}
%\examples{
%x <- 1:5; coef(lm(c(1:3, 7, 6) ~ x))
%}
%\keyword{regression}
%\keyword{models}
%
%\encoding{UTF-8}
%