% File src/library/stats/man/cov.wt.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{cov.wt}
\alias{cov.wt}
%%\title{Weighted Covariance Matrices}
\title{重み付き共分散行列}
\usage{
cov.wt(x, wt = rep(1/nrow(x), nrow(x)), cor = FALSE, center = TRUE,
       method = c("unbiased", "ML"))
}
\description{
  データの重み付き共分散行列と平均を含むリストを返す．
  オプションで(重み付き)相関係数行列も含む．
}
\arguments{
  \item{x}{行列かデータフレーム．通常のように行は観測値で列は変数．}
  \item{wt}{各観測値に対する非負でゼロでない重みのベクトル．
    その長さは \code{x} の行数に等しくなければならない．}
  \item{cor}{推定重み付き相関係数行列も返すべきかどうかを指示する
    論理値．}
  \item{center}{共分散を計算する際に使われる中心を指定する
    論理値か数値ベクトル．もし \code{TRUE} ならば
    各変数の(重み付き)付き平均が使われ，
    もし \code{FALSE} ならばゼロが使われる．
    もし \code{center} が数値なら，その長さは
    \code{x} の列数に等しくなければならない．}
  \item{method}{結果をどのようにスケール化するかを指示する文字列，
    下の\sQuote{詳細}を見よ．短縮できる．}
}
\value{
  次の名前付き成分を持つリスト：
  \item{cov}{推定された(重み付き)共分散行列．}
  \item{center}{推定されたデータの中心(平均)．}
  \item{n.obs}{\code{x} 中の観測値(行)の数．}
  \item{wt}{推定で使われた重み．
    もし引数として与えられた時だけ返される．}
  \item{cor}{推定された相関係数行列．
    \code{cor} が \code{TRUE} の時だけ返される．}
}
\details{
  既定の \code{method = "unbiased"} では，
  共分散行列は重みの二乗和から 1 を引いたもので割られるので，
  もし重みが既定 (\eqn{1/n}) ならば \eqn{(n - 1)} で割られる
  伝統的な共分散行列の不偏推定量が得られる．
  これは \code{method = "ML"} に対応し割られない
  S-PLUS の動作と異なる．
}
\seealso{\code{\link{cov}} and \code{\link{var}}.
}
\examples{
 (xy <- cbind(x = 1:10, y = c(1:3, 8:5, 8:10)))
 w1 <- c(0,0,0,1,1,1,1,1,0,0)
 cov.wt(xy, wt = w1) # つまり method = "unbiased"
 cov.wt(xy, wt = w1, method = "ML", cor = TRUE)
}
\keyword{multivariate}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/cov.wt.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{cov.wt}
%\alias{cov.wt}
%\title{Weighted Covariance Matrices}
%\usage{
%cov.wt(x, wt = rep(1/nrow(x), nrow(x)), cor = FALSE, center = TRUE,
%       method = c("unbiased", "ML"))
%}
%\description{
%  Returns a list containing estimates of the weighted covariance matrix
%  and the mean of the data, and optionally of the (weighted) correlation
%  matrix.}
%\arguments{
%  \item{x}{a matrix or data frame.  As usual, rows are observations and
%    columns are variables.}
%  \item{wt}{a non-negative and non-zero vector of weights for each
%    observation.  Its length must equal the number of rows of \code{x}.}
%  \item{cor}{a logical indicating whether the estimated correlation
%    weighted matrix will be returned as well.}
%  \item{center}{either a logical or a numeric vector specifying the
%    centers to be used when computing covariances.  If \code{TRUE}, the
%    (weighted) mean of each variable is used, if \code{FALSE}, zero is
%    used.  If \code{center} is numeric, its length must equal the number
%    of columns of \code{x}.}
%  \item{method}{string specifying how the result is scaled, see
%    \sQuote{Details} below.  Can be abbreviated.}
%}
%\value{
%  A list containing the following named components:
%  \item{cov}{the estimated (weighted) covariance matrix}
%  \item{center}{an estimate for the center (mean) of the data.}
%  \item{n.obs}{the number of observations (rows) in \code{x}.}
%  \item{wt}{the weights used in the estimation.  Only returned if given
%    as an argument.}
%  \item{cor}{the estimated correlation matrix.  Only returned if
%    \code{cor} is \code{TRUE}.}
%}
%\details{
%  By default, \code{method = "unbiased"},
%  The covariance matrix is divided by one minus the sum of squares of
%  the weights, so if the weights are the default (\eqn{1/n}) the conventional
%  unbiased estimate of the covariance matrix with divisor \eqn{(n - 1)}
%  is obtained.  This differs from the behaviour in S-PLUS which
%  corresponds to \code{method = "ML"} and does not divide.
%}
%\seealso{\code{\link{cov}} and \code{\link{var}}.
%}
%\examples{
% (xy <- cbind(x = 1:10, y = c(1:3, 8:5, 8:10)))
% w1 <- c(0,0,0,1,1,1,1,1,0,0)
% cov.wt(xy, wt = w1) # i.e. method = "unbiased"
% cov.wt(xy, wt = w1, method = "ML", cor = TRUE)
%}
%\keyword{multivariate}
%
%\encoding{UTF-8}
