% File src/library/stats/man/dist.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{dist}
\alias{dist}%@%\alias{距離行列の計算}
\alias{print.dist}
\alias{format.dist}
\alias{labels.dist}
\alias{as.matrix.dist}
\alias{as.dist}
\alias{as.dist.default}
\concept{dissimilarity}
\title{Distance Matrix Computation}
\description{
  この関数はデータ行列の行の間の距離を
  指定された距離測度を使い計算し，距離行列を返す．
}
\usage{
dist(x, method = "euclidean", diag = FALSE, upper = FALSE, p = 2)

as.dist(m, diag = FALSE, upper = FALSE)
\method{as.dist}{default}(m, diag = FALSE, upper = FALSE)

\method{print}{dist}(x, diag = NULL, upper = NULL,
      digits = getOption("digits"), justify = "none",
      right = TRUE, \dots)

\method{as.matrix}{dist}(x, \dots)
}
\arguments{
  \item{x}{数値行列，データフレーム，又は \code{"dist"} オブジェクト．}
  \item{method}{使われる距離法．これは
    \code{"euclidean"}, \code{"maximum"}, \code{"manhattan"},
    \code{"canberra"}, \code{"binary"} 又は \code{"minkowski"}
    のどれかでなければならない．
    曖昧でない任意の副文字列を与えることが出来る．}
  \item{diag}{
    距離行列の対角部分が \code{print.dist} でプリントされるべきか
    どうかを指示する論理値．}
  \item{upper}{
    距離行列の上三角部分が \code{print.dist} でプリントされるべきか
    どうかを指示する論理値．}
  \item{p}{ミンコウスキー距離の指数．}
  \item{m}{
    \code{"dist"} オブジェクトに変換される距離情報を持つ
    オブジェクト．
    既定メソッドに対しては \code{"dist"} オブジェクト，
    又は(距離の)行列，又は
    \code{\link{as.matrix}()} を用いてそうした行列に変換できるオブジェクト．
    (行列の下三角部分だけが使われ，残りは無視される．)．}
  \item{digits, justify}{
    \code{print()} の内部で \code{\link{format}} に渡される．}
  \item{right, \dots}{他のメソッドに渡される追加引数．}
}
\details{
  利用できる距離測度(ベクトル \eqn{x} と \eqn{y} に対して書く)は：
  \describe{
    \item{ユークリッド：}{二つのベクトル間の通常の距離
      \eqn{\sqrt{\sum_i (x_i - y_i)^2}}{sqrt(sum((x_i - y_i)^2))}
      (\eqn{L_2} としても知られている 2 ノルム)．}

    \item{最大：}{
      二つの成分 \eqn{x} と \eqn{y} 間の最大距離(スープノルム)．}

    \item{マンハッタン：}{
     二つのベクトル間の絶対値距離
     (\eqn{L_1} としても知られている 1 ノルム)．}
     
    \item{キャンベラ：}{
      \eqn{\sum_i |x_i - y_i| / |x_i + y_i|}{sum(|x_i - y_i| / |x_i + y_i|)}．
      ゼロの分子と分母の項は和から除かれておりあたかも欠損しているかのように
      扱われる．
      
      これは非負の値(例えばカウント)用を意図している：
      分母の絶対値は負の距離を避けるための
      1998年の \R 修正である．
    }

    \item{バイナリ：}{(\emph{非対称バイナリ}とも呼ばれる)：
      ベクトルはバイナリのビット列とみなされるので，
      ゼロでない要素は
      \sQuote{オン}でゼロの項は
      \sQuote{オフ}である．距離は
      少なくとも一つがオンである中でのただ一つが\emph{オン}である比率である．}

    \item{ミンコウスキー：}{\eqn{p} ノルム，
      成分の差の \eqn{p} 乗の和の \eqn{p} 乗根．}
  }

  欠損値は許されるがそれらが登場する行を含む全ての計算から除外される．
  さらに，もし \code{Inf} 値が含まれれば，
  それらの距離への寄与が
  \code{NaN} や \code{NA} を与えるときは全ての値の対は除外される．
  ユークリッド，マンハッタン，キャンベラ，もしくはミンコウスキー距離の
  計算である列が除外されると，和は使われた列数に比例して
  スケールアップされる．
  特定の距離の計算で全ての対が除外されれば，値は
  \code{NA} になる．

  \code{as.matrix()} と \code{as.dist()} の \code{"dist"} メソッドは
  クラス \code{"dist"} のオブジェクトと慣習的な距離行列の
  間の変換に使える．

  \code{as.dist()} は総称的関数である．
  その既定メソッドは
  クラス \code{"dist"} を継承するオブジェクトを処理する．
  又は \code{\link{as.matrix}()} を使って行列に変換できる．
  距離(非類似度とも呼ばれる)を表現するクラスへのサポートは
  \code{\link{as.matrix}()} 又は，より直接にそうしたクラスへの
  \code{as.dist} メソッドを提供することで付け加えることが出来る．
}
\value{
  \code{dist} はクラス
  \code{"dist"} のオブジェクトを返す．

  距離行列の下三角部分を列順にベクトル，\code{do} とする，に保管する，
  もし \code{n} が観測値数，つまり
  \code{n <- attr(do, "Size")} ならば，
  \eqn{i < j \le n} に対して
  (行) i と j の間の非類似度は
  \code{do[n*(i-1) - i*(i-1)/2 + j-i]}．
  ベクトルの長さは \eqn{n*(n-1)/2}，つまりオーダー \eqn{n^2}．

  このオブジェクトは次の属性(\code{"dist"} に等しいクラス以外に)
    を持つ：
  \item{Size}{整数，データセット中の観測値の数．}
  \item{Labels}{オプションで，もしあれば，データセットのラベルを含む．}
  \item{Diag, Upper}{
    引数 \code{diag} と \code{upper} に対応する論理値で，
    オブジェクトをどのようにプリントするかを指示する．}
  \item{call}{オプションで，
    オブジェクトを作るのに使われる呼び出し．}
  \item{method}{オプションで，使われる距離法；
    \code{\link{dist}()} に由来する, (\code{\link{match.arg}()} で
    マッチした) \code{method} 引数．}
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Mardia, K. V., Kent, J. T. and Bibby, J. M. (1979)
  \emph{Multivariate Analysis.} Academic Press.

  Borg, I. and Groenen, P. (1997)
  \emph{Modern Multidimensional Scaling.  Theory and Applications.}
  Springer.
}
\seealso{
  パッケージ \CRANpkg{cluster} 中の \code{\link[cluster]{daisy}} は
  \emph{混合} (連続 / カテゴリカル)変数の場合に対するより多くの
  可能性をもつ．
  \code{\link{hclust}}.
}
\examples{
require(graphics)

x <- matrix(rnorm(100), nrow = 5)
dist(x)
dist(x, diag = TRUE)
dist(x, upper = TRUE)
m <- as.matrix(dist(x))
d <- as.dist(m)
stopifnot(d == dist(x))

## 変数間の相関を"距離として"使う
dd <- as.dist((1 - cor(USJudgeRatings))/2)
round(1000 * dd) # (より見栄え良くプリント)
plot(hclust(dd)) # クラスター化された変数のデンドログラムを見る

## バイナリとキャンベラ距離の例
x <- c(0, 0, 1, 1, 1, 1)
y <- c(1, 0, 1, 1, 0, 1)
dist(rbind(x, y), method = "binary")
## 答え 0.4 = 2/5
dist(rbind(x, y), method = "canberra")
## 答え 2 * (6/5)

## 名前を見つける
labels(eurodist)

## "Inf" を含む例：
## 1)
x[6] <- Inf
(m2 <- rbind(x, y))
dist(m2, method = "binary")   # 警告，答え 0.5 = 2/4
## 次は全て "Inf" を与える：
stopifnot(Inf == dist(m2, method =  "euclidean"),
          Inf == dist(m2, method =  "maximum"),
          Inf == dist(m2, method =  "manhattan"))
##  "Inf" は非常に大きな数と同じ：
x1 <- x; x1[6] <- 1e100
stopifnot(dist(cbind(x, y), method = "canberra") ==
    print(dist(cbind(x1, y), method = "canberra")))

## 2)
y[6] <- Inf #-> 6 番目の対は除外される
dist(rbind(x, y), method = "binary"  )   # 警告; 0.5
dist(rbind(x, y), method = "canberra"  ) # 3
dist(rbind(x, y), method = "maximum")    # 1
dist(rbind(x, y), method = "manhattan")  # 2.4
}
\keyword{multivariate}
\keyword{cluster}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/dist.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{dist}
%\alias{dist}
%\alias{print.dist}
%\alias{format.dist}
%\alias{labels.dist}
%\alias{as.matrix.dist}
%\alias{as.dist}
%\alias{as.dist.default}
%\concept{dissimilarity}
%\title{Distance Matrix Computation}
%\description{
%  This function computes and returns the distance matrix computed by
%  using the specified distance measure to compute the distances between
%  the rows of a data matrix.
%}
%\usage{
%dist(x, method = "euclidean", diag = FALSE, upper = FALSE, p = 2)
%
%as.dist(m, diag = FALSE, upper = FALSE)
%\method{as.dist}{default}(m, diag = FALSE, upper = FALSE)
%
%\method{print}{dist}(x, diag = NULL, upper = NULL,
%      digits = getOption("digits"), justify = "none",
%      right = TRUE, \dots)
%
%\method{as.matrix}{dist}(x, \dots)
%}
%\arguments{
%  \item{x}{a numeric matrix, data frame or \code{"dist"} object.}
%  \item{method}{the distance measure to be used. This must be one of
%    \code{"euclidean"}, \code{"maximum"}, \code{"manhattan"},
%    \code{"canberra"}, \code{"binary"} or \code{"minkowski"}.
%    Any unambiguous substring can be given.}
%  \item{diag}{logical value indicating whether the diagonal of the
%    distance matrix should be printed by \code{print.dist}.}
%  \item{upper}{logical value indicating whether the upper triangle of the
%    distance matrix should be printed by \code{print.dist}.}
%  \item{p}{The power of the Minkowski distance.}
%  \item{m}{An object with distance information to be converted to a
%    \code{"dist"} object.  For the default method, a \code{"dist"}
%    object, or a matrix (of distances) or an object which can be coerced
%    to such a matrix using \code{\link{as.matrix}()}.  (Only the lower
%    triangle of the matrix is used, the rest is ignored).}
%  \item{digits, justify}{passed to \code{\link{format}} inside of
%    \code{print()}.}
%  \item{right, \dots}{further arguments, passed to other methods.}
%}
%\details{
%  Available distance measures are (written for two vectors \eqn{x} and
%  \eqn{y}):
%  \describe{
%    \item{\code{euclidean}:}{Usual distance between the two vectors (2
%      norm aka \eqn{L_2}), \eqn{\sqrt{\sum_i (x_i - y_i)^2}}{sqrt(sum((x_i - y_i)^2))}.}
%
%    \item{\code{maximum}:}{Maximum distance between two components of \eqn{x}
%      and \eqn{y} (supremum norm)}
%
%    \item{\code{manhattan}:}{Absolute distance between the two vectors (1 norm aka \eqn{L_1}).}
%
%    \item{\code{canberra}:}{
%      \eqn{\sum_i |x_i - y_i| / |x_i + y_i|}{sum(|x_i - y_i| / |x_i + y_i|)}.
%      Terms with zero numerator and denominator are omitted from the sum
%      and treated as if the values were missing.
%
%      This is intended for non-negative values (e.g., counts): taking the
%      absolute value of the denominator is a 1998 \R modification to
%      avoid negative distances.
%    }
%
%    \item{\code{binary}:}{(aka \emph{asymmetric binary}): The vectors
%      are regarded as binary bits, so non-zero elements are \sQuote{on}
%      and zero elements are \sQuote{off}.  The distance is the
%      \emph{proportion} of bits in which only one is on amongst those in
%      which at least one is on.}
%
%    \item{\code{minkowski}:}{The \eqn{p} norm, the \eqn{p}th root of the
%      sum of the \eqn{p}th powers of the differences of the components.}
%  }
%
%  Missing values are allowed, and are excluded from all computations
%  involving the rows within which they occur.
%  Further, when \code{Inf} values are involved, all pairs of values are
%  excluded when their contribution to the distance gave \code{NaN} or
%  \code{NA}.
%  If some columns are excluded in calculating a Euclidean, Manhattan,
%  Canberra or Minkowski distance, the sum is scaled up proportionally to
%  the number of columns used.  If all pairs are excluded when
%  calculating a particular distance, the value is \code{NA}.
%
%  The \code{"dist"} method of \code{as.matrix()} and \code{as.dist()}
%  can be used for conversion between objects of class \code{"dist"}
%  and conventional distance matrices.
%
%  \code{as.dist()} is a generic function.  Its default method handles
%  objects inheriting from class \code{"dist"}, or coercible to matrices
%  using \code{\link{as.matrix}()}.  Support for classes representing
%  distances (also known as dissimilarities) can be added by providing an
%  \code{\link{as.matrix}()} or, more directly, an \code{as.dist} method
%  for such a class.
%}
%\value{
%  \code{dist} returns an object of class \code{"dist"}.
%
%  The lower triangle of the distance matrix stored by columns in a
%  vector, say \code{do}. If \code{n} is the number of
%  observations, i.e., \code{n <- attr(do, "Size")}, then
%  for \eqn{i < j \le n}, the dissimilarity between (row) i and j is
%  \code{do[n*(i-1) - i*(i-1)/2 + j-i]}.
%  The length of the vector is \eqn{n*(n-1)/2}, i.e., of order \eqn{n^2}.
%
%  The object has the following attributes (besides \code{"class"} equal
%  to \code{"dist"}):
%  \item{Size}{integer, the number of observations in the dataset.}
%  \item{Labels}{optionally, contains the labels, if any, of the
%    observations of the dataset.}
%  \item{Diag, Upper}{logicals corresponding to the arguments \code{diag}
%    and \code{upper} above, specifying how the object should be printed.}
%  \item{call}{optionally, the \code{\link{call}} used to create the
%    object.}
%  \item{method}{optionally, the distance method used; resulting from
%    \code{\link{dist}()}, the (\code{\link{match.arg}()}ed) \code{method}
%    argument.}
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Mardia, K. V., Kent, J. T. and Bibby, J. M. (1979)
%  \emph{Multivariate Analysis.} Academic Press.
%
%  Borg, I. and Groenen, P. (1997)
%  \emph{Modern Multidimensional Scaling.  Theory and Applications.}
%  Springer.
%}
%\seealso{
%  \code{\link[cluster]{daisy}} in the \CRANpkg{cluster} package with more
%  possibilities in the case of \emph{mixed} (continuous / categorical)
%  variables.
%  \code{\link{hclust}}.
%}
%\examples{
%require(graphics)
%
%x <- matrix(rnorm(100), nrow = 5)
%dist(x)
%dist(x, diag = TRUE)
%dist(x, upper = TRUE)
%m <- as.matrix(dist(x))
%d <- as.dist(m)
%stopifnot(d == dist(x))
%
%## Use correlations between variables "as distance"
%dd <- as.dist((1 - cor(USJudgeRatings))/2)
%round(1000 * dd) # (prints more nicely)
%plot(hclust(dd)) # to see a dendrogram of clustered variables
%
%## example of binary and canberra distances.
%x <- c(0, 0, 1, 1, 1, 1)
%y <- c(1, 0, 1, 1, 0, 1)
%dist(rbind(x, y), method = "binary")
%## answer 0.4 = 2/5
%dist(rbind(x, y), method = "canberra")
%## answer 2 * (6/5)
%
%## To find the names
%labels(eurodist)
%
%## Examples involving "Inf" :
%## 1)
%x[6] <- Inf
%(m2 <- rbind(x, y))
%dist(m2, method = "binary")   # warning, answer 0.5 = 2/4
%## These all give "Inf":
%stopifnot(Inf == dist(m2, method =  "euclidean"),
%          Inf == dist(m2, method =  "maximum"),
%          Inf == dist(m2, method =  "manhattan"))
%##  "Inf" is same as very large number:
%x1 <- x; x1[6] <- 1e100
%stopifnot(dist(cbind(x, y), method = "canberra") ==
%    print(dist(cbind(x1, y), method = "canberra")))
%
%## 2)
%y[6] <- Inf #-> 6-th pair is excluded
%dist(rbind(x, y), method = "binary"  )   # warning; 0.5
%dist(rbind(x, y), method = "canberra"  ) # 3
%dist(rbind(x, y), method = "maximum")    # 1
%dist(rbind(x, y), method = "manhattan")  # 2.4
%}
%\keyword{multivariate}
%\keyword{cluster}
%
%\encoding{UTF-8}
%
