% File src/library/stats/man/glm.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{glm}
\title{Fitting Generalized Linear Models}
\alias{glm}%@%\alias{一般化線形モデルの当てはめ}
\alias{glm.fit}
\alias{weights.glm}
%\alias{print.glm}
\concept{regression}
\concept{logistic}
\concept{log-linear}
\concept{loglinear}
\description{
  \code{glm} は，シンボリックな線形予測子の記述と
  誤差分布の記述を与えて指定される一般化線形モデルの
  当てはめに使われる．
}
\usage{
glm(formula, family = gaussian, data, weights, subset,
    na.action, start = NULL, etastart, mustart, offset,
    control = list(\dots), model = TRUE, method = "glm.fit",
    x = FALSE, y = TRUE, contrasts = NULL, \dots)

glm.fit(x, y, weights = rep(1, nobs),
        start = NULL, etastart = NULL, mustart = NULL,
        offset = rep(0, nobs), family = gaussian(),
        control = list(), intercept = TRUE)

\method{weights}{glm}(object, type = c("prior", "working"), \dots)
}
\arguments{
  \item{formula}{
    クラス \code{"\link{formula}"} (またはそのクラスに変換できるもの)：
    当てはめられるモデルのシンボリックな記述．
    モデル指定の詳細は\sQuote{詳細}節にある．}

  \item{family}{
    モデル中で使われる誤差分布とリンク関数の記述．
    \code{glm} に対してはこれはファミリ関数の名前である文字列，
    ファミリ関数，又はファミリ関数への呼び出しの結果で良い．
    \code{glm.fit} に対しては三番目のオプションだけがサポートされている．
    (ファミリ関数の詳細は \code{\link{family}} を見よ．)}

  \item{data}{モデル中の変数を含むオプションのデータフレーム，リスト，
    又は環境(もしくは
    \code{\link{as.data.frame}} でデータフレームに変換できるオブジェクト)．
    もし \code{data} 中に見つからなければ，変数は
    \code{environment(formula)} から取られ，
    典型的にはそこから \code{glm} が呼び出された環境．}

  \item{weights}{
    当てはめ過程で使われる\sQuote{事前重み}のオプションの
    ベクトル．\code{NULL} か数値ベクトルでなければならない．}

  \item{subset}{
    当てはめ過程で使われる観測値の部分集合を与えるオプションのベクトル．}

  \item{na.action}{
    データが \code{NA} を含む時何が起きるべきかを指示する関数．
    既定は
    \code{\link{options}} の \code{na.action} 設定で，
    もしそれが未設定なら \code{\link{na.fail}} である．
    \sQuote{工場出荷時}の既定値は
    \code{\link{na.omit}} である．別の可能な値は
    何もしない \code{NULL} である．
    値 \code{\link{na.exclude}} を使うことが出来る．}

  \item{start}{線形予測子中のパラメータに対する初期値．}

  \item{etastart}{線形予測子に対する初期値．}

  \item{mustart}{平均のベクトルに対する初期値．}

  \item{offset}{これは当てはめの途中で
    線形予測子中に含められる
    \emph{事前}に既知の成分を指定するのに使うことが出来る．
    これは \code{NULL} かケース数に等しい数値ベクトル
    でなければならない．
    一つ又はそれ以上の \code{\link{offset}} 項が公式中に
    代わりに又は同じように含めることが出来，そして
    もし一つ以上が指定されるとそれらの和が使われる．
    \code{\link{model.offset}} を見よ．}

  \item{control}{当てはめ過程を制御するパラメータのリスト．
    \code{glm.fit} に対してはこれは 
    \code{\link{glm.control}} に渡される．}

  \item{model}{\emph{モデルフレーム}が返り値の成分として
    含まれるべきかどうかを指示する論理値．}

  \item{method}{モデルの当てはめ中で使われる手法．
    既定手法の \code{"glm.fit"} は繰り返し再重み付け最少二乗法
    (IWLS)を使う：もしくは \code{"model.frame"} は
    モデルフレームを返し当てはめを行わない．

    ユーザ提供の当てはめ関数を
    \code{glm.fit} と同じ引数を取る
    関数又は関数の名前の文字列として提供できる．
    もし文字列として指定されるとそれは
    \pkg{stats} の名前空間中から探される．
  }

  \item{x, y}{\code{glm} に対しては：
    当てはめ過程で使われた応答ベクトルと
    モデル行列を返り値の成分として返すべきかどうかを指示する論理値．

    \code{glm.fit} に対しては：\code{x} は次元
    \code{n * p} のデザイン行列で，
    \code{y} は 長さ \code{n} の観測値のベクトル．
  }

  \item{contrasts}{オプションのリスト．
    \code{model.matrix.default} の \code{contrasts.arg} を見よ．}

\item{intercept}{論理値．
    \emph{ナル}モデルに切片項を含めるべきか?}

  \item{object}{クラス \code{"glm"} を継承するオブジェクト．}

  \item{type}{文字列，部分マッチングが許される．
    当てはめモデルオブジェクトから取り出される重みのタイプ．
    短縮できる．}

  \item{\dots}{\code{glm} に対しては：
    もしそれが直接与えられなければ，既定の \code{control} 引数を
    作るのに使われる引数．
    \code{weights} に対しては：他のメソッドに・から渡される追加引数．}
}
\details{
  典型的な予測子は形式
  \code{response ~ terms} を持つ．ここで
  \code{response} は(数値)応答ベクトルで
  \code{terms} は \code{response} に対する線形予測子を指定する項の系列である．
  \code{binomial} と \code{quasibinomial} ファミリに対しては
  応答はまた因子(最初の水準が失敗を他は成功を示す)か
  成功と失敗数を与える列を持つ二列の行列
  でも良い．\code{first + second} の形の項の指定は
  \code{first} 中の全ての項と重複を除いた
  \code{second} 中の項を合わせたものを指示する．

  \code{first:second} の形の指定は
  \code{first} 中と \code{second} 中の全ての項の相互作用を取った
  項の集合を指示する．
  指定 \code{first*second} は
  \code{first} と \code{second} の\emph{クロス}を指示する．
  これは \code{first + second + first:second} と同じである．

  公式中の項は主効果が最初で，交互作用，二次，そして三次等がそれに続く
  ように並べ替えられる：
  これを \code{terms} オブジェクトに公式として渡すことを防ぐためである．

  \code{NULL} でない \code{weights} は異なった観測値が異なった
  散布度を持つことを指示出来る
  (\code{weights} 中の値は散布度の逆数に比例する)；
  又は同値であるが，
  \code{weights} の要素が正整数
  \eqn{w_i} ならば，各応答 \eqn{y_i} は
  \eqn{w_i} 単位で重み付けられた観測値の平均である．
  二項 GLM に対しては事前重みが
  応答が成功率である時試行数を与えるのに使うことが出来る：
  これらはポアッソン GLM に対しては滅多に使われない．


  \code{glm.fit} は実働関数である：
  これは普通直接呼び出されることはないが，
  応答ベクトル，デザイン行列，そしてファミリが既に計算されているときは
  より効率的であり得る．

  \code{etastart}, \code{start} そして \code{mustart} の一つ以上が
  指定されると，リスト中の最初が使われる．
  \code{\link{quasi}} ファミリや
  \code{gaussian("log")} のような普通でないリンクを持つファミリ
  に対しては初期値を提供することがしばしば勧められる．

  \code{weights}, \code{subset}, \code{offset}, \code{etastart}
  そして \code{mustart} の全ては
  \code{formula} 中の変数と同じように評価される．
  つまり最初は \code{data} 中でそれから
  \code{formula} の環境中である．

  二項 GLM に対する
  \sQuote{fitted probabilities numerically 0 or 1 occurred}
  というメッセージの背景は
  Venables & Ripley (2002, pp.\sspace{}197--8) を見よ．
}

\section{当てはめ関数}{
  引数 \code{method} は二つの役割を持つ．
  一つには当てはめ無しでモデルフレームを再構成することを許す．
  もう一つは既定の
  当てはめ関数 \code{glm.fit} を同じ引数を取り異なった当てはめアルゴリズム
  を持つ関数に置き換えることである．
  もし \code{glm.fit} は文字列として与えられると，それは
  その名前の関数を \pkg{stats} の名前空間から始めて探すのに使われる．

  当てはめ関数が返すオブジェクトのクラス(もしあれば)は
  \code{glm} が返すクラスの前に追加される．
}

\value{
  \code{glm} は
  \code{"glm"} を継承するクラスのオブジェクトを返す．
  \code{"glm"} はクラス \code{"lm"} を継承する．
  この節の最後を見よ．
  標準的でない \code{method} が使われると，オブジェクトは
  その関数が返す(もしあれば)クラスを継承する．

  関数 \code{\link{summary}} (つまり \code{\link{summary.glm}}) は
  結果の要約を得たりプリントするのに使うことが出来，
  関数 \code{\link{anova}} (つまり \code{\link{anova.glm}})
  は分散分析表を作ることが出来る．

  一般的なアクセス関数 \code{\link{coefficients}},
  \code{effects}, \code{fitted.values} そして \code{residuals} は
  \code{glm} が返した値の様々な有用な特性を取り出すのに使える．

  \code{weights} は(部分抽出と \code{na.action} の後で)
  当てはめ中の各ケースに対して一つずつ重みを取り出す．

  An object of class
  クラス \code{"glm"} のオブジェクトは少なくとも以下の成分を含む：

  \item{coefficients}{係数の名前付きベクトル．}
  \item{residuals}{\emph{作業}残差，
    つまり IWLS 当てはめの最後の繰り返し中の残差．
    重みゼロのケースは除かれているので，それらの
    作業残差は \code{NA} である．}
  \item{fitted.values}{当てはめ平均値ベクトル，
    リンク関数の逆関数で線形予測子を変換することで得られる．}
  \item{rank}{当てはめ線形モデルの数値的ランク．}
  \item{family}{使われた \code{\link{family}} オブジェクト．}
  \item{linear.predictors}{リンクスケールでの線形フィット．}
  \item{deviance}{定数を除き最大対数尤度のマイナス2 倍．
    意味があるところでは定数は飽和モデルが逸脱度ゼロを
    持つように選ばれる．}
  \item{aic}{赤池の\emph{情報量規準}のバージョン，
    最大対数尤度のマイナス2倍にパラメータ数の2倍を加えたもので，
    ファミリの \code{aic} 成分から計算される．
    二項とポアッソンファミリに対しては散布度は1に固定され，
    パラメータ数は係数の数である．
    ガウシアン，ガンマそして逆ガウシアンファミリに対しては，
    散布度は残差逸脱度から推定され，
    パラメータ数は係数の数に1を加えたものである．
    ガウシアンファミリに対しては散布度の MLE が使われ，
    従ってこれは真正の AIC 値であるが，
    ガンマと逆ガウシアンファミリに対してはそうではない．
    準尤度で当てはめられたファミリに対しては値は
    \code{NA} である．}
  \item{null.deviance}{ナルモデルに対する逸脱度で，
    \code{deviance} と比較される．
    ナルモデルはオフセットと，そして
    もしモデル中にあれば切片を含む．これはもしリンク関数が
    当てはめ平均値以外にデータに依存すれば正確ではないことを
    注意する：
    正確な計算を強制するためにゼロのオフセットを指定する．}
  \item{iter}{使われた IWLS の繰り返し回数．}
  \item{weights}{\emph{作業}重み，つまり
    IWLS 当てはめの最後の繰り返し中の重み．}
  \item{prior.weights}{最初に提供された重み，
    もしなければ \code{1} のベクトル．}
  \item{df.residual}{残差自由度．}
  \item{df.null}{ナルモデルに対する残差自由度．}
  \item{y}{もし要求されれば(既定)使われた \code{y} ベクトル．
    (これは二項モデルに対してすらベクトルである)．}
  \item{x}{もし要求されればモデル行列．}
  \item{model}{もし要求されれば(既定)モデルフレーム．}
  \item{converged}{論理値．IWLS アルゴリズムは収束したと判断されるか?．}
  \item{boundary}{論理値．当てはめ値は到達可能な値の
    境界上にあるか?}
  \item{call}{マッチした呼び出し．}
  \item{formula}{与えられた公式．}
  \item{terms}{使われた \code{\link{terms}}．}
  \item{data}{\code{data} 引数．}
  \item{offset}{使われたオフセットベクトル．}
  \item{control}{使われた \code{control} 引数の値．}
  \item{method}{使われた当てはめ関数の名前，現在常に
    \code{"glm.fit"}．}
  \item{contrasts}{(関連があれば)使われた対比．}
  \item{xlevels}{(関連があれば)当てはめで使われた水準の記録．}
  \item{na.action}{(関連があれば)
    \code{NA} の特別な処理に関して
    \code{\link{model.frame}} が返した情報．}

  加えて，空でない当てはめは最終的な重み付き線形当てはめに関連した成分
  \code{qr}, \code{R} そして \code{effects} を持つ．

  クラス \code{"glm"} のオブジェクトは普通クラス
  \code{c("glm", "lm")} である，つまり
  クラス \code{"lm"} を継承する．そして
  クラス \code{"lm"} に対する熟考されたメソッドは
  IWLS の最後の繰り返しに於ける重み付き線形モデルに対して適用される．
  しかしながら，\code{\link{residuals}} と \code{weights} のような
  クラス \code{"glm"} に対する抽出関数は同名の当てはめ成分を
  単に取り出すわけではないので注意がいる．

  もし \code{\link{binomial}} \code{glm} モデルが
  二列の応答を与えて指定されると，
  \code{prior.weights} が返す重みは
  (提供されたケース重みを掛けられた)
  総ケース数であり，結果の成分
  \code{y} は成功数に比例する．
}
\seealso{
  \code{glm} メソッドに対しては \code{\link{anova.glm}},
  \code{\link{summary.glm}} 等，そして
  総称的関数 \code{\link{anova}}, \code{\link{summary}},
  \code{\link{effects}}, \code{\link{fitted.values}},
  そして \code{\link{residuals}}．

  一般化されていない
  \emph{線形}モデルについては
  \code{\link{lm}}
  (SAS が GLM，\sQuote{一般}線形モデル，と呼んでいるもの)．

  対数線形モデル(二項とポアッソン GLM がそうである)の分割表への
  あてはめに対しては
  \code{\link{loglin}} と \code{\link[MASS]{loglm}}
  (パッケージ \CRANpkg{MASS})．

  GLM を大きなデータセット(特に多くのケースをもつもの)
  に当てはめる別の方法は
  パッケージ \CRANpkg{biglm} 中の \code{bigglm}．

  \code{\link{esoph}}, \code{\link{infert}} そして
  \code{\link{predict.glm}} は二項 glm の当てはめの例を
  持つ．
}
\author{
  \code{glm} の最初の \R への実装は
  Aukland 大学で Ross Ihaka のために働いていた
  Simon Davies に依るが，それ以来徹底的に
  R Core チームのメンバーにより書き換えられてきた．

  デザインは
  Hastie & Pregibon (1992) に記述された同名の関数に啓発された．
}
\references{
  Dobson, A. J. (1990)
  \emph{An Introduction to Generalized Linear Models.}
  London: Chapman and Hall.

  Hastie, T. J. and Pregibon, D. (1992)
  \emph{Generalized linear models.}
  Chapter 6 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.

  McCullagh P. and Nelder, J. A. (1989)
  \emph{Generalized Linear Models.}
  London: Chapman and Hall.

  Venables, W. N. and Ripley, B. D. (2002)
  \emph{Modern Applied Statistics with S.}
  New York: Springer.
}

\examples{
## Dobson (1990) Page 93: 無作為化対照実験：
counts <- c(18,17,15,20,10,20,25,13,12)
outcome <- gl(3,1,9)
treatment <- gl(3,3)
print(d.AD <- data.frame(treatment, outcome, counts))
glm.D93 <- glm(counts ~ outcome + treatment, family = poisson())
anova(glm.D93)
\donttest{summary(glm.D93)}

\donttest{## Venables & Ripley (2002, p.189) からのオフセット付きの例
utils::data(anorexia, package = "MASS")

anorex.1 <- glm(Postwt ~ Prewt + Treat + offset(Prewt),
                family = gaussian, data = anorexia)
summary(anorex.1)
}

# McCullagh & Nelder (1989, pp. 300-2) からのガンマファミリの例
clotting <- data.frame(
    u = c(5,10,15,20,30,40,60,80,100),
    lot1 = c(118,58,42,35,27,25,21,19,18),
    lot2 = c(69,35,26,21,18,16,13,12,12))
summary(glm(lot1 ~ log(u), data = clotting, family = Gamma))
summary(glm(lot2 ~ log(u), data = clotting, family = Gamma))

\dontrun{
## 公式としての項オブジェクトの使用法の例に対しては
demo(glm.vr)
}}
\keyword{models}
\keyword{regression}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/glm.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{glm}
%\title{Fitting Generalized Linear Models}
%\alias{glm}
%\alias{glm.fit}
%\alias{weights.glm}
%%\alias{print.glm}
%\concept{regression}
%\concept{logistic}
%\concept{log-linear}
%\concept{loglinear}
%\description{
%  \code{glm} is used to fit generalized linear models, specified by
%  giving a symbolic description of the linear predictor and a
%  description of the error distribution.
%}
%\usage{
%glm(formula, family = gaussian, data, weights, subset,
%    na.action, start = NULL, etastart, mustart, offset,
%    control = list(\dots), model = TRUE, method = "glm.fit",
%    x = FALSE, y = TRUE, contrasts = NULL, \dots)
%
%glm.fit(x, y, weights = rep(1, nobs),
%        start = NULL, etastart = NULL, mustart = NULL,
%        offset = rep(0, nobs), family = gaussian(),
%        control = list(), intercept = TRUE)
%
%\method{weights}{glm}(object, type = c("prior", "working"), \dots)
%}
%\arguments{
%  \item{formula}{an object of class \code{"\link{formula}"} (or one that
%    can be coerced to that class): a symbolic description of the
%    model to be fitted.  The details of model specification are given
%    under \sQuote{Details}.}
%
%  \item{family}{a description of the error distribution and link
%    function to be used in the model.  For \code{glm} this can be a
%    character string naming a family function, a family function or the
%    result of a call to a family function.  For \code{glm.fit} only the
%    third option is supported.  (See \code{\link{family}} for details of
%    family functions.)}
%
%  \item{data}{an optional data frame, list or environment (or object
%    coercible by \code{\link{as.data.frame}} to a data frame) containing
%    the variables in the model.  If not found in \code{data}, the
%    variables are taken from \code{environment(formula)},
%    typically the environment from which \code{glm} is called.}
%
%  \item{weights}{an optional vector of \sQuote{prior weights} to be used
%    in the fitting process.  Should be \code{NULL} or a numeric vector.}
%
%  \item{subset}{an optional vector specifying a subset of observations
%    to be used in the fitting process.}
%
%  \item{na.action}{a function which indicates what should happen
%    when the data contain \code{NA}s.  The default is set by
%    the \code{na.action} setting of \code{\link{options}}, and is
%    \code{\link{na.fail}} if that is unset.  The \sQuote{factory-fresh}
%    default is \code{\link{na.omit}}.  Another possible value is
%    \code{NULL}, no action.  Value \code{\link{na.exclude}} can be useful.}
%
%  \item{start}{starting values for the parameters in the linear predictor.}
%
%  \item{etastart}{starting values for the linear predictor.}
%
%  \item{mustart}{starting values for the vector of means.}
%
%  \item{offset}{this can be used to specify an \emph{a priori} known
%    component to be included in the linear predictor during fitting.
%    This should be \code{NULL} or a numeric vector of length equal to
%    the number of cases.  One or more \code{\link{offset}} terms can be
%    included in the formula instead or as well, and if more than one is
%    specified their sum is used.  See \code{\link{model.offset}}.}
%
%  \item{control}{a list of parameters for controlling the fitting
%    process.  For \code{glm.fit} this is passed to
%    \code{\link{glm.control}}.}
%
%  \item{model}{a logical value indicating whether \emph{model frame}
%    should be included as a component of the returned value.}
%
%  \item{method}{the method to be used in fitting the model.  The default
%    method \code{"glm.fit"} uses iteratively reweighted least squares
%    (IWLS): the alternative \code{"model.frame"} returns the model frame
%    and does no fitting.
%
%    User-supplied fitting functions can be supplied either as a function
%    or a character string naming a function, with a function which takes
%    the same arguments as \code{glm.fit}.  If specified as a character
%    string it is looked up from within the \pkg{stats} namespace.
%  }
%
%  \item{x, y}{For \code{glm}:
%    logical values indicating whether the response vector and model
%    matrix used in the fitting process should be returned as components
%    of the returned value.
%
%    For \code{glm.fit}: \code{x} is a design matrix of dimension
%    \code{n * p}, and \code{y} is a vector of observations of length
%    \code{n}.
%  }
%
%  \item{contrasts}{an optional list. See the \code{contrasts.arg}
%    of \code{model.matrix.default}.}
%
%  \item{intercept}{logical. Should an intercept be included in the
%    \emph{null} model?}
%
%  \item{object}{an object inheriting from class \code{"glm"}.}
%  \item{type}{character, partial matching allowed.  Type of weights to
%    extract from the fitted model object.  Can be abbreviated.}
%
%  \item{\dots}{
%    For \code{glm}: arguments to be used to form the default
%    \code{control} argument if it is not supplied directly.
%
%    For \code{weights}: further arguments passed to or from other methods.
%  }
%}
%\details{
%  A typical predictor has the form \code{response ~ terms} where
%  \code{response} is the (numeric) response vector and \code{terms} is a
%  series of terms which specifies a linear predictor for
%  \code{response}.  For \code{binomial} and \code{quasibinomial}
%  families the response can also be specified as a \code{\link{factor}}
%  (when the first level denotes failure and all others success) or as a
%  two-column matrix with the columns giving the numbers of successes and
%  failures.  A terms specification of the form \code{first + second}
%  indicates all the terms in \code{first} together with all the terms in
%  \code{second} with any duplicates removed.
%
%  A specification of the form \code{first:second} indicates the set
%  of terms obtained by taking the interactions of all terms in
%  \code{first} with all terms in \code{second}.  The specification
%  \code{first*second} indicates the \emph{cross} of \code{first} and
%  \code{second}.  This is the same as \code{first + second +
%  first:second}.
%
%  The terms in the formula will be re-ordered so that main effects come
%  first, followed by the interactions, all second-order, all third-order
%  and so on: to avoid this pass a \code{terms} object as the formula.
%
%  Non-\code{NULL} \code{weights} can be used to indicate that different
%  observations have different dispersions (with the values in
%  \code{weights} being inversely proportional to the dispersions); or
%  equivalently, when the elements of \code{weights} are positive
%  integers \eqn{w_i}, that each response \eqn{y_i} is the mean of
%  \eqn{w_i} unit-weight observations.  For a binomial GLM prior weights
%  are used to give the number of trials when the response is the
%  proportion of successes: they would rarely be used for a Poisson GLM.
%
%
%  \code{glm.fit} is the workhorse function: it is not normally called
%  directly but can be more efficient where the response vector, design
%  matrix and family have already been calculated.
%
%  If more than one of \code{etastart}, \code{start} and \code{mustart}
%  is specified, the first in the list will be used.  It is often
%  advisable to supply starting values for a \code{\link{quasi}} family,
%  and also for families with unusual links such as \code{gaussian("log")}.
%
%  All of \code{weights}, \code{subset}, \code{offset}, \code{etastart}
%  and \code{mustart} are evaluated in the same way as variables in
%  \code{formula}, that is first in \code{data} and then in the
%  environment of \code{formula}.
%
%  For the background to warning messages about \sQuote{fitted probabilities
%    numerically 0 or 1 occurred} for binomial GLMs, see Venables &
%  Ripley (2002, pp.\sspace{}197--8).
%}
%
%\section{Fitting functions}{
%  The argument \code{method} serves two purposes.  One is to allow the
%  model frame to be recreated with no fitting.  The other is to allow
%  the default fitting function \code{glm.fit} to be replaced by a
%  function which takes the same arguments and uses a different fitting
%  algorithm.  If \code{glm.fit} is supplied as a character string it is
%  used to search for a function of that name, starting in the
%  \pkg{stats} namespace.
%
%  The class of the object return by the fitter (if any) will be
%  prepended to the class returned by \code{glm}.
%}
%
%\value{
%  \code{glm} returns an object of class inheriting from \code{"glm"}
%  which inherits from the class \code{"lm"}. See later in this section.
%  If a non-standard \code{method} is used, the object will also inherit
%  from the class (if any) returned by that function.
%
%  The function \code{\link{summary}} (i.e., \code{\link{summary.glm}}) can
%  be used to obtain or print a summary of the results and the function
%  \code{\link{anova}} (i.e., \code{\link{anova.glm}})
%  to produce an analysis of variance table.
%
%  The generic accessor functions \code{\link{coefficients}},
%  \code{effects}, \code{fitted.values} and \code{residuals} can be used to
%  extract various useful features of the value returned by \code{glm}.
%
%  \code{weights} extracts a vector of weights, one for each case in the
%  fit (after subsetting and \code{na.action}).
%
%  An object of class \code{"glm"} is a list containing at least the
%  following components:
%
%  \item{coefficients}{a named vector of coefficients}
%  \item{residuals}{the \emph{working} residuals, that is the residuals
%    in the final iteration of the IWLS fit.  Since cases with zero
%    weights are omitted, their working residuals are \code{NA}.}
%  \item{fitted.values}{the fitted mean values, obtained by transforming
%    the linear predictors by the inverse of the link function.}
%  \item{rank}{the numeric rank of the fitted linear model.}
%  \item{family}{the \code{\link{family}} object used.}
%  \item{linear.predictors}{the linear fit on link scale.}
%  \item{deviance}{up to a constant, minus twice the maximized
%    log-likelihood.  Where sensible, the constant is chosen so that a
%    saturated model has deviance zero.}
%  \item{aic}{A version of Akaike's \emph{An Information Criterion},
%    minus twice the maximized log-likelihood plus twice the number of
%    parameters, computed by the \code{aic} component of the family.
%    For binomial and Poison families the dispersion is
%    fixed at one and the number of parameters is the number of
%    coefficients. For gaussian, Gamma and inverse gaussian families the
%    dispersion is estimated from the residual deviance, and the number
%    of parameters is the number of coefficients plus one.  For a
%    gaussian family the MLE of the dispersion is used so this is a valid
%    value of AIC, but for Gamma and inverse gaussian families it is not.
%    For families fitted by quasi-likelihood the value is \code{NA}.}
%  \item{null.deviance}{The deviance for the null model, comparable with
%    \code{deviance}. The null model will include the offset, and an
%    intercept if there is one in the model.  Note that this will be
%    incorrect if the link function depends on the data other than
%    through the fitted mean: specify a zero offset to force a correct
%    calculation.}
%  \item{iter}{the number of iterations of IWLS used.}
%  \item{weights}{the \emph{working} weights, that is the weights
%    in the final iteration of the IWLS fit.}
%  \item{prior.weights}{the weights initially supplied, a vector of
%    \code{1}s if none were.}
%  \item{df.residual}{the residual degrees of freedom.}
%  \item{df.null}{the residual degrees of freedom for the null model.}
%  \item{y}{if requested (the default) the \code{y} vector
%    used. (It is a vector even for a binomial model.)}
%  \item{x}{if requested, the model matrix.}
%  \item{model}{if requested (the default), the model frame.}
%  \item{converged}{logical. Was the IWLS algorithm judged to have converged?}
%  \item{boundary}{logical. Is the fitted value on the boundary of the
%    attainable values?}
%  \item{call}{the matched call.}
%  \item{formula}{the formula supplied.}
%  \item{terms}{the \code{\link{terms}} object used.}
%  \item{data}{the \code{data argument}.}
%  \item{offset}{the offset vector used.}
%  \item{control}{the value of the \code{control} argument used.}
%  \item{method}{the name of the fitter function used, currently always
%    \code{"glm.fit"}.}
%  \item{contrasts}{(where relevant) the contrasts used.}
%  \item{xlevels}{(where relevant) a record of the levels of the factors
%    used in fitting.}
%  \item{na.action}{(where relevant) information returned by
%    \code{\link{model.frame}} on the special handling of \code{NA}s.}
%
%  In addition, non-empty fits will have components \code{qr}, \code{R}
%  and \code{effects} relating to the final weighted linear fit.
%
%  Objects of class \code{"glm"} are normally of class \code{c("glm",
%    "lm")}, that is inherit from class \code{"lm"}, and well-designed
%  methods for class \code{"lm"} will be applied to the weighted linear
%  model at the final iteration of IWLS.  However, care is needed, as
%  extractor functions for class \code{"glm"} such as
%  \code{\link{residuals}} and \code{weights} do \bold{not} just pick out
%  the component of the fit with the same name.
%
%  If a \code{\link{binomial}} \code{glm} model was specified by giving a
%  two-column response, the weights returned by \code{prior.weights} are
%  the total numbers of cases (factored by the supplied case weights) and
%  the component \code{y} of the result is the proportion of successes.
%}
%\seealso{
%  \code{\link{anova.glm}}, \code{\link{summary.glm}}, etc. for
%  \code{glm} methods,
%  and the generic functions \code{\link{anova}}, \code{\link{summary}},
%  \code{\link{effects}}, \code{\link{fitted.values}},
%  and \code{\link{residuals}}.
%
%  \code{\link{lm}} for non-generalized \emph{linear} models (which SAS
%  calls GLMs, for \sQuote{general} linear models).
%
%  \code{\link{loglin}} and \code{\link[MASS]{loglm}} (package
%  \CRANpkg{MASS}) for fitting log-linear models (which binomial and
%  Poisson GLMs are) to contingency tables.
%
%  \code{bigglm} in package \CRANpkg{biglm} for an alternative
%  way to fit GLMs to large datasets (especially those with many cases).
%
%  \code{\link{esoph}}, \code{\link{infert}} and
%  \code{\link{predict.glm}} have examples of fitting binomial glms.
%}
%\author{
%  The original \R implementation of \code{glm} was written by Simon
%  Davies working for Ross Ihaka at the University of Auckland, but has
%  since been extensively re-written by members of the R Core team.
%
%  The design was inspired by the S function of the same name described
%  in Hastie & Pregibon (1992).
%}
%\references{
%  Dobson, A. J. (1990)
%  \emph{An Introduction to Generalized Linear Models.}
%  London: Chapman and Hall.
%
%  Hastie, T. J. and Pregibon, D. (1992)
%  \emph{Generalized linear models.}
%  Chapter 6 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%
%  McCullagh P. and Nelder, J. A. (1989)
%  \emph{Generalized Linear Models.}
%  London: Chapman and Hall.
%
%  Venables, W. N. and Ripley, B. D. (2002)
%  \emph{Modern Applied Statistics with S.}
%  New York: Springer.
%}
%
%\examples{
%## Dobson (1990) Page 93: Randomized Controlled Trial :
%counts <- c(18,17,15,20,10,20,25,13,12)
%outcome <- gl(3,1,9)
%treatment <- gl(3,3)
%print(d.AD <- data.frame(treatment, outcome, counts))
%glm.D93 <- glm(counts ~ outcome + treatment, family = poisson())
%anova(glm.D93)
%\donttest{summary(glm.D93)}
%
%\donttest{## an example with offsets from Venables & Ripley (2002, p.189)
%utils::data(anorexia, package = "MASS")
%
%anorex.1 <- glm(Postwt ~ Prewt + Treat + offset(Prewt),
%                family = gaussian, data = anorexia)
%summary(anorex.1)
%}
%
%# A Gamma example, from McCullagh & Nelder (1989, pp. 300-2)
%clotting <- data.frame(
%    u = c(5,10,15,20,30,40,60,80,100),
%    lot1 = c(118,58,42,35,27,25,21,19,18),
%    lot2 = c(69,35,26,21,18,16,13,12,12))
%summary(glm(lot1 ~ log(u), data = clotting, family = Gamma))
%summary(glm(lot2 ~ log(u), data = clotting, family = Gamma))
%
%\dontrun{
%## for an example of the use of a terms object as a formula
%demo(glm.vr)
%}}
%\keyword{models}
%\keyword{regression}
%
%\encoding{UTF-8}
%
