% File src/library/stats/man/heatmap.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{heatmap}
\alias{heatmap}%@%\alias{ヒートマップを描く}
\title{ Draw a Heat Map }
\description{
  ヒートマップはデンドログラムの左側と上側に付け加えられる
  擬似的なイメージ(基本的に \code{\link{image}(t(x))})である．
  典型的には，ある値のセット(行又は列平均)に従い
  デンドログラムによって課せられた制約の範囲内で
  行と列の再順序化が実行される．
}
\usage{
heatmap(x, Rowv = NULL, Colv = if(symm)"Rowv" else NULL,
        distfun = dist, hclustfun = hclust,
        reorderfun = function(d, w) reorder(d, w),
        add.expr, symm = FALSE, revC = identical(Colv, "Rowv"),
        scale = c("row", "column", "none"), na.rm = TRUE,
        margins = c(5, 5), ColSideColors, RowSideColors,
        cexRow = 0.2 + 1/log10(nr), cexCol = 0.2 + 1/log10(nc),
        labRow = NULL, labCol = NULL, main = NULL,
        xlab = NULL, ylab = NULL,
        keep.dendro = FALSE, verbose = getOption("verbose"), \dots)
}
\arguments{
  \item{x}{プロットされる値の数値行列．}
  \item{Rowv}{
    \emph{行}デンドログラムをどのように計算し再順序化するかを決める．
    デンドログラムか行デンドログラムを再順序化するのに使われる
    値のベクトルか 行デンドログラム(と再順序化)を抑制する \code{\link{NA}}．
    既定では \code{\link{NULL}}，下の\sQuote{詳細}を見よ．}
  \item{Colv}{
    \emph{列}デンドログラムを再順序化するか，そしてどのようにするかを
    決める． 
    上の \code{Rowv} 引数と同じオプションを持ち，
    \emph{加えて} \code{x} が正方行列の時 \code{Colv = "Rowv"} は
    列が行と同じように扱われることを意味する
    (従って行デンドログラムがなければ列デンドログラムも又無い)．}
  \item{distfun}{行と列双方の間の距離(非類似度)を計算するのに使われる
    関数．既定は \code{\link{dist}}．}
  \item{hclustfun}{\code{Rowv} か \code{Colv} がデンドログラムでない時
    階層的クラスタリングを計算するのに使われる関数．
    既定では \code{\link{hclust}}．
    引数として \code{distfun} の結果を取り
    \code{\link{as.dendrogram}} が適用できるようなオブジェクトを
    返す．}
  \item{reorderfun}{
    デンドログラムと行と列デンドログラムの再順序化に対する重みの\cr
    \code{function(d, w)}．
    既定では \code{\link{reorder.dendrogram}} を使う．}
  \item{add.expr}{
    \code{image} の呼び出しの後に評価される表現式．
    プロットへに成分を加えるのに使うことが出来る．}
  \item{symm}{
    \code{x} を対称に扱うかどうかを指示する論理値；
    \code{x} が正方行列の時だけ真になれる．}
  \item{revC}{
    総ロットのために列の順序を逆転すべきかどうかを指示する論理値で，
    例えば対称なケースに対して
    対称軸が通常であるようにする．}
  \item{scale}{
    値を行方向か列方向に中心化とスケール化するか，又は何もしないかを
    指示する文字列．
    既定はもし \code{symm} が偽なら \code{"row"} で，さもなければ
    \code{"none"}．}
  \item{na.rm}{\code{NA} を除くべきかどうかを指示する論理値．}
  \item{margins}{それぞれ列名と行名に対する余白
    (\code{\link{par}(mar = *)} を見よ)を含む長さ2の数値ベクトル．}
  \item{ColSideColors}{
    \code{x} の行の注釈に使われるかもしれない水平横側バーに対する
    色の名前を含む(オプションの)
    長さ \code{ncol(x)} の文字列を含む．}
  \item{RowSideColors}{
    \code{x} の行の注釈に使われるかもしれない垂直横側バーに対する
    色の名前を含む(オプションの)
    長さ \code{nrow(x)} の文字列を含む．}
  \item{cexRow, cexCol}{
    正数，行又は列軸のラベル中の
    \code{cex.axis} に使われる．
    既定は現在行か列数でだけを使う．}
  \item{labRow, labCol}{使用される行と列ラベルの文字列ベクトル；
    既定はそれぞれ \code{rownames(x)} 又は \code{colnames(x)}．}
  \item{main, xlab, ylab}{主，x と y 軸タイトル；既定では無い．}
  \item{keep.dendro}{デンドログラムを結果の一部として
    保持するかどうかを指示する論理値
    (\code{Rowv} と/又は \code{Colv} が NA でない時)．}
  \item{verbose}{情報をプリントすべきかどうかを指示する論理値．}
  \item{\dots}{
    \code{\link{image}} に渡される追加引数，
    例えば色を指定する \code{col}．}
}
\details{
  もし \code{Rowv} 又は \code{Colv} のいずれかがデンドログラムならば，
  それらは尊重される
  (そして再順序化されない)．さもなければ，デンドログラムが
  \code{dd <- as.dendrogram(hclustfun(distfun(X)))} として計算される，
  ここで \code{X} は
  \code{x} か \code{t(x)} である．

  もしどちらかが(\sQuote{重み}の)ベクトルならば， 適当な
  デンドログラムが
  行ケースならば\cr
  \code{\link{reorder}(dd, Rowv)} で
  デンドログラムに課せられた制約の下で与えられた値に従い再順序化される．
  既定であるように，もしどちらもなければ，
  対応するデンドログラムの順序は行/列の平均値に依る．
  つまり行の場合は，
  \code{Rowv <- rowMeans(x, na.rm = na.rm)}．
  もしどちらかが \code{\link{NA}} なら，対応する側は
  再順序化は\emph{されない}．

  既定(\code{scale = "row"})では行は平均がゼロで単位標準偏差を
  持つようにスケール化されない．
  遺伝子情報のプロットからこれが有用である経験的な証拠がある．

  既定の色はそれほど見栄えが良くない．
  パッケージ \CRANpkg{RColorBrewer} のような拡張を考慮しよう．
}
\note{
  \code{Rowv = NA} (または \code{Colw = NA})で無い限り，
  オリジナルの行と列はデンドログラムにマッチするように
  \emph{いかなる場合も}再順序化される．
  例えば，行は \code{\link{order.dendrogram}(Rowv)} が使われる，
  ここで \code{Rowv} は(もしかすると \code{\link{reorder}()} された)行
  デンドログラム．

  \code{heatmap()} は \code{\link{layout}} を使い
  下右側の隅に 2x2 のレイアウトでイメージを描く．
  従って，それは多重列/行レイアウト中では\bold{使えない}，
  つまり \code{\link{par}(mfrow = *)} か \code{(mfcol = *)}
  が呼び出されている時．
}
\value{
  不可視の次の成分を持つリスト
  \item{rowInd}{
    \code{\link{order.dendrogram}} が返すような行添字の置換ベクトル．}
  \item{colInd}{列添字の置換ベクトル．}
  \item{Rowv}{行デンドログラム；
    入力 \code{Rowv} が NA で無く \code{keep.dendro} が真の時だけ．}
  \item{Colv}{列デンドログラム；
    入力 \code{Colv} が NA で無く \code{keep.dendro} が真の時だけ．}
}
\author{オリジナル Andy Liaw；改訂 R. Gentleman, M. Maechler, W. Huber．}

\seealso{\code{\link{image}}, \code{\link{hclust}}}

\examples{
require(graphics); require(grDevices)
x  <- as.matrix(mtcars)
rc <- rainbow(nrow(x), start = 0, end = .3)
cc <- rainbow(ncol(x), start = 0, end = .3)
hv <- heatmap(x, col = cm.colors(256), scale = "column",
              RowSideColors = rc, ColSideColors = cc, margins = c(5,10),
              xlab = "specification variables", ylab =  "Car Models",
              main = "heatmap(<Mtcars data>, ..., scale = \"column\")")
utils::str(hv) # 添字ベクトルの再並べ替え

## 列デンドログラムは一切ない(再並べ替えも無い)：
heatmap(x, Colv = NA, col = cm.colors(256), scale = "column",
        RowSideColors = rc, margins = c(5,10),
        xlab = "specification variables", ylab =  "Car Models",
        main = "heatmap(<Mtcars data>, ..., scale = \"column\")")
\testonly{
## 行デンドログラムは一切ない(再並べ替えも無い)：
heatmap(x, Rowv = NA, col = cm.colors(256), scale = "column",
        ColSideColors = cc, margins = c(5,10),
        xlab = "xlab", ylab =  "ylab")  # 主ラベル無し
}
## "何もない"
heatmap(x, Rowv = NA, Colv = NA, scale = "column",
        main = "heatmap(*, NA, NA) ~= image(t(x))")
%% also want example using the `add.exp' argument!

round(Ca <- cor(attitude), 2)
symnum(Ca) # simple graphic
heatmap(Ca,               symm = TRUE, margins = c(6,6)) # reorder() 有り
heatmap(Ca, Rowv = FALSE, symm = TRUE, margins = c(6,6)) # reorder() 無し
## 並べ替え有りと無しの少々人工的な色調バー：
cc <- rainbow(nrow(Ca))
heatmap(Ca, Rowv = FALSE, symm = TRUE, RowSideColors = cc, ColSideColors = cc,
	margins = c(6,6))
heatmap(Ca,		symm = TRUE, RowSideColors = cc, ColSideColors = cc,
	margins = c(6,6))

## 変数のクラスタリングのために，むしろ cor() に基づく距離を使う：
symnum( cU <- cor(USJudgeRatings) )

hU <- heatmap(cU, Rowv = FALSE, symm = TRUE, col = topo.colors(16),
             distfun = function(c) as.dist(1 - c), keep.dendro = TRUE)
## 同じ再順序化を持つ相関行列：
round(100 * cU[hU[[1]], hU[[2]]])
## 列デンドログラム：
utils::str(hU$Colv)
}
\keyword{hplot}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/heatmap.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{heatmap}
%\alias{heatmap}
%\title{ Draw a Heat Map }
%\description{
%  A heat map is a false color image (basically
%  \code{\link{image}(t(x))}) with a dendrogram added to the left side
%  and to the top.  Typically, reordering of the rows and columns
%  according to some set of values (row or column means) within the
%  restrictions imposed by the dendrogram is carried out.
%}
%\usage{
%heatmap(x, Rowv = NULL, Colv = if(symm)"Rowv" else NULL,
%        distfun = dist, hclustfun = hclust,
%        reorderfun = function(d, w) reorder(d, w),
%        add.expr, symm = FALSE, revC = identical(Colv, "Rowv"),
%        scale = c("row", "column", "none"), na.rm = TRUE,
%        margins = c(5, 5), ColSideColors, RowSideColors,
%        cexRow = 0.2 + 1/log10(nr), cexCol = 0.2 + 1/log10(nc),
%        labRow = NULL, labCol = NULL, main = NULL,
%        xlab = NULL, ylab = NULL,
%        keep.dendro = FALSE, verbose = getOption("verbose"), \dots)
%}
%\arguments{
%  \item{x}{numeric matrix of the values to be plotted. }
%  \item{Rowv}{determines if and how the \emph{row} dendrogram should be
%    computed and reordered.  Either a \code{\link{dendrogram}} or a
%    vector of values used to reorder the row dendrogram or
%    \code{\link{NA}} to suppress any row dendrogram (and reordering) or
%    by default, \code{\link{NULL}}, see \sQuote{Details} below.}
%  \item{Colv}{determines if and how the \emph{column} dendrogram should be
%    reordered.  Has the same options as the \code{Rowv} argument above and
%    \emph{additionally} when \code{x} is a square matrix, \code{Colv =
%      "Rowv"} means that columns should be treated identically to the
%    rows (and so if there is to be no row dendrogram there will not be a
%    column one either).}
%  \item{distfun}{function used to compute the distance (dissimilarity)
%    between both rows and columns.  Defaults to \code{\link{dist}}.}
%  \item{hclustfun}{function used to compute the hierarchical clustering
%    when \code{Rowv} or \code{Colv} are not dendrograms.  Defaults to
%    \code{\link{hclust}}. Should take as argument a result of \code{distfun}
%    and return an object to which \code{\link{as.dendrogram}} can be applied.}
%  \item{reorderfun}{\code{function(d, w)} of dendrogram and weights for
%    reordering the row and column dendrograms.  The default uses
%    \code{\link{reorder.dendrogram}}.}
%  \item{add.expr}{expression that will be evaluated after the call to
%    \code{image}.  Can be used to add components to the plot.}
%  \item{symm}{logical indicating if \code{x} should be treated
%    \bold{symm}etrically; can only be true when \code{x} is a square matrix.}
%  \item{revC}{logical indicating if the column order should be
%    \code{\link{rev}}ersed for plotting, such that e.g., for the
%    symmetric case, the symmetry axis is as usual.}
%  \item{scale}{character indicating if the values should be centered and
%    scaled in either the row direction or the column direction, or
%    none.  The default is \code{"row"} if \code{symm} false, and
%    \code{"none"} otherwise.}
%  \item{na.rm}{logical indicating whether \code{NA}'s should be removed.}
%  \item{margins}{numeric vector of length 2 containing the margins
%    (see \code{\link{par}(mar = *)}) for column and row names, respectively.}
%  \item{ColSideColors}{(optional) character vector of length \code{ncol(x)}
%    containing the color names for a horizontal side bar that may be used to
%    annotate the columns of \code{x}.}
%  \item{RowSideColors}{(optional) character vector of length \code{nrow(x)}
%    containing the color names for a vertical side bar that may be used to
%    annotate the rows of \code{x}.}
%  \item{cexRow, cexCol}{positive numbers, used as \code{cex.axis} in
%    for the row or column axis labeling.  The defaults currently only
%    use number of rows or columns, respectively.}
%  \item{labRow, labCol}{character vectors with row and column labels to
%    use; these default to \code{rownames(x)} or \code{colnames(x)},
%    respectively.}
%  \item{main, xlab, ylab}{main, x- and y-axis titles; defaults to none.}
%  \item{keep.dendro}{logical indicating if the dendrogram(s) should be
%    kept as part of the result (when \code{Rowv} and/or \code{Colv} are
%    not NA).}
%  \item{verbose}{logical indicating if information should be printed.}
%  \item{\dots}{additional arguments passed on to \code{\link{image}},
%    e.g., \code{col} specifying the colors.} %
%}
%\details{
%  If either \code{Rowv} or \code{Colv} are dendrograms they are honored
%  (and not reordered).  Otherwise, dendrograms are computed as
%  \code{dd <- as.dendrogram(hclustfun(distfun(X)))} where \code{X} is
%  either \code{x} or \code{t(x)}.
%
%  If either is a vector (of \sQuote{weights}) then the appropriate
%  dendrogram is reordered according to the supplied values subject to
%  the constraints imposed by the dendrogram, by \code{\link{reorder}(dd,
%    Rowv)}, in the row case.
%  If either is missing, as by default, then the ordering of the
%  corresponding dendrogram is by the mean value of the rows/columns,
%  i.e., in the case of rows, \code{Rowv <- rowMeans(x, na.rm = na.rm)}.
%  If either is \code{\link{NA}}, \emph{no reordering} will be done for
%  the corresponding side.
%
%  By default (\code{scale = "row"}) the rows are scaled to have mean
%  zero and standard deviation one.  There is some empirical evidence
%  from genomic plotting that this is useful.
%
%  The default colors are not pretty.  Consider using enhancements such
%  as the \CRANpkg{RColorBrewer} package.
%}
%\note{
%  Unless \code{Rowv = NA} (or \code{Colw = NA}), the original rows and
%  columns are reordered \emph{in any case} to match the dendrogram,
%  e.g., the rows by \code{\link{order.dendrogram}(Rowv)} where
%  \code{Rowv} is the (possibly \code{\link{reorder}()}ed) row
%  dendrogram.
%
%  \code{heatmap()} uses \code{\link{layout}} and draws the
%  \code{\link{image}} in the lower right corner of a 2x2 layout.
%  Consequentially, it can \bold{not} be used in a multi column/row
%  layout, i.e., when \code{\link{par}(mfrow = *)} or \code{(mfcol = *)}
%  has been called.
%}
%\value{
%  Invisibly, a list with components
%  \item{rowInd}{\bold{r}ow index permutation vector as returned by
%    \code{\link{order.dendrogram}}.}
%  \item{colInd}{\bold{c}olumn index permutation vector.}
%  \item{Rowv}{the row dendrogram; only if input \code{Rowv} was not NA
%    and \code{keep.dendro} is true.}
%  \item{Colv}{the column dendrogram; only if input \code{Colv} was not NA
%    and \code{keep.dendro} is true.}
%}
%\author{Andy Liaw, original; R. Gentleman, M. Maechler, W. Huber, revisions.}
%
%\seealso{\code{\link{image}}, \code{\link{hclust}}}
%
%\examples{
%require(graphics); require(grDevices)
%x  <- as.matrix(mtcars)
%rc <- rainbow(nrow(x), start = 0, end = .3)
%cc <- rainbow(ncol(x), start = 0, end = .3)
%hv <- heatmap(x, col = cm.colors(256), scale = "column",
%              RowSideColors = rc, ColSideColors = cc, margins = c(5,10),
%              xlab = "specification variables", ylab =  "Car Models",
%              main = "heatmap(<Mtcars data>, ..., scale = \"column\")")
%utils::str(hv) # the two re-ordering index vectors
%
%## no column dendrogram (nor reordering) at all:
%heatmap(x, Colv = NA, col = cm.colors(256), scale = "column",
%        RowSideColors = rc, margins = c(5,10),
%        xlab = "specification variables", ylab =  "Car Models",
%        main = "heatmap(<Mtcars data>, ..., scale = \"column\")")
%\testonly{
%## no row dendrogram (nor reordering) at all:
%heatmap(x, Rowv = NA, col = cm.colors(256), scale = "column",
%        ColSideColors = cc, margins = c(5,10),
%        xlab = "xlab", ylab =  "ylab")  # no main
%}
%## "no nothing"
%heatmap(x, Rowv = NA, Colv = NA, scale = "column",
%        main = "heatmap(*, NA, NA) ~= image(t(x))")
%%% also want example using the `add.exp' argument!
%
%round(Ca <- cor(attitude), 2)
%symnum(Ca) # simple graphic
%heatmap(Ca,               symm = TRUE, margins = c(6,6)) # with reorder()
%heatmap(Ca, Rowv = FALSE, symm = TRUE, margins = c(6,6)) # _NO_ reorder()
%## slightly artificial with color bar, without and with ordering:
%cc <- rainbow(nrow(Ca))
%heatmap(Ca, Rowv = FALSE, symm = TRUE, RowSideColors = cc, ColSideColors = cc,
%	margins = c(6,6))
%heatmap(Ca,		symm = TRUE, RowSideColors = cc, ColSideColors = cc,
%	margins = c(6,6))
%
%## For variable clustering, rather use distance based on cor():
%symnum( cU <- cor(USJudgeRatings) )
%
%hU <- heatmap(cU, Rowv = FALSE, symm = TRUE, col = topo.colors(16),
%             distfun = function(c) as.dist(1 - c), keep.dendro = TRUE)
%## The Correlation matrix with same reordering:
%round(100 * cU[hU[[1]], hU[[2]]])
%## The column dendrogram:
%utils::str(hU$Colv)
%}
%\keyword{hplot}
%
%\encoding{UTF-8}
%
