% File src/library/stats/man/lm.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{lm}
\alias{lm}%@%\alias{線形モデルを当てはめる}
%\alias{print.lm}
\concept{regression}
\title{Fitting Linear Models}
\description{
  \code{lm} は線形モデルの当てはめに使われる．
  回帰分析，そして(\code{\link{aov}} がこれらに対してはより便利なインタフェイスを与えるが)
  単一層の分散分析と共分散分析の実行に
  使うことが出来る．
}
\usage{
lm(formula, data, subset, weights, na.action,
   method = "qr", model = TRUE, x = FALSE, y = FALSE, qr = TRUE,
   singular.ok = TRUE, contrasts = NULL, offset, \dots)
}
\arguments{
  \item{formula}{
    クラス \code{"\link{formula}"} (又はそうしたクラスに強制変換出来るもの)
    のオブジェクト：当てはめられるモデルのシンボリックな記述．
    モデル指定の詳細は\sQuote{詳細}節で与えられる．}
    
  \item{data}{
    モデル中の変数を含むオプションのデータフレーム，リスト，又は
    環境(または
    \code{\link{as.data.frame}} でデータフレームに変換できるもの)．
    もし \code{data} 中に見つからなければ，変数は
    \code{environment(formula)} から取られる，これは典型的には
    \code{lm} が呼び出された環境である．}

  \item{subset}{当てはめ過程で使われる観測値の部分集合を指定するオプションのベクトル．}

  \item{weights}{当てはめ過程で使われるオプションの重みのベクトル．
    \code{NULL} か数値ベクトルであるべきである．
    もし NULL でなければ，最少二乗法が重み
    \code{weights} で使われる
    (つまり \code{sum(w*e^2)} を最小化する)；さもなければ
    通常最少二乗法が使われる．
    \sQuote{詳細}節も見よ．}

  \item{na.action}{
    データが \code{NA} を含む時何が起こるかを指示する関数．
    既定値は \code{\link{options}} の
    \code{na.action} 設定で，もし未設定ならば
    \code{\link{na.fail}}．
    \sQuote{工場出荷}既定値は
    \code{\link{na.omit}}．もうひとつの可能な値は
    何もしない \code{NULL}．
    値 \code{\link{na.exclude}} は役に立つかもしれない．}

  \item{method}{使われる手法；当てはめに対しては，現在
  the method to be used; for fitting, currently only
    \code{method = "qr"} だけがサポートされている；
    is supported;
    \code{method = "model.frame"} はモデルフレームを
    返す(\code{model = TRUE} と同じ，下を見よ)．}

  \item{model, x, y, qr}{論理値．
    もし \code{TRUE} なら対応する当てはめの成分
    (モデルフレーム，モデル行列，応答，QR 分解)が返される．
  }

  \item{singular.ok}{論理値．もし \code{FALSE}
    (S の既定であるが \R ではそうでない)ならば特異な当てはめはエラーになる．}

  \item{contrasts}{オプションのリスト．
    \code{contrasts.arg} 又は \code{\link{model.matrix.default}} を見よ．}

  \item{offset}{
    これは当てはめの過程で線形予測子に含められるべき\emph{事前}に既知な
    成分を指定するのに使うことが出来る．
    これは \code{NULL} かケースの数に長さが等しい数値ベクトル
    であるべきである．
    一つもしくはそれ以上の \code{\link{offset}} 項を代わりに/同様に
    含めることが出来，そしてもし複数が指定されると
    それらの和が使われる．
    \code{\link{model.offset}} を見よ．}

  \item{\dots}{低レベルの回帰当てはめ関数に渡される追加の引数．}
}
\details{
  \code{lm} に対するモデルはシンボリックに指定される．
  典型的なモデルは形式 \code{response ~ terms} を持ち，
  ここで \code{response} は(数値)応答ベクトルで
  \code{terms} は
  \code{response} に対する線形予測子を指定する一連の項である．
  形式 \code{first + second} の項の指定は重複を除いた
  \code{first} 中の全ての項に \code{first} 中の全ての項を
  加えたものを指示する．
  形式 \code{first:second} は
  \code{first} 中の全ての項と \code{second} 中の全ての項の相互作用を
  取って得られる項のセットを意味する．
  指定 \code{first*second} は \code{first} と \code{second} の
  \emph{クロス}を指示する．これは
  \code{first + second + first:second} と同じである．

  もし公式が \code{\link{offset}} を含めばこれは評価され応答から
  引かれる．

  もし \code{response} が行列なら行列の各列に
  最少に乗法で線形モデルが当てはめられる．

  より以上の詳細は \code{\link{model.matrix}} を見よ．
  公式中の項は主効果が最初で，相互作用が次で，全ての二次項，
  全ての三次項等となるように並べ替えられる：
  これを避けるためには \code{terms} オブジェクトを公式として渡す
  (例は \code{\link{aov}} と \code{demo(glm.vr)} を見よ)．

  公式は切片項を暗黙のうちに含む．
  これを除くには \code{y ~ x - 1} 又は \code{y ~ 0 + x} を使う．
  許される公式のより詳細は \code{\link{formula}} を見よ．

  \code{NULL} でない \code{weights} は異なった観測値が
  異なった分散を持つことを指示できる
  (\code{weights} 中の値は分散に逆比例する)；又は
  同値であるが
  \code{weights} の要素が正整数 \eqn{w_i} であれば各応答 \eqn{y_i}
  は \eqn{w_i} 個で重みを付けられた観測値の平均である
  (\eqn{w_i} 個の観測値が \eqn{y_i} に等しくデータが要約されている)．

  \code{lm} は実際の計算には低水準関数
  \code{\link{lm.fit}} 等を呼び出す．
  プログラミングのためだけには同じようにすることを
  考慮出来るかもしれない．

  \code{weights}, \code{subset} そして \code{offset} の全ては
  \code{formula} 中の変数と同様に評価される，
  つまり最初 \code{data} 中で，それから環境 \code{formula} 中評価される．
}
\value{
  \code{lm} はクラス
  \code{\link{class}} \code{"lm"} 又は
  多重応答に対してはクラス
  \code{c("mlm", "lm")} のオブジェクトを返す．

  関数 \code{summary} と \code{\link{anova}} は結果の要約と
  分散分析表のプリントに使われる．
  一般的なアクセス関数 \code{coefficients},
  \code{effects}, \code{fitted.values} そして \code{residuals} は
  \code{lm} が返す値の様々な有用な特徴を取り出す．

  クラス \code{"lm"} のオブジェクトは少なくとも次の成分を含む：

  \item{coefficients}{係数の名前付きベクトル．}
  \item{residuals}{残差，つまり応答から当てはめ値を引いたもの．}
  \item{fitted.values}{当てはめ平均値．}
  \item{rank}{当てはめ線形モデルの数値的ランク．}
  \item{weights}{(重み付き当てはめだけ)指定された重み．}
  \item{df.residual}{残差自由度．}
  \item{call}{マッチした呼び出し．}
  \item{terms}{使われた項．}
  \item{contrasts}{(関連がある場合だけ)使用された対比．}
  \item{xlevels}{(関連がある場合だけ)当てはめで使われた
    因子の水準の記録．}
  \item{offset}{使用されたオフセット(何も使われなければ欠損)．}
  \item{y}{もし要求されれば，使われた応答．}
  \item{x}{もし要求されれば，使われたモデル行列．}
  \item{model}{もし要求されれば(既定)，使われたモデルフレーム．}
  \item{na.action}{(関連があれば)
    \code{NA} の特殊な処理に関して
    \code{\link{model.frame}} が返した情報．}

  加えて，ナルでない当てはめは
  \code{summary} と \code{\link{effects}} のような抽出関数が使うため，
  線形当てはめに関連する成分
  \code{assign},  \code{effects} そして(不要とされない限り) \code{qr} を持つ．
}
\section{時系列の使用}{
  \code{lm} を時系列に適用するには相当の注意がいる．

  \code{na.action = NULL} でない限り，時系列属性は
  回帰が行われる前に取り除かれる．
  (これは
  \code{NA} 値の除去が時系列属性を無効化するために必要であり，
  もし \code{NA} が系列の中途で除かれれば結果は最早
  正規の時系列ではない．)

  時系列属性が保たれたとしてもそれらは
  系列を並べるのに使われないので，
  ラグや階差による変量の時間シフトは無視される．
  残差と当てはめ値が時系列になるように，
  \code{data} 引数を
  \code{\link{ts.intersect}(\dots, dframe = TRUE)} で準備し，
  それから適当な 
  \code{na.action} をデータフレームに適用し
  \code{lm} を \code{na.action = NULL} で呼び出すのは
  良い心がけである．
}
\seealso{
  要約は \code{\link{summary.lm}} そして ANOVA 表は
  \code{\link{anova.lm}}；
  異なったインタフェイスは \code{\link{aov}}．

  総称的関数 \code{\link{coef}}, \code{\link{effects}},
  \code{\link{residuals}}, \code{\link{fitted}}, \code{\link{vcov}}．

  信頼区間と予測区間を含む予測には \code{\link{predict.lm}}
  (\code{\link{predict}} 経由)；
  \emph{パラメータ}の信頼区間は .\code{\link{confint}}．

  回帰診断に対しては \code{\link{lm.influence}}，そして
  \bold{一般化}線形モデルに対しては \code{\link{glm}}．

  基礎にある低水準関数は，
  The underlying low level functions,
  通常のものには \code{\link{lm.fit}}，そして重み付き回帰当てはめには
  \code{\link{lm.wfit}}．

  \code{lm()} のより多くの例が例えば
  \code{\link{anscombe}}, \code{\link{attitude}}, \code{\link{freeny}},
  \code{\link{LifeCycleSavings}}, \code{\link{longley}},
  \code{\link{stackloss}}, \code{\link{swiss}} 中にある．

  大きなデータベース(特に多くのケースを持つもの)への
  線形モデルの別の当てはめ方については
  パッケージ \CRANpkg{biglm} 中の \code{biglm}．
}
\references{
  Chambers, J. M. (1992)
  \emph{Linear models.}
  Chapter 4 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.

  Wilkinson, G. N. and Rogers, C. E. (1973)
  Symbolic descriptions of factorial models for analysis of variance.
  \emph{Applied Statistics}, \bold{22}, 392--9.
}
\author{
  デザインは
  Chambers (1992) に記述されている同名の S 関数に啓発されている．
  Ross Ihaka によるモデル公式の実装は
  Wilkinson & Rogers (1973) に基づく．
}

\note{
  \code{offset} で指定されるオフセットは
  予測 \code{\link{predict.lm}} 中には含まれないが，
  公式中でオフセット項により指定されたそれらは含まれる．
}
\examples{
require(graphics)

## Annette Dobson (1990) "An Introduction to Generalized Linear Models".
## Page 9: 植物重量データ．
ctl <- c(4.17,5.58,5.18,6.11,4.50,4.61,5.17,4.53,5.33,5.14)
trt <- c(4.81,4.17,4.41,3.59,5.87,3.83,6.03,4.89,4.32,4.69)
group <- gl(2, 10, 20, labels = c("Ctl","Trt"))
weight <- c(ctl, trt)
lm.D9 <- lm(weight ~ group)
lm.D90 <- lm(weight ~ group - 1) # 切片を除く
\donttest{
anova(lm.D9)
summary(lm.D90)
}
opar <- par(mfrow = c(2,2), oma = c(0, 0, 1.1, 0))
plot(lm.D9, las = 1)      # 残差，当てはめ, ...
par(opar)
\dontshow{
## モデルフレーム：
stopifnot(identical(lm(weight ~ group, method = "model.frame"),
                    model.frame(lm.D9)))
}
### 上の"関連"節中のそれほど単純でない例
}
\keyword{regression}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/lm.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{lm}
%\alias{lm}
%%\alias{print.lm}
%\concept{regression}
%\title{Fitting Linear Models}
%\description{
%  \code{lm} is used to fit linear models.
%  It can be used to carry out regression,
%  single stratum analysis of variance and
%  analysis of covariance (although \code{\link{aov}} may provide a more
%  convenient interface for these).
%}
%\usage{
%lm(formula, data, subset, weights, na.action,
%   method = "qr", model = TRUE, x = FALSE, y = FALSE, qr = TRUE,
%   singular.ok = TRUE, contrasts = NULL, offset, \dots)
%}
%\arguments{
%  \item{formula}{an object of class \code{"\link{formula}"} (or one that
%    can be coerced to that class): a symbolic description of the
%    model to be fitted.  The details of model specification are given
%    under \sQuote{Details}.}
%
%  \item{data}{an optional data frame, list or environment (or object
%    coercible by \code{\link{as.data.frame}} to a data frame) containing
%    the variables in the model.  If not found in \code{data}, the
%    variables are taken from \code{environment(formula)},
%    typically the environment from which \code{lm} is called.}
%
%  \item{subset}{an optional vector specifying a subset of observations
%    to be used in the fitting process.}
%
%  \item{weights}{an optional vector of weights to be used in the fitting
%    process.  Should be \code{NULL} or a numeric vector.
%    If non-NULL, weighted least squares is used with weights
%    \code{weights} (that is, minimizing \code{sum(w*e^2)}); otherwise
%    ordinary least squares is used.  See also \sQuote{Details},}
%
%  \item{na.action}{a function which indicates what should happen
%    when the data contain \code{NA}s.  The default is set by
%    the \code{na.action} setting of \code{\link{options}}, and is
%    \code{\link{na.fail}} if that is unset.  The \sQuote{factory-fresh}
%    default is \code{\link{na.omit}}.  Another possible value is
%    \code{NULL}, no action.  Value \code{\link{na.exclude}} can be useful.}
%
%  \item{method}{the method to be used; for fitting, currently only
%    \code{method = "qr"} is supported; \code{method = "model.frame"} returns
%    the model frame (the same as with \code{model = TRUE}, see below).}
%
%  \item{model, x, y, qr}{logicals.  If \code{TRUE} the corresponding
%    components of the fit (the model frame, the model matrix, the
%    response, the QR decomposition) are returned.
%  }
%
%  \item{singular.ok}{logical. If \code{FALSE} (the default in S but
%    not in \R) a singular fit is an error.}
%
%  \item{contrasts}{an optional list. See the \code{contrasts.arg}
%    of \code{\link{model.matrix.default}}.}
%
%  \item{offset}{this can be used to specify an \emph{a priori} known
%    component to be included in the linear predictor during fitting.
%    This should be \code{NULL} or a numeric vector of length equal to
%    the number of cases.  One or more \code{\link{offset}} terms can be
%    included in the formula instead or as well, and if more than one are
%    specified their sum is used.  See \code{\link{model.offset}}.}
%
%  \item{\dots}{additional arguments to be passed to the low level
%    regression fitting functions (see below).}
%}
%\details{
%  Models for \code{lm} are specified symbolically.  A typical model has
%  the form \code{response ~ terms} where \code{response} is the (numeric)
%  response vector and \code{terms} is a series of terms which specifies a
%  linear predictor for \code{response}.  A terms specification of the form
%  \code{first + second} indicates all the terms in \code{first} together
%  with all the terms in \code{second} with duplicates removed.  A
%  specification of the form \code{first:second} indicates the set of
%  terms obtained by taking the interactions of all terms in \code{first}
%  with all terms in \code{second}.  The specification \code{first*second}
%  indicates the \emph{cross} of \code{first} and \code{second}.  This is
%  the same as \code{first + second + first:second}.
%
%  If the formula includes an \code{\link{offset}}, this is evaluated and
%  subtracted from the response.
%
%  If \code{response} is a matrix a linear model is fitted separately by
%  least-squares to each column of the matrix.
%
%  See \code{\link{model.matrix}} for some further details.  The terms in
%  the formula will be re-ordered so that main effects come first,
%  followed by the interactions, all second-order, all third-order and so
%  on: to avoid this pass a \code{terms} object as the formula (see
%  \code{\link{aov}} and \code{demo(glm.vr)} for an example).
%
%  A formula has an implied intercept term.  To remove this use either
%  \code{y ~ x - 1} or \code{y ~ 0 + x}.  See \code{\link{formula}} for
%  more details of allowed formulae.
%
%  Non-\code{NULL} \code{weights} can be used to indicate that different
%  observations have different variances (with the values in
%  \code{weights} being inversely proportional to the variances); or
%  equivalently, when the elements of \code{weights} are positive
%  integers \eqn{w_i}, that each response \eqn{y_i} is the mean of
%  \eqn{w_i} unit-weight observations (including the case that there are
%  \eqn{w_i} observations equal to \eqn{y_i} and the data have been
%  summarized).
%
%  \code{lm} calls the lower level functions \code{\link{lm.fit}}, etc,
%  see below, for the actual numerical computations.  For programming
%  only, you may consider doing likewise.
%
%  All of \code{weights}, \code{subset} and \code{offset} are evaluated
%  in the same way as variables in \code{formula}, that is first in
%  \code{data} and then in the environment of \code{formula}.
%}
%\value{
%  \code{lm} returns an object of \code{\link{class}} \code{"lm"} or for
%  multiple responses of class \code{c("mlm", "lm")}.
%
%  The functions \code{summary} and \code{\link{anova}} are used to
%  obtain and print a summary and analysis of variance table of the
%  results.  The generic accessor functions \code{coefficients},
%  \code{effects}, \code{fitted.values} and \code{residuals} extract
%  various useful features of the value returned by \code{lm}.
%
%  An object of class \code{"lm"} is a list containing at least the
%  following components:
%
%  \item{coefficients}{a named vector of coefficients}
%  \item{residuals}{the residuals, that is response minus fitted values.}
%  \item{fitted.values}{the fitted mean values.}
%  \item{rank}{the numeric rank of the fitted linear model.}
%  \item{weights}{(only for weighted fits) the specified weights.}
%  \item{df.residual}{the residual degrees of freedom.}
%  \item{call}{the matched call.}
%  \item{terms}{the \code{\link{terms}} object used.}
%  \item{contrasts}{(only where relevant) the contrasts used.}
%  \item{xlevels}{(only where relevant) a record of the levels of the
%    factors used in fitting.}
%  \item{offset}{the offset used (missing if none were used).}
%  \item{y}{if requested, the response used.}
%  \item{x}{if requested, the model matrix used.}
%  \item{model}{if requested (the default), the model frame used.}
%  \item{na.action}{(where relevant) information returned by
%    \code{\link{model.frame}} on the special handling of \code{NA}s.}
%
%  In addition, non-null fits will have components \code{assign},
%  \code{effects} and (unless not requested) \code{qr} relating to the linear
%  fit, for use by extractor functions such as \code{summary} and
%  \code{\link{effects}}.
%}
%\section{Using time series}{
%  Considerable care is needed when using \code{lm} with time series.
%
%  Unless \code{na.action = NULL}, the time series attributes are
%  stripped from the variables before the regression is done.  (This is
%  necessary as omitting \code{NA}s would invalidate the time series
%  attributes, and if \code{NA}s are omitted in the middle of the series
%  the result would no longer be a regular time series.)
%
%  Even if the time series attributes are retained, they are not used to
%  line up series, so that the time shift of a lagged or differenced
%  regressor would be ignored.  It is good practice to prepare a
%  \code{data} argument by \code{\link{ts.intersect}(\dots, dframe = TRUE)},
%  then apply a suitable \code{na.action} to that data frame and call
%  \code{lm} with \code{na.action = NULL} so that residuals and fitted
%  values are time series.
%}
%\seealso{
%  \code{\link{summary.lm}} for summaries and \code{\link{anova.lm}} for
%  the ANOVA table; \code{\link{aov}} for a different interface.
%
%  The generic functions \code{\link{coef}}, \code{\link{effects}},
%  \code{\link{residuals}}, \code{\link{fitted}}, \code{\link{vcov}}.
%
%  \code{\link{predict.lm}} (via \code{\link{predict}}) for prediction,
%  including confidence and prediction intervals;
%  \code{\link{confint}} for confidence intervals of \emph{parameters}.
%
%  \code{\link{lm.influence}} for regression diagnostics, and
%  \code{\link{glm}} for \bold{generalized} linear models.
%
%  The underlying low level functions,
%  \code{\link{lm.fit}} for plain, and \code{\link{lm.wfit}} for weighted
%  regression fitting.
%
%  More \code{lm()} examples are available e.g., in
%  \code{\link{anscombe}}, \code{\link{attitude}}, \code{\link{freeny}},
%  \code{\link{LifeCycleSavings}}, \code{\link{longley}},
%  \code{\link{stackloss}}, \code{\link{swiss}}.
%
%  \code{biglm} in package \CRANpkg{biglm} for an alternative
%  way to fit linear models to large datasets (especially those with many
%  cases).
%}
%\references{
%  Chambers, J. M. (1992)
%  \emph{Linear models.}
%  Chapter 4 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%
%  Wilkinson, G. N. and Rogers, C. E. (1973)
%  Symbolic descriptions of factorial models for analysis of variance.
%  \emph{Applied Statistics}, \bold{22}, 392--9.
%}
%\author{
%  The design was inspired by the S function of the same name described
%  in Chambers (1992).  The implementation of model formula by Ross Ihaka
%  was based on Wilkinson & Rogers (1973).
%}
%
%\note{
%  Offsets specified by \code{offset} will not be included in predictions
%  by \code{\link{predict.lm}}, whereas those specified by an offset term
%  in the formula will be.
%}
%\examples{
%require(graphics)
%
%## Annette Dobson (1990) "An Introduction to Generalized Linear Models".
%## Page 9: Plant Weight Data.
%ctl <- c(4.17,5.58,5.18,6.11,4.50,4.61,5.17,4.53,5.33,5.14)
%trt <- c(4.81,4.17,4.41,3.59,5.87,3.83,6.03,4.89,4.32,4.69)
%group <- gl(2, 10, 20, labels = c("Ctl","Trt"))
%weight <- c(ctl, trt)
%lm.D9 <- lm(weight ~ group)
%lm.D90 <- lm(weight ~ group - 1) # omitting intercept
%\donttest{
%anova(lm.D9)
%summary(lm.D90)
%}
%opar <- par(mfrow = c(2,2), oma = c(0, 0, 1.1, 0))
%plot(lm.D9, las = 1)      # Residuals, Fitted, ...
%par(opar)
%\dontshow{
%## model frame :
%stopifnot(identical(lm(weight ~ group, method = "model.frame"),
%                    model.frame(lm.D9)))
%}
%### less simple examples in "See Also" above
%}
%\keyword{regression}
%
%\encoding{UTF-8}
%
