% File src/library/stats/man/mcnemar.test.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{mcnemar.test}
\alias{mcnemar.test}%@%\alias{計数データに対する Mcnemar のカイ二乗検定}
\title{McNemar's Chi-squared Test for Count Data}
\description{
  二元分割表における行と列の対称性に対する McNemar の
  カイ二乗検定を実行する．
}
\usage{
mcnemar.test(x, y = NULL, correct = TRUE)
}
\arguments{
  \item{x}{行列形式の二元分割表か因子オブジェクト．}
  \item{y}{因子オブジェクト；もし \code{x} が行列ならば無視される．}
  \item{correct}{
    検定統計量を計算する際に連続補正を適用するかどうかを指示する論理値．}
}
\value{
  クラス \code{"htest"} のりストで次の成分を含む：
  \item{statistic}{McNemar 統計量の値．}
  \item{parameter}{検定統計量の漸近カイ二乗分布の自由度．}
  \item{p.value}{検定の p 値．}
  \item{method}{実行された検定のタイプと，
    連続補正がされたかどうかを指示する文字列．}
  \item{data.name}{データの名前を与える文字列．}
}
\details{
  帰無仮説はセル
  \code{[i,j]} と \code{[j,i]} に分類される確率が同じということである．

  もし \code{x} が行列ならば，それは二元分割表とされ，
  従ってその項目は非負整数でなければならない．
  さもなければ \code{x} と \code{y} の双方は同じ長さの
  ベクトルか因子でなければならない．
  不完全なケースは除かれ，ベクトルは因子に変換され，
  それらから分割表が計算される．

  \code{correct} が \code{TRUE} ならば連続補正は
  2 x 2 ケースだけで行われる．
}
\references{
  Alan Agresti (1990).
  \emph{Categorical data analysis}.
  New York: Wiley.
  Pages 350--354.
}
\examples{
## Agresti (1990), p. 350.
## 大統領の支持率．
## 二つの調査における大統領の事務能力の信任率
## 一ヶ月を挟んだ1600人のアメリカ投票年齢者からの無作為標本
Performance <-
matrix(c(794, 86, 150, 570),
       nrow = 2,
       dimnames = list("1st Survey" = c("Approve", "Disapprove"),
                       "2nd Survey" = c("Approve", "Disapprove")))
Performance
mcnemar.test(Performance)
## => 信任率に有意な変化(実際は急落)
}
\keyword{htest}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/mcnemar.test.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{mcnemar.test}
%\alias{mcnemar.test}
%\title{McNemar's Chi-squared Test for Count Data}
%\description{
%  Performs McNemar's chi-squared test for symmetry of rows and columns
%  in a two-dimensional contingency table.
%}
%\usage{
%mcnemar.test(x, y = NULL, correct = TRUE)
%}
%\arguments{
%  \item{x}{either a two-dimensional contingency table in matrix form,
%    or a factor object.}
%  \item{y}{a factor object; ignored if \code{x} is a matrix.}
%  \item{correct}{a logical indicating whether to apply continuity
%    correction when computing the test statistic.}
%}
%\value{
%  A list with class \code{"htest"} containing the following components:
%  \item{statistic}{the value of McNemar's statistic.}
%  \item{parameter}{the degrees of freedom of the approximate
%    chi-squared distribution of the test statistic.}
%  \item{p.value}{the p-value of the test.}
%  \item{method}{a character string indicating the type of test
%    performed, and whether continuity correction was used.}
%  \item{data.name}{a character string giving the name(s) of the data.}
%}
%\details{
%  The null is that the probabilities of being classified into cells
%  \code{[i,j]} and \code{[j,i]} are the same.
%
%  If \code{x} is a matrix, it is taken as a two-dimensional contingency
%  table, and hence its entries should be nonnegative integers.
%  Otherwise, both \code{x} and \code{y} must be vectors or factors of the
%  same length.  Incomplete cases are removed, vectors are coerced into
%  factors, and the contingency table is computed from these.
%
%  Continuity correction is only used in the 2-by-2 case if
%  \code{correct} is \code{TRUE}.
%}
%\references{
%  Alan Agresti (1990).
%  \emph{Categorical data analysis}.
%  New York: Wiley.
%  Pages 350--354.
%}
%\examples{
%## Agresti (1990), p. 350.
%## Presidential Approval Ratings.
%##  Approval of the President's performance in office in two surveys,
%##  one month apart, for a random sample of 1600 voting-age Americans.
%Performance <-
%matrix(c(794, 86, 150, 570),
%       nrow = 2,
%       dimnames = list("1st Survey" = c("Approve", "Disapprove"),
%                       "2nd Survey" = c("Approve", "Disapprove")))
%Performance
%mcnemar.test(Performance)
%## => significant change (in fact, drop) in approval ratings
%}
%\keyword{htest}
%
%\encoding{UTF-8}
%
