% File src/library/stats/man/optim.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{optim}
\alias{optim}%@%\alias{汎用的最適化}
\alias{optimHess}
\concept{minimization}
\concept{maximization}

\title{General-purpose Optimization}

\description{
  Nelder--Mead 法, 準ニュートン法，そして
  共役グラディエントアルゴリズムに
  基づく汎用的最適化関数．
  矩形制約最適化とシミュレーテッドアニーリング法に
  対するオプションを持つ．
}
\usage{
optim(par, fn, gr = NULL, \dots,
      method = c("Nelder-Mead", "BFGS", "CG", "L-BFGS-B", "SANN",
                 "Brent"),
      lower = -Inf, upper = Inf,
      control = list(), hessian = FALSE)

optimHess(par, fn, gr = NULL, \dots, control = list())
}
\arguments{
 \item{par}{最適化されるパラメータ用の初期値．}
 \item{fn}{最小化(又は最大化)されるべき関数で，
   最初の引数はそれに対して最小化が行われるパラメータベクトル
   である．これはスカラの結果を返すべきである．}
 \item{gr}{
   \code{"BFGS"},  \code{"CG"} そして \code{"L-BFGS-B"} 法に
   対するグラディエントを返す関数．
   もしこれが \code{NULL} ならば有限階差近似が使われる．

   \code{"SANN"} 法に対してはこれは新しい候補点を生成する関数を
   指定する．
   もしこれが \code{NULL} なら既定の Gaussian Markov カーネルが
   使われる．}
 \item{\dots}{\code{fn} と \code{gr} に渡される追加引数．}
 \item{method}{使用される手法．\sQuote{詳細}節を見よ．短縮化出来る．}
 \item{lower, upper}{
   \code{"L-BFGS-B"} 法に対する変数の限界，又は
   \code{"Brent"} 法に対する\emph{探索}が行われる限界．}
 \item{control}{
   制御パラメータのリスト．\sQuote{詳細}節を見よ．}
 \item{hessian}{
   論理値．数値的に微分されたへッシアン行列を返すべきか?}
}
\details{
  \code{\dots} の後の引数は正確にマッチされなければならない
  ことを注意する．

  既定では \code{optim} は最小化を実行するが，
  \code{control$fnscale} が負であれば最大化を実行する．
  \code{optimHess} は
  \code{hessian = TRUE} が忘れられている時に後段のステージで
  へッシアンを計算する補助関数である．

  既定の手法は
  Nelder and Mead (1965) の実装であり，これは関数値だけを使い頑健であるが，
  相対的に遅い．これは微分不可能な関数に対してもかなり上手く
  動作する．

  手法 \code{"BFGS"} は準ニュートン法
  (可変メトリックアルゴリズムとしても知られている)であり，
  具体的には
  1970年に Broyden, Fletcher, Goldfarb そして Shanno により
  同時に発表された．これは最適化されるべき曲面の図を
  関数値とグラディエントを使って構築する．

  \code{"CG"} 法は
  Fletcher and Reeves (1964) によるそれに基づく
  共役グラディエント法である
  (しかし Polak--Ribiere 又は Beale--Sorenson 更新を用いる)．
  共役グラディエント法は一般に
  BFGS 法よりも脆弱であるが，行列を保管しないので
  かなり大規模の最適化問題でも成功するかもしれない．

  \code{"L-BFGS-B"} 法は
  Byrd \emph{et. al.} (1995) のそれで，
  \emph{矩形制約}を認める，つまり各変数は
  上限/下限を与えることが出来る．
  初期値は制約を満たさなければならない．
  これは
  BFGS 準ニュートン法のメモリ節約修正版を使う．
  もしトリビアルでない限界が与えられると，
  この手法が警告と共に選ばれる．

  Nocedal and Wright (1999) は上の三つの手法に対する完璧な参考文献である．

  \code{"SANN"} 法は既定では
  Belisle (1992) で与えられたシミュレーテッドアニーリング法の
  変種である．シミュレーテッドアニーリング法は確率的大局的最適化
  手法のクラスに属する．これは関数値だけを使うが相対的に遅い．
  微分不可能な関数に対しても動作する．
  この実装は採択率に対して Metropolis 関数を使う．
  既定では次の候補点は
  実際の温度に比例するスケールの Gaussian Markov カーネルで生成される．
  もし新しい候補点を生成する関数が与えられれば
  \code{"SANN"} 法は組み合わせ的最適化問題を解くのにも使える．
  温度は Belisle (1992, p.\sspace{}890) で与えられた対数的冷却計画に
  従って減少する；具体的には温度は
  \code{temp / log(((t-1) \%/\% tmax)*tmax + exp(1))} と設定される，
  ここで \code{t} は現在の繰り返しステップで
  \code{temp} と \code{tmax} は
  \code{control} で指定可能である，下を見よ．
  \code{"SANN"} 法は制御パラメータの設定に本質的に依存することを
  注意しよう．それは汎用的な方法では無いが，
  非常に荒い曲面上で良い値を得ることに
  極めて有用であり得る．

  Method
  \code{"Brent"} 法は一次元の問題専用であり，
  \code{\link{optimize}()} を使う．これは \code{optim()} が，
  パッケージ \pkg{stats4} の \code{\link{mle}} 中のような
  \code{method} だけが指定できる
  他の関数の内部で使われるケースで有用であり得る．

  関数 \code{fn} は関数が与えられた値で評価出来なければ
  \code{NA} や \code{Inf} を返すことが出来るが，
  初期値は計算可能な有限の
  \code{fn} を持たなければならない．
  (値が常に有限でなければならない手法 \code{"L-BFGS-B"} を除く)．

  \code{optim} は再帰的に使うことが出来，
  単一のパラメータでも複数でも使える．
  また長さゼロの \code{par} も受付け，その引数での関数の
  値を単に評価する．

  \code{control} 引数は次の成分のaどれでも提供できるリストである：
  \describe{
    \item{\code{trace}}{非負整数．もし正なら，
      最適化の進行に関するトレース情報が作られる．
      値が大きければより多くの情報が作りだされる：
      \code{"L-BFGS-B"} に対してはトレースには6段階ある．
      (これらが正確に何をするのかはソースコードを見よ：
      大きな値ほどより詳細を与える．)}
    \item{\code{fnscale}}{
      最適化の過程で \code{fn} と \code{gr} の値に適用される
      全般的なスケーリング．
      もし負なら，問題を最大化問題に切り替える．
      最適化は \code{fn(par)/fnscale} に関して行われる．}
    \item{\code{parscale}}{
        パラメータに対するスケーリング値のベクトル．
        最適化は \code{par/parscale} に関して行われ，
	これらは任意の要素の単位長の変化がスケール化された
	値の約単位長の変化を生み出すという意味で比較可能で
	なければならない．
	\code{method = "Brent"} に対しては使われない(し不要)．}
    \item{\code{ndeps}}{グラディエントの有限階差近似に対する
      ステップサイズのベクトルで，
      スケールは \code{par/parscale}．  
      既定は \code{1e-3}．}
    \item{\code{maxit}}{
      最大繰り返し数．既定では
      導関数ベースの手法では \code{100}で，
      \code{"Nelder-Mead"} 法では \code{500}．
      
      \code{"SANN"} 法に対しては \code{maxit} は関数評価の総回数を
      与える：これ以外の停止基準は無い．既定では
      \code{10000}.
    }
    \item{\code{abstol}}{絶対収束許容度．
      非負関数に対してだけ有用で，ゼロに近づく許容度として
      使われる．}
    \item{\code{reltol}}{相対収束許容度．
      アルゴリズムはあるステップで値を因子\cr
      \code{reltol * (abs(val) + reltol)} 以下に出来なければ
      停止する．既定は\cr
      \code{sqrt(.Machine$double.eps)} で，
      典型的に約 \code{1e-8}．}
    \item{\code{alpha}, \code{beta}, \code{gamma}}{
      \code{"Nelder-Mead"} 法に対するスケーリングパラメータ．
      \code{alpha} は反転因子(既定 1.0)，\code{beta} は縮約因子(0.5)，
      そして \code{gamma} は拡大因子(2.0)．}
    \item{\code{REPORT}}{\code{control$trace} が正の時，
      \code{"BFGS"}, \code{"L-BFGS-B"} そして \code{"SANN"} 法に対する
      レポートの頻度．
      \code{"BFGS"} と \code{"L-BFGS-B"} に対しては10回毎，
      \code{"SANN"} に対しては100温度毎．}
    \item{\code{type}}{
      共役グラディエント法用．
      Fletcher--Reeves 更新に対しては値 \code{1}，
      Polak--Ribiere 更新に対しては値 \code{2}，
      そして Beale--Sorenson 更新に対しては値 \code{3}．}
    \item{\code{lmm}}{
      \code{"L-BFGS-B"} 法で保持される BFGS 更新の数を与える整数．
      その既定値は \code{5}．}
    \item{\code{factr}}{
      \code{"L-BFGS-B"} 法の手足を制御する．
      目的関数の減少が機械許容度のこの因子以内なら収束したとされる．
      既定は \code{1e7} で，これは約 \code{1e-8} の許容度になる．}
    \item{\code{pgtol}}{
      \code{"L-BFGS-B"} 法の収束の制御を助ける．
      これは現在の探索方向の中への射影グラディエントに関する
      許容度である．既定値はゼロで，チェックは抑制される．}
    \item{\code{temp}}{
      \code{"SANN"} 法を制御する．これは冷却計画に対する初期温度として
      使われる．既定値は \code{10}．}
    \item{\code{tmax}}{
      \code{"SANN"} 法に対する各温度での関数の評価回数．既定値は \code{10}．}
  }

  \code{par} に与えられた任意の名前は
  \code{fn} と \code{gr} に渡されるベクトルにコピーされる．
  \code{par} の他の属性はコピーされないことを注意する．

  \code{fn} に渡されるパラメータベクトルは特殊な
  セマンティックスを持ち，呼び出し間で共有されないかもしれない：
  関数はそれを変更したりコピーしたりしてはならない．
}
%% when numerical derivatives are used, fn is called repeatedly with
%% modified copies of the same objet.

\value{
  \code{optim} に対しては次の成分を持つリスト：
  \item{par}{見つかった最良のパラメータのセット．}
  \item{value}{\code{par} に対応する \code{fn} の値．}
  \item{counts}{それぞれ
    \code{fn} と \code{gr} の呼び出し回数を与える二要素の整数ベクトル．
    これは要求されればへッシアンの計算に必要だった呼び出しと
    グラディエントの有限階差近似を計算する \code{fn} への任意の呼び出し
    を含まない．}
  \item{convergence}{整数コード．\code{0} は成功裡の終了を指示する
    (\code{"SANN"} と \code{"Brent"} では常にこうなる)．
    可能なエラーコードは
    \describe{
      \item{\code{1}}{最大繰り返し回数 \code{maxit} に達したことを示す．}
      \item{\code{10}}{Nelder--Mead 単体の退化を示す．}
      \item{\code{51}}{\code{"L-BFGS-B"} 法からの警告を示す；
        より詳細は成分 \code{message} を見よ．}
      \item{\code{52}}{
	\code{"L-BFGS-B"} 法からのエラーを示す；
        より詳細は成分 \code{message} を見よ．}	
    }
  }
  \item{message}{
    最適化関数化から返された任意の追加の情報を
    与える文字列，又は \code{NULL}．}
  \item{hessian}{
    引数 \code{hessian} が真の時だけ．見つかった解における
    へッシアンの推定値を与える対称行列．
    たとえ矩形制約下でもこれは無制約問題のへッシアンであることを
    注意する．}

  \code{optimHess} に対しては適用された \code{hessian} 成分の記述．
}
\note{
  \code{optim} は一次元の
  \code{par} でも動作するが，既定メソッドは上手く動作しない
  (そして警告が出る)．
  \code{"Brent"} 法は \code{\link{optimize}} を使い利用可能な限界
  を必要とする；
  \code{"BFGS"} 法はしばしば十分なほどに上手く動作する．
}
\source{
  手法 \code{"Nelder-Mead"}, \code{"BFGS"} そして
  \code{"CG"} 用のコードは元々は
  Nash (1990) 中の Pascal コードに基づいており，
  それを \code{p2c} で翻訳しそれから手作業で最適化した．
  Dr Nash はコードが自由に利用可能なことに同意している．

  手法 \code{"L-BFGS-B"} に対するコードは
  Netlib から入手できる
  Zhu, Byrd, Lu-Chen and Nocedal の Fortran コード
  (ファイル \file{opt/lbfgs_bcm.shar}：別のバージョンは \file{toms/778} にある)
  に基づいている．

  手法 \code{"SANN"} に対するコードは A. Trapletti により
  提供された．
}
\references{
  Belisle, C. J. P. (1992) Convergence theorems for a class of simulated
  annealing algorithms on \eqn{R^d}{Rd}. \emph{J. Applied Probability},
  \bold{29}, 885--895.

  Byrd, R. H., Lu, P., Nocedal, J. and Zhu, C.  (1995) A limited
  memory algorithm for bound constrained optimization.
  \emph{SIAM J. Scientific Computing}, \bold{16}, 1190--1208.

  Fletcher, R. and Reeves, C. M. (1964) Function minimization by
  conjugate gradients. \emph{Computer Journal} \bold{7}, 148--154.

  Nash, J. C. (1990) \emph{Compact Numerical Methods for
    Computers. Linear Algebra and Function Minimisation.} Adam Hilger.

  Nelder, J. A. and Mead, R. (1965) A simplex algorithm for function
  minimization. \emph{Computer Journal} \bold{7}, 308--313.

  Nocedal, J. and Wright, S. J. (1999) \emph{Numerical Optimization}.
  Springer.
}

\seealso{
  \code{\link{nlm}}, \code{\link{nlminb}}.

  一次元最小化に対しては \code{\link{optimize}} そして
  制約付き最適化に対しては \code{\link{constrOptim}}．
}

\examples{\donttest{
require(graphics)

fr <- function(x) {   ## Rosenbrock のバナナ関数
    x1 <- x[1]
    x2 <- x[2]
    100 * (x2 - x1 * x1)^2 + (1 - x1)^2
}
grr <- function(x) { ## 'fr' のグラディエント
    x1 <- x[1]
    x2 <- x[2]
    c(-400 * x1 * (x2 - x1 * x1) - 2 * (1 - x1),
       200 *      (x2 - x1 * x1))
}
optim(c(-1.2,1), fr)
(res <- optim(c(-1.2,1), fr, grr, method = "BFGS"))
optimHess(res$par, fr, grr)
optim(c(-1.2,1), fr, NULL, method = "BFGS", hessian = TRUE)
## これらは既定のステップ数では収束しない
optim(c(-1.2,1), fr, grr, method = "CG")
optim(c(-1.2,1), fr, grr, method = "CG", control = list(type = 2))
optim(c(-1.2,1), fr, grr, method = "L-BFGS-B")

flb <- function(x)
    { p <- length(x); sum(c(1, rep(4, p-1)) * (x - c(1, x[-p])^2)^2) }
## 25次元矩形制約
optim(rep(3, 25), flb, NULL, method = "L-BFGS-B",
      lower = rep(2, 25), upper = rep(4, 25)) # par[24] は境界に無い

## "ワイルドな"関数，大局的最小値はおおよそ -15.81515 あたり
fw <- function (x)
    10*sin(0.3*x)*sin(1.3*x^2) + 0.00001*x^4 + 0.2*x+80
plot(fw, -50, 50, n = 1000, main = "optim() minimising 'wild function'")

res <- optim(50, fw, method = "SANN",
             control = list(maxit = 20000, temp = 20, parscale = 20))
res
## そして局所的に改良{普通僅か}：
(r2 <- optim(res$par, fw, method = "BFGS"))
points(r2$par, r2$value, pch = 8, col = "red", cex = 2)

## 組み合わせ的最適化：トラベリングセールスマン問題
library(stats) # 普通ロードされている

eurodistmat <- as.matrix(eurodist)

distance <- function(sq) {  # 目的関数
    sq2 <- embed(sq, 2)
    sum(eurodistmat[cbind(sq2[,2], sq2[,1])])
}

genseq <- function(sq) {  # 新しい候補列を作る
    idx <- seq(2, NROW(eurodistmat)-1)
    changepoints <- sample(idx, size = 2, replace = FALSE)
    tmp <- sq[changepoints[1]]
    sq[changepoints[1]] <- sq[changepoints[2]]
    sq[changepoints[2]] <- tmp
    sq
}

sq <- c(1:nrow(eurodistmat), 1)  # 初期列：アルファベット順
distance(sq)
# ありきたりの方向に対する回転
loc <- -cmdscale(eurodist, add = TRUE)$points
x <- loc[,1]; y <- loc[,2]
s <- seq_len(nrow(eurodistmat))
tspinit <- loc[sq,]

plot(x, y, type = "n", asp = 1, xlab = "", ylab = "",
     main = "initial solution of traveling salesman problem", axes = FALSE)
arrows(tspinit[s,1], tspinit[s,2], tspinit[s+1,1], tspinit[s+1,2],
       angle = 10, col = "green")
text(x, y, labels(eurodist), cex = 0.8)

set.seed(123) # 良い解を相対的に素早く得るために選択
res <- optim(sq, distance, genseq, method = "SANN",
             control = list(maxit = 30000, temp = 2000, trace = TRUE,
                            REPORT = 500))
res  # 最適距離約 12842 に近い

tspres <- loc[res$par,]
plot(x, y, type = "n", asp = 1, xlab = "", ylab = "",
     main = "optim() 'solving' traveling salesman problem", axes = FALSE)
arrows(tspres[s,1], tspres[s,2], tspres[s+1,1], tspres[s+1,2],
       angle = 10, col = "red")
text(x, y, labels(eurodist), cex = 0.8)
}}
\keyword{nonlinear}
\keyword{optimize}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/optim.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{optim}
%\alias{optim}
%\alias{optimHess}
%\concept{minimization}
%\concept{maximization}
%
%\title{General-purpose Optimization}
%
%\description{
%  General-purpose optimization based on Nelder--Mead, quasi-Newton and
%  conjugate-gradient algorithms. It includes an option for
%  box-constrained optimization and simulated annealing.
%}
%\usage{
%optim(par, fn, gr = NULL, \dots,
%      method = c("Nelder-Mead", "BFGS", "CG", "L-BFGS-B", "SANN",
%                 "Brent"),
%      lower = -Inf, upper = Inf,
%      control = list(), hessian = FALSE)
%
%optimHess(par, fn, gr = NULL, \dots, control = list())
%}
%\arguments{
% \item{par}{Initial values for the parameters to be optimized over.}
% \item{fn}{A function to be minimized (or maximized), with first
%   argument the vector of parameters over which minimization is to take
%   place.  It should return a scalar result.}
% \item{gr}{A function to return the gradient for the \code{"BFGS"},
%   \code{"CG"} and \code{"L-BFGS-B"} methods.  If it is \code{NULL}, a
%   finite-difference approximation will be used.
%
%   For the \code{"SANN"} method it specifies a function to generate a new
%   candidate point.  If it is \code{NULL} a default Gaussian Markov
%   kernel is used.}
% \item{\dots}{Further arguments to be passed to \code{fn} and \code{gr}.}
% \item{method}{The method to be used. See \sQuote{Details}.  Can be abbreviated.}
% \item{lower, upper}{Bounds on the variables for the \code{"L-BFGS-B"}
%   method, or bounds in which to \emph{search} for method \code{"Brent"}.}
% \item{control}{A list of control parameters. See \sQuote{Details}.}
% \item{hessian}{Logical. Should a numerically differentiated Hessian
%   matrix be returned?}
%}
%\details{
%  Note that arguments after \code{\dots} must be matched exactly.
%
%  By default \code{optim} performs minimization, but it will maximize
%  if \code{control$fnscale} is negative.  \code{optimHess} is an
%  auxiliary function to compute the Hessian at a later stage if
%  \code{hessian = TRUE} was forgotten.
%
%  The default method is an implementation of that of Nelder and Mead
%  (1965), that uses only function values and is robust but relatively
%  slow.  It will work reasonably well for non-differentiable functions.
%
%  Method \code{"BFGS"} is a quasi-Newton method (also known as a variable
%  metric algorithm), specifically that published simultaneously in 1970
%  by Broyden, Fletcher, Goldfarb and Shanno.  This uses function values
%  and gradients to build up a picture of the surface to be optimized.
%
%  Method \code{"CG"} is a conjugate gradients method based on that by
%  Fletcher and Reeves (1964) (but with the option of Polak--Ribiere or
%  Beale--Sorenson updates).  Conjugate gradient methods will generally
%  be more fragile than the BFGS method, but as they do not store a
%  matrix they may be successful in much larger optimization problems.
%
%  Method \code{"L-BFGS-B"} is that of Byrd \emph{et. al.} (1995) which
%  allows \emph{box constraints}, that is each variable can be given a lower
%  and/or upper bound. The initial value must satisfy the constraints.
%  This uses a limited-memory modification of the BFGS quasi-Newton
%  method. If non-trivial bounds are supplied, this method will be
%  selected, with a warning.
%
%  Nocedal and Wright (1999) is a comprehensive reference for the
%  previous three methods.
%
%  Method \code{"SANN"} is by default a variant of simulated annealing
%  given in Belisle (1992). Simulated-annealing belongs to the class of
%  stochastic global optimization methods. It uses only function values
%  but is relatively slow. It will also work for non-differentiable
%  functions. This implementation uses the Metropolis function for the
%  acceptance probability. By default the next candidate point is
%  generated from a Gaussian Markov kernel with scale proportional to the
%  actual temperature. If a function to generate a new candidate point is
%  given, method \code{"SANN"} can also be used to solve combinatorial
%  optimization problems. Temperatures are decreased according to the
%  logarithmic cooling schedule as given in Belisle (1992, p.\sspace{}890);
%  specifically, the temperature is set to
%  \code{temp / log(((t-1) \%/\% tmax)*tmax + exp(1))}, where \code{t} is
%  the current iteration step and \code{temp} and \code{tmax} are
%  specifiable via \code{control}, see below.  Note that the
%  \code{"SANN"} method depends critically on the settings of the control
%  parameters. It is not a general-purpose method but can be very useful
%  in getting to a good value on a very rough surface.
%
%  Method \code{"Brent"} is for one-dimensional problems only, using
%  \code{\link{optimize}()}.  It can be useful in cases where
%  \code{optim()} is used inside other functions where only \code{method}
%  can be specified, such as in \code{\link{mle}} from package \pkg{stats4}.
%
%  Function \code{fn} can return \code{NA} or \code{Inf} if the function
%  cannot be evaluated at the supplied value, but the initial value must
%  have a computable finite value of \code{fn}.
%  (Except for method \code{"L-BFGS-B"} where the values should always be
%  finite.)
%
%  \code{optim} can be used recursively, and for a single parameter
%  as well as many.  It also accepts a zero-length \code{par}, and just
%  evaluates the function with that argument.
%
%  The \code{control} argument is a list that can supply any of the
%  following components:
%  \describe{
%    \item{\code{trace}}{Non-negative integer. If positive,
%      tracing information on the
%      progress of the optimization is produced. Higher values may
%      produce more tracing information: for method \code{"L-BFGS-B"}
%      there are six levels of tracing.  (To understand exactly what
%      these do see the source code: higher levels give more detail.)}
%    \item{\code{fnscale}}{An overall scaling to be applied to the value
%      of \code{fn} and \code{gr} during optimization. If negative,
%      turns the problem into a maximization problem. Optimization is
%      performed on \code{fn(par)/fnscale}.}
%    \item{\code{parscale}}{A vector of scaling values for the parameters.
%        Optimization is performed on \code{par/parscale} and these should be
%        comparable in the sense that a unit change in any element produces
%        about a unit change in the scaled value.  Not used (nor needed)
%	for \code{method = "Brent"}.}
%    \item{\code{ndeps}}{A vector of step sizes for the finite-difference
%      approximation to the gradient, on \code{par/parscale}
%      scale. Defaults to \code{1e-3}.}
%    \item{\code{maxit}}{The maximum number of iterations. Defaults to
%      \code{100} for the derivative-based methods, and
%      \code{500} for \code{"Nelder-Mead"}.
%
%      For \code{"SANN"} \code{maxit} gives the total number of function
%      evaluations: there is no other stopping criterion. Defaults to
%      \code{10000}.
%    }
%    \item{\code{abstol}}{The absolute convergence tolerance. Only
%      useful for non-negative functions, as a tolerance for reaching zero.}
%    \item{\code{reltol}}{Relative convergence tolerance.  The algorithm
%      stops if it is unable to reduce the value by a factor of
%      \code{reltol * (abs(val) + reltol)} at a step.  Defaults to
%      \code{sqrt(.Machine$double.eps)}, typically about \code{1e-8}.}
%    \item{\code{alpha}, \code{beta}, \code{gamma}}{Scaling parameters
%      for the \code{"Nelder-Mead"} method. \code{alpha} is the reflection
%      factor (default 1.0), \code{beta} the contraction factor (0.5) and
%      \code{gamma} the expansion factor (2.0).}
%    \item{\code{REPORT}}{The frequency of reports for the \code{"BFGS"},
%      \code{"L-BFGS-B"} and \code{"SANN"} methods if \code{control$trace}
%      is positive. Defaults to every 10 iterations for \code{"BFGS"} and
%      \code{"L-BFGS-B"}, or every 100 temperatures for \code{"SANN"}.}
%    \item{\code{type}}{for the conjugate-gradients method. Takes value
%      \code{1} for the Fletcher--Reeves update, \code{2} for
%      Polak--Ribiere and \code{3} for Beale--Sorenson.}
%    \item{\code{lmm}}{is an integer giving the number of BFGS updates
%      retained in the \code{"L-BFGS-B"} method, It defaults to \code{5}.}
%    \item{\code{factr}}{controls the convergence of the \code{"L-BFGS-B"}
%      method. Convergence occurs when the reduction in the objective is
%      within this factor of the machine tolerance. Default is \code{1e7},
%      that is a tolerance of about \code{1e-8}.}
%    \item{\code{pgtol}}{helps control the convergence of the \code{"L-BFGS-B"}
%      method. It is a tolerance on the projected gradient in the current
%      search direction. This defaults to zero, when the check is
%      suppressed.}
%    \item{\code{temp}}{controls the \code{"SANN"} method. It is the
%      starting temperature for the cooling schedule. Defaults to
%      \code{10}.}
%    \item{\code{tmax}}{is the number of function evaluations at each
%      temperature for the \code{"SANN"} method. Defaults to \code{10}.}
%  }
%
%  Any names given to \code{par} will be copied to the vectors passed to
%  \code{fn} and \code{gr}.  Note that no other attributes of \code{par}
%  are copied over.
%
%  The parameter vector passed to \code{fn} has special semantics and may
%  be shared between calls: the function should not change or copy it.
%}
%%% when numerical derivatives are used, fn is called repeatedly with
%%% modified copies of the same objet.
%
%\value{
%  For \code{optim}, a list with components:
%  \item{par}{The best set of parameters found.}
%  \item{value}{The value of \code{fn} corresponding to \code{par}.}
%  \item{counts}{A two-element integer vector giving the number of calls
%    to \code{fn} and \code{gr} respectively. This excludes those calls needed
%    to compute the Hessian, if requested, and any calls to \code{fn} to
%    compute a finite-difference approximation to the gradient.}
%  \item{convergence}{An integer code. \code{0} indicates successful
%    completion (which is always the case for \code{"SANN"} and
%    \code{"Brent"}).  Possible error codes are
%    \describe{
%      \item{\code{1}}{indicates that the iteration limit \code{maxit}
%      had been reached.}
%      \item{\code{10}}{indicates degeneracy of the Nelder--Mead simplex.}
%      \item{\code{51}}{indicates a warning from the \code{"L-BFGS-B"}
%      method; see component \code{message} for further details.}
%      \item{\code{52}}{indicates an error from the \code{"L-BFGS-B"}
%      method; see component \code{message} for further details.}
%    }
%  }
%  \item{message}{A character string giving any additional information
%    returned by the optimizer, or \code{NULL}.}
%  \item{hessian}{Only if argument \code{hessian} is true. A symmetric
%    matrix giving an estimate of the Hessian at the solution found.  Note
%    that this is the Hessian of the unconstrained problem even if the
%    box constraints are active.}
%
%  For \code{optimHess}, the description of the \code{hessian} component
%  applies.
%}
%\note{
%  \code{optim} will work with one-dimensional \code{par}s, but the
%  default method does not work well (and will warn).  Method
%  \code{"Brent"} uses \code{\link{optimize}} and needs bounds to be available;
%  \code{"BFGS"} often works well enough if not.
%}
%\source{
%  The code for methods \code{"Nelder-Mead"}, \code{"BFGS"} and
%  \code{"CG"} was based originally on Pascal code in Nash (1990) that was
%  translated by \code{p2c} and then hand-optimized.  Dr Nash has agreed
%  that the code can be made freely available.
%
%  The code for method \code{"L-BFGS-B"} is based on Fortran code by Zhu,
%  Byrd, Lu-Chen and Nocedal obtained from Netlib (file
%  \file{opt/lbfgs_bcm.shar}: another version is in \file{toms/778}).
%
%  The code for method \code{"SANN"} was contributed by A. Trapletti.
%}
%\references{
%  Belisle, C. J. P. (1992) Convergence theorems for a class of simulated
%  annealing algorithms on \eqn{R^d}{Rd}. \emph{J. Applied Probability},
%  \bold{29}, 885--895.
%
%  Byrd, R. H., Lu, P., Nocedal, J. and Zhu, C.  (1995) A limited
%  memory algorithm for bound constrained optimization.
%  \emph{SIAM J. Scientific Computing}, \bold{16}, 1190--1208.
%
%  Fletcher, R. and Reeves, C. M. (1964) Function minimization by
%  conjugate gradients. \emph{Computer Journal} \bold{7}, 148--154.
%
%  Nash, J. C. (1990) \emph{Compact Numerical Methods for
%    Computers. Linear Algebra and Function Minimisation.} Adam Hilger.
%
%  Nelder, J. A. and Mead, R. (1965) A simplex algorithm for function
%  minimization. \emph{Computer Journal} \bold{7}, 308--313.
%
%  Nocedal, J. and Wright, S. J. (1999) \emph{Numerical Optimization}.
%  Springer.
%}
%
%\seealso{
%  \code{\link{nlm}}, \code{\link{nlminb}}.
%
%  \code{\link{optimize}} for one-dimensional minimization and
%  \code{\link{constrOptim}} for constrained optimization.
%}
%
%\examples{\donttest{
%require(graphics)
%
%fr <- function(x) {   ## Rosenbrock Banana function
%    x1 <- x[1]
%    x2 <- x[2]
%    100 * (x2 - x1 * x1)^2 + (1 - x1)^2
%}
%grr <- function(x) { ## Gradient of 'fr'
%    x1 <- x[1]
%    x2 <- x[2]
%    c(-400 * x1 * (x2 - x1 * x1) - 2 * (1 - x1),
%       200 *      (x2 - x1 * x1))
%}
%optim(c(-1.2,1), fr)
%(res <- optim(c(-1.2,1), fr, grr, method = "BFGS"))
%optimHess(res$par, fr, grr)
%optim(c(-1.2,1), fr, NULL, method = "BFGS", hessian = TRUE)
%## These do not converge in the default number of steps
%optim(c(-1.2,1), fr, grr, method = "CG")
%optim(c(-1.2,1), fr, grr, method = "CG", control = list(type = 2))
%optim(c(-1.2,1), fr, grr, method = "L-BFGS-B")
%
%flb <- function(x)
%    { p <- length(x); sum(c(1, rep(4, p-1)) * (x - c(1, x[-p])^2)^2) }
%## 25-dimensional box constrained
%optim(rep(3, 25), flb, NULL, method = "L-BFGS-B",
%      lower = rep(2, 25), upper = rep(4, 25)) # par[24] is *not* at boundary
%
%## "wild" function , global minimum at about -15.81515
%fw <- function (x)
%    10*sin(0.3*x)*sin(1.3*x^2) + 0.00001*x^4 + 0.2*x+80
%plot(fw, -50, 50, n = 1000, main = "optim() minimising 'wild function'")
%
%res <- optim(50, fw, method = "SANN",
%             control = list(maxit = 20000, temp = 20, parscale = 20))
%res
%## Now improve locally {typically only by a small bit}:
%(r2 <- optim(res$par, fw, method = "BFGS"))
%points(r2$par, r2$value, pch = 8, col = "red", cex = 2)
%
%## Combinatorial optimization: Traveling salesman problem
%library(stats) # normally loaded
%
%eurodistmat <- as.matrix(eurodist)
%
%distance <- function(sq) {  # Target function
%    sq2 <- embed(sq, 2)
%    sum(eurodistmat[cbind(sq2[,2], sq2[,1])])
%}
%
%genseq <- function(sq) {  # Generate new candidate sequence
%    idx <- seq(2, NROW(eurodistmat)-1)
%    changepoints <- sample(idx, size = 2, replace = FALSE)
%    tmp <- sq[changepoints[1]]
%    sq[changepoints[1]] <- sq[changepoints[2]]
%    sq[changepoints[2]] <- tmp
%    sq
%}
%
%sq <- c(1:nrow(eurodistmat), 1)  # Initial sequence: alphabetic
%distance(sq)
%# rotate for conventional orientation
%loc <- -cmdscale(eurodist, add = TRUE)$points
%x <- loc[,1]; y <- loc[,2]
%s <- seq_len(nrow(eurodistmat))
%tspinit <- loc[sq,]
%
%plot(x, y, type = "n", asp = 1, xlab = "", ylab = "",
%     main = "initial solution of traveling salesman problem", axes = FALSE)
%arrows(tspinit[s,1], tspinit[s,2], tspinit[s+1,1], tspinit[s+1,2],
%       angle = 10, col = "green")
%text(x, y, labels(eurodist), cex = 0.8)
%
%set.seed(123) # chosen to get a good soln relatively quickly
%res <- optim(sq, distance, genseq, method = "SANN",
%             control = list(maxit = 30000, temp = 2000, trace = TRUE,
%                            REPORT = 500))
%res  # Near optimum distance around 12842
%
%tspres <- loc[res$par,]
%plot(x, y, type = "n", asp = 1, xlab = "", ylab = "",
%     main = "optim() 'solving' traveling salesman problem", axes = FALSE)
%arrows(tspres[s,1], tspres[s,2], tspres[s+1,1], tspres[s+1,2],
%       angle = 10, col = "red")
%text(x, y, labels(eurodist), cex = 0.8)
%}}
%\keyword{nonlinear}
%\keyword{optimize}
%
%\encoding{UTF-8}
%
