% File src/library/stats/man/plot.isoreg.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{plot.isoreg}
\alias{plot.isoreg}%@%\alias{isoreg オブジェクトに対するプロットメソッド}
\alias{lines.isoreg}
\title{Plot Method for isoreg Objects}
\description{
  クラス \code{\link{isoreg}} の \R オブジェクトに対する
  \code{\link{plot}} と \code{\link{lines}} メソッド．
}
\usage{
\method{plot}{isoreg}(x, plot.type = c("single", "row.wise", "col.wise"),
      main = paste("Isotonic regression", deparse(x$call)),
      main2 = "Cumulative Data and Convex Minorant",
      xlab = "x0", ylab = "x$y",
      par.fit = list(col = "red", cex = 1.5, pch = 13, lwd = 1.5),
      mar = if (both) 0.1 + c(3.5, 2.5, 1, 1) else par("mar"),
      mgp = if (both) c(1.6, 0.7, 0) else par("mgp"),
      grid = length(x$x) < 12, \dots)

\method{lines}{isoreg}(x, col = "red", lwd = 1.5,
       do.points = FALSE, cex = 1.5, pch = 13, \dots)
}
\arguments{
  \item{x}{\code{\link{isoreg}} オブジェクト．}
  \item{plot.type}{どのタイプのプロットが必要かを指示する文字列．
    最初(既定)はデータと当てはめ値だけを描く一方，他は
    累積データと当てはめ値のプロットを加える．簡略化出来る．}
  \item{main}{プロットの主タイトル，\code{\link{title}} を見よ．}
  \item{main2}{第二(累積)のプロットに対するタイトル．}
  \item{xlab, ylab}{x と y 軸の注釈．}
  \item{par.fit}{当てはめ値を描くための引数の \code{\link{list}}
    (\code{\link{points}} と \code{\link{lines}} 用)．}
  \item{mar, mgp}{主に二つのプロット用のグラフィックスパラメータ，
    \code{\link{par}} を見よ．}
  \item{grid}{グリッド線を描くべきかどうかを指示する論理値．
    もし真なら，
    \code{\link{grid}()} が最初のプロット用に使われ，
    垂直線は累積プロットに対する\sQuote{接触}点に描かれる．}
  \item{do.points}{\code{lines()} 用：
    ステップ点が同様に描かれるべきかを指示する論理値
    (そしてそれらが \code{plot()}) 中で描かれるように．}
  \item{col, lwd, cex, pch}{
    \code{lines()} に対するグラフィカル引数，
    ここで \code{cex} と \code{pch} は
    \code{do.points} が \code{TRUE} の時だけ使われる．}
  \item{\dots}{メソッドに・から渡される追加引数．}
%  \item{digits}{integer indicating number of digits to use for printing.}
}
\seealso{
  \code{isoreg} オブジェクトの計算に対しては
  \code{\link{isoreg}}．}
\examples{
require(graphics)

utils::example(isoreg) # そこにある例のため

plot(y3, main = "simple plot(.)  +  lines(<isoreg>)")
lines(ir3)

## 上と'同じ'プロット，'x' のランクだけが重要なことを"証明する"
plot(isoreg(2^(1:9), c(1,0,4,3,3,5,4,2,0)), plot.type = "row", log = "x")

plot(ir3, plot.type = "row", ylab = "y3")
plot(isoreg(y3 - 4), plot.t="r", ylab = "y3 - 4")
plot(ir4, plot.type = "ro",  ylab = "y4", xlab = "x = 1:n")

## これら(C-c C-j)で少し実験：
plot(isoreg(sample(9),  y3), plot.type = "row")
plot(isoreg(sample(9),  y3), plot.type = "col.wise")

plot(ir <- isoreg(sample(10), sample(10, replace = TRUE)),
                  plot.type = "r")
}
\keyword{hplot}
\keyword{print}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/plot.isoreg.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{plot.isoreg}
%\alias{plot.isoreg}
%\alias{lines.isoreg}
%\title{Plot Method for isoreg Objects}
%\description{
%  The \code{\link{plot}} and \code{\link{lines}} method for
%  \R objects of class \code{\link{isoreg}}.
%}
%\usage{
%\method{plot}{isoreg}(x, plot.type = c("single", "row.wise", "col.wise"),
%      main = paste("Isotonic regression", deparse(x$call)),
%      main2 = "Cumulative Data and Convex Minorant",
%      xlab = "x0", ylab = "x$y",
%      par.fit = list(col = "red", cex = 1.5, pch = 13, lwd = 1.5),
%      mar = if (both) 0.1 + c(3.5, 2.5, 1, 1) else par("mar"),
%      mgp = if (both) c(1.6, 0.7, 0) else par("mgp"),
%      grid = length(x$x) < 12, \dots)
%
%\method{lines}{isoreg}(x, col = "red", lwd = 1.5,
%       do.points = FALSE, cex = 1.5, pch = 13, \dots)
%}
%\arguments{
%  \item{x}{an \code{\link{isoreg}} object.}
%  \item{plot.type}{character indicating which type of plot is desired.
%    The first (default) only draws the data and the fit, where the
%    others add a plot of the cumulative data and fit.  Can be abbreviated.}
%  \item{main}{main title of plot, see \code{\link{title}}.}
%  \item{main2}{title for second (cumulative) plot.}
%  \item{xlab, ylab}{x- and y- axis annotation.}
%  \item{par.fit}{a \code{\link{list}} of arguments (for
%    \code{\link{points}} and \code{\link{lines}}) for drawing the fit.}
%  \item{mar, mgp}{graphical parameters, see \code{\link{par}}, mainly
%    for the case of two plots.}
%  \item{grid}{logical indicating if grid lines should be drawn.  If
%    true, \code{\link{grid}()} is used for the first plot, where as
%    vertical lines are drawn at \sQuote{touching} points for the
%    cumulative plot.}
%  \item{do.points}{for \code{lines()}: logical indicating if the step
%    points should be drawn as well (and as they are drawn in \code{plot()}).}
%  \item{col, lwd, cex, pch}{graphical arguments for \code{lines()},
%    where \code{cex} and \code{pch} are only used when \code{do.points}
%    is \code{TRUE}.}
%  \item{\dots}{further arguments passed to and from methods.}
%%  \item{digits}{integer indicating number of digits to use for printing.}
%}
%\seealso{\code{\link{isoreg}} for computation of \code{isoreg} objects.}
%\examples{
%require(graphics)
%
%utils::example(isoreg) # for the examples there
%
%plot(y3, main = "simple plot(.)  +  lines(<isoreg>)")
%lines(ir3)
%
%## 'same' plot as above, "proving" that only ranks of 'x' are important
%plot(isoreg(2^(1:9), c(1,0,4,3,3,5,4,2,0)), plot.type = "row", log = "x")
%
%plot(ir3, plot.type = "row", ylab = "y3")
%plot(isoreg(y3 - 4), plot.t="r", ylab = "y3 - 4")
%plot(ir4, plot.type = "ro",  ylab = "y4", xlab = "x = 1:n")
%
%## experiment a bit with these (C-c C-j):
%plot(isoreg(sample(9),  y3), plot.type = "row")
%plot(isoreg(sample(9),  y3), plot.type = "col.wise")
%
%plot(ir <- isoreg(sample(10), sample(10, replace = TRUE)),
%                  plot.type = "r")
%}
%\keyword{hplot}
%\keyword{print}
%
%\encoding{UTF-8}
%
