% File src/library/stats/man/poly.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{poly}
\alias{poly}%@%\alias{直交多項式を計算}
\alias{polym}
\alias{predict.poly}
\alias{makepredictcall.poly}
\title{Compute Orthogonal Polynomials}
\usage{
poly(x, \dots, degree = 1, coefs = NULL, raw = FALSE, simple = FALSE)
polym  (\dots, degree = 1, coefs = NULL, raw = FALSE)

\method{predict}{poly}(object, newdata, \dots)
}
\description{
  Returns or evaluates orthogonal polynomials of degree 1 to
  \code{degree} over the specified set of points
  指定された点集合 \code{x} 上で次数 1 から \code{degree} までの
  直交多項式を返すか評価する．これらは全て次数 0 の定数多項式に
  直行する．又は生の多項式を評価する．
}
\arguments{
 \item{x, newdata}{そこで多項式を評価する数値ベクトル．
   \code{x} は行列でも良い．
   \code{x} 中には欠損値は許されない．}
 \item{degree}{多項式の次数．
   もし \code{raw = TRUE} ならユニークな点の数よりも小さくなければならない．}
 \item{coefs}{予測に対しては，前の当てはめからの係数．}
 \item{raw}{もし真なら，直交ではなく生の多項式を使う．}
 \item{simple}{
   単純な行列(\code{\link{dimnames}} 以外の属性を持たない)が返されるべきかどうかを
   指示する論理値．単に速度向上のため．}
 \item{object}{
   クラス \code{"poly"} を継承するオブジェクトで，
   普通単一の引数を持つ \code{poly} の呼び出しの結果．}
 \item{\dots}{\code{poly}, \code{polym}: 追加のベクトル．\cr
   \code{predict.poly}: 他のメソッドに・から渡される引数．}
}
\value{
  \code{poly} と \code{polym()} に対しては
  (既定である \code{simple=FALSE} と \code{coefs=NULL} の際)：\cr
  行が \code{x} 中の点で列が次数に対応する行列で，
  列の次数を指示する属性 \code{"degree"} と
  (\code{raw = TRUE} でない限り)
  直交多項式を構成する際に使われるセンタリングと正規化定数を
  含む \code{"coefs"}，そしてクラス
  \code{c("poly", "matrix")} を持つ．

  \code{poly(*, simple=TRUE)}, \code{polym(*, coefs=<non-NULL>)}
  そして \code{predict.poly()}：行列．
}
\details{
  形式的には \code{degree} は名前付きであるべきであるが
  (\code{\dots} に従うから)，
  名前のない二番目の長さ1の引数は次数と解釈されるので
  \code{poly(x, 3)} は公式中で使うことが出来る．

  直交多項式は係数で要約され，
  Kennedy & Gentle (1980, pp.\sspace{}343--4) で与えられる三項再帰式
  を使いそれを評価するのに使うことが出来る．

  \code{\dots} を使った \code{poly} は単に
  \code{polym} に対するラッパである：\code{coef} は無視される．
  逆に，もし \code{polym} が
  \code{\dots} 中の単一の引数で呼び出されると，それは
  \code{poly} に対するラッパである．
}
\note{
  このルーチンは
  \code{contr.poly} のような統計的目的用を意図している：
  機械精度までの直交化は試みない．
}
\author{
  R Core Team.  Keith Jewell (Campden BRI Group, UK) は部分集合上の
  正しい予測に対する改良に貢献した．
}
\references{
  Chambers, J. M. and Hastie, T. J. (1992)
  \emph{Statistical Models in S}.
  Wadsworth & Brooks/Cole.

  Kennedy, W. J. Jr and Gentle, J. E. (1980)
  \emph{Statistical Computing} Marcel Dekker.
}

\seealso{
  \code{\link{contr.poly}}.

  多項式回帰の例に対しては \code{\link{cars}}．
}

\examples{
od <- options(digits = 3) # 視覚的な混乱を避けるため
(z <- poly(1:10, 3))
predict(z, seq(2, 4, 0.5))
zapsmall(poly(seq(4, 6, 0.5), 3, coefs = attr(z, "coefs")))

 zm <- zapsmall(polym (    1:4, c(1, 4:6),  degree = 3)) # 又は単に poly()：
(z1 <- zapsmall(poly(cbind(1:4, c(1, 4:6)), degree = 3)))
## これらは同じ：
stopifnot(all.equal(zm, z1, tol = 1e-15))
options(od)
}
\keyword{math}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/poly.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{poly}
%\alias{poly}
%\alias{polym}
%\alias{predict.poly}
%\alias{makepredictcall.poly}
%\title{Compute Orthogonal Polynomials}
%\usage{
%poly(x, \dots, degree = 1, coefs = NULL, raw = FALSE, simple = FALSE)
%polym  (\dots, degree = 1, coefs = NULL, raw = FALSE)
%
%\method{predict}{poly}(object, newdata, \dots)
%}
%\description{
%  Returns or evaluates orthogonal polynomials of degree 1 to
%  \code{degree} over the specified set of points \code{x}: these are all
%  orthogonal to the constant polynomial of degree 0.  Alternatively,
%  evaluate raw polynomials.
%}
%\arguments{
% \item{x, newdata}{a numeric vector at which to evaluate the
%   polynomial. \code{x} can also be a matrix.  Missing values are not
%   allowed in \code{x}.}
% \item{degree}{the degree of the polynomial.  Must be less than the
%   number of unique points if \code{raw = TRUE}.}
% \item{coefs}{for prediction, coefficients from a previous fit.}
% \item{raw}{if true, use raw and not orthogonal polynomials.}
% \item{simple}{logical indicating if a simple matrix (with no further
%   \code{\link{attributes}} but \code{\link{dimnames}}) should be
%   returned.  For speedup only.}
% \item{object}{an object inheriting from class \code{"poly"}, normally
%   the result of a call to \code{poly} with a single vector argument.}
% \item{\dots}{\code{poly}, \code{polym}: further vectors.\cr
%   \code{predict.poly}: arguments to be passed to or from other methods.
% }
%}
%\value{
%  For \code{poly} and \code{polym()} (when \code{simple=FALSE} and
%  \code{coefs=NULL} as per default):\cr
%  A matrix with rows corresponding to points in \code{x} and columns
%  corresponding to the degree, with attributes \code{"degree"} specifying
%  the degrees of the columns and (unless \code{raw = TRUE})
%  \code{"coefs"} which contains the centering and normalization
%  constants used in constructing the orthogonal polynomials and
%  class \code{c("poly", "matrix")}.
%
%  For \code{poly(*, simple=TRUE)}, \code{polym(*, coefs=<non-NULL>)},
%  and \code{predict.poly()}: a matrix.
%}
%\details{
%  Although formally \code{degree} should be named (as it follows
%  \code{\dots}), an unnamed second argument of length 1 will be
%  interpreted as the degree, such that \code{poly(x, 3)} can be used in
%  formulas.
%
%  The orthogonal polynomial is summarized by the coefficients, which can
%  be used to evaluate it via the three-term recursion given in Kennedy
%  & Gentle (1980, pp.\sspace{}343--4), and used in the \code{predict} part of
%  the code.
%
%  \code{poly} using \code{\dots} is just a convenience wrapper for
%  \code{polym}: \code{coef} is ignored.  Conversely, if \code{polym} is
%  called with a single argument in \code{\dots} it is a wrapper for
%  \code{poly}.
%}
%\note{
%  This routine is intended for statistical purposes such as
%  \code{contr.poly}: it does not attempt to orthogonalize to
%  machine accuracy.
%}
%\author{
%  R Core Team.  Keith Jewell (Campden BRI Group, UK) contributed
%  improvements for correct prediction on subsets.
%}
%\references{
%  Chambers, J. M. and Hastie, T. J. (1992)
%  \emph{Statistical Models in S}.
%  Wadsworth & Brooks/Cole.
%
%  Kennedy, W. J. Jr and Gentle, J. E. (1980)
%  \emph{Statistical Computing} Marcel Dekker.
%}
%
%\seealso{
%  \code{\link{contr.poly}}.
%
%  \code{\link{cars}} for an example of polynomial regression.
%}
%
%\examples{
%od <- options(digits = 3) # avoid too much visual clutter
%(z <- poly(1:10, 3))
%predict(z, seq(2, 4, 0.5))
%zapsmall(poly(seq(4, 6, 0.5), 3, coefs = attr(z, "coefs")))
%
% zm <- zapsmall(polym (    1:4, c(1, 4:6),  degree = 3)) # or just poly():
%(z1 <- zapsmall(poly(cbind(1:4, c(1, 4:6)), degree = 3)))
%## they are the same :
%stopifnot(all.equal(zm, z1, tol = 1e-15))
%options(od)
%}
%\keyword{math}
%
%\encoding{UTF-8}
%
