% File src/library/stats/man/power.t.test.Rd
% Part of the R package, https://www.R-project.org
% Copyright (C) 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{power.t.test}
\alias{power.t.test}%@%\alias{一・二標本 t 検定に対するパワー計算}

\title{Power calculations for one and two sample t tests}
\usage{
power.t.test(n = NULL, delta = NULL, sd = 1, sig.level = 0.05,
             power = NULL,
             type = c("two.sample", "one.sample", "paired"),
             alternative = c("two.sided", "one.sided"),
             strict = FALSE, tol = .Machine$double.eps^0.25)
}
\arguments{
  \item{n}{観測値数(グループ毎)．}
 \item{delta}{真の平均の差．}
 \item{sd}{標準偏差．}
 \item{sig.level}{信頼水準(タイプ I エラー確率)．}
 \item{power}{検定のパワー(1 引くタイプ II エラー確率)．}
 \item{type}{t 検定のタイプを指定する文字列．短縮化出来る．}
 \item{alternative}{片側もしくは両側検定．短縮化出来る．}
 \item{strict}{両側ケースで厳格な解釈を使う．}
 \item{tol}{根を見つける際の数値許容度．既定値は
   (少なくとも)有効精度4桁を与える．}
}
\description{
  一標本と二標本 t 検定のパワーを計算する，もしくは
  目標パワーを得るためのパラメータを決定する．
}

\details{
  正確にパラメータ
  \code{n}, \code{p1}, \code{p2},
  \code{power} そして \code{sig.level} の一つが NULL として
  渡されなければならず，そしてそのパラメータは他から計算される．
  \code{sig.level} は NULL でない既定値を持つので，
  それを計算したければ明示的に NULL を渡さなければならない．

  もし \code{strict = TRUE} が使われると，両側ケースではパワーは
  真の効果と反対方向への棄却の確率を含む．
  これがなければ，真の差がゼロであればパワーは信頼水準の半分になる．
}
\value{
  クラス \code{"power.htest"} のオブジェクトで，
  引数(計算されたものを含む)に \code{method} と
  \code{note} 要素が加わったリスト．
}

\author{Peter Dalgaard.  
  Claus \enc{Ekstrøm}{Ekstroem} の先の仕事に基づく．}

\note{
  未知のパワー方程式を解くのに \code{uniroot} が使われるので，
  不正な引数があたえられた場合はそれからエラー，特に
  根をくくり出すことの不可能性，を確認することが出来る．
}
\seealso{\code{\link{t.test}}, \code{\link{uniroot}}}

\examples{
 power.t.test(n = 20, delta = 1)
 power.t.test(power = .90, delta = 1)
 power.t.test(power = .90, delta = 1, alternative = "one.sided")
}
\keyword{htest}



\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/power.t.test.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright (C) 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{power.t.test}
%\alias{power.t.test}
%
%\title{Power calculations for one and two sample t tests}
%\usage{
%power.t.test(n = NULL, delta = NULL, sd = 1, sig.level = 0.05,
%             power = NULL,
%             type = c("two.sample", "one.sample", "paired"),
%             alternative = c("two.sided", "one.sided"),
%             strict = FALSE, tol = .Machine$double.eps^0.25)
%}
%\arguments{
% \item{n}{number of observations (per group)}
% \item{delta}{true difference in means}
% \item{sd}{standard deviation}
% \item{sig.level}{significance level (Type I error probability)}
% \item{power}{power of test (1 minus Type II error probability)}
% \item{type}{string specifying the type of t test.  Can be abbreviated.}
% \item{alternative}{one- or two-sided test.  Can be abbreviated.}
% \item{strict}{use strict interpretation in two-sided case}
%  \item{tol}{numerical tolerance used in root finding, the default
%    providing (at least) four significant digits.}
%}
%\description{
%  Compute the power of the one- or two- sample t test,
%  or determine parameters to obtain a target power.
%}
%
%\details{
%  Exactly one of the parameters \code{n}, \code{delta}, \code{power},
%  \code{sd}, and \code{sig.level} must be passed as \code{NULL}, and that
%  parameter is determined from the others.  Notice that the last two have
%  non-NULL defaults, so NULL must be explicitly passed if you want to
%  compute them.
%
%  If \code{strict = TRUE} is used, the power will include the probability of
%  rejection in the opposite direction of the true effect, in the two-sided
%  case.  Without this the power will be half the significance level if the
%  true difference is zero.
%}
%\value{
%  Object of class \code{"power.htest"}, a list of the arguments
%  (including the computed one) augmented with \code{method} and
%  \code{note} elements.
%}
%
%\author{Peter Dalgaard.  Based on previous work by Claus
%  \enc{Ekstrøm}{Ekstroem}}
%
%\note{
%  \code{uniroot} is used to solve the power equation for unknowns, so
%  you may see errors from it, notably about inability to bracket the
%  root when invalid arguments are given.
%}
%\seealso{\code{\link{t.test}}, \code{\link{uniroot}}}
%
%\examples{
% power.t.test(n = 20, delta = 1)
% power.t.test(power = .90, delta = 1)
% power.t.test(power = .90, delta = 1, alternative = "one.sided")
%}
%\keyword{htest}
%
%
%
%\encoding{UTF-8}
%
