% File src/library/stats/man/print.power.htest.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{print.power.htest}
\title{Print Methods for Hypothesis Tests and Power Calculation Objects}
\alias{print.htest}%@%\alias{仮説検定とパワー計算用のプリントメソッド}
\alias{print.power.htest}
\description{
  クラス \code{"htest"} 又は \code{"power.htest"} の
  オブジェクトをそれぞれ
  単純な \code{\link{print}}メソッドを使いプリントする．
}
\usage{
\method{print}{htest}(x, digits = getOption("digits"), prefix = "\t", \dots)

\method{print}{power.htest}(x, digits = getOption("digits"), \dots)
}
\arguments{
  \item{x}{
    クラス \code{"htest"} 又は \code{"power.htest"} のオブジェクト．}
  \item{digits}{使用される有効桁数．}
  \item{prefix}{文字列，\code{htest} オブジェクトの
    \code{method} 成分を表示するため
    \code{\link{strwrap}} に渡される．}
  \item{\dots}{メソッドへ・から渡される追加引数．}
}
\details{
  二つの \code{\link{print}} メソッドは伝統的に
  \code{digits} 引数を適切に処理してこなかった．
  それらは今では適切に処理され，
  \code{htest} メソッドは主に
  \code{max(1, digits - 2)} のような表現式を使う．

  \code{power.htest} オブジェクトは単に数と文字列の名前付きリストであり，
  \code{method} と \code{note} 要素が補足されている．
  \code{method} はタイトルとして，
  \code{note} はフットノートとして，
  残りの要素は揃えられた
  \sQuote{name = value} 書式で与えられる．
}
\value{
  引数 \code{x}，
  全ての \code{\link{print}} メソッドのように不可視．
}
\author{Peter Dalgaard}% and MMaechler for 'digits'

\seealso{
  \code{\link{power.t.test}},
  \code{\link{power.prop.test}}
}
\examples{
(ptt <- power.t.test(n = 20, delta = 1))
print(ptt, digits =  4) # 既定より少ない桁数を使う
print(ptt, digits = 12) # 既定より多い桁数を使う
}
\keyword{htest}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/print.power.htest.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{print.power.htest}
%\title{Print Methods for Hypothesis Tests and Power Calculation Objects}
%\alias{print.htest}
%\alias{print.power.htest}
%\description{
%  Printing objects of class \code{"htest"} or \code{"power.htest"},
%  respectively, by simple \code{\link{print}} methods.
%}
%\usage{
%\method{print}{htest}(x, digits = getOption("digits"), prefix = "\t", \dots)
%
%\method{print}{power.htest}(x, digits = getOption("digits"), \dots)
%}
%\arguments{
%  \item{x}{object of class \code{"htest"} or \code{"power.htest"}.}
%  \item{digits}{number of significant digits to be used.}
%  \item{prefix}{string, passed to \code{\link{strwrap}} for displaying
%    the \code{method} component of the \code{htest} object.}
%  \item{\dots}{further arguments to be passed to or from methods.}
%}
%\details{
%  Both \code{\link{print}} methods traditionally have not obeyed the
%  \code{digits} argument properly.  They now do, the \code{htest}
%  method mostly in expressions like \code{max(1, digits - 2)}.
%
%  A \code{power.htest} object is just a named list of numbers and
%  character strings, supplemented with \code{method} and \code{note}
%  elements.  The \code{method} is displayed as a title, the \code{note}
%  as a footnote, and the remaining elements are given in an aligned
%  \sQuote{name = value} format.
%}
%\value{
%  the argument \code{x}, invisibly, as for all \code{\link{print}}
%  methods.
%}
%\author{Peter Dalgaard}% and MMaechler for 'digits'
%
%\seealso{
%  \code{\link{power.t.test}},
%  \code{\link{power.prop.test}}
%}
%\examples{
%(ptt <- power.t.test(n = 20, delta = 1))
%print(ptt, digits =  4) # using less digits than default
%print(ptt, digits = 12) # using more  "       "     "
%}
%\keyword{htest}
%
%\encoding{UTF-8}
%
