% File src/library/stats/man/reshape.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{reshape}
\alias{reshape}%@%\alias{グループ化されたデータの再整形}
\title{Reshape Grouped Data}
\description{
  この関数はデータフレームを
  繰り返し計測値を同じレコードの別個の列に持つ\sQuote{ワイド}書式と
  繰り返し計測値を別個のレコードとして持つ\sQuote{ロング}書式の
  間で再整形する．
}
\usage{
reshape(data, varying = NULL, v.names = NULL, timevar = "time",
        idvar = "id", ids = 1:NROW(data),
        times = seq_along(varying[[1]]),
        drop = NULL, direction, new.row.names = NULL,
        sep = ".",
        split = if (sep == "") {
            list(regexp = "[A-Za-z][0-9]", include = TRUE)
        } else {
            list(regexp = sep, include = FALSE, fixed = TRUE)}
        )

}
\arguments{
  \item{data}{データフレーム．}
  \item{varying}{
    ロング書式(\sQuote{可変時間})で単一の変数に対応する
    ワイド書式の変数の集合の名前．
    これは標準的には変数名のベクトルのリストであるが，
    オプションで名前の行列，又は単一の名前のベクトルでも良い．
    それぞれのケースで，名前は
    \code{names(data)} を参照すると解釈される添字で置き換えることが出来る．
    より詳細とオプションについては\sQuote{詳細}節を見よ．}
  \item{v.names}{
    ワイド書式での複数の変数に対応するロング書式中の変数の名前．
    \sQuote{詳細}節を見よ．}
  \item{timevar}{
    多重レコードを同じグループか個別かを識別するロング書式中の変数．
    もし一つより多いレコードがマッチしたら，(警告と共に)最初のものが使われる．}
  \item{idvar}{
    多重レコードを同じグループ/個体から特定するロング書式中の
    一つ又はそれ以上の変数の名前．
    これらの変数はワイド書式でも存在するかもしれない．}
  \item{ids}{ロング書式で新たに作られた \code{idvar} 変数に使われる値．}
  \item{times}{
    ワイド書式で新たに作られた \code{timevar} 変数に使われる値
    \sQuote{詳細}節を見よ．}
  \item{drop}{再整形の前に捨てられる変数名のベクトル．}
  \item{direction}{
    文字列で，
    ワイド書式への再整形の \code{"wide"}，又はロング書式への再整形の
    \code{"long"} に部分的にマッチする．}
  \item{new.row.names}{
    文字列又は \code{NULL}：NULL でない値は結果の行名に使われる．}
  \item{sep}{長さ 1 の文字列ベクトルで，
    ワイド書式中の変数名中の分離文字列として使われる．
    これは \code{varying} 中の名前に基づいて \code{v.names} と \code{times}
    を推測するのに使われる．
    もし \code{sep == ""} なら分割はアルファベット文字に続く
    最初の数値の丁度前である．
    これは又ワイド書式に再整形する際にも変数名を作るのに使われる．}
  \item{split}{三つの成分
    \code{regexp},  \code{include} そして(オプションで) \code{fixed} を
    持つリスト．これは変数名分割に対する拡張インタフェイスを許す．
    \sQuote{詳細}節を見よ．}
}
\details{
  この関数への引数は経時的なデータの言葉で説明され，
  そしてそれが関数のモチベーションになった応用である．
  \sQuote{全体}としての経時的データセットは各個体に対して
  各時間毎に一つの列を占めるある時間に対して一定の変数を
  持つ一つのレコードを持つ．
  \sQuote{ロング}書式では各個体に対して複数の記録があり，
  ある変数はこれらのレコードを横切って定数であり，
  他はレコードを横切って変化する．
  \sQuote{ロング}書式はまた
  各レコードがどの時点からレコードが来たかを特定する
  \sQuote{時間}変数と
  どのレコードが同じ個体を参照するかを示す\sQuote{id}変数を持つ．

  もしデータフレームが先の
  \code{reshape} の結果であれば，
  捜査は単に \code{reshape(a)} で逆転できる．
  \code{direction} 引数はオプションで，他の引数は
  データフレームに関する属性として保管されている．

  もし \code{direction = "wide"} で \code{varying} 又は \code{v.names}
  引数が提供されないと，
  \code{idvar} と \code{timevar} を除く全ての変数が経時的と仮定される．
  これらはワイド書式では多重変数に展開される．

  もし \code{direction = "long"} ならば \code{varying} 引数は
  列名(または対応する添字)のベクトルで良い．
  関数はこれらの名前から \code{v.names} と \code{times} を推測する．
  既定では \code{x.1}, \code{x.2} のような変数名で，ここで
  \code{sep = "."} はドットで分割しそれを名前から取り去ることを
  指定する．
  アルファベットの後に数値番号を得るためには
  \code{sep = ""} を使う．

  上で説明された変数名分割は
  \code{varying} が原子的なベクトルである時だけ試みられる．
  もしそれがリストや行列ならば
  \code{v.names} と \code{times} が一般に指定される必要があるが，
  それらは既定でそれぞれ各セットの最初の変数名と
  続き番号の時間とされる．

  又，もし
  \code{v.names} が明示的に与えられれば推測は試みられない．
  \code{varying} 中の変数の順序は
  \code{x.1},\code{y.1},\code{x.2},\code{y.2} のようになることを注意する．

  \code{split} 引数は普通必要であるべきではない．
  \code{split$regexp} 成分は
  \code{\link{strsplit}} か \code{\link{regexpr}} に渡され，
  ここで後者は
  もし \code{split$include} が \code{TRUE} なら使われ，
  その場合分割はマッチした文字列の最初の文字の後で起こる．
  \code{\link{strsplit}} ケースでは，分離記号は結果に含まれず，
  \code{split$fixed} を使って固定文字列マッチングを指定することが出来る．
}
\value{
  オリジナルの形に整形し戻すことを簡略化する追加属性を持つ
  再整形されたデータフレーム．
}
\seealso{\code{\link{stack}}, \code{\link{aperm}};
  \code{\link{unlist}} の結果の再整形に対しては \code{\link{relist}}．
}
\examples{
summary(Indometh)
wide <- reshape(Indometh, v.names = "conc", idvar = "Subject",
                timevar = "time", direction = "wide")
wide

reshape(wide, direction = "long")
reshape(wide, idvar = "Subject", varying = list(2:12),
        v.names = "conc", direction = "long")

## 時間は数値である必要はない
df <- data.frame(id = rep(1:4, rep(2,4)),
                 visit = I(rep(c("Before","After"), 4)),
                 x = rnorm(4), y = runif(4))
df
reshape(df, timevar = "visit", idvar = "id", direction = "wide")
## y が実際に変化していることを警告
reshape(df, timevar = "visit", idvar = "id", direction = "wide", v.names = "x")


##  不釣り合いの '長い' データは '幅広' 書式では NA で埋められる
df2 <- df[1:7, ]
df2
reshape(df2, timevar = "visit", idvar = "id", direction = "wide")

##名前の推測に対する別の正規表現
df3 <- data.frame(id = 1:4, age = c(40,50,60,50), dose1 = c(1,2,1,2),
                  dose2 = c(2,1,2,1), dose4 = c(3,3,3,3))
reshape(df3, direction = "long", varying = 3:5, sep = "")


## 経時データではない例
state.x77 <- as.data.frame(state.x77)
long <- reshape(state.x77, idvar = "state", ids = row.names(state.x77),
                times = names(state.x77), timevar = "Characteristic",
                varying = list(names(state.x77)), direction = "long")

reshape(long, direction = "wide")

reshape(long, direction = "wide", new.row.names = unique(long$state))

## 多重の id 変数
df3 <- data.frame(school = rep(1:3, each = 4), class = rep(9:10, 6),
                  time = rep(c(1,1,2,2), 3), score = rnorm(12))
wide <- reshape(df3, idvar = c("school","class"), direction = "wide")
wide
## 変換し戻す
reshape(wide)

}
\keyword{manip}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/reshape.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{reshape}
%\alias{reshape}
%\title{Reshape Grouped Data}
%\description{
%  This function reshapes a data frame between \sQuote{wide} format with
%  repeated measurements in separate columns of the same record and
%  \sQuote{long} format with the repeated measurements in separate
%  records.
%}
%\usage{
%reshape(data, varying = NULL, v.names = NULL, timevar = "time",
%        idvar = "id", ids = 1:NROW(data),
%        times = seq_along(varying[[1]]),
%        drop = NULL, direction, new.row.names = NULL,
%        sep = ".",
%        split = if (sep == "") {
%            list(regexp = "[A-Za-z][0-9]", include = TRUE)
%        } else {
%            list(regexp = sep, include = FALSE, fixed = TRUE)}
%        )
%
%}
%\arguments{
%  \item{data}{a data frame}
%  \item{varying}{names of sets of variables in the wide format that
%    correspond to single variables in long format
%    (\sQuote{time-varying}).  This is canonically a list of vectors of
%    variable names, but it can optionally be a matrix of names, or a
%    single vector of names.  In each case, the names can be replaced by
%    indices which are interpreted as referring to \code{names(data)}.
%    See \sQuote{Details} for more details and options.}
%  \item{v.names}{names of variables in the long format that correspond
%    to multiple variables in the wide format.  See \sQuote{Details}.}
%  \item{timevar}{the variable in long format that differentiates multiple
%    records from the same group or individual.  If more than one record
%    matches, the first will be taken (with a warning). }
%  \item{idvar}{Names of one or more variables in long format that
%    identify multiple records from the same group/individual.  These
%    variables may also be present in wide format.}
%  \item{ids}{the values to use for a newly created \code{idvar}
%    variable in long format.}
%  \item{times}{the values to use for a newly created \code{timevar}
%    variable in long format.  See \sQuote{Details}.}
%  \item{drop}{a vector of names of variables to drop before reshaping.}
%  \item{direction}{character string, partially matched to either
%    \code{"wide"} to reshape to wide format, or \code{"long"} to reshape
%    to long format.}
%  \item{new.row.names}{character or \code{NULL}: a non-null value will be
%    used for the row names of the result.}
%  \item{sep}{A character vector of length 1, indicating a separating
%    character in the variable names in the wide format.  This is used for
%    guessing \code{v.names} and \code{times} arguments based on the
%    names in \code{varying}.  If \code{sep == ""}, the split is just before
%    the first numeral that follows an alphabetic character.  This is
%    also used to create variable names when reshaping to wide format.}
%  \item{split}{A list with three components, \code{regexp},
%    \code{include}, and (optionally) \code{fixed}.  This allows an
%    extended interface to variable name splitting.  See \sQuote{Details}.}
%}
%\details{
%  The arguments to this function are described in terms of longitudinal
%  data, as that is the application motivating the functions.  A
%  \sQuote{wide} longitudinal dataset will have one record for each
%  individual with some time-constant variables that occupy single
%  columns and some time-varying variables that occupy a column for each
%  time point.  In \sQuote{long} format there will be multiple records
%  for each individual, with some variables being constant across these
%  records and others varying across the records.  A \sQuote{long} format
%  dataset also needs a \sQuote{time} variable identifying which time
%  point each record comes from and an \sQuote{id} variable showing which
%  records refer to the same person.
%
%  If the data frame resulted from a previous \code{reshape} then the
%  operation can be reversed simply by \code{reshape(a)}.  The
%  \code{direction} argument is optional and the other arguments are
%  stored as attributes on the data frame.
%
%  If \code{direction = "wide"} and no \code{varying} or \code{v.names}
%  arguments are supplied it is assumed that all variables except
%  \code{idvar} and \code{timevar} are time-varying.  They are all
%  expanded into multiple variables in wide format.
%
%  If \code{direction = "long"} the \code{varying} argument can be a vector
%  of column names (or a corresponding index).  The function will attempt
%  to guess the \code{v.names} and \code{times} from these names.  The
%  default is variable names like \code{x.1}, \code{x.2}, where
%  \code{sep = "."} specifies to split at the dot and drop it from the
%  name.  To have alphabetic followed by numeric times use \code{sep = ""}.
%
%  Variable name splitting as described above is only attempted in the
%  case where \code{varying} is an atomic vector, if it is a list or a
%  matrix, \code{v.names} and \code{times} will generally need to be
%  specified, although they will default to, respectively, the first
%  variable name in each set, and sequential times.
%
%  Also, guessing is not attempted if \code{v.names} is given
%  explicitly.  Notice that the order of variables in \code{varying} is
%  like \code{x.1},\code{y.1},\code{x.2},\code{y.2}.
%
%  The \code{split} argument should not usually be necessary.  The
%  \code{split$regexp} component is passed to either
%  \code{\link{strsplit}} or \code{\link{regexpr}}, where the latter is
%  used if \code{split$include} is \code{TRUE}, in which case the
%  splitting occurs after the first character of the matched string.  In
%  the \code{\link{strsplit}} case, the separator is not included in the
%  result, and it is possible to specify fixed-string matching using
%  \code{split$fixed}.
%}
%\value{
%  The reshaped data frame with added attributes to simplify reshaping
%  back to the original form.
%}
%\seealso{\code{\link{stack}}, \code{\link{aperm}};
%  \code{\link{relist}} for reshaping the result of \code{\link{unlist}}.
%}
%\examples{
%summary(Indometh)
%wide <- reshape(Indometh, v.names = "conc", idvar = "Subject",
%                timevar = "time", direction = "wide")
%wide
%
%reshape(wide, direction = "long")
%reshape(wide, idvar = "Subject", varying = list(2:12),
%        v.names = "conc", direction = "long")
%
%## times need not be numeric
%df <- data.frame(id = rep(1:4, rep(2,4)),
%                 visit = I(rep(c("Before","After"), 4)),
%                 x = rnorm(4), y = runif(4))
%df
%reshape(df, timevar = "visit", idvar = "id", direction = "wide")
%## warns that y is really varying
%reshape(df, timevar = "visit", idvar = "id", direction = "wide", v.names = "x")
%
%
%##  unbalanced 'long' data leads to NA fill in 'wide' form
%df2 <- df[1:7, ]
%df2
%reshape(df2, timevar = "visit", idvar = "id", direction = "wide")
%
%## Alternative regular expressions for guessing names
%df3 <- data.frame(id = 1:4, age = c(40,50,60,50), dose1 = c(1,2,1,2),
%                  dose2 = c(2,1,2,1), dose4 = c(3,3,3,3))
%reshape(df3, direction = "long", varying = 3:5, sep = "")
%
%
%## an example that isn't longitudinal data
%state.x77 <- as.data.frame(state.x77)
%long <- reshape(state.x77, idvar = "state", ids = row.names(state.x77),
%                times = names(state.x77), timevar = "Characteristic",
%                varying = list(names(state.x77)), direction = "long")
%
%reshape(long, direction = "wide")
%
%reshape(long, direction = "wide", new.row.names = unique(long$state))
%
%## multiple id variables
%df3 <- data.frame(school = rep(1:3, each = 4), class = rep(9:10, 6),
%                  time = rep(c(1,1,2,2), 3), score = rnorm(12))
%wide <- reshape(df3, idvar = c("school","class"), direction = "wide")
%wide
%## transform back
%reshape(wide)
%
%}
%\keyword{manip}
%
%\encoding{UTF-8}
%
