% File src/library/stats/man/scatter.smooth.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{scatter.smooth}
\title{Scatter Plot with Smooth Curve Fitted by Loess}
\alias{scatter.smooth}%@%\alias{散布図に Loess 平滑化曲線を加える}
\alias{loess.smooth}
\description{
  散布図に \code{loess} で解散された平滑化曲線をプロットする，加える．
}
\usage{
scatter.smooth(x, y = NULL, span = 2/3, degree = 1,
    family = c("symmetric", "gaussian"),
    xlab = NULL, ylab = NULL,
    ylim = range(y, pred$y, na.rm = TRUE),
    evaluation = 50, \dots, lpars = list())

loess.smooth(x, y, span = 2/3, degree = 1,
    family = c("symmetric", "gaussian"), evaluation = 50, \dots)
}
\arguments{
  \item{x, y}{\code{x} と \code{y} 引数はプロットに対する
    x と y 座標を与える．
    任意の合理的な座標の定義方法が受け入れられる．
    詳細は \code{\link{xy.coords}} を見よ．}
  \item{span}{
    \code{loess} に対する平滑度パラメータ．}
  \item{degree}{使われる局所多項式の次数．}
  \item{family}{もし \code{"gaussian"} なら当てはめは最少二乗法で，
    又もし
    \code{family = "symmetric"} なら再下降 M 推定量が使われる．
    短縮化出来る．}
  \item{xlab}{x 軸ラベル．}
  \item{ylab}{y 軸ラベル．}
  \item{ylim}{プロットの y 限界．}
  \item{evaluation}{そこで平滑曲線を評価する点の数．}
  \item{\dots}{\code{scatter.smooth()} に対してはグラフィカルパラメータで，
    \code{plot()} だけに渡される．
    \code{loess.smooth} に対しては制御パラメータで，
    \code{\link{loess.control}} に渡される．}
  \item{lpars}{
    \code{\link{lines}()} に渡される引数のリスト．}
}
\details{
  \code{loess.smooth} は \code{x} の範囲を覆う等間隔の
  \code{evaluation} 個の点で
  \code{loess} 平滑値を評価する補助関数である．
}
\value{
  \code{scatter.smooth} に対しては無い．

  \code{loess.smooth} に対しては二つの成分
  \code{x} (評価点のグリッド)と \code{y}
  (グリッド店での平滑化値)．
}
\seealso{
  \code{\link{loess}};
  カラー表現の平滑化\emph{密度}を持つ散布図に対しては
  \code{\link{smoothScatter}}．
}
\examples{
require(graphics)

with(cars, scatter.smooth(speed, dist))
## 又は太いドット線による平滑化の結果には：
with(cars, scatter.smooth(speed, dist, lpars =
                    list(col = "red", lwd = 3, lty = 3)))
}
\keyword{smooth}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/scatter.smooth.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{scatter.smooth}
%\title{Scatter Plot with Smooth Curve Fitted by Loess}
%\alias{scatter.smooth}
%\alias{loess.smooth}
%\description{
%  Plot and add a smooth curve computed by \code{loess} to a scatter plot.
%}
%\usage{
%scatter.smooth(x, y = NULL, span = 2/3, degree = 1,
%    family = c("symmetric", "gaussian"),
%    xlab = NULL, ylab = NULL,
%    ylim = range(y, pred$y, na.rm = TRUE),
%    evaluation = 50, \dots, lpars = list())
%
%loess.smooth(x, y, span = 2/3, degree = 1,
%    family = c("symmetric", "gaussian"), evaluation = 50, \dots)
%}
%\arguments{
%  \item{x, y}{the \code{x} and \code{y} arguments provide the x and y
%    coordinates for the plot.  Any reasonable way of defining the
%    coordinates is acceptable.  See the function \code{\link{xy.coords}}
%    for details.}
%  \item{span}{smoothness parameter for \code{loess}.}
%  \item{degree}{degree of local polynomial used.}
%  \item{family}{if \code{"gaussian"} fitting is by least-squares, and if
%    \code{family = "symmetric"} a re-descending M estimator is used.
%    Can be abbreviated.}
%  \item{xlab}{label for x axis.}
%  \item{ylab}{label for y axis.}
%  \item{ylim}{the y limits of the plot.}
%  \item{evaluation}{number of points at which to evaluate the smooth
%    curve.}
%  \item{\dots}{For \code{scatter.smooth()}, graphical parameters, passed
%    to \code{plot()} only.  For \code{loess.smooth}, control parameters
%    passed to \code{\link{loess.control}}.}
%  \item{lpars}{a \code{\link{list}} of arguments to be passed to
%    \code{\link{lines}()}.}
%}
%\details{
%  \code{loess.smooth} is an auxiliary function which evaluates the
%  \code{loess} smooth at \code{evaluation} equally spaced points
%  covering the range of \code{x}.
%}
%\value{
%  For \code{scatter.smooth}, none.
%
%  For \code{loess.smooth}, a list with two components, \code{x} (the
%  grid of evaluation points) and \code{y} (the smoothed values at the
%  grid points).
%}
%\seealso{
%  \code{\link{loess}}; \code{\link{smoothScatter}} for scatter plots
%  with smoothed \emph{density} color representation.
%}
%\examples{
%require(graphics)
%
%with(cars, scatter.smooth(speed, dist))
%## or with dotted thick smoothed line results :
%with(cars, scatter.smooth(speed, dist, lpars =
%                    list(col = "red", lwd = 3, lty = 3)))
%}
%\keyword{smooth}
%
%\encoding{UTF-8}
%
