% File src/library/stats/man/summary.nls.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2009 R Core Team
% Distributed under GPL 2 or later

\name{summary.nls}
\alias{summary.nls}%@%\alias{非線型最少二乗法当てはめを要約}
\alias{print.summary.nls}
\title{Summarizing Non-Linear Least-Squares Model Fits}
\description{
  クラス \code{"nls"} に対する \code{summary} メソッド．
}
\usage{
\method{summary}{nls}(object, correlation = FALSE, symbolic.cor = FALSE, \dots)

\method{print}{summary.nls}(x, digits = max(3, getOption("digits") - 3),
      symbolic.cor = x$symbolic.cor,
      signif.stars = getOption("show.signif.stars"), \dots)
}
\arguments{
  \item{object}{
    クラス \code{"nls"} のオブジェクト．}
  \item{x}{
    クラス \code{"summary.nls"} のオブジェクト，普通
    \code{summary.nls} 呼び出しの結果．}
  \item{correlation}{論理値；もし \code{TRUE} なら，
    推定パラメータの相関行列が返されプリントされる．}
  \item{digits}{
    プリントの際使われる有効桁数．}
  \item{symbolic.cor}{論理値．もし \code{TRUE} なら，
    相関を数値ではなくシンボリックな形式
    (\code{\link{symnum}} を見よ)でプリントする．}
  \item{signif.stars}{論理値．もし \code{TRUE} なら
    \sQuote{信頼星印}が各係数に対してプリントされる．}
  \item{\dots}{他のメソッドに・から渡される追加引数．}
}
\details{
  標準エラーと残差標準エラー(t 比)の分布を見つけるための分布理論
  は線形化に基づき近似である(非常に近似的かもしれない)，

  \code{print.summary.nls} は係数，標準エラー等のスマートな整形を
  試み，もし \code{signif.stars} が \code{TRUE} なら追加で
  \sQuote{信頼星印}を与える．

  相関は二桁(又はシンボリックに)でプリントする：
  実際の相関を見るには\cr
  \code{summary(object)$correlation} を直接にプリントする．
}
\value{
  関数 \code{summary.nls} は
  その引数の成分 \code{"formula"} 
  を使い，\code{object} で与えられた当てはめモデルの要約統計量の
  リストを計算し返す．
  \item{residuals}{\emph{重み付き}残差，通常の残差を
    呼び出し \code{nls} 中で指定された重みの平方根で
    再スケールした物．}
  \item{coefficients}{
    推定係数，その標準エラー，
    t 統計量，そして対応する(両側) p 値の列を持つ
    \eqn{p \times 4}{p x 4} 行列．}
  \item{sigma}{
    ランダム誤差
    \deqn{\hat\sigma^2 = \frac{1}{n-p}\sum_i{R_i^2},}{\sigma^2 = 1/(n-p) Sum(R[i]^2),}
    の推定分散の平方根，ここで
    \eqn{R_i}{R[i]} は \eqn{i} 番目の重み付き残差．}
  \item{df}{自由度の長さ 2 のベクトル \eqn{(p, n-p)}．
    (ここと他でも
    \eqn{n} は重みゼロの観測値を除外する．)}
  \item{cov.unscaled}{
    (スケール化されていない)パラメータ推定値の共分散の
    \eqn{p \times p}{p x p} 行列．}
  \item{correlation}{
    もし \code{correlation = TRUE} が指定され
    残差自由度の数がゼロでなければ，
    上の \code{cov.unscaled} に対応する相関行列．}
  \item{symbolic.cor}{
    (\code{correlation} が真の時だけ．)
    引数 \code{symbolic.cor} の値．}
}
\seealso{
  モデル当てはめ関数 \code{\link{nls}}, \code{\link{summary}}．

  関数 \code{\link{coef}} は標準エラー， t 統計量，そして
  p 値を持つを持つ係数の行列を取り出す．
}

\keyword{regression}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/summary.nls.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2009 R Core Team
%% Distributed under GPL 2 or later
%
%\name{summary.nls}
%\alias{summary.nls}
%\alias{print.summary.nls}
%\title{Summarizing Non-Linear Least-Squares Model Fits}
%\description{
%  \code{summary} method for class \code{"nls"}.
%}
%\usage{
%\method{summary}{nls}(object, correlation = FALSE, symbolic.cor = FALSE, \dots)
%
%\method{print}{summary.nls}(x, digits = max(3, getOption("digits") - 3),
%      symbolic.cor = x$symbolic.cor,
%      signif.stars = getOption("show.signif.stars"), \dots)
%}
%\arguments{
%  \item{object}{an object of class \code{"nls"}.}
%  \item{x}{an object of class \code{"summary.nls"}, usually the result of a
%    call to \code{summary.nls}.}
%  \item{correlation}{logical; if \code{TRUE}, the correlation matrix of
%    the estimated parameters is returned and printed.}
%  \item{digits}{the number of significant digits to use when printing.}
%  \item{symbolic.cor}{logical.  If \code{TRUE}, print the correlations in
%    a symbolic form (see \code{\link{symnum}}) rather than as numbers.}
%  \item{signif.stars}{logical.  If \code{TRUE}, \sQuote{significance stars}
%    are printed for each coefficient.}
%  \item{\dots}{further arguments passed to or from other methods.}
%}
%\details{
%  The distribution theory used to find the distribution of the
%  standard errors and of the residual standard error (for t ratios) is
%  based on linearization and is approximate, maybe very approximate.
%
%  \code{print.summary.nls} tries to be smart about formatting the
%  coefficients, standard errors, etc. and additionally gives
%  \sQuote{significance stars} if \code{signif.stars} is \code{TRUE}.
%
%  Correlations are printed to two decimal places (or symbolically): to
%  see the actual correlations print \code{summary(object)$correlation}
%  directly.
%}
%\value{
%  The function \code{summary.nls} computes and returns a list of summary
%  statistics of the fitted model given in \code{object}, using
%  the component  \code{"formula"} from its argument, plus
%  \item{residuals}{the \emph{weighted} residuals, the usual residuals
%    rescaled by the square root of the weights specified in the call to
%    \code{nls}.}
%  \item{coefficients}{a \eqn{p \times 4}{p x 4} matrix with columns for
%    the estimated coefficient, its standard error, t-statistic and
%    corresponding (two-sided) p-value.}
%  \item{sigma}{the square root of the estimated variance of the random
%    error
%    \deqn{\hat\sigma^2 = \frac{1}{n-p}\sum_i{R_i^2},}{\sigma^2 = 1/(n-p) Sum(R[i]^2),}
%    where \eqn{R_i}{R[i]} is the \eqn{i}-th weighted residual.}
%  \item{df}{degrees of freedom, a 2-vector \eqn{(p, n-p)}.  (Here and
%    elsewhere \eqn{n} omits observations with zero weights.)}
%  \item{cov.unscaled}{a \eqn{p \times p}{p x p} matrix of (unscaled)
%    covariances of the parameter estimates.}
%  \item{correlation}{the correlation matrix corresponding to the above
%    \code{cov.unscaled}, if \code{correlation = TRUE} is specified and
%    there are a non-zero number of residual degrees of freedom.}
%  \item{symbolic.cor}{(only if \code{correlation} is true.)  The value
%    of the argument \code{symbolic.cor}.}
%}
%\seealso{
%  The model fitting function \code{\link{nls}}, \code{\link{summary}}.
%
%  Function \code{\link{coef}} will extract the matrix of coefficients
%  with standard errors, t-statistics and p-values.
%}
%
%\keyword{regression}
%\keyword{models}
%
%\encoding{UTF-8}
%
