% File src/library/stats/man/ts.union.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{ts.union}%@%\alias{時系列の結合}
\alias{ts.union}
\alias{ts.intersect}
\title{Bind Two or More Time Series}
\usage{
ts.intersect(\dots, dframe = FALSE)
ts.union(\dots, dframe = FALSE)
}
\arguments{
  \item{\dots}{二つ以上の一変量時系列か多変量時系列，又は
    時系列に強制変換できるオブジェクト．}
  \item{dframe}{論理値；もし \code{TRUE} なら結果を
    データフレームとして返す．}
}
\description{
  同じ周波数を持つ時系列を結合する．
  \code{ts.union} は全ての時間をカバーするように
  \code{NA} で埋め，
  \code{ts.intersect} は全ての系列によりカバーされる
  時間に制限する．
}
\details{
  特別な場合として，
  \code{\dots} は同じ長さのベクトルや行列を
  存在する時系列の結合時系列として含むことが出来る．
  単一の行のそれらでも良い．
}
\value{
  もし \code{dframe} が \code{FALSE} ならば時系列オブジェクト，
  さもなければデータフレーム．
}
\seealso{\code{\link{cbind}}.}
\examples{
ts.union(mdeaths, fdeaths)
cbind(mdeaths, fdeaths) # 前の行と同じ
ts.intersect(window(mdeaths, 1976), window(fdeaths, 1974, 1978))

sales1 <- ts.union(BJsales, lead = BJsales.lead)
ts.intersect(sales1, lead3 = lag(BJsales.lead, -3))
}
\keyword{ts}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/ts.union.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{ts.union}
%\alias{ts.union}
%\alias{ts.intersect}
%\title{Bind Two or More Time Series}
%\usage{
%ts.intersect(\dots, dframe = FALSE)
%ts.union(\dots, dframe = FALSE)
%}
%\arguments{
%  \item{\dots}{two or more univariate or multivariate time series, or
%    objects which can coerced to time series.}
%  \item{dframe}{logical; if \code{TRUE} return the result as a data
%    frame.}
%}
%\description{
%  Bind time series which have a common frequency. \code{ts.union} pads
%  with \code{NA}s to the total time coverage, \code{ts.intersect}
%  restricts to the time covered by all the series.
%}
%\details{
%  As a special case, \code{\dots} can contain vectors or matrices of the
%  same length as the combined time series of the time series present, as
%  well as those of a single row.
%}
%\value{
%  A time series object if \code{dframe} is \code{FALSE}, otherwise a
%  data frame.
%}
%\seealso{\code{\link{cbind}}.}
%\examples{
%ts.union(mdeaths, fdeaths)
%cbind(mdeaths, fdeaths) # same as the previous line
%ts.intersect(window(mdeaths, 1976), window(fdeaths, 1974, 1978))
%
%sales1 <- ts.union(BJsales, lead = BJsales.lead)
%ts.intersect(sales1, lead3 = lag(BJsales.lead, -3))
%}
%\keyword{ts}
%
%\encoding{UTF-8}
%
