% File src/library/tools/man/RdTextFilter.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2009-2014 R Core Team
% Distributed under GPL 2 or later

\name{RdTextFilter}
%@%\alias{Rd ファイル中のテキストの選択}
\alias{RdTextFilter}
\title{Rd ファイル中のテキストの選択}
%\title{Select text in an Rd file.}
\description{
この関数はスペルチェック等に使用するため
Rd ファイル中の全てのテキストでない部分を空白にする，

}
\usage{
RdTextFilter(ifile, encoding = "unknown", keepSpacing = TRUE,
             drop = character(), keep = character(),
             macros = file.path(R.home("share"), "Rd", "macros", "system.Rd"))
}
\arguments{
\item{ifile}{
  ファイル名やコネクションとして指定された入力ファイル名，又は
  \code{\link{parse_Rd}} からの \code{"Rd"} オブジェクト．
}
\item{encoding}{
  \code{\link{parse_Rd}} に渡されるエンコーディング名．
}
\item{keepSpacing}{
  テキストを元々のファイルと同じ行と欄に留めておくかどうか．
}
\item{drop}{捨て去る追加 Rd の節．}
\item{keep}{残しておく Rd の節．}
\item{macros}{
  構文解析時に仮定するマクロ定義．\code{\link{parse_Rd}} を見よ．
}
}
\details{
  この関数は Rd ファイルを構文解析し，それからそれを要素ごとに見て回る．
  タグ \code{"TEXT"} の付いた項目は元々のファイルに登場したのと同じ
  位置に保たれ，
  一方ファイルの他の部分は空白で置き換えられるでの，
  \code{\link{aspell}} 等のスペルチェックソフトが
  テキストだけをチェック出来，元のファイル中の位置を報告する．
  (もし \code{keepSpacing} が \code{FALSE} ならば，空白による置き換えは
  されず，テキストは元々の位置には出力されない．)

  既定では，タグ \verb{\S3method}, \verb{\S4method},
  \verb{\command}, \verb{\docType}, \verb{\email}, \verb{\encoding},
  \verb{\file}, \verb{\keyword}, \verb{\link}, \verb{\linkS4class},
  \verb{\method}, \verb{\pkg} そして \verb{\var} はスキップされる．
  追加のタグはそれらを
  \code{drop} 引数中にリストすることでスキップ出来る；
  \code{keep} 引数中にリストされたタグはスキップされない．
  また R 風のコード，コメント，そしてそのままのテキストに対応する
  \code{c("RCODE", "COMMENT", "VERB")} タグのどれも \code{keep}
  したり，  \code{"TEXT"} を捨て去ることが可能である．
}
\value{
  文字列ベクトルで，もし一行につき一要素でファイルに書き込まれると
  元々の Rd ファイルのテキスト要素を複製しているかもしれない．
}
\author{
  Duncan Murdoch
}
\note{
  このフィルターは
  Rd ファイル中で単に単語の初めをハイライトするためにマークアップが
  使われている時テキスト要素を単一の単語に併合しようと試みる．
}

\seealso{
  これが受け入れられる \code{filter} である \code{\link{aspell}}．
}
\keyword{ utilities }
\keyword{ documentation }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/RdTextFilter.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2009-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{RdTextFilter}
%\alias{RdTextFilter}
%\title{
%Select text in an Rd file.
%}
%\description{
%This function blanks out all non-text in an Rd file,
%for spell checking or other uses.
%}
%\usage{
%RdTextFilter(ifile, encoding = "unknown", keepSpacing = TRUE,
%             drop = character(), keep = character(),
%             macros = file.path(R.home("share"), "Rd", "macros", "system.Rd"))
%}
%\arguments{
%\item{ifile}{
%  An input file specified as a filename or connection, or an \code{"Rd"} object
%  from \code{\link{parse_Rd}}.
%}
%\item{encoding}{
%  An encoding name to pass to \code{\link{parse_Rd}}.
%}
%\item{keepSpacing}{
%  Whether to try to leave the text in the same lines and columns
%  as in the original file.
%}
%\item{drop}{
%  Additional sections of the Rd to drop.
%}
%  \item{keep}{
%  Sections of the Rd file to keep.
%}
%  \item{macros}{
%  Macro definitions to assume when parsing.  See \code{\link{parse_Rd}}.
%}
%}
%\details{
%  This function parses the Rd file, then walks through it, element by
%  element.  Items with tag \code{"TEXT"} are kept in the same position as
%  they appeared in the original file, while other parts of the file are
%  replaced with blanks, so a spell checker such as \code{\link{aspell}}
%  can check only the text and report the position in the original file.
%  (If \code{keepSpacing} is \code{FALSE}, blank filling will not occur,
%  and text will not be output in its original location.)
%
%  By default, the tags \verb{\S3method}, \verb{\S4method},
%  \verb{\command}, \verb{\docType}, \verb{\email}, \verb{\encoding},
%  \verb{\file}, \verb{\keyword}, \verb{\link}, \verb{\linkS4class},
%  \verb{\method}, \verb{\pkg}, and \verb{\var} are skipped.  Additional
%  tags can be skipped by listing them in the \code{drop} argument;
%  listing tags in the \code{keep} argument will stop them from being
%  skipped.  It is also possible to \code{keep} any of the
%  \code{c("RCODE", "COMMENT", "VERB")} tags, which correspond to R-like
%  code, comments, and verbatim text respectively, or to drop
%  \code{"TEXT"}.
%}
%\value{
%  A character vector which if written to a file, one element per line, would
%  duplicate the text elements of the original Rd file.
%}
%\author{
%  Duncan Murdoch
%}
%\note{
%  The filter attempts to merge text elements into single words when markup in
%  the Rd file is used to highlight just the start of a word.
%}
%
%\seealso{
%  \code{\link{aspell}}, for which this is an acceptable \code{filter}.
%}
%\keyword{ utilities }
%\keyword{ documentation }
%
%\encoding{UTF8}
%