% File src/library/tools/man/bibstyle.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2010-2013 R Core Team
% Distributed under GPL 2 or later

\name{bibstyle}
%@%\alias{文献スタイル}
\alias{bibstyle}
\alias{getBibstyle}
\title{文献スタイルを選択，定義する}
%\title{Select or define a bibliography style}
\description{
  この関数は
  \code{\link{bibentry}} オブジェクトを，後で
  テキストや HTML 等に変換するために定義したり登録したりする．
}
\usage{
bibstyle(style, envir, ..., .init = FALSE, .default = TRUE)
getBibstyle(all = FALSE)
}
\arguments{
  \item{style}{
    スタイルの名前を与える文字列．
  }
  \item{envir}{
    (オプションの)スタイルを実装する関数を保持する環境．
  }
  \item{\dots}{
    環境に付け加えられる名前付き引数．
  }
  \item{.init}{
    既定のスタイル \code{"JSS"} から環境を初期化するか．
  }
  \item{.default}{
    指定したスタイルを既定スタイルに設定するか．
  }
  \item{all}{
    全ての登録されたスタイルの名前を返すか．
  }
}
\details{
  \code{\link{bibentry}} オブジェクトの翻訳は
  BibTeX で使われているようなものに倣ってモデル化されたルーチンを
  用いてなされる．この関数はこうしたルーチンを含む環境を作り操作
  することを許す．

  新しいスタイル環境を作る二つの方法が有る．
  最も簡単なものは
  \code{.init = TRUE} を設定することで，この場合環境は
  既定の \code{"JSS"} 環境のコピーで初期化される．
  (このスタイルは \emph{Journal of Statistical Software} で使われている
  \file{jss.bst} スタイルに倣ってモデル化されている．)
  別の方法としては，全く新しいスタイル環境を指定するのに
  \code{envir} 引数を使うことが出来る．

  既定のスタイルの名前を見つけるには
  \code{getBibstyle()} を使う．
  既存のスタイルを既定に設定することなしに検索するには，
  \code{bibstyle(style, .default = FALSE)} を使う．
  既存のスタイルを改変するには，
  \code{style} を指定しある名前付き項目を
  \code{...} を使って指定する．
  (既定の \code{"JSS"} スタイルの改変は勧められない．)
  \code{style} を \code{NULL} に設定するか，又は
  それを欠損のままにすると既定のスタイルが回収されるが，
  改変は許されない．

  最低でも環境は
  \code{\link{bibentry}} によりサポートされる12の文献項目タイプの各々と
  各々と並び以下で説明される幾つかの他のルーチンの
  を翻訳するルーチンを含むべきである．
  前者は次のような名前を持たなければならない；
  \code{formatArticle},
  \code{formatBook}, \code{formatInbook}, \code{formatIncollection},
  \code{formatInProceedings}, \code{formatManual},
  \code{formatMastersthesis},\cr
  \code{formatMisc}, \code{formatPhdthesis},
  \code{formatProceedings}, \code{formatTechreport} そして\cr
  \code{formatUnpublished}．これらの各々は一つの引数，
  翻訳器に渡された \code{\link{bibentry}} ベクトルからの
  単一のクラスを持たない項目，を取り，
  そして単一の要素を持つ文字列ベクトルを生成すべきである
  (新行文字を含むかもしれない)．
  
  他のルーチンは次のようである．
  項目をソートするソートキーを作り出す \code{sortKeys}
  はオリジナルの \code{\link{bibentry}} ベクトルを渡し
  ソート順序を定義する同じ長さのソート可能なベクトルを生成する．
  最後に，オプションの関数 \code{cite} は
  \code{utils::\link{cite}} と同じ引数リストを持つべきであり，
  そしてテキスト中で使われる引用文献を作り出すべきである．

  \code{"bibentry"} オブジェクトに対する \code{\link{format}} メソッドは
  ソート後で整形前に各項目に \code{".index"} という名前の欄を加える．
  これは番号付けを必要とするスタイル中で使える完全なオブジェクト中の
  1-based 索引である．\code{"JSS"} スタイルは番号を使わないが，
  それらを表示するのに使うことができる
  スタブ関数 \code{fmtPrefix()} を含む．下の例を見よ．
}
\value{
  \code{bibstyle} は選択されたか作られた環境を返す．

  \code{getBibstyle} は既定のスタイルの名前を返す，又は全てのスタイル名を返す．
}
\author{
  Duncan Murdoch
}
\seealso{
  \code{\link{bibentry}}
}
\examples{
\testonly{options(useFancyQuotes = FALSE)}
refs <-
c(bibentry(bibtype = "manual",
    title = "R: A Language and Environment for Statistical Computing",
    author = person("R Core Team"),
    organization = "R Foundation for Statistical Computing",
    address = "Vienna, Austria",
    year = 2013,
    url = "https://www.R-project.org"),
  bibentry(bibtype = "article",
    author = c(person(c("George", "E.", "P."), "Box"),
               person(c("David",  "R."),      "Cox")),
    year = 1964,
    title = "An Analysis of Transformations",
    journal = "Journal of the Royal Statistical Society, Series B",
    volume = 26,
    pages = "211-252"))

bibstyle("unsorted", sortKeys = function(refs) seq_along(refs),
    fmtPrefix = function(paper) paste0("[", paper$.index, "]"),
       .init = TRUE)
print(refs, .bibstyle = "unsorted")
}
\keyword{ utilties }
\keyword{ documentation }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/bibstyle.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2010-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{bibstyle}
%\alias{bibstyle}
%\alias{getBibstyle}
%\title{
%Select or define a bibliography style.
%}
%\description{
%  This function defines and registers styles for rendering
%  \code{\link{bibentry}} objects into \file{Rd} format, for later
%  conversion to text, HTML, etc.
%}
%\usage{
%bibstyle(style, envir, ..., .init = FALSE, .default = TRUE)
%getBibstyle(all = FALSE)
%}
%\arguments{
%  \item{style}{
%    A character string naming the style.
%  }
%  \item{envir}{
%    (optional) An environment holding the functions to implement the style.
%  }
%  \item{\dots}{
%    Named arguments to add to the environment.
%  }
%  \item{.init}{
%    Whether to initialize the environment from the default style \code{"JSS"}.
%  }
%  \item{.default}{
%    Whether to set the specified style as the default style.
%  }
%  \item{all}{
%    Whether to return the names of all registered styles.
%  }
%}
%\details{
%  Rendering of \code{\link{bibentry}} objects may be done using routines
%  modelled after those used by BibTeX.  This function allows environments
%  to be created and manipulated to contain those routines.
%
%  There are two ways to create a new style environment.  The easiest
%  is to set \code{.init = TRUE}, in which case the environment will be
%  initialized with a copy of the default \code{"JSS"} environment.  (This style
%  is modelled after the \file{jss.bst} style used by the \emph{Journal
%    of Statistical Software}.)  Alternatively, the \code{envir} argument
%  can be used to specify a completely new style environment.
%
%  To find the name of the default style, use \code{getBibstyle()}. To
%  retrieve an existing style without setting it as the default, use
%  \code{bibstyle(style, .default = FALSE)}.  To modify an existing style,
%  specify \code{style} and some named entries via \code{...}.
%  (Modifying the default \code{"JSS"} style is discouraged.)  Setting
%  \code{style} to \code{NULL} or leaving it missing will retrieve the
%  default style, but modifications will not be allowed.
%
%  At a minimum, the environment should contain routines to render each
%  of the 12 types of bibliographic entry supported by
%  \code{\link{bibentry}} as well as several other routines
%  described below.
%  The former must be named \code{formatArticle},
%  \code{formatBook}, \code{formatInbook}, \code{formatIncollection},
%  \code{formatInProceedings}, \code{formatManual},
%  \code{formatMastersthesis}, \code{formatMisc}, \code{formatPhdthesis},
%  \code{formatProceedings}, \code{formatTechreport} and
%  \code{formatUnpublished}.  Each of these takes one argument, a single
%  \code{\link{unclass}}'ed entry from the \code{\link{bibentry}} vector
%  passed to the renderer, and should produce a single element character
%  vector (possibly containing newlines).
%  
%  The other routines are as follows.  \code{sortKeys}, a function to
%  produce a sort key to sort the entries, is passed the original
%  \code{\link{bibentry}} vector and should produce a sortable vector of
%  the same length to define the sort order.  Finally,
%  the optional function \code{cite} should have the same argument list
%  as \code{utils::\link{cite}}, and should produce a citation to be used
%  in text.
%
%  The \code{\link{format}} method for \code{"bibentry"} objects adds a
%  field named \code{".index"} to each entry after sorting and before
%  formatting.  This is a 1-based index within the complete object that
%  can be used in styles that require numbering.  Although the
%  \code{"JSS"} style doesn't use numbers, it includes a
%  \code{fmtPrefix()} stub function that may be used to display them.
%  See the example below.
%}
%\value{
%  \code{bibstyle} returns the environment which has been selected or created.
%
%  \code{getBibstyle} returns the name of the default style, or all
%  style names.
%}
%\author{
%  Duncan Murdoch
%}
%\seealso{
%  \code{\link{bibentry}}
%}
%\examples{
%\testonly{options(useFancyQuotes = FALSE)}
%refs <-
%c(bibentry(bibtype = "manual",
%    title = "R: A Language and Environment for Statistical Computing",
%    author = person("R Core Team"),
%    organization = "R Foundation for Statistical Computing",
%    address = "Vienna, Austria",
%    year = 2013,
%    url = "https://www.R-project.org"),
%  bibentry(bibtype = "article",
%    author = c(person(c("George", "E.", "P."), "Box"),
%               person(c("David",  "R."),      "Cox")),
%    year = 1964,
%    title = "An Analysis of Transformations",
%    journal = "Journal of the Royal Statistical Society, Series B",
%    volume = 26,
%    pages = "211-252"))
%
%bibstyle("unsorted", sortKeys = function(refs) seq_along(refs),
%    fmtPrefix = function(paper) paste0("[", paper$.index, "]"),
%       .init = TRUE)
%print(refs, .bibstyle = "unsorted")
%}
%\keyword{ utilties }
%\keyword{ documentation }
%
%\encoding{UTF8}
%