% File src/library/tools/man/buildVignette.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{buildVignette}
%@%\alias{ビニエットを作る}
\alias{buildVignette}
\title{ビニエットを作る}
%\title{Build one vignette}
\description{
  一つのビニエットに対して \code{\link{Sweave}} (または他の weave 関数)
  \code{\link{texi2dvi}} そして/または \code{\link{Stangle}} 
  (または他のカスタム tangle 関数)を実行する．

  これは
  \command{R CMD Sweave} の実働関数である．
}
\usage{
buildVignette(file, dir = ".", weave = TRUE, latex = TRUE, tangle = TRUE, 
              quiet = TRUE, clean = TRUE, keep = character(),
              engine = NULL, buildPkg = NULL, encoding, ...)
}
\arguments{
  \item{file}{文字列；ビニエットのソースファイル}
  \item{dir}{文字列；中間ファイルと出力ファイルが作られる作業ディレクトリ}
  \item{weave}{論理値；weave を実行するか?}
  \item{latex}{論理値；weave が \file{.tex} ファイルを作ったならば
    \link{texi2pdf} を実行するか?}
  \item{tangle}{論理値；tangle を実行するか?}
  \item{quiet}{論理値；静音モードで実行するか?}
  \item{clean}{論理値；しばしば中間であるある種の新しく作られたファイルを
    取り除くかどうか．下の詳細節を見よ．}
  \item{keep}{掃除の際にいかなる場合も保存して置くファイル名のリスト．
    \dQuote{target} ファイルはいずれにせよ保存されることを注意する．}
  \item{engine}{\code{NULL} 又は文字列；使用するビニエットエンジンの名前．
    ビニエット中の任意の \code{\\VignetteEngine\{\}} マークアップに優先する．}
  \item{buildPkg}{\code{NULL} 又は文字列；
    その中でビニエットエンジンをみつけるオプションのパッケージ．}
  \item{encoding}{
    ファイルに対して仮定されたエンコーディング．
    もし指定されないとそれはファイルの中身から推測される．}
  \item{...}{weave と tangle に渡される追加引数．}

}
\details{
  この関数はビニエットに対するビニエットエンジンを決定し
  (既定は \code{utils::Sweave}), それからそのエンジンを使ってビニエットを
  weave したり(と) tangle を実行する．
  最後にもし \code{clean} が \code{TRUE} ならば，新しく作られた
  中間ファイル
  (エンジン等に依存する\dQuote{ターゲット}でなく，
  そして \code{keep} 中に有るどれでもなく)
  は削除される．
  もし \code{clean} が \code{NA} で \code{weave} が真なら，
  新しく作られた中間出力ファイル
  (例えば \file{.tex}) はたとえそれらから
  \file{.pdf} ファイルが既に作られていても消されない．

  もし \code{buildPkg} が指定されると，それはビニエットが処理される前に
  ロードされ，ビニエットエンジンの探索中に既定パッケージとして使われるが，
  ビニエットのソース中で明示的に指定されたパッケージ
  (例えば \pkg{utils} パッケージ中の \code{Sweave} エンジンを指定するのに
  \code{\\VignetteEngine\{utils::Sweave\}} を使う)はそれに優先する．
  反対にもし \code{engine} 引数が与えられると，
  それはビニエットソースに優先する．
}
\value{
  作られたファイルの名前である文字列ベクトル．
}
\author{
  Henrik Bengtsson と Duncan Murdoch
}
\seealso{
  パッケージ中の全てのビニエットを構築するには \code{\link{buildVignettes}}．
}
\keyword{documentation}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/buildVignette.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{buildVignette}
%\alias{buildVignette}
%\title{Build one vignette}
%\description{
%  Run \code{\link{Sweave}} (or other custom weave function)
%  \code{\link{texi2dvi}}, and/or \code{\link{Stangle}} 
%  (or other custom tangle function) on one vignette.
%
%  This is the workhorse of \command{R CMD Sweave}.
%}
%\usage{
%buildVignette(file, dir = ".", weave = TRUE, latex = TRUE, tangle = TRUE, 
%              quiet = TRUE, clean = TRUE, keep = character(),
%              engine = NULL, buildPkg = NULL, encoding, ...)
%}
%\arguments{
%  \item{file}{character; the vignette source file}
%  \item{dir}{character; the working directory in which the intermediate and 
%                 output files will be produced}
%  \item{weave}{logical; should weave be run?}
%  \item{latex}{logical; \link{texi2pdf} be run if weaving produces a \file{.tex} file?}
%  \item{tangle}{logical; should tangle be run?}
%  \item{quiet}{logical; run in quiet mode?}
%  \item{clean}{logical; whether to remove some newly created, often
%    intermediate, files.  See details below.}
%  \item{keep}{a list of file names to keep in any case when cleaning.  Note
%    that \dQuote{target} files are kept anyway.}
%  \item{engine}{\code{NULL} or character; name of vignette engine to
%    use.  Overrides any \code{\\VignetteEngine\{\}} markup in the vignette.}
%  \item{buildPkg}{\code{NULL} or character; an optional package in which to find
%    the vignette engine.}
%  \item{encoding}{the encoding to assume for the file.  If not specified, it will
%    be inferred from the file contents.}
%  \item{...}{Additional arguments passed to weave and tangle.}
%
%}
%\details{
%  This function determines the vignette engine for the vignette (default
%  \code{utils::Sweave}), then weaves and/or tangles the vignette using
%  that engine.  Finally, if \code{clean} is \code{TRUE}, newly created
%  intermediate files (non \dQuote{targets}, where these depend on the engine,
%  etc, and not any in \code{keep}) will be deleted.  If \code{clean} is
%  \code{NA}, and \code{weave} is true, newly created intermediate output
%  files (e.g., \file{.tex}) will not be deleted even if a \file{.pdf}
%  file has been produced from them.  
%
%  If \code{buildPkg} is specified, it will be loaded before the vignette
%  is processed, and will be used as the default package in the search
%  for a vignette engine, but an explicitly specified package in the
%  vignette source (e.g., using \code{\\VignetteEngine\{utils::Sweave\}}
%  to specify the \code{Sweave} engine in the \pkg{utils} package) will
%  override it.  In contrast, if the \code{engine} argument is given, it
%  will override the vignette source.
%}
%\value{
%  A character vector naming the files that have been produced.
%}
%\author{
%  Henrik Bengtsson and Duncan Murdoch
%}
%\seealso{
%  \code{\link{buildVignettes}} for building all vignettes in a package.
%}
%\keyword{documentation}
%
%\encoding{UTF8}
%