% File src/library/tools/man/checkFF.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{checkFF}
%@%\alias{外部言語関数呼び出しのチェック}
\alias{checkFF}
\alias{print.checkFF}
\title{外部言語関数呼び出しのチェック}
%\title{Check Foreign Function Calls}
\usage{
checkFF(package, dir, file, lib.loc = NULL,
        registration = FALSE, check_DUP = FALSE,
        verbose = getOption("verbose"))
}
\description{
  R こーどからのコンパイルコードへの呼び出しに関するチェックを行う．
  現在 \code{.C} と \code{.Fortran} の様なインタフェイス関数が
  最初の引数 \code{"\link{NativeSymbolInfo}"} 又は
  引数 \code{PACKAGE} が指定されて呼び出されているかどうかを
  チェックする．これは外部言語呼び出し中の名前の衝突を避けるため
  是非とも勧められる．
}
\arguments{
  \item{package}{インストールされたパッケージの名前を与える文字列．
    もし与えられると，パッケージのインストールされた R がチェックされる．}
  \item{dir}{パッケージのルートソースディレクトリへのパスを
    指定する文字列．
    これは副ディレクトリ \file{R} (R コード用)を含むべきである．
    \code{package} が与えられない時だけ使われる．}
  \item{file}{
    チェックされるべき R コードを含むファイル名．
    \code{package} も \code{dir} も与えられない時使われる．}
  \item{lib.loc}{
    \R ライブラリのディレクトリ名の文字列，又は \code{NULL}．
    既定値の \code{NULL} は現在知られている全てのライブラリに対応する．
    指定されたライブラリツリーは \code{package} を探すのに使われる．}
  \item{registration}{論理値．もし \code{TRUE} なら
    呼び出しに関する登録情報をチェックする
    (もし利用できれば)．}
  \item{check_DUP}{論理値．もし \code{TRUE} なら，
    \code{DUP = FALSE} である \code{.C} と
    \code{.Fortran} 呼び出しが報告される．}
  \item{verbose}{論理値．もし \code{TRUE} なら，追加の診断がプリントされる
    (そして結果は不可視で返される)．}
}
\details{
  \code{name} 引数がシンボルか文字列であることだけがチェックされ，
  シンボルが実行時にどんなオブジェクトのクラスに解決されるかはチェックされないことを
  注意する．

  もしパッケージがディレクティブ \code{useDynLib} を含む名前空間を持てば，
  パッケージ中のトップレベル関数中の呼び出しは報告されない．
  それらのシンボルは
  最初の \code{useDynLib} ディレクティブ 中で命名された DLL 中で
  優先的に探されるからである．

  これは指定された
  \code{PACKAGE} の呼び出しが同じパッケージに対するものであることを
  チェックし，そして
  基本パッケージ中に有るものと他のパッケージ中に有るものを
  個別に報告する
  (そしてもしこれらのパッケージが
  \file{DESCRIPTION} ファイル中で指定されていれば)．
}
\value{
  クラス \code{"checkFF"} のオブジェクト．

  そうしたオブジェクト中の情報を表示するメソッド
  \code{\link{format}} と \code{print} が有る．
}
\seealso{
  \code{\link{.C}},
  \code{\link{.Fortran}};
  \code{\link{Foreign}}.
}
\examples{\donttest{ # 順序はかなりランダム
checkFF(package = "stats", verbose = TRUE)
}}
\keyword{programming}
\keyword{utilities}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/checkFF.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{checkFF}
%\alias{checkFF}
%\alias{print.checkFF}
%\title{Check Foreign Function Calls}
%\usage{
%checkFF(package, dir, file, lib.loc = NULL,
%        registration = FALSE, check_DUP = FALSE,
%        verbose = getOption("verbose"))
%}
%\description{
%  Performs checks on calls to compiled code from R code.  Currently only
%  checks whether the interface functions such as \code{.C} and
%  \code{.Fortran} are called with a \code{"\link{NativeSymbolInfo}"}
%  first argument or with argument \code{PACKAGE} specified, which is
%  highly recommended to avoid name clashes in foreign function calls.
%}
%\arguments{
%  \item{package}{a character string naming an installed package.  If
%    given, the installed R code of the package is checked.}
%  \item{dir}{a character string specifying the path to a package's root
%    source directory.  This should contain the subdirectory \file{R}
%    (for R code).  Only used if \code{package} is not given.}
%  \item{file}{the name of a file containing R code to be checked.  Used
%    if neither \code{package} nor \code{dir} are given.}
%  \item{lib.loc}{a character vector of directory names of \R libraries,
%    or \code{NULL}.  The default value of \code{NULL} corresponds to all
%    libraries currently known.  The specified library trees are used to
%    search for \code{package}.}
%  \item{registration}{a logical.  If \code{TRUE}, checks
%    the registration information on the call (if available).}
%  \item{check_DUP}{a logical.  If \code{TRUE}, \code{.C} and
%    \code{.Fortran} calls with \code{DUP = FALSE} are reported.}
%  \item{verbose}{a logical.  If \code{TRUE}, additional diagnostics are
%    printed (and the result is returned invisibly).}
%}
%\details{
%  Note that we can only check if the \code{name} argument is a symbol or
%  a character string, not what class of object the symbol resolves to
%  at run-time.
%
%  If the package has a namespace which contains a \code{useDynLib}
%  directive, calls in top-level functions in the package are not
%  reported as their symbols will be preferentially looked up in the DLL
%  named in the first \code{useDynLib} directive.
%
%  This checks that calls with \code{PACKAGE} specified are to the
%  same package, and reports separately those which are in base packages
%  and those which are in other packages (and if those packages are
%  specified in the \file{DESCRIPTION} file).
%}
%\value{
%  An object of class \code{"checkFF"}.
%
%  There are \code{\link{format}} and \code{print} methods to display the
%  information contained in such objects.
%}
%\seealso{
%  \code{\link{.C}},
%  \code{\link{.Fortran}};
%  \code{\link{Foreign}}.
%}
%\examples{\donttest{ # order is pretty much random
%checkFF(package = "stats", verbose = TRUE)
%}}
%\keyword{programming}
%\keyword{utilities}
%
%\encoding{UTF8}
%