% File src/library/tools/man/checkRdaFiles.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2009-11 R Core Team
% Distributed under GPL 2 or later

\name{checkRdaFiles}
%@%\alias{保存イメージの詳細報告}
\alias{checkRdaFiles}
\alias{resaveRdaFiles}
\title{保存イメージの詳細の報告またはそれらの再セーブ}
%\title{Report on Details of Saved Images or Re-saves them}
\description{
  これは \code{save} により生成されたファイルの各々に対して，
  そのサイズ，
  ASCII か XDR バイナリ書式でセーブされたか，そして
  圧縮されているか
  (そしてもしそうならどのような形式でか)を報告する．

  普通そうしたファイルは拡張子 \file{.rda} や \file{.RData} を持つことに
  関数の名前が由来する．
}
\usage{
checkRdaFiles(paths)
resaveRdaFiles(paths, compress = c("auto", "gzip", "bzip2", "xz"),
               compression_level)
}

\arguments{
  \item{paths}{
    \code{save} ファイルへのパスの文字列ベクトル．
    もしこれが単一のディレクトリを指定すれば，
    それはそのディレクトリ中の全ての
    \file{.rda} そして \file{.RData} ファイルを参照する．}

  \item{compress, compression_level}{圧縮のタイプとレベル：
    \code{\link{save}} を見よ．\code{compress} の値は短縮出来る．}
}

\details{
  \code{compress = "auto"} は \R に圧縮法を選ぶように問い合わせ，
  \code{compression_level} を無視する．これは \code{"gzip"}, \code{"bzip2"}
  そして，もし \code{"gzip"} 圧縮サイズが10Kbを超えれば \code{"xz"} で，
  最少の圧縮サイズファイルを選択する
  (しかし \code{"gzip"} に 10\% のバイアス)．これは遅いかもしれない．
}

\value{
  \code{checkRdaFiles} に対しては，
  行名 \code{paths} を持つデータフレームで，列は
  \item{size}{数値：バイト単位のファイルサイズ，もしファイルが存在しなければ \code{NA}．}
  \item{ASCII}{論理値：save(ASCII = TRUE) に対しては真で，もし
    書式が \R のセーブファイルでなければ \code{NA}．}
  \item{compress}{文字列：圧縮のタイプ．
    \code{"gzip"}, \code{"bzip2"}, \code{"xz"}, \code{"none"} 又は \code{"unknown"}
    (これはもしそれが \R のセーブファイルなら \R の最近のバージョン由来であることを
    意味する)のどれか．}
  \item{version}{整数：保存のバージョン -- 普通 \code{2} であるが
    非常に古いファイルに対しては \code{1} で，他のファイルに対しては
    \code{NA}．}
}
\examples{\dontrun{
## パッケージのトップレベルのソースディレクトリから
paths <- sort(Sys.glob(c("data/*.rda", "data/*.RData")))
(res <- checkRdaFiles(paths))
## より注意が必要な幾つかをピックアップ
bad <- is.na(res$ASCII) | res$ASCII | (res$size > 1e4 & res$compress == "none")
res[bad, ]
}}
\keyword{ utilities }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/checkRdaFiles.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2009-11 R Core Team
%% Distributed under GPL 2 or later
%
%\name{checkRdaFiles}
%\alias{checkRdaFiles}
%\alias{resaveRdaFiles}
%\title{
%  Report on Details of Saved Images or Re-saves them
%}
%\description{
%  This reports for each of the files produced by \code{save} the size,
%  if it was saved in ASCII or XDR binary format, and if it was
%  compressed (and if so in what format).
%
%  Usually such files have extension \file{.rda} or \file{.RData}, hence
%  the name of the function.
%}
%\usage{
%checkRdaFiles(paths)
%resaveRdaFiles(paths, compress = c("auto", "gzip", "bzip2", "xz"),
%               compression_level)
%}
%
%\arguments{
%  \item{paths}{A character vector of paths to \code{save} files.  If
%    this specifies a single directory, it is taken to refer to all
%    \file{.rda} and \file{.RData} files in that directory.}
%
%  \item{compress, compression_level}{type and level of compression: see
%    \code{\link{save}}.  Values of \code{compress} can be abbreviated.}
%}
%
%\details{
%  \code{compress = "auto"} asks \R to choose the compression and ignores
%  \code{compression_level}.  It will try \code{"gzip"}, \code{"bzip2"}
%  and if the \code{"gzip"} compressed size is over 10Kb, \code{"xz"} and
%  choose the smallest compressed file (but with a 10\% bias towards
%  \code{"gzip"}).  This can be slow.
%}
%
%\value{
%  For \code{checkRdaFiles}, a data frame with rows names \code{paths}
%  and columns
%  \item{size}{numeric: file size in bytes, \code{NA} if the file does
%    not exist.}
%  \item{ASCII}{logical: true for save(ASCII = TRUE), \code{NA} if the
%    format is not that of an \R save file.}
%  \item{compress}{character: type of compression.  One of \code{"gzip"},
%    \code{"bzip2"}, \code{"xz"}, \code{"none"} or \code{"unknown"} (which
%    means that if this is an \R save file it is from a later version of
%    \R).}
%  \item{version}{integer: the version of the save -- usually \code{2}
%    but \code{1} for very old files, and \code{NA} for other files.}
%}
%\examples{\dontrun{
%## from a package top-level source directory
%paths <- sort(Sys.glob(c("data/*.rda", "data/*.RData")))
%(res <- checkRdaFiles(paths))
%## pick out some that may need attention
%bad <- is.na(res$ASCII) | res$ASCII | (res$size > 1e4 & res$compress == "none")
%res[bad, ]
%}}
%\keyword{ utilities }
%
%\encoding{UTF8}
%