% File src/library/tools/man/find_gs_cmd.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2008-2014 R Core Team
% Distributed under GPL 2 or later

\name{find_gs_cmd}
%@%\alias{GhostScript の実行ファイル}
\alias{find_gs_cmd}
\alias{R_GSCMD}
\alias{GSC}

%\title{Find a GhostScript Executable}
\title{GhostScript の実行ファイルを見つける}
\description{
  GhostScript の実行ファイルをプラットホームを跨ぐような仕方で見つける．
}
\usage{
find_gs_cmd(gs_cmd = "")
}
\arguments{
  \item{gs_cmd}{名前，GhostScript 実行ファイルの完全か部分的なパス．}
}
\details{
  詳細はプラットホームにより異なる．

  Unix 風システムでは GhostScript の実行ファイルは普通
  \command{gs} と呼ばれる．命令の名前(そしてもしかするとパス)
  は先ず \code{gs_cmd} から，そして環境変数
  \env{R_GSCMD} から取られ，既定値は \code{gs} である．
  これはそれからシステムパス上で探され，そして
  もしマッチするものが見つかれば返される．

  Windows では，命令の名前は引数
  \code{gs_cmd} そしてそれから環境変数
  \env{R_GSCMD} と \env{GSC} から取られる．
  もしこれらのどれも適当な命令名を与えなければ，
  \command{gswin64c} と \command{gswin32c} が順番に試みられる．
  全ての場合で命令はシステム \env{PATH} 上で探される．

  Windows (そしてある種の他の OS)上では
  Postscript/PDF ファイルを表示するのと
  それらを操作するものという別個の GhostScript 実行ファイルが存在することを注意する：
  この関数は後者を探す．
}
\value{
  もし見つかれば
  GhostScript 実行ファイルへの完全なパスを与える文字列で，
  さもなければ空の文字列．
}
\examples{\dontrun{
## Solaris システムがパス上に GhostScript 9.00 を持ち
## /opt/csw/bin に 9.07 を持つと仮定する．
## すると次のように設定できるかもしれない
Sys.setenv(R_GSCMD = "/opt/csw/bin/gs")
}}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/find_gs_cmd.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2008-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{find_gs_cmd}
%\alias{find_gs_cmd}
%
%\alias{R_GSCMD}
%\alias{GSC}
%
%\title{
%  Find a GhostScript Executable
%}
%\description{
%  Find a GhostScript executable in a cross-platform way.
%}
%\usage{
%find_gs_cmd(gs_cmd = "")
%}
%\arguments{
%  \item{gs_cmd}{The name, full or partial path of a GhostScript executable.}
%}
%\details{
%  The details differ by platform.
%
%  On a Unix-alike, the GhostScript executable is usually called
%  \command{gs}.  The name (and possibly path) of the command is taken
%  first from argument \code{gs_cmd} then from the environment variable
%  \env{R_GSCMD} and default \code{gs}.  This is then looked for on the
%  system path and the value returned if a match is found.
%
%  On Windows, the name of the command is taken from argument
%  \code{gs_cmd} then from the environment variables \env{R_GSCMD} and
%  \env{GSC}.  If neither of those produces a suitable command name,
%  \command{gswin64c} and \command{gswin32c} are tried in turn.  In all
%  cases the command is looked for on the system \env{PATH}.
%
%  Note that on Windows (and some other OSes) there are separate
%  GhostScript executables to display Postscript/PDF files and to
%  manipulate them: this function looks for the latter.  
%}
%\value{
%  A character string giving the full path to a GhostScript executable if
%  one was found, otherwise an empty string.
%}
%\examples{\dontrun{
%## Suppose a Solaris system has GhostScript 9.00 on the path and
%## 9.07 in /opt/csw/bin.  Then one might set
%Sys.setenv(R_GSCMD = "/opt/csw/bin/gs")
%}}
%
%\encoding{UTF8}
%