% File src/library/tools/man/md5sum.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{md5sum}
%@%\alias{MD5 チェックサム}
\alias{md5sum}
%\title{Compute MD5 Checksums}
\title{MD5 チェックサムを計算する}
\description{
  一つまたはそれ以上のファイルの 32 バイトの MD5 ハッシュを計算する．
}
\usage{
md5sum(files)
}
\arguments{
  \item{files}{文字列．その内容がハッシュされるファイルへのパス．}
}
\details{
  MD5 \sQuote{ハッシュ} または\sQuote{チェックサム}または\sQuote{メッセージダイジェスト}
  は32個の16進数で表現されるファイル内容の
  128 ビット要約である．
  異なった MD5 サムのファイルは異なる：非常に稀に
  (そして普通誤解させる意図で)
  異なったファイルが同じサムを持つことがある．

  Windows では全てのファイルはバイナリモードで読み取られる
  (そこでの \code{md5sum} ユーティリティがそうする)：
  他の OS ではファイルは既定のモードで読み取られる
  (もしひとつ以上のテキストがあればテキストモードで)．

  MD5 サムは
  \R パッケージが正しく展開されその後に修正されていないかをチェックするために
  使われる．
}
\value{
  \code{files} と同じ長さの文字列ベクトルで，名前は
  \code{files} に等しい．要素は存在しないファイルや読み取れないファイルに対しては
  \code{NA} で，さもなければ16進の 32 文字の文字列．
}
\source{
  基礎にある C コードは Ulrich Drepper により書かれ
  \code{glibc} の2001年のリリースから取られた．
}
\seealso{
  \code{\link{checkMD5sums}}
}
\examples{
as.vector(md5sum(dir(R.home(), pattern = "^COPY", full.names = TRUE)))
}
\keyword{utilities}


\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/md5sum.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{md5sum}
%\alias{md5sum}
%\title{Compute MD5 Checksums}
%\description{
%  Compute the 32-byte MD5 hashes of one or more files.
%}
%\usage{
%md5sum(files)
%}
%\arguments{
%  \item{files}{character. The paths of file(s) whose contents are to be hashed.}
%}
%\details{
%  A MD5 \sQuote{hash} or \sQuote{checksum} or \sQuote{message digest} is
%  a 128-bit summary of the file contents represented by 32 hexadecimal
%  digits.  Files with different MD5 sums are different: only very
%  exceptionally (and usually with the intent to deceive) are those with
%  the same sums different.
%
%  On Windows all files are read in binary mode (as the \code{md5sum}
%  utilities there do): on other OSes the files are read in the default
%  mode (almost always text mode where there is more than one).
%
%  MD5 sums are used as a check that \R packages have been unpacked
%  correctly and not subsequently modified.
%}
%\value{
%  A character vector of the same length as \code{files}, with names
%  equal to \code{files}.  The elements will be \code{NA} for non-existent
%  or unreadable files, otherwise a 32-character string of hexadecimal
%  digits.
%}
%\source{
%  The underlying C code was written by Ulrich Drepper and extracted from
%  a 2001 release of \code{glibc}.
%}
%\seealso{
%  \code{\link{checkMD5sums}}
%}
%\examples{
%as.vector(md5sum(dir(R.home(), pattern = "^COPY", full.names = TRUE)))
%}
%\keyword{utilities}
%
%
%\encoding{UTF8}
%