% File src/library/tools/man/package_dependencies.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2012-2015 R Core Team
% Distributed under GPL 2 or later

\name{package_dependencies}
%@%\alias{パッケージの従属性の階層}
\alias{package_dependencies}
%\title{Computations on the Dependency Hierarchy of Packages}
\title{パッケージの従属性の階層を計算}
\description{
   パッケージの(再帰的)従属性や逆向き従属性を見つける．
}
\usage{
package_dependencies(packages = NULL, db = NULL,
        which = c("Depends", "Imports", "LinkingTo"),
	recursive = FALSE, reverse = FALSE, verbose = getOption("verbose"))
}
\arguments{
  \item{packages}{パッケージ名の文字列ベクトル．}
  \item{db}{
    \code{\link{available.packages}()} からのような
    文字列ベクトル(既定の \code{NULL} ではこの呼び出しの結果)
    またはそれのデータフレーム版．
    もしくは
    \url{https://cran.r-project.org/web/packages/packages.rds}
    から得られるようなものに似たパッケージのデータベース．
  }
  \item{which}{
    従属性のタイプをリストする文字列ベクトルで，\cr
    \code{c("Depends", "Imports", "LinkingTo", "Suggests", "Enhances")}
    のサブセット．文字列 \code{"all"} はこのベクトルの省略形であり，
    文字列 \code{"most"} は
    \code{"Enhances"} を除いた同じベクトルである．
  }
  \item{recursive}{論理値：
    (逆向き)従属性の(逆向き)従属性(等々)を含めるべきか?}
  \item{reverse}{論理値：もし \code{FALSE} ならば(既定)，通常の従属性が
    ，さもなければ逆向き従属性が計算される．}
  \item{verbose}{出力がパッケージの探索サイクルをモニターすべきかどうかを
    指示する論理値．}
}
\value{
  引数 \code{packages} 中の各パッケージに対して一つの要素を持つ
  名前付きリストで，各々はパッケージの
  (再帰的) (逆向き)従属性を命名する文字列ベクトルからなる．

  データベースに見つからない与えられたパッケージに対しては
  項目 \code{NULL} が返され，
  従属性がなければ項目 \code{character(0)} が返される．
}
\seealso{
  \code{\link{dependsOnPkgs}} そして従属性のチェックには
  \code{\link{package.dependencies}}．
}
\examples{
\dontrun{
pdb <- available.packages()
deps <- package_dependencies(packages = "MASS", pdb,
                    which = c("Depends", "Imports", "LinkingTo", "Suggests"),
                    recursive = TRUE, reverse = TRUE)
length(deps$MASS)
}
}
\keyword{utilities}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/package_dependencies.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2012-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{package_dependencies}
%\alias{package_dependencies}
%\title{Computations on the Dependency Hierarchy of Packages}
%\description{
%   Find (recursively) dependencies or reverse dependencies of packages.
%}
%\usage{
%package_dependencies(packages = NULL, db = NULL,
%        which = c("Depends", "Imports", "LinkingTo"),
%	recursive = FALSE, reverse = FALSE, verbose = getOption("verbose"))
%}
%\arguments{
%  \item{packages}{a character vector of package names.}
%  \item{db}{character matrix as from \code{\link{available.packages}()}
%    (with the default \code{NULL} the results of this call)
%    or data frame variants thereof.  Alternatively, a package database
%    like the one available from
%    \url{https://cran.r-project.org/web/packages/packages.rds}.
%  }
%  \item{which}{a character vector listing the types of
%    dependencies, a subset of
%    \code{c("Depends", "Imports", "LinkingTo", "Suggests", "Enhances")}.
%    Character string \code{"all"} is shorthand for that vector,
%    character string \code{"most"} for the same vector without
%    \code{"Enhances"}.
%  }
%  \item{recursive}{logical: should (reverse) dependencies of (reverse)
%    dependencies (and so on) be included?}
%  \item{reverse}{logical: if \code{FALSE} (default), regular
%    dependencies are calculated, otherwise reverse dependencies.}
%  \item{verbose}{logical indicating if output should monitor the package
%    search cycles.}
%}
%\value{
%  Named list with one element for each package in argument \code{packages},
%  each consists of a character vector naming the (recursive) (reverse) dependencies
%  of that package.
%
%  For given packages which are not found in the db, \code{NULL} entries are returned,
%  as opposed to \code{character(0)} entries which indicate no dependencies.
%}
%\seealso{
%  \code{\link{dependsOnPkgs}}, and \code{\link{package.dependencies}} for checking
%  dependencies.
%}
%\examples{
%\dontrun{
%pdb <- available.packages()
%deps <- package_dependencies(packages = "MASS", pdb,
%                    which = c("Depends", "Imports", "LinkingTo", "Suggests"),
%                    recursive = TRUE, reverse = TRUE)
%length(deps$MASS)
%}
%}
%\keyword{utilities}
%
%\encoding{UTF8}
%