% File src/library/tools/man/pskill.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2011 R Core Team
% Distributed under GPL 2 or later

\name{pskill}
%@%\alias{プロセスの停止}
\alias{pskill}

\alias{SIGHUP}
\alias{SIGINT}
\alias{SIGQUIT}
\alias{SIGKILL}
\alias{SIGTERM}
\alias{SIGSTOP}
\alias{SIGTSTP}
\alias{SIGCONT}
\alias{SIGCHLD}
\alias{SIGUSR1}
\alias{SIGUSR2}

\title{プロセスを停止する}
%\title{Kill a Process}
\description{
  \code{pskill} はプロセスにシグナルを送り，普通それを停止する．
}
\usage{
pskill(pid, signal = SIGTERM)

SIGHUP
SIGINT
SIGQUIT
SIGKILL
SIGTERM
SIGSTOP
SIGTSTP
SIGCHLD
SIGUSR1
SIGUSR2
}
\arguments{
  \item{pid}{整数：
    \code{\link{Sys.getpid}} が返すような一つまたはそれ以上の
    プロセス ID．}
  \item{signal}{整数，最もしばしばシンボリックな定数の一つ．}
}
\details{
  シグナルは C99 の概念であるが，僅かな数のサポートだけが要求されている
  (リストされたものの内 \code{SIGINT} と \code{SIGTERM} だけ)．
  これらは POSIX オペレーティングシステムではより幅広く使われ
  (ここでリストされた全てが定義される必要がある)，
  またプロセスにシグナルを送る
  \code{kill} システムコールもサポートしており，最もしばしば
  それを停止する．関数 \code{pskill} はラッパを提供する：
  これはゼロや負の pid を含むその引数の不正な値を黙って無視する．

  Unix 風システムでの普通の用法では，\kbd{Ctrl-C} は \code{SIGINT}，
  \kbd{Ctrl-\\} は \code{SIGQUIT} そして \kbd{Ctrl-Z} は
  \code{SIGTSTP} を送る：これと \code{SIGSTOP} は
  プロセスを一時停止し \code{SIGCONT} で再開できる.

  シグナルは小さな整数であるが，実際の数値は標準化されていない
  (そして多くが OS 間で異なる)．\code{SIG*} オブジェクトは
  現在のプラットホームに対して適当な整数値を含む
  (またはシグナルが定義されていない時は \code{NA_INTEGER_})．

  Windows では \code{SIGINT} と \code{SIGKILL} だけが定義されており，
  \code{pskill} は常に Windows のシステムコール
  \code{TerminateProcess} を使う．
}
\value{
  \code{pid}, \code{TRUE} (成功に対して)または \code{FALSE} と
  同じ長さの論理値ベクトルで不可視．
}
\seealso{
  パッケージ \pkg{parallel} は子プロセスを起動する幾つかの手段を
  持ち，プロセス ID を記録する．

  \code{\link{psnice}}
}

\examples{\dontrun{
pskill(c(237, 245), SIGKILL)
}}
\keyword{utilities}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/pskill.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{pskill}
%\alias{pskill}
%
%\alias{SIGHUP}
%\alias{SIGINT}
%\alias{SIGQUIT}
%\alias{SIGKILL}
%\alias{SIGTERM}
%\alias{SIGSTOP}
%\alias{SIGTSTP}
%\alias{SIGCONT}
%\alias{SIGCHLD}
%\alias{SIGUSR1}
%\alias{SIGUSR2}
%
%\title{Kill a Process}
%\description{
%  \code{pskill} sends a signal to a process, usually to terminate it.
%}
%\usage{
%pskill(pid, signal = SIGTERM)
%
%SIGHUP
%SIGINT
%SIGQUIT
%SIGKILL
%SIGTERM
%SIGSTOP
%SIGTSTP
%SIGCHLD
%SIGUSR1
%SIGUSR2
%}
%\arguments{
%  \item{pid}{positive integers: one or more process IDs as returned by
%    \code{\link{Sys.getpid}}.}
%  \item{signal}{integer, most often one of the symbolic constants.}
%}
%\details{
%  Signals are a C99 concept, but only a small number are required to be
%  supported (of those listed, only \code{SIGINT} and \code{SIGTERM}).
%  They are much more widely used on POSIX operating systems (which
%  should define all of those listed here), which also support a
%  \code{kill} system call to send a signal to a process, most often to
%  terminate it.  Function \code{pskill} provides a wrapper: it silently
%  ignores invalid values of its arguments, including zero or negative pids.
%
%  In normal use on a Unix-alike, \kbd{Ctrl-C} sends \code{SIGINT},
%  \kbd{Ctrl-\\} sends \code{SIGQUIT} and \kbd{Ctrl-Z} sends
%  \code{SIGTSTP}: that and \code{SIGSTOP} suspend a process which can be
%  resumed by \code{SIGCONT}.
%
%  The signals are small integers, but the actual numeric values are not
%  standardized (and most do differ between OSes).  The \code{SIG*}
%  objects contain the appropriate integer values for the current platform
%  (or \code{NA_INTEGER_} if the signal is not defined).
%
%  Only \code{SIGINT} and \code{SIGKILL} will be defined on Windows, and
%  \code{pskill} will always use the Windows system call
%  \code{TerminateProcess}.
%}
%\value{
%  A logical vector of the same length as \code{pid},
%  \code{TRUE} (for success) or \code{FALSE}, invisibly.
%}
%\seealso{
%  Package \pkg{parallel} has several means to launch child processes
%  which record the process IDs.
%
%  \code{\link{psnice}}
%}
%
%\examples{\dontrun{
%pskill(c(237, 245), SIGKILL)
%}}
%\keyword{utilities}
%
%\encoding{UTF8}
%