% File src/library/tools/man/undoc.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{undoc}
%@%\alias{未ドキュメント化オブジェクト}
\alias{undoc}
\alias{print.undoc}
\title{ドキュメント化されていないオブジェクトを見つける}
%\title{Find Undocumented Objects}
\usage{
undoc(package, dir, lib.loc = NULL)
}
\description{
  ユーザに見えるが(またはパッケージが提供するデータオブジェクトか
  S4 クラス)がドキュメント項目が存在しないという意味で
  ドキュメント化されていないパッケージ中の
  オブジェクト見つける．
}
\arguments{
  \item{package}{インストール済みパッケージの名前の文字列ベクトル．}
  \item{dir}{パッケージのルートソースディレクトリへのパスを指定する
    文字列．
    これは \R のドキュメントのソース(Rd 書式の)副ディレクトリ \file{man}
    と \R コードまたはデータをそれぞれ含む
    \file{R} か \file{data} 副ディレクトリの少なくとも一つを
    含む必要がある．}
  \item{lib.loc}{
    \R ライブラリのディレクトリ名の文字列ベクトルか
    \code{NULL}．
    既定値の \code{NULL} は現在知られている全てのライブラリに
    対応する．指定されたライブラリツリーは
    \code{package} を探すのに使われる．}
}
\details{
  この関数はパッケージの管理者に最も有用である．
  原則として
  \emph{全て}のユーザレベルの \R オブジェクトはドキュメント化されるべきである．

  \pkg{base} パッケージは特別で，プリミティブなオブジェクトを含みそして
  これらはコードレベルで利用できる定義を持たない．
  様々な目的のために使われる \pkg{base} パッケージ中の
  環境 \code{.ArgsEnv} と \code{.GenericArgsEnv} 中に同値な
  クロージャを提供している：
  \code{undoc("base")} は言語構成子ではない
  全てのプリミティブがこれらの環境中にあり他のものは無い
  ことをチェクする．
}
\value{
  クラス \code{"undoc"} のオブジェクトで，ドキュメントのタイプで
  分割されたドキュメント化されていないオブジェクトの名前を含む
  文字列ベクトルのりスト．

  そうしたオブジェクトに含まれる情報を見栄え良く表示する
  \code{print} メソッドがある．
}
\seealso{
  \code{\link{codoc}}, \code{\link{QC}}
}
\examples{
undoc("tools")                  # 'tools' 中のドキュメント化されていないオブジェクト
}
\keyword{documentation}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/undoc.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{undoc}
%\alias{undoc}
%\alias{print.undoc}
%\title{Find Undocumented Objects}
%\usage{
%undoc(package, dir, lib.loc = NULL)
%}
%\description{
%  Finds the objects in a package which are undocumented, in the sense
%  that they are visible to the user (or data objects or S4 classes
%  provided by the package), but no documentation entry exists.
%}
%\arguments{
%  \item{package}{a character string naming an installed package.}
%  \item{dir}{a character string specifying the path to a package's root
%    source directory.  This must contain the subdirectory \file{man}
%    with \R documentation sources (in Rd format), and at least one of
%    the \file{R} or \file{data} subdirectories with \R code or data
%    objects, respectively.}
%  \item{lib.loc}{a character vector of directory names of \R libraries,
%    or \code{NULL}.  The default value of \code{NULL} corresponds to all
%    libraries currently known.  The specified library trees are used to
%    search for \code{package}.}
%}
%\details{
%  This function is useful for package maintainers mostly.  In principle,
%  \emph{all} user-level \R objects should be documented.
%
%  The \pkg{base} package is special as it contains the primitives and
%  these do not have definitions available at code level.  We provide
%  equivalent closures in environments \code{.ArgsEnv} and
%  \code{.GenericArgsEnv} in the \pkg{base} package that are used
%  for various purposes: \code{undoc("base")} checks that all the
%  primitives that are not language constructs are prototyped in those
%  environments and no others are.
%}
%\value{
%  An object of class \code{"undoc"} which is a list of character vectors
%  containing the names of the undocumented objects split according to
%  documentation type.
%
%  There is a \code{print} method for nicely displaying the information
%  contained in such objects.
%}
%\seealso{
%  \code{\link{codoc}}, \code{\link{QC}}
%}
%\examples{
%undoc("tools")                  # Undocumented objects in 'tools'
%}
%\keyword{documentation}
%
%\encoding{UTF8}
%